@@ -32,46 +32,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class iAnimator;
 class iAnimatorScript;
-class iControlModule;
-class iDataReader;
-class iExtendableObject;
-class iObject;
-class iObjectType;
-class iPicker;
 class iRenderTool;
-class iString;
 class iViewModule;
-class iViewObject;
-class iViewObjectParent;
 
 
 class iExtensionFactory
 {
 	
-	friend class iAnimatorScript;
-	friend class iControlModule;
-	friend class iDataExplorer;
-	friend class iDataReader;
-	friend class iExtendableObject;
-	friend class iParticlesViewSubject;
-	friend class iPicker;
-	friend class iRenderTool;
-	friend class iViewModule;
-	friend class iViewObject;
-
-protected:
+public:
 		
 	static iAnimatorScript*		CreateAnimatorScript(iAnimator *animator);
 	static iRenderTool*			CreateRenderTool(iViewModule *vm);
-	static iViewObject*			CreateViewObject(iViewObjectParent *parent);
-
-	//
-	//  Extensions for extendable objects
-	//
-	static void					InstallExtensions(iControlModule *cm);
-	static void					InstallExtensions(iDataReader *dr);
-	static void					InstallExtensions(iPicker *picker);
-	static void					InstallExtensions(iViewModule *vm);
 };
 
 #endif // IEXTENSIONFACTORY_H
