@@ -33,11 +33,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  IFrIT version
 //
-#define IVERSION_BASE			"3.0.5"
+#define IVERSION_BASE			"3.1.5"
 
-#define IVERSION_EXT_HART		"2.0.5"
-#define IVERSION_EXT_MV			"1.0.0"
-#define IVERSION_EXT_GADGET		"1.0.0"
+#define IVERSION_EXT_HART		"2.1.5"
+#define IVERSION_EXT_MV			"1.0.4"
+#define IVERSION_EXT_VTK		"1.0.0b1"
+#define IVERSION_EXT_GADGET		"1.0.0b2"
 
 //
 //  History
@@ -57,16 +58,49 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //  060930  Base-3.0.3    HART-2.0.3    MV-1.0.0    -- Need to re-release, created a branch in CVS too early by mistake
 //  061003  Base-3.0.4    HART-2.0.4    MV-1.0.0    -- Added special brightness palette, fixed iArray out-of-boundary bug, fixed DataExplorer bug
 //  061010  Base-3.0.5    HART-2.0.5    MV-1.0.0    -- fixed Interactor bug, HART isosurface bugs(?), more iArray out-of-boundary bugs
+//  061119  Base-3.0.6    HART-2.0.6    MV-1.0.0    -- fixed DataLimits+clones bug, RulerDialog bug, parallel stitch bug, added window list idalog, x-section placement enhancements
+//  061120  Base-3.0.7    HART-2.0.7    MV-1.0.0    -- work around vtkMarchingContourFilter multi-threaded bug.
+//  061221  Base-3.0.8    HART-2.0.8    MV-1.0.1    -- internal changes, pseudo-color composing in ImageComposer, minor GUI modifications, bug fixes.
+//  070203  Base-3.0.9    HART-2.0.9    MV-1.0.1    -- internal changes to particle masking, new masking modes, bug fixes
+//
+//  070325  Base-3.1.0    HART-2.1.0    MV-1.0.2    VTK-1.0.0b0     GADGET-1.0.0b0 
+//          split DataSubject into DataSubject proper and DataFileLoader
+//          added VTK & GADGET extensions
+//          fixed MultiView full-screen mode bugs
+//
+//  070422  Base-3.1.1    HART-2.1.2    MV-1.0.2    VTK-1.0.0b0     GADGET-1.0.0b1
+//          fixed marker Create/Delete panel bug
+//          other stylistic bug fixes
+//          redone volume rendering interface
+//          HART 2D & 3D texture volume rendering by uniform resampling
+//
+//  070502  Base-3.1.2    HART-2.1.3    MV-1.0.3    VTK-1.0.0b0     GADGET-1.0.0b2
+//			C-style casting replaced whereever possible
+//			ViewModule::LabelOffset property added
+//			Fixed bugs in iDataExplorer
+//			Fixed bugs in recognizing animatable filename without a suffix
+//
+//  070508  Base-3.1.3    HART-2.1.3    MV-1.0.3    VTK-1.0.0b0     GADGET-1.0.0b2
+//			Fixed bugs with saving markers and animation not stopping on error
+//			New markers are placed in the camera focal point
+//
+//  070527  Base-3.1.4    HART-2.1.4    MV-1.0.4    VTK-1.0.0b1     GADGET-1.0.0b2
+//			Added external image as a background
+//			Fixed batch mode and channeling output
+//			Fixed shifting
+//
+//  070618  Base-3.1.5    HART-2.1.5    MV-1.0.4    VTK-1.0.0b1     GADGET-1.0.0b2
+//			Added zooms in Composer
+//			Fixed particle picking
+//			Added particle auto-scaling
+//			Fixed offscreen mode with Mesa libraries
 //
 
 //
 //  ToDo (major additions)
 //
-//  1. HART 2D & 3D texture volume rendering by uniform resampling
-//  2. Point sprats for particles
-//  3. Gadget extension
-//  4. VTK native format extension
-//  5. Coloring by brightness for particles and, perhaps, other objects (a special palette?) - DONE in 3.0.4
+//  1. Point sprats for particles
+//  2. Multiple images in Composer
 //
 
 #if ISHELL_INCLUDED(ISHELL_QT)
@@ -90,7 +124,10 @@ const iString iVersion::GetIncludedExtensions()
 	tmp += iString("MultiView extension v") + IVERSION_EXT_MV +";";
 #endif
 #if IEXTENSION_INCLUDED(IEXTENSION_GADGET)
-	tmp += iString("Gadget extension v") + IVERSION_EXT_GADGET +";";
+	tmp += iString("GADGET extension v") + IVERSION_EXT_GADGET +";";
+#endif
+#if IEXTENSION_INCLUDED(IEXTENSION_VTK)
+	tmp += iString("Native-VTK extension v") + IVERSION_EXT_VTK +";";
 #endif
 	return tmp;
 }
