@@ -32,14 +32,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ianimator.h"
 
 #include "ianimatorscript.h"
+#include "icommoneventobservers.h"
 #include "icontrolmodule.h"
 #include "icrosssectionviewsubject.h"
 #include "idatareader.h"
+#include "idirectory.h"
 #include "ierror.h"
 #include "ierrorstatus.h"
-#include "ieventobserver.h"
+#include "ifile.h"
 #include "iimagecomposer.h"
 #include "imath.h"
+#include "ishell.h"
 #include "ishellfactory.h"
 #include "isystem.h"
 #include "iviewmodule.h"
@@ -48,7 +51,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iwriter.h"
 
 #include <vtkCamera.h>
-#include <vtkCommand.h>
 #include <vtkMath.h>
 #include <vtkImageBlend.h>
 #include <vtkPolyData.h>
@@ -96,6 +98,7 @@ IOBJECT_DEFINE_KEY(iAnimator,FocalPathY,fpy,Float,0);
 IOBJECT_DEFINE_KEY(iAnimator,FocalPathZ,fpz,Float,0);
 IOBJECT_DEFINE_KEY(iAnimator,FlybySpeed,fs,Float,1);
 IOBJECT_DEFINE_KEY(iAnimator,InheritSettings,is,Bool,1);
+IOBJECT_DEFINE_KEY(iAnimator,LoadScriptFile,ls,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoFile,lf,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoOpacity,lo,Float,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoPosition,lp,Int,1);
@@ -131,13 +134,14 @@ IOBJECT_DEFINE_KEY(iAnimator,TitlePageImage,-ti,Any,0);
 //
 iAnimator* iAnimator::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iAnimator(vm); // non-inheritable, so no need to use Object Factory
 }
 
 
-iAnimator::iAnimator(iViewModule *vm) : iViewModuleComponent(vm), mBlenderBase(0)
+iAnimator::iAnimator(iViewModule *vm) : iObject("Animator"), mViewModule(vm)
 {
-	mStarted = mStartedRender = mUseScript = false;
+	mStarted = mStartedRender = mUseScript = mIsPlayingDemo = false;
 	mInheritSettings = true;
 	mRestoreCamera = true;
 	mDebugFlag = 0;
@@ -179,11 +183,16 @@ iAnimator::iAnimator(iViewModule *vm) : iViewModuleComponent(vm), mBlenderBase(0
 	mAnimatorObserver = iAnimatorEventObserver::New(this->GetViewModule()); IERROR_ASSERT(mAnimatorObserver);
 
 	mCameraPath = iCameraPath::New(this->GetViewModule()); IERROR_ASSERT(mCameraPath);
+
+	mLeader = 0;
 }
 
 
 iAnimator::~iAnimator()
 {
+	this->RemoveAllFollowers();
+	if(mLeader != 0) mLeader->RemoveFollower(this);
+
 	mAnimatorObserver->Delete();
 	mAnimatorScript->Delete();
 	while(mBlenderBase.Size() > 0) delete mBlenderBase.RemoveLast();
@@ -237,6 +246,9 @@ void iAnimator::Start()
 
 	mStarted = true;
 	this->ClearCache();
+
+	int i;
+	for(i=0; i<mFollowers.Size(); i++) mFollowers[i]->Start();
 }
 
 
@@ -251,7 +263,7 @@ bool iAnimator::Continue()
 		return false;
 	}
 
-	this->GetErrorStatus()->Monitor(mAnimatorScript);
+	this->GetErrorStatus()->Monitor(mAnimatorScript->GetErrorStatus());
 	this->ClearCache();
 	return mAnimatorScript->Continue();
 }
@@ -262,6 +274,9 @@ bool iAnimator::Continue()
 //
 void iAnimator::Finish()
 {
+	int i;
+	for(i=0; i<mFollowers.Size(); i++) mFollowers[i]->Finish();
+
 	if(!mStarted)
 	{
 		this->GetErrorStatus()->Set("Attempting to finish a never started animation.");
@@ -295,6 +310,43 @@ void iAnimator::Finish()
 }
 
 
+void iAnimator::AddFollower(iAnimator *f)
+{
+	if(f!=0 && f!=this)
+	{
+		mFollowers.AddUnique(f);
+		f->SetLeader(this);
+	}
+}
+
+
+void iAnimator::RemoveFollower(iAnimator *f)
+{
+	if(f != 0)
+	{
+		mFollowers.Remove(f);
+		f->SetLeader(0);
+	}
+}
+
+
+void iAnimator::SetLeader(iAnimator *l)
+{
+	if(l != this)
+	{
+		mLeader = l;
+	}
+}
+
+
+void iAnimator::RemoveAllFollowers()
+{
+	int i;
+	for(i=0; i<mFollowers.Size(); i++) mFollowers[i]->SetLeader(0);
+	mFollowers.Clear();
+}
+
+
 //
 //  Internal functions
 //
@@ -328,7 +380,7 @@ void iAnimator::ResetCurrentFile()
 
 void iAnimator::SaveState()
 {
-	if(XSECTION != 0) mState.xsecPos = XSECTION->GetPos(); else mState.xsecPos = 0.0;
+	if(XSECTION != 0) mState.xsecPos = XSECTION->GetLocation(); else mState.xsecPos = 0.0;
 	mState.ifBoundingBox = this->GetViewModule()->IsBoundingBoxVisible();
 	mState.ifColorBars = this->GetViewModule()->IsColorBarsVisible();
 	mState.ifTimeLabel = this->GetViewModule()->IsLabelVisible();
@@ -355,7 +407,7 @@ void iAnimator::RestoreState()
 		DATAREADER->LoadRecord(mState.currec,0,true);
 	}
 
-	if(XSECTION != 0) XSECTION->SetPos(mState.xsecPos);
+	if(XSECTION != 0) XSECTION->SetLocation(mState.xsecPos);
 	this->GetViewModule()->ShowBoundingBox(mState.ifBoundingBox );
 	this->GetViewModule()->ShowColorBars(mState.ifColorBars);
 	this->GetViewModule()->ShowLabel(mState.ifTimeLabel);
@@ -446,6 +498,36 @@ bool iAnimator::SetTitlePageFile(const iString &s)
 }
 
 
+bool iAnimator::LoadScriptFile(const iString &name)
+{
+	iString fname(name);
+	iDirectory::ExpandFileName(fname,this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(_EnvironmentScript));
+
+	iFile f(fname);
+	if(!f.Open(iFile::_Read,iFile::_Text))
+	{
+		this->GetErrorStatus()->Set("Animation script file is not found.");
+		return false;
+	}
+
+	iString st, tmp;
+	while(f.ReadLine(tmp)) st += tmp + "\n";
+	if(st.IsEmpty())
+	{
+		this->GetErrorStatus()->Set("Animation script file is empty or unreadable.");
+		return false;
+	}
+
+	f.Close();
+
+	mAnimatorScript->SetText(st);
+	mUseScript = true;
+	this->SetScriptFileName(fname);
+
+	return true;
+}
+
+
 bool iAnimator::RenderImages(bool dumpImage)
 {
 	static float Pi = 3.1415927;
@@ -524,11 +606,16 @@ bool iAnimator::RenderImages(bool dumpImage)
 
 	if(mCurFrame == mState.nframes)
 	{
-		this->GetErrorStatus()->Monitor(DATAREADER);
+		this->GetErrorStatus()->Monitor(DATAREADER->GetErrorStatus());
+		
+		iProgressEventObserver *obs = DATAREADER->GetProgressEventObserver(DATAREADER->GetFileSetDataType());
+		if(obs != 0) obs->AttachScript(mAnimatorScript);
 		DATAREADER->LoadRecord(-1,1,mDebugFlag>1);
+		if(obs != 0) obs->AttachScript(0);
+
 		if(this->GetErrorStatus()->IsError())
 		{
-			if(this->GetErrorStatus()->GetLevel()==10)
+			if(this->GetErrorStatus()->Level()==10)
 			{
 				this->GetErrorStatus()->Clear();
 				if(mUseScript)
@@ -561,10 +648,10 @@ bool iAnimator::RenderImages(bool dumpImage)
 	{
 		if(fabs(mState.slideSpeed)>1.0e-30 && XSECTION!=0)
 		{
-			double p = XSECTION->GetPos();
+			double p = XSECTION->GetLocation();
 			p = p + mState.slideSpeed;
-			bool ret = XSECTION->SetPos(p);
-			if(p<-1.0 || ret) mState.slideSpeed = -mState.slideSpeed;
+			XSECTION->SetLocation(p);
+			if(XSECTION->GetOverTheEdgeFlag()) mState.slideSpeed = -mState.slideSpeed;
 		}
 		//
 		//	Add transformations for rotate & tumble
@@ -704,16 +791,16 @@ bool iAnimator::RenderImages(bool dumpImage)
 		//
 		//  Objects for transition effects (blending with previous record)
 		//
-		this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+		this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 		this->GetViewModule()->CreateImages(images);
 		if(this->GetErrorStatus()->NoError())
 		{
-			this->GetErrorStatus()->Monitor(DATAREADER,"Data reader: ");
+			this->GetErrorStatus()->Monitor(DATAREADER->GetErrorStatus(),true);
 			DATAREADER->LoadRecord(mPrevRec,0,false);
 			if(this->GetErrorStatus()->NoError())
 			{
 				this->GetViewModule()->UpdateLabel();
-				this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+				this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 				this->GetViewModule()->CreateImages(tmparr);
 				if(this->GetErrorStatus()->NoError())
 				{
@@ -727,7 +814,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 		}
 		if(this->GetErrorStatus()->NoError())
 		{
-			this->GetErrorStatus()->Monitor(DATAREADER,"Data reader: ");
+			this->GetErrorStatus()->Monitor(DATAREADER->GetErrorStatus(),true);
 			DATAREADER->LoadRecord(mCurRec,0,false);	
 		}
 		else return false;
@@ -741,7 +828,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 	{
 		if(images.Size() == 0)
 		{
-			this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+			this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 			this->GetViewModule()->CreateImages(images);
 		}
 		if(this->GetErrorStatus()->NoError())
@@ -820,7 +907,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 			//
 			if(images.Size() == 0)
 			{
-				this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+				this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 				this->GetViewModule()->CreateImages(images);
 			}
 			//
@@ -844,7 +931,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 		//
 		if(images.Size() == 0)
 		{
-			this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+			this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 			this->GetViewModule()->CreateImages(images);
 		}
 		if(this->GetErrorStatus()->NoError())  // we do have the image
@@ -903,9 +990,15 @@ bool iAnimator::RenderImages(bool dumpImage)
 		else return false;
 	}
 
+	for(i=0; i<mFollowers.Size(); i++)
+	{
+		this->GetErrorStatus()->Monitor(mFollowers[i]->GetErrorStatus(),true,"Follower Animator from window #"+iString::FromNumber(1+mFollowers[i]->GetViewModule()->GetWindowNumber()));
+		if(!mFollowers[i]->RenderImages(false)) break;
+	}
+
 	if(mDebugFlag==0 && dumpImage)
 	{
-		this->GetErrorStatus()->Monitor(this->GetViewModule(),"Visual Module: ");
+		this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
 		this->GetViewModule()->DumpImages(images,_ImageTypeAnimationFrame);
 	}
 
@@ -1088,6 +1181,12 @@ bool iAnimator::IsCameraPathValid() const
 }
 
 
+void iAnimator::StopCameraPathDemo()
+{
+	mIsPlayingDemo = false;
+}
+
+
 void iAnimator::PlayCameraPathDemo()
 {
 	if(mState.mode == 4)
@@ -1111,7 +1210,8 @@ void iAnimator::PlayCameraPathDemo()
 		//
 		//  Fly along the main path
 		//
-		for(; mState.posOnPath<mNumPathSteps; mState.posOnPath++)
+		mIsPlayingDemo = true;
+		for(; mIsPlayingDemo && mState.posOnPath<mNumPathSteps; mState.posOnPath++)
 		{
 			this->PositionCameraOnThePath();
 			this->GetViewModule()->Render(); 
@@ -1120,8 +1220,10 @@ void iAnimator::PlayCameraPathDemo()
 			//
 			this->GetViewModule()->Render(); 
 			t = this->GetViewModule()->GetRenderer()->GetLastRenderTimeInSeconds();
-			if(t < 0.1) iSystem::Sleep(round(1000.0*(0.1-t)));
+			if(t < 0.1) iSystem::Sleep(round(500.0*(0.1-t)));
+			this->ClearCache();
 		}
+		mIsPlayingDemo = false;
 
 		mCameraPath->SetHandleOpacity(1.0);
 		mState.posOnPath = pos;
@@ -1137,6 +1239,8 @@ void iAnimator::PlayCameraPathDemo()
 		this->GetViewModule()->Render(); 
 	}
 }
+
+
 //
 //  Two functions used in saving/restoring the state and in creating new instances with
 //
@@ -1222,7 +1326,6 @@ void iAnimator::UnPackStateBody(const iString &s)
 
 	if(this->UnPackValue(s,KeyDebugFlag(),i)) this->SetDebugFlag(i);
 	if(this->UnPackValue(s,KeyUseScript(),b)) this->SetUseScript(b);
-	if(this->UnPackValue(s,KeyScriptFileName(),ss)) this->SetScriptFileName(ss);
 	if(this->UnPackValue(s,KeyFocalPathEnabled(),b)) this->SetFocalPathEnabled(b);
 	if(this->UnPackValue(s,KeyFocalPathToPoint(),b)) this->SetFocalPathToPoint(b);
 	if(this->UnPackValue(s,KeyCameraPathClosed(),b)) this->SetCameraPathClosed(b);
@@ -1292,7 +1395,12 @@ void iAnimator::UnPackStateBody(const iString &s)
 	//
 	iObject::ReportMissingKeys(false); //action keys are not part of the states
 
-	if(this->UnPackValue(s,KeyCameraPathDemo(),b) && b) this->PlayCameraPathDemo();
+	if(this->UnPackValue(s,KeyLoadScriptFile(),ss)) this->LoadScriptFile(ss);
+
+	if(this->UnPackValue(s,KeyCameraPathDemo(),b))
+	{
+		if(b) this->PlayCameraPathDemo(); else this->StopCameraPathDemo();
+	}
 
 	iObject::ReportMissingKeys(true);
 }
