@@ -31,21 +31,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iobject.h"
-#include "iviewmodulecomponent.h"
-#include "ierrorstatusholder.h"
-#include "ideletable.h"
 
 
 #include "iarray.h"
 #include "imath.h"
 #include "iimage.h"
 
-
 class iAnimatorEventObserver;
 class iAnimatorScript;
 class iCameraPath;
 class iStereoImageArray;
 
+class vtkImageData;
+class vtkPolyData;
+
 
 struct iAnimatorState 
 {
@@ -81,21 +80,17 @@ struct iAnimatorState
 };
 
 
-class vtkPolyData;
-class iCameraPath;
-class vtkImageData;
-
-
-class iAnimator : public iObject, public iViewModuleComponent, public iErrorStatusHolder, public iDeletable
+class iAnimator : public iObject
 {
 	
 	friend class iAnimatorScript;
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 	
-	IOBJECT_DECLARE_SELF(iAnimator,iObject);
-
-	static iAnimator* New(iViewModule *vm);
+	vtkTypeMacro(iAnimator,iObject);
+	static iAnimator* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 		
 	IOBJECT_DECLARE_GETSET(Mode,mState.mode,int);
@@ -173,6 +168,8 @@ public:
 	IOBJECT_DECLARE_GETSET1(ScriptFileName,const iString&);
 	//virtual void SetScriptFileName(const iString &s);
 	//inline const String& GetScriptFileName() const { return mScriptFileName; }
+	static const iObjectKey& KeyLoadScriptFile();
+	bool LoadScriptFile(const iString &fname);
 
 	IOBJECT_DECLARE_GETSET1(DebugFlag,int);
 	//virtual void SetDebugFlag(int s);
@@ -232,10 +229,14 @@ public:
 	virtual void Finish();
 	virtual bool Continue();
 
+	void AddFollower(iAnimator *f);
+	void RemoveFollower(iAnimator *f);
+	void RemoveAllFollowers();
+
 	inline iAnimatorEventObserver* GetObserver() const { return mAnimatorObserver; }
 	inline iAnimatorScript* GetScript() const { return mAnimatorScript; }
 	inline void GetInfo(bool &nr, int &cr, int &cf) const { nr = mNewRec; cr = mCurRec; cf = mCurFrame; }
-	virtual void CopyState(iAnimator *);
+	virtual void CopyState(iAnimator *other);
 
 	//
 	//  Camera path functions
@@ -243,13 +244,21 @@ public:
 	void SetCameraPathColor(iColor &c);
 	bool IsCameraPathValid() const;
 	void PlayCameraPathDemo();
+	void StopCameraPathDemo();
 
 protected:
 
-	iAnimator(iViewModule *vm);
 	virtual ~iAnimator();
 
+	virtual void PackStateBody(iString &s) const;
+	virtual void UnPackStateBody(const iString &s);
+
+private:
+	
+	iAnimator(iViewModule *vm);
+
 	void PositionCameraOnThePath();
+	void SetLeader(iAnimator *l);
 
 	bool RenderImages(bool dumpImage = true);
 	void Reset();
@@ -258,12 +267,7 @@ protected:
 	void SaveState();
 	void RestoreState();
 
-	virtual void PackStateBody(iString &s) const;
-	virtual void UnPackStateBody(const iString &s);
-
-private:
-
-	bool mStarted, mStartedRender, mUseScript, mRestoreCamera, mInheritSettings;
+	bool mStarted, mStartedRender, mUseScript, mRestoreCamera, mInheritSettings, mIsPlayingDemo;
 	long mSeed;
 	int mDebugFlag;
 
@@ -286,6 +290,9 @@ private:
 
 	iCameraPath *mCameraPath;
 
+	iSearchableArray<iAnimator*> mFollowers;
+	iAnimator *mLeader;
+
 	//
 	//  Internal (work) variables
 	//
@@ -300,105 +307,123 @@ private:
 
 
 inline void iAnimator::SetNumberOfFrames(int na)
-{ 
-	mState.nframes = na;
-	this->ClearCache();
+{
+	if(na > 0)
+	{
+		mState.nframes = na;
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetPhi(float va)
-{ 
+{
 	mState.dphi = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetTheta(float va)
-{ 
+{
 	mState.dtheta = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetZoom(float va)
-{ 
+{
 	mState.dscale = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetRoll(float va)
-{ 
+{
 	mState.droll = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetSlideSpeed(float va)
-{ 
+{
 	mState.slideSpeed = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetFlybySpeed(float va)
-{ 
+{
 	mState.flybySpeed = va; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetNumberOfBlendedFrames(int na)
-{ 
-	mState.nBlendedFrames = na; 
-	this->ClearCache();
+{
+	if(na >= 0)
+	{
+		mState.nBlendedFrames = na; 
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetNumberOfTransitionFrames(int na)
-{ 
-	mState.nTransitionFrames = na; 
-	this->ClearCache();
+{
+	if(na >= 0)
+	{
+		mState.nTransitionFrames = na; 
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetNumberOfTitlePageFrames(int n)
-{ 
-	mState.titlePageNumFrames = n; 
-	this->ClearCache();
+{
+	if(n >= 0)
+	{
+		mState.titlePageNumFrames = n; 
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetNumberOfTitlePageBlendedFrames(int n)
-{ 
-	mState.titlePageNumBlendedFrames = n; 
-	this->ClearCache();
+{
+	if(n >= 0)
+	{
+		mState.titlePageNumBlendedFrames = n; 
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetLogoPosition(int n)
-{ 
-	mState.logoPosition = n; 
-	this->ClearCache();
+{
+	if(n>0 && n<5)
+	{
+		mState.logoPosition = n; 
+		this->ClearCache();
+	}
 }
 
 
 inline void iAnimator::SetLogoOpacity(float v)
-{ 
+{
 	mState.logoOpacity = v; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetStopOnPath(bool s)
-{ 
+{
 	mState.stopOnPath = s; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetPositionOnPath(int s)
-{ 
+{
 	if(s>=0 && s<mNumPathSteps)
 	{
 		mState.posOnPath = s;
@@ -409,28 +434,28 @@ inline void iAnimator::SetPositionOnPath(int s)
 
 
 inline void iAnimator::SetUseScript(bool s)
-{ 
+{
 	mUseScript = s; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetRestoreCamera(bool s)
-{ 
+{
 	mRestoreCamera = s; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetInheritSettings(bool s)
-{ 
+{
 	mInheritSettings = s; 
 	this->ClearCache();
 }
 
 
 inline void iAnimator::SetScriptFileName(const iString &s)
-{ 
+{
 	mScriptFileName = s; 
 	this->ClearCache();
 }
