@@ -30,13 +30,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ianimator.h"
+#include "ibasicdatasubjects.h"
 #include "icamera.h"
 #include "icontrolmodule.h"
 #include "icontrolscript.h"
 #include "icrosssectionviewsubject.h"
-#include "idata.h"
 #include "idatalimits.h"
 #include "idatareader.h"
+#include "idirectory.h"
 #include "ierror.h"
 #include "ierrorstatus.h"
 #include "iextensionfactory.h"
@@ -69,6 +70,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  macros
 //
+#include "ianimatorscriptmacro.h"
 #include "ibasescriptmacro.h"
 
 
@@ -83,29 +85,20 @@ iValue* iAnimatorScript::valRS = 0;
 iValue* iAnimatorScript::valRP = 0;
 iValue* iAnimatorScript::valVA3 = 0;
 
-#define curScript			iPointerCast<iAnimatorScript,iScript>(me)
-#define curAnimator			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()
-#define curVisual			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()
-#define curControl			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetControlModule()
-#define curReader			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()
-#define curRenderer			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()
-#define curCamera			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()->GetActiveCamera()
-#define curLimits(t)		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()->GetLimits(t)
-#define curObject(name)		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->Get##name##ViewSubject()
-#define numObject(name,n)	iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->Get##name##ViewSubject(n)
-#define curObjectFamily(name)	iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetViewObjectFamily(_ObjectType##name)
+#define curScript	iRequiredCast<iAnimatorScript>(INFO,me)
 
 
-iAnimatorScript* iAnimatorScript::New(iAnimator *m)
+iAnimatorScript* iAnimatorScript::New(iAnimator *an)
 {
-	return iExtensionFactory::CreateAnimatorScript(m);
+	IERROR_ASSERT(an);
+	return iExtensionFactory::CreateAnimatorScript(an);
 }
 
 
-iAnimatorScript::iAnimatorScript(iAnimator *m) : iBaseScript(m->GetViewModule()->GetControlModule()->GetControlScript()) // always embedded
+iAnimatorScript::iAnimatorScript(iAnimator *an) : iBaseScript(an->GetViewModule()->GetControlModule()->GetControlScript()) // always embedded
 {
-	mEmbeddedControlScript = iShellFactory::CreateControlScript(m->GetViewModule()->GetControlModule(),this);
-	mAnimator = m;
+	mEmbeddedControlScript = iShellFactory::CreateControlScript(an->GetViewModule()->GetControlModule(),this);
+	mAnimator = an;
 	mInRender = false;
 
 	//
@@ -115,7 +108,7 @@ iAnimatorScript::iAnimatorScript(iAnimator *m) : iBaseScript(m->GetViewModule()-
 	{
 		valIS = iValue::New(0,"tmpIS",iValue::_ByValue,0);
 		valRS = iValue::New(0,"tmpRS",iValue::_ByValue,0.0);
-		valRP = iValue::New(0,"tmpRP",iValue::_ByValue,(double *)0);
+		valRP = iValue::New(0,"tmpRP",iValue::_ByValue,static_cast<double *>(0));
 		valVA3 = this->TransformSingleTokenToValue("(0.0,0.0,0.0)");
 	}
 
@@ -136,12 +129,18 @@ iAnimatorScript::iAnimatorScript(iAnimator *m) : iBaseScript(m->GetViewModule()-
 	this->CreateAliasWord("vector","vector-field"); 
 	this->CreateAliasWord("tensor","tensor-field"); 
 
-	this->CreateAliasWord("mesh-variable-lower-limit","scalar-field-lower-limit");
-	this->CreateAliasWord("mesh-variable-upper-limit","scalar-field-upper-limit");
-	this->CreateAliasWord("particle-attribute-lower-limit","particle-set-lower-limit");
-	this->CreateAliasWord("particle-attribute-upper-limit","particle-set-upper-limit");
-	this->CreateAliasWord("vector-upper-limit","vector-field-upper-limit");
-	this->CreateAliasWord("tensor-upper-limit","tensor-field-upper-limit");
+	this->CreateAliasWord("mesh-variable-lower-limit","uniform-scalars-lower-limit");
+	this->CreateAliasWord("mesh-variable-upper-limit","uniform-scalars-upper-limit");
+	this->CreateAliasWord("particle-attribute-lower-limit","basic-particles-lower-limit");
+	this->CreateAliasWord("particle-attribute-upper-limit","basic-particles-upper-limit");
+	this->CreateAliasWord("vector-upper-limit","uniform-vectors-upper-limit");
+	this->CreateAliasWord("tensor-upper-limit","uniform-tensors-upper-limit");
+	this->CreateAliasWord("scalar-field-lower-limit","uniform-scalars-lower-limit");
+	this->CreateAliasWord("scalar-field-upper-limit","uniform-scalars-upper-limit");
+	this->CreateAliasWord("particle-set-lower-limit","basic-particles-lower-limit");
+	this->CreateAliasWord("particle-set-upper-limit","basic-particles-upper-limit");
+	this->CreateAliasWord("vector-field-upper-limit","uniform-vectors-upper-limit");
+	this->CreateAliasWord("tensor-field-upper-limit","uniform-tensors-upper-limit");
 
 	this->CreateAliasWord("xsection-var","cross-section-var");
 	this->CreateAliasWord("xsection-dir","cross-section-dir");
@@ -240,12 +239,12 @@ iAnimatorScript::iAnimatorScript(iAnimator *m) : iBaseScript(m->GetViewModule()-
 	//
 	// This is depreciated: use embed control-script instead
 	//
-	this->CreateCommandWord(iOperation::New(this,"","scalar-field-lower-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::ScalarFieldLowerLimit,(unsigned char)4));
-	this->CreateCommandWord(iOperation::New(this,"","scalar-field-upper-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::ScalarFieldUpperLimit,(unsigned char)4));
-	this->CreateCommandWord(iOperation::New(this,"","particle-set-lower-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::ParticleSetLowerLimit,(unsigned char)4));
-	this->CreateCommandWord(iOperation::New(this,"","particle-set-upper-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::ParticleSetUpperLimit,(unsigned char)4));
-	this->CreateCommandWord(iOperation::New(this,"","vector-field-upper-limit",1,iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::VectorFieldUpperLimit,(unsigned char)3));
-	this->CreateCommandWord(iOperation::New(this,"","tensor-field-upper-limit",1,iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::TensorFieldUpperLimit,(unsigned char)3));
+	this->CreateCommandWord(iOperation::New(this,"","uniform-scalars-lower-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::UniformScalarsLowerLimit,(unsigned char)4));
+	this->CreateCommandWord(iOperation::New(this,"","uniform-scalars-upper-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::UniformScalarsUpperLimit,(unsigned char)4));
+	this->CreateCommandWord(iOperation::New(this,"","basic-particles-lower-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::BasicParticlesLowerLimit,(unsigned char)4));
+	this->CreateCommandWord(iOperation::New(this,"","basic-particles-upper-limit",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::BasicParticlesUpperLimit,(unsigned char)4));
+	this->CreateCommandWord(iOperation::New(this,"","uniform-vectors-upper-limit",1,iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::UniformVectorsUpperLimit,(unsigned char)3));
+	this->CreateCommandWord(iOperation::New(this,"","uniform-tensors-upper-limit",1,iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::UniformTensorsUpperLimit,(unsigned char)3));
 
 	this->CreateCommandWord(iOperation::New(this,"","surface-var",1,iValue::NewIndex(this),iValue::_Absolute,iValue::NewIndex(this),iAnimatorScript::SurfaceVar,(unsigned char)4));
 	this->CreateCommandWord(iOperation::New(this,"","surface-level",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::SurfaceLevel,(unsigned char)4));
@@ -258,7 +257,6 @@ iAnimatorScript::iAnimatorScript(iAnimator *m) : iBaseScript(m->GetViewModule()-
 	this->CreateCommandWord(iOperation::New(this,"","volume-var",1,iValue::NewIndex(this),iValue::_Absolute,iValue::NewIndex(this),iAnimatorScript::VolumeVar,(unsigned char)4));
 
 	this->CreateCommandWord(iOperation::New(this,"","particles-opacity",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::ParticlesOpacity,(unsigned char)4));
-	this->CreateCommandWord(iOperation::New(this,"","particles-downsample-factor",1,iValue::_Absolute,iValue::NewInt(this),iAnimatorScript::ParticlesDownsampleFactor,(unsigned char)3));
 
 	this->CreateCommandWord(iOperation::New(this,"","marker-position",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewArray(this,3),iAnimatorScript::MarkerPosition,(unsigned char)4));
 	this->CreateCommandWord(iOperation::New(this,"","marker-size",1,iValue::NewIndex(this),iValue::_RelativeAddMult,iValue::NewReal(this),iAnimatorScript::MarkerSize,(unsigned char)4));
@@ -323,7 +321,7 @@ void iAnimatorScript::Render(iScript *me, iValue *v0, iValue::Assignment vtkNotU
 	curScript->SetInRender(true);
 
 	if(v == -1) v = iMath::_IntMax;
-	me->GetErrorStatus()->Monitor(curAnimator,"Animator: ");
+	me->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
 	for(i=0; i<v && !me->CheckAbort(i,v,1) && me->GetErrorStatus()->NoError(); i++) 
 	{
 		if(!curAnimator->RenderImages()) me->GetErrorStatus()->Set("Animation finished.",-1);
@@ -343,7 +341,7 @@ void iAnimatorScript::RenderAll(iScript *me, iValue *v0, iValue::Assignment vtkN
 	{
 		for(k=0; !me->CheckAbort(k,curControl->GetNumberOfViewModules(),1) && me->GetErrorStatus()->NoError() && k<curControl->GetNumberOfViewModules(); k++) if(k != curControl->GetCurrentViewModuleIndex())
 		{
-			me->GetErrorStatus()->Monitor(curControl->GetViewModule(k)->GetAnimator(),"Animator: ");
+			me->GetErrorStatus()->Monitor(curControl->GetViewModule(k)->GetAnimator()->GetErrorStatus(),true);
 			//
 			//  Force other animators to continue, even if they are done
 			//
@@ -351,7 +349,7 @@ void iAnimatorScript::RenderAll(iScript *me, iValue *v0, iValue::Assignment vtkN
 		}
 		if(me->GetErrorStatus()->NoError())
 		{
-			me->GetErrorStatus()->Monitor(curAnimator,"Animator: ");
+			me->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
 			if(!curAnimator->RenderImages()) me->GetErrorStatus()->Set("Animation finished.",-1);
 		}
 	}
@@ -370,7 +368,7 @@ void iAnimatorScript::MultiRender(iScript *me, iValue *v0, iValue::Assignment vt
 		return;
 	}
 
-	int n = ((iValue_VA *)v0)->GetSize();
+	int n = static_cast<iValue_VA *>(v0)->GetSize();
 	int *v = new int[n]; IERROR_ASSERT(v);
 	if(v == 0)
 	{
@@ -391,12 +389,12 @@ void iAnimatorScript::MultiRender(iScript *me, iValue *v0, iValue::Assignment vt
 	for(i=0; i<n; i++) v[i]--;
 	for(i=0; me->GetErrorStatus()->NoError() && !me->CheckAbort(i,n,3) && i<n; i++) if(v[i]>=0 && v[i]<curControl->GetNumberOfViewModules() && v[i]!=curControl->GetCurrentViewModuleIndex())
 	{
-		me->GetErrorStatus()->Monitor(curControl->GetViewModule(v[i])->GetAnimator(),"Animator: ");
+		me->GetErrorStatus()->Monitor(curControl->GetViewModule(v[i])->GetAnimator()->GetErrorStatus(),true);
 		curControl->GetViewModule(v[i])->GetAnimator()->RenderImages(false);
 	}
 	for(i=0; me->GetErrorStatus()->NoError() && !me->CheckAbort(i,n,3) && i<n; i++) if(v[i] == curControl->GetCurrentViewModuleIndex())
 	{
-		me->GetErrorStatus()->Monitor(curAnimator,"Animator: ");
+		me->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
 		if(!curAnimator->RenderImages()) me->GetErrorStatus()->Set("Animation finished.",-1);
 		break;
 	}
@@ -421,7 +419,7 @@ void iAnimatorScript::ExecuteControlScript(iScript *me, iValue *v0, iValue::Assi
 	}
 	else
 	{
-		if(v[0] == '+') v = curControl->GetFileName(_EnvironmentBase,v.Part(1));
+		iDirectory::ExpandFileName(v,curControl->GetShell()->GetEnvironment(_EnvironmentBase));
 
 		iFile f(v);
 		if(!f.Open(iFile::_Read,iFile::_Text))
@@ -441,7 +439,7 @@ void iAnimatorScript::ExecuteControlScript(iScript *me, iValue *v0, iValue::Assi
 		f.Close();
 
 		curScript->mAllowChildAccess = true;
-		me->GetErrorStatus()->Monitor(curScript->mEmbeddedControlScript,"Control script: ");
+		me->GetErrorStatus()->Monitor(curScript->mEmbeddedControlScript->GetErrorStatus(),true,"Control script: ");
 		curScript->mEmbeddedControlScript->Run(v,false,false); // do not reset the script!!!
 		curScript->mAllowChildAccess = false;
 	}
@@ -461,7 +459,7 @@ void iAnimatorScript::EmbedControlScript(iScript *me, iValue *v0, iValue::Assign
 	if(curScript->mEmbeddedControlScript != 0)
 	{
 		curScript->mAllowChildAccess = true;
-		me->GetErrorStatus()->Monitor(curScript->mEmbeddedControlScript,"Control script: ");
+		me->GetErrorStatus()->Monitor(curScript->mEmbeddedControlScript->GetErrorStatus(),true,"Control script: ");
 		curScript->mEmbeddedControlScript->Run(v,false,false); // do not reset the script!!!
 		curScript->mAllowChildAccess = false;
 	}
@@ -566,121 +564,80 @@ void iAnimatorScript::CrossSectionSpeed(iScript *me, iValue *v0, iValue::Assignm
 //
 //  variable limits
 //
-void iAnimatorScript::ScalarFieldLowerLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::UniformScalarsLowerLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
 	float v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
 	n--;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ScalarField");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
+	if(n>=0 && n<curLimits(iUniformScalarsDataSubject::DataType())->GetNumVars())
 	{
-		me->GetErrorStatus()->Set("There are no scalar field data in the set.");
-		return;
+		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iUniformScalarsDataSubject::DataType())->GetLowerLimit(n));
+		curLimits(iUniformScalarsDataSubject::DataType())->SetLowerLimit(n,v);
 	}
-	if(n>=0 && n<curLimits(t)->GetNumVars())
-	{
-		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetLowerLimit(n));
-		curLimits(t)->SetLowerLimit(n,v);
-	}
-	else me->GetErrorStatus()->Set("Invalid scalar field variable number.");
+	else me->GetErrorStatus()->Set("Invalid variable index.");
 }
 
-void iAnimatorScript::ScalarFieldUpperLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::UniformScalarsUpperLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
 	float v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
 	n--;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ScalarField");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
+	if(n>=0 && n<curLimits(iUniformScalarsDataSubject::DataType())->GetNumVars())
 	{
-		me->GetErrorStatus()->Set("There are no scalar field data in the set.");
-		return;
+		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iUniformScalarsDataSubject::DataType())->GetUpperLimit(n));
+		curLimits(iUniformScalarsDataSubject::DataType())->SetUpperLimit(n,v);
 	}
-
-	if(n>=0 && n<curLimits(t)->GetNumVars())
-	{
-		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetUpperLimit(n));
-		curLimits(t)->SetUpperLimit(n,v);
-	}
-	else me->GetErrorStatus()->Set("Invalid scalar field variable number.");
+	else me->GetErrorStatus()->Set("Invalid variable index.");
 }
 
-void iAnimatorScript::ParticleSetLowerLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::BasicParticlesLowerLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
 	float v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
 	n--;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ParticleSet");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
+	if(n>=0 && n<curLimits(iBasicParticlesDataSubject::DataType())->GetNumVars())
 	{
-		me->GetErrorStatus()->Set("There are no particle set data in the set.");
-		return;
+		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iBasicParticlesDataSubject::DataType())->GetLowerLimit(n));
+		curLimits(iBasicParticlesDataSubject::DataType())->SetLowerLimit(n,v);
 	}
-
-	if(n>=0 && n<curLimits(t)->GetNumVars())
-	{
-		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetLowerLimit(n));
-		curLimits(t)->SetLowerLimit(n,v);
-	}
-	else me->GetErrorStatus()->Set("Invalid particle set variable number.");
+	else me->GetErrorStatus()->Set("Invalid attribute index.");
 }
 
-void iAnimatorScript::ParticleSetUpperLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::BasicParticlesUpperLimit(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
 	float v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
 	n--;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ParticleSet");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
+	if(n>=0 && n<curLimits(iBasicParticlesDataSubject::DataType())->GetNumVars())
 	{
-		me->GetErrorStatus()->Set("There are no particle set data in the set.");
-		return;
+		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iBasicParticlesDataSubject::DataType())->GetUpperLimit(n));
+		curLimits(iBasicParticlesDataSubject::DataType())->SetUpperLimit(n,v);
 	}
-
-	if(n>=0 && n<curLimits(t)->GetNumVars())
-	{
-		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetUpperLimit(n));
-		curLimits(t)->SetUpperLimit(n,v);
-	}
-	else me->GetErrorStatus()->Set("Invalid particle set variable number.");
+	else me->GetErrorStatus()->Set("Invalid attribute index.");
 }
 
-void iAnimatorScript::VectorFieldUpperLimit(iScript *me, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::UniformVectorsUpperLimit(iScript *me, iValue *v0, iValue::Assignment rel)
 {
 	float v;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"VectorField");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
-	{
-		me->GetErrorStatus()->Set("There are no vector field data in the set.");
-		return;
-	}
-
-	IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetUpperLimit(0));
-	curLimits(t)->SetUpperLimit(0,v);
+	IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iUniformVectorsDataSubject::DataType())->GetUpperLimit(0));
+	curLimits(iUniformVectorsDataSubject::DataType())->SetUpperLimit(0,v);
 }
 
-void iAnimatorScript::TensorFieldUpperLimit(iScript *me, iValue *v0, iValue::Assignment rel)
+void iAnimatorScript::UniformTensorsUpperLimit(iScript *me, iValue *v0, iValue::Assignment rel)
 {
 	float v;
 
-	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"TensorField");
-	if(t==iData::None() || !curReader->IsThereData(t)) 
-	{
-		me->GetErrorStatus()->Set("There are no tensor field data in the set.");
-		return;
-	}
-
-	IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(t)->GetUpperLimit(0));
-	curLimits(t)->SetUpperLimit(0,v);
+	IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,curLimits(iUniformTensorsDataSubject::DataType())->GetUpperLimit(0));
+	curLimits(iUniformTensorsDataSubject::DataType())->SetUpperLimit(0,v);
 }
 
 //
@@ -739,7 +696,7 @@ void iAnimatorScript::Projection(iScript *me, iValue *v0, iValue::Assignment vtk
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetRenderTool()->GetCamera()->SetParallelProjection(!v?1:0);
+	curCamera->SetParallelProjection(!v?1:0);
 }
 
 //
@@ -833,7 +790,7 @@ void iAnimatorScript::SurfaceVar(iScript *me, iValue *n0, iValue *v0, iValue::As
 	int v;
 	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
+	if(n <= 0) s = curObject(Surface); else s = indObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -847,7 +804,7 @@ void iAnimatorScript::SurfaceLevel(iScript *me, iValue *n0, iValue *v0, iValue::
 	float v;
 	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
+	if(n <= 0) s = curObject(Surface); else s = indObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetIsoSurfaceLevel());
@@ -861,7 +818,7 @@ void iAnimatorScript::SurfaceOpacity(iScript *me, iValue *n0, iValue *v0, iValue
 	float v;
 	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
+	if(n <= 0) s = curObject(Surface); else s = indObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetOpacity(0));
@@ -876,7 +833,7 @@ void iAnimatorScript::CrossSectionVar(iScript *me, iValue *n0, iValue *v0, iValu
 	int v;
 	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = indObject(CrossSection,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -890,7 +847,7 @@ void iAnimatorScript::CrossSectionDir(iScript *me, iValue *n0, iValue *v0, iValu
 	int v;
 	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = indObject(CrossSection,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -904,11 +861,11 @@ void iAnimatorScript::CrossSectionPos(iScript *me, iValue *n0, iValue *v0, iValu
 	double v;
 	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = indObject(CrossSection,n-1);
 	if(s != 0)
 	{
-		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,(double)s->GetPos());
-		s->SetPos(v);
+		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,(double)s->GetLocation());
+		s->SetLocation(v);
 	}
 }
 
@@ -918,7 +875,7 @@ void iAnimatorScript::VolumeVar(iScript *me, iValue *n0, iValue *v0, iValue::Ass
 	int v;
 	iVolumeViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curObject(Volume); else s = numObject(Volume,n-1);
+	if(n <= 0) s = curObject(Volume); else s = indObject(Volume,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -940,16 +897,6 @@ void iAnimatorScript::ParticlesOpacity(iScript *me, iValue *n0, iValue *v0, iVal
 	}
 }
 
-void iAnimatorScript::ParticlesDownsampleFactor(iScript *me, iValue *v0, iValue::Assignment vtkNotUsed(rel))
-{
-	int v;
-	IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	if(v < 1) return;
-	curReader->SetParticlesDownsampleFactor(v);
-	me->GetErrorStatus()->Monitor(curReader,"Data reader: ");
-	curReader->ReloadData(iData::BasicParticles());
-}
-
 void iAnimatorScript::MarkerPosition(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
@@ -1006,7 +953,7 @@ iValue* iAnimatorScript::GetMarkerPosition(iScript *me, int i)
 	if(i>=0 && i<=curVisual->GetMarkerFamily()->GetMaxMemberIndex())
 	{
 		const double *p = curVisual->GetMarkerFamily()->GetMember(i)->GetPosition();
-		for(j=0; j<3; j++) ((iValue_RS*)((iValue_VA*)valVA3)->GetComponent(j+1))->SetNumericValue(p[j]);
+		for(j=0; j<3; j++) static_cast<iValue_RS*>(static_cast<iValue_VA*>(valVA3)->GetComponent(j+1))->SetNumericValue(p[j]);
 		return valVA3;
 	}
 	else
@@ -1019,7 +966,7 @@ iValue* iAnimatorScript::GetMarkerPosition(iScript *me, int i)
 //
 //  File loading functions - for batch operations
 //
-void iAnimatorScript::LoadFileByType(iScript *me, iValue* v0, int key, const iDataType &type)
+void iAnimatorScript::LoadFileByType(iScript *me, iValue* v0, const iDataType &type)
 {
 	iString v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -1029,33 +976,33 @@ void iAnimatorScript::LoadFileByType(iScript *me, iValue* v0, int key, const iDa
 	//
 	if(v[0]=='\'' && v[v.Length()-1]=='\'') v = v.Part(1,v.Length()-2);
 
-	if(v[0] == '+') v = curControl->GetFileName(key,v.Part(1));
-	me->GetErrorStatus()->Monitor(curReader,"Data reader: ");
+	iDirectory::ExpandFileName(v,type.GetEnvironment(curControl->GetShell()));
+	me->GetErrorStatus()->Monitor(curReader->GetErrorStatus(),true);
 	curReader->LoadFile(type,v);
 }
 
 
 void iAnimatorScript::LoadUniformScalarsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentScalarFieldData,iData::UniformScalars());
+	LoadFileByType(me,v0,iUniformScalarsDataSubject::DataType());
 }
 
 
 void iAnimatorScript::LoadBasicParticlesFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentParticleSetData,iData::BasicParticles());
+	LoadFileByType(me,v0,iBasicParticlesDataSubject::DataType());
 }
 
 
 void iAnimatorScript::LoadUniformVectorsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentVectorFieldData,iData::UniformVectors());
+	LoadFileByType(me,v0,iUniformVectorsDataSubject::DataType());
 }
 
 
 void iAnimatorScript::LoadUniformTensorsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentTensorFieldData,iData::UniformTensors());
+	LoadFileByType(me,v0,iUniformTensorsDataSubject::DataType());
 }
 
 
