@@ -49,7 +49,8 @@ class iAnimatorScript: public iBaseScript
 
 public:
 
-	static iAnimatorScript* New(iAnimator *);
+	vtkTypeMacro(iAnimatorScript,iBaseScript);
+	static iAnimatorScript* New(iAnimator *an = 0);
 
 	inline iAnimator* GetAnimator() const { return mAnimator; }
 
@@ -61,6 +62,8 @@ protected:
 	iAnimatorScript(iAnimator *m);
 	virtual ~iAnimatorScript();
 
+private:
+
 	//
 	//  Access to line-by-line driver
 	//
@@ -71,9 +74,10 @@ protected:
 	//
 	//  helper functions
 	//
-	static void LoadFileByType(iScript *me, iValue* v, int key, const iDataType &type);
+	static void LoadFileByType(iScript *me, iValue* v, const iDataType &type);
 
 	iControlScript *mEmbeddedControlScript;
+
 	//
 	//  Temporary iValues
 	//
@@ -101,12 +105,12 @@ protected:
 	static void RotationRoll(iScript *me, iValue* v1, iValue::Assignment rel);
 	static void Scale(iScript *me, iValue* v, iValue::Assignment rel);
 	static void CrossSectionSpeed(iScript *me, iValue* v, iValue::Assignment rel);
-	static void ScalarFieldLowerLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
-	static void ScalarFieldUpperLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
-	static void ParticleSetLowerLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
-	static void ParticleSetUpperLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
-	static void VectorFieldUpperLimit(iScript *me, iValue* v, iValue::Assignment rel);
-	static void TensorFieldUpperLimit(iScript *me, iValue* v, iValue::Assignment rel);
+	static void UniformScalarsLowerLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
+	static void UniformScalarsUpperLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
+	static void BasicParticlesLowerLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
+	static void BasicParticlesUpperLimit(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
+	static void UniformVectorsUpperLimit(iScript *me, iValue* v, iValue::Assignment rel);
+	static void UniformTensorsUpperLimit(iScript *me, iValue* v, iValue::Assignment rel);
 	static void CameraFocus(iScript *me, iValue* v, iValue::Assignment rel);
 	static void CameraPosition(iScript *me, iValue* v, iValue::Assignment rel);
 	static void CameraViewUp(iScript *me, iValue* v, iValue::Assignment rel);
@@ -145,7 +149,6 @@ protected:
 	static void VolumeVar(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
 
 	static void ParticlesOpacity(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
-	static void ParticlesDownsampleFactor(iScript *me, iValue *v0, iValue::Assignment rel);
 
 	static void MarkerPosition(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
 	static void MarkerSize(iScript *me, iValue* n, iValue* v, iValue::Assignment rel);
