@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iactor.h"
+#include "icontrolmodule.h"
 #include "ierror.h"
 #include "iviewmodule.h"
 
@@ -46,6 +47,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 class iSplineWidget : public vtkSplineWidget
 {
+
 public:
 
 	iSplineWidget()
@@ -63,11 +65,12 @@ public:
 //
 iCameraPath* iCameraPath::New(iViewModule *vm)
 { 
+	IERROR_ASSERT(vm);
 	return new iCameraPath(vm);
 }
 
 
-iCameraPath::iCameraPath(iViewModule *vm) : iViewModuleComponent(vm), mNumIntervalsPerSegment(5)
+iCameraPath::iCameraPath(iViewModule *vm) : iEventObserver(vm->GetControlModule()->GetShell()), mViewModule(vm), mNumIntervalsPerSegment(5)
 {
 	mIsFocalPath = mIsFocalPathToPoint = false;
 
@@ -268,7 +271,7 @@ void iCameraPath::SetHandleOpacity(float v)
 }
 
 
-void iCameraPath::Execute(vtkObject *caller, unsigned long eventId, void *vtkNotUsed(callData))
+void iCameraPath::ExecuteBody(vtkObject *caller, unsigned long eventId, void *)
 {
 	int i;
 
