@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iactor.h"
 #include "ierror.h"
+#include "ioverlayhelper.h"
 
 #include <vtkActor2D.h>
 #include <vtkCamera.h>
@@ -46,13 +47,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkTextProperty.h>
 
 
-iCaption* iCaption::New(const iRenderTool *rv)
+iCaption* iCaption::New(iRenderTool *rt)
 {
-	return new iCaption(rv);
+	IERROR_ASSERT(rt);
+	return new iCaption(rt);
 }
 
 
-iCaption::iCaption(const iRenderTool *rv) : iOverlayBase(rv)
+iCaption::iCaption(iRenderTool *rt) : mOverlayHelper(rt)
 {
 	this->BorderOff(); // we redefine border and leader - they do not scale under magnification
 	this->LeaderOff();
@@ -62,10 +64,6 @@ iCaption::iCaption(const iRenderTool *rv) : iOverlayBase(rv)
 	this->GetPosition2Coordinate()->SetCoordinateSystemToNormalizedViewport();
 	this->SetPosition(0.02,0.88);
 	this->SetPosition2(0.20,0.10);
-	this->GetCaptionTextProperty()->SetFontFamilyToArial();
-	this->GetCaptionTextProperty()->ItalicOff();
-	this->GetCaptionTextProperty()->ShadowOn();
-	this->GetCaptionTextProperty()->BoldOn();
 	this->GetCaptionTextProperty()->SetJustificationToCentered(); 
 	this->GetCaptionTextProperty()->SetVerticalJustificationToCentered();
 
@@ -154,7 +152,7 @@ int iCaption::RenderOverlay(vtkViewport* viewport)
 
 int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 {
-	vtkCamera *cam = this->GetCamera(viewport);
+	vtkCamera *cam = mOverlayHelper->GetCamera(viewport);
 	if(cam == 0) return 0;
 	
 	int ret = 0;
@@ -164,10 +162,10 @@ int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 	double *x1, *x2;
 	x1 = this->GetPosition();
 	x2 = this->GetPosition2();
-	int mag = this->GetRenderingMagnification();
+	int mag = mOverlayHelper->GetRenderingMagnification();
 	int *size = viewport->GetSize();
 
-	float s = (this->GetFontSize(viewport)+2*Padding)/fabs(size[1]*x2[1]);
+	float s = (mOverlayHelper->GetFontSize(viewport)+2*Padding)/fabs(size[1]*x2[1]);
 
 	if(mag == 1)
 	{
@@ -179,19 +177,22 @@ int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 	else
 	{
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
 		
 		this->SetPosition(mag*mUnmagx1[0]-winij[0],mag*mUnmagx1[1]-winij[1]);
 		Padding *= mag;
 	}
 	
-	mTmpMapper->GetTextProperty()->SetFontSize(this->GetFontSize(viewport));
+	mTmpMapper->GetTextProperty()->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag));
 	mTmpMapper->SetInput(Caption);
 	int w = mTmpMapper->GetWidth(viewport);
 	if(w+2*Padding >= size[0]*mUnmagx2[0]) mUnmagx2[0] = 10.0*floor(1+0.1*(w+2*Padding))/size[0];
 	
 	this->SetPosition2(mUnmagx2[0]*mag,mUnmagx2[1]*mag);
 
+	this->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+	this->GetCaptionTextProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+	this->GetOverlayHelper()->UpdateTextProperty(this->GetCaptionTextProperty());
 	ret = this->vtkCaptionActor2D::RenderOpaqueGeometry(viewport);
 	
 	//
@@ -322,7 +323,6 @@ int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 				pts->SetPoint(0,p1);
 				pts->SetPoint(1,minPt[0],minPt[1],0.0);
 			}
-			
 		}
 		else
 		{
@@ -330,7 +330,7 @@ int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 			//  Shift positions if under magnification - 
 			//
 			int winij[2];
-			this->ComputePositionShiftsUnderMagnification(winij);
+			mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
 
 			pts = mLeaderPolyData->GetPoints();
 		}
@@ -338,8 +338,8 @@ int iCaption::RenderOpaqueGeometry(vtkViewport* viewport)
 		//
 		// assign properties
 		//
-		mBorderActor->SetProperty(this->GetProperty());
-		if(mLeader3D) mLeaderActor3D->GetProperty()->SetColor(this->GetProperty()->GetColor()); else mLeaderActor2D->GetProperty()->SetColor(this->GetProperty()->GetColor());
+		mBorderActor->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+		if(mLeader3D) mLeaderActor3D->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK()); else mLeaderActor2D->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 		
 	}
 	
