@@ -34,10 +34,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icolor.h"
 #include "icontrolmodule.h"
 #include "idatareader.h"
+#include "idirectory.h"
 #include "ierror.h"
 #include "ierrorstatus.h"
 #include "ifile.h"
 #include "iobjecthelp.h"
+#include "ishell.h"
 #include "ishellfactory.h"
 #include "istring.h"
 #include "iviewmodule.h"
@@ -50,10 +52,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibasescriptmacro.h"
 
 
-#define curScript		iPointerCast<iControlScript,iScript>(me)
-#define curRender		iPointerCast<iControlScript,iScript>(me)->mRender
-#define curControl		iPointerCast<iControlScript,iScript>(me)->GetControlModule()
-#define curVisual		iPointerCast<iControlScript,iScript>(me)->GetControlModule()->GetViewModule()
+#define curScript		iRequiredCast<iControlScript>(INFO,me)
+#define curRender		curScript->mAutoRender
+#define curControl		curScript->GetControlModule()
+#define curVisual		curScript->GetControlModule()->GetViewModule()
 
 
 namespace iControlScript_Private
@@ -74,23 +76,37 @@ namespace iControlScript_Private
 	}
 
 	template<class T>
-	iValue* CreateValueFromKeyData(T *data, iControlScript *me, int d)
+	iValue* CreateValueFromKeyData(T *data, iControlScript *me, int d, int index)
 	{
 		int i;
 		iValue *val;
 
 		if(data == 0) 
 		{
-			me->GetErrorStatus()->Set("The value of this property is not currently available.");
-			return 0;
+			if(d == 0)
+			{
+				//
+				//  Empty array
+				//
+				val = iValue::New(me,"",iValue::_ByValue,d,iValue::New(me,"",iValue::_ByValue,1),0);
+				me->GetErrorStatus()->Clear();  // clean errors accumulated earlier
+				return val;
+			}
+			else
+			{
+				me->GetErrorStatus()->Set("The value of this property is not currently available.");
+				return 0;
+			}
 		}
 
-		if(d == 1)
+		if(d == 1) index = 0;
+
+		if(index>=0 && index<d)
 		{
 			//
 			//  Return the single value
 			//
-			val = iValue::New(me,"",iValue::_ByValue,data[0]);
+			val = iValue::New(me,"",iValue::_ByValue,data[index]);
 		}
 		else
 		{
@@ -145,11 +161,12 @@ using namespace iParameter;
 
 iControlScript* iControlScript::New(iControlModule *cm, iScript *parent)
 {
+	IERROR_ASSERT(cm);
 	return iShellFactory::CreateControlScript(cm,parent);
 }
 
 
-iControlScript::iControlScript(iControlModule *cm, iScript *parent) : iBaseScript(parent), iControlModuleComponent(cm)
+iControlScript::iControlScript(iControlModule *cm, iScript *parent) : iBaseScript(parent), mControlModule(cm)
 {
 	//
 	//  Alias words (shortcuts)
@@ -173,6 +190,12 @@ iControlScript::iControlScript(iControlModule *cm, iScript *parent) : iBaseScrip
 	this->CreateAliasWord(".eo","exec-all-objects"); 
 	this->CreateAliasWord(".ew","exec-all-windows"); 
 
+	//
+	//  Backward compatibility
+	//
+	this->CreateAliasWord("Vector","VectorField"); 
+	this->CreateAliasWord("Tensor","TensorField"); 
+
 	//
 	//  Parameter words
 	//
@@ -217,7 +240,7 @@ iControlScript::iControlScript(iControlModule *cm, iScript *parent) : iBaseScrip
 	//
 	this->CreateCommandWord(iOperation::New(this,"","render",1,iValue::_Absolute,iValue::NewBool(this),iControlScript::Render,(unsigned char)1));
 
-	mRender = true;
+	mAutoRender = true;
 }
 
 
@@ -233,30 +256,60 @@ iValue* iControlScript::TransformUnknownTokenToValue(const iString &v, bool /*ac
 {
 	if(v.Find(iObjectKey::PrefixSeparator()) < 0) return 0; // is not even in a key format
 
+	this->GetErrorStatus()->Clear();  // clean errors accumulated earlier
+
 	const iObjectKey *key = iObjectKeyRegistry::FindKey(v,true);
 	if(key != 0)
 	{
-		int d = key->Dimension();
+		int index, d = key->Dimension();
 
 		if(d <= 0)
 		{
 			iString s;
-			this->GetControlModule()->QueryValueAsString(*key,s);
-			this->GetErrorStatus()->Clear();  // clean errors accumulated earlier
-			return iValue::New(this,"",iValue::_ByValue,s);
+			if(this->GetControlModule()->QueryValueAsString(*key,s))
+			{
+				int n = s.Contains(iObjectKey::FieldSeparator()) - 1;
+				if(d<0 || n<1)
+				{
+					return iValue::New(this,"",iValue::_ByValue,s);
+				}
+				else
+				{
+					//
+					//  Arrays w/o bound checking
+					//
+					d = n;
+				}
+			}
+			else
+			{
+				//
+				//  This key is missing - that can only be if it is an empty array
+				//
+				d = 0;
+			}
+		}
+
+		key->FindInString(v,index);
+
+		if(index<-1 || index>=d)
+		{
+			this->GetErrorStatus()->Set("Index is out of range.");
+			return 0;
 		}
 
 		switch(key->Argument())
 		{
 		case iObjectKey::_Int:
+		case iObjectKey::_OffsetInt:
 			{
 				int *data = QueryKeyData(0,key,this,d);
-				return CreateValueFromKeyData(data,this,d);
+				return CreateValueFromKeyData(data,this,d,index);
 			}
 		case iObjectKey::_Bool:
 			{
 				bool *data = QueryKeyData(false,key,this,d);
-				return CreateValueFromKeyData(data,this,d);
+				return CreateValueFromKeyData(data,this,d,index);
 			}
 		case iObjectKey::_Float:
 			{
@@ -275,17 +328,17 @@ iValue* iControlScript::TransformUnknownTokenToValue(const iString &v, bool /*ac
 					}
 					delete [] data;
 				}
-				return CreateValueFromKeyData(ddata,this,d);
+				return CreateValueFromKeyData(ddata,this,d,index);
 			}
 		case iObjectKey::_Double:
 			{
 				double *data = QueryKeyData(0.0,key,this,d);
-				return CreateValueFromKeyData(data,this,d);
+				return CreateValueFromKeyData(data,this,d,index);
 			}
 		case iObjectKey::_Color:
 			{
 				int *idata = 0;
-				iColor *data = QueryKeyData(iColor(),key,this,d);
+				iColor *data = QueryKeyData(iColor::Black(),key,this,d);
 				if(data != 0)
 				{
 					//
@@ -299,12 +352,12 @@ iValue* iControlScript::TransformUnknownTokenToValue(const iString &v, bool /*ac
 					}
 					delete [] data;
 				}
-				return CreateValueFromKeyData(idata,this,d);
+				return CreateValueFromKeyData(idata,this,d,index);
 			}
 		case iObjectKey::_String:
 			{
 				iString *data = QueryKeyData(iString(),key,this,d);
-				return CreateValueFromKeyData(data,this,d);
+				return CreateValueFromKeyData(data,this,d,index);
 			}
 		default:
 			{
@@ -362,19 +415,19 @@ iValue* iControlScript::TransformUnknownTokenToValue(const iString &v, bool /*ac
 //
 void iControlScript::Exec(iScript *me, iValue *v0, iValue::Assignment)
 {
-	ExecBody(me,v0,_ObjectModeCurrent|_ModuleModeCurrent|_RenderModeAuto);
+	ExecBody(me,v0,_ObjectOptionOne|_ModuleOptionOne|_RenderOptionAuto);
 }
 
 
 void iControlScript::ExecAllObjects(iScript *me, iValue *v0, iValue::Assignment)
 {
-	ExecBody(me,v0,_ObjectModeAll|_ModuleModeCurrent|_RenderModeAuto);
+	ExecBody(me,v0,_ObjectOptionAll|_ModuleOptionOne|_RenderOptionAuto);
 }
 
 
 void iControlScript::ExecAllWindows(iScript *me, iValue *v0, iValue::Assignment)
 {
-	ExecBody(me,v0,_ObjectModeAll|_ModuleModeAll|_RenderModeAuto);
+	ExecBody(me,v0,_ObjectOptionAll|_ModuleOptionAll|_RenderOptionAuto);
 }
 
 
@@ -407,7 +460,7 @@ void iControlScript::ExecBody(iScript *me, iValue *v0, int mode)
 		val = curScript->TransformToValue(tmp);
 		if(val == 0)
 		{
-			me->GetErrorStatus()->Set(curScript->GetErrorStatus()->GetMessage() + " in position " + iString::FromNumber(i1));
+			me->GetErrorStatus()->Set(curScript->GetErrorStatus()->Message() + " in position " + iString::FromNumber(i1));
 			return;
 		}
 		v.Replace(i1,i2-i1+1,val->GetValueAsText());
@@ -418,9 +471,10 @@ void iControlScript::ExecBody(iScript *me, iValue *v0, int mode)
 	//
 	//  Execute the command
 	//
-	if(!curControl->Execute(v,curRender,mode))
+	me->GetErrorStatus()->Monitor(curControl->GetErrorStatus());
+	if(!curControl->Execute(v,curRender,mode) && curControl->GetErrorStatus()->NoError())
 	{
-		me->GetErrorStatus()->Set("Incorrect command syntax.");
+		me->GetErrorStatus()->Set("Incorrect command syntax or invalid parameter.");
 	}
 }
 
@@ -435,7 +489,7 @@ void iControlScript::Show(iScript *me, iValue *v0, iValue::Assignment)
 	const iObjectType *tmp = iObjectTypeRegistry::FindType(v);
 	if(tmp != 0)
 	{
-		curControl->Show(*tmp,true);
+		curControl->Show(*tmp,true,curRender);
 	}
 	else
 	{
@@ -452,7 +506,7 @@ void iControlScript::Hide(iScript *me, iValue *v0, iValue::Assignment)
 	const iObjectType *tmp = iObjectTypeRegistry::FindType(v);
 	if(tmp != 0)
 	{
-		curControl->Show(*tmp,false);
+		curControl->Show(*tmp,false,curRender);
 	}
 	else
 	{
@@ -561,12 +615,18 @@ void iControlScript::Current(iScript *me, iValue *v0, iValue::Assignment)
 	int v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
 
-	curControl->SetCurrentViewModuleIndex(v);
+	if(!curControl->SetCurrentViewModuleIndex(v-1))
+	{
+		me->GetErrorStatus()->Set("Incorrect ViewModule index.");
+	}
 }
 
 
 void iControlScript::Animate(iScript *me, iValue *v0, iValue::Assignment)
 {
+	static const iString all("/all");
+	static const iString clones("/clones");
+
 	if(curScript->mParent != 0) return;
 
 	if(!curVisual->GetReader()->IsFileAnimatable())
@@ -578,13 +638,9 @@ void iControlScript::Animate(iScript *me, iValue *v0, iValue::Assignment)
 	iString v;
 	IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
 
-	if(v.IsEmpty())
+	if(!v.IsEmpty() && v!=all && v!=clones)
 	{
-		curVisual->GetAnimator()->SetUseScript(false);
-	}
-	else
-	{
-		if(v[0] == '+') v = curControl->GetFileName(_EnvironmentBase,v.Part(1));
+		iDirectory::ExpandFileName(v,curControl->GetShell()->GetEnvironment(_EnvironmentBase));
 
 		iFile f(v);
 		if(!f.Open(iFile::_Read,iFile::_Text))
@@ -607,8 +663,27 @@ void iControlScript::Animate(iScript *me, iValue *v0, iValue::Assignment)
 		curVisual->GetAnimator()->SetUseScript(true);
 	}
 
-	me->GetErrorStatus()->Monitor(curVisual->GetAnimator());
+	if(v == all)
+	{
+		int i, n = curControl->GetNumberOfViewModules();
+		for(i=0; i<n; i++)
+		{
+			curVisual->GetAnimator()->AddFollower(curControl->GetViewModule(i)->GetAnimator());
+		}
+	}
+		
+	if(v == clones)
+	{
+		int i, n = curControl->GetNumberOfViewModules();
+		for(i=0; i<n; i++) if(curControl->GetViewModule(i)->IsClone(curVisual))
+		{
+			curVisual->GetAnimator()->AddFollower(curControl->GetViewModule(i)->GetAnimator());
+		}
+	}
+		
+	me->GetErrorStatus()->Monitor(curVisual->GetAnimator()->GetErrorStatus());
 	curVisual->GetAnimator()->Animate();
+	curVisual->GetAnimator()->RemoveAllFollowers();
 }
 
 
@@ -630,7 +705,7 @@ void iControlScript::EmbedAnimatorScript(iScript *me, iValue *v0, iValue::Assign
 	//
 	v.Replace("%%","\n");
 
-	me->GetErrorStatus()->Monitor(curVisual->GetAnimator());
+	me->GetErrorStatus()->Monitor(curVisual->GetAnimator()->GetErrorStatus());
 	curVisual->GetAnimator()->GetScript()->SetText(v);
 	curVisual->GetAnimator()->SetUseScript(true);
 	curScript->mAllowChildAccess = true;
