@@ -75,8 +75,9 @@ void iDataSyncRequest::Set(int var, const iDataInfo &info)
 //
 //  Main class
 //
-iDataConsumer::iDataConsumer(iViewModule *vm, const iDataType &type) : iViewModuleComponent(vm), mPrimaryDataInfo(new iDataInfo(type))
+iDataConsumer::iDataConsumer(iViewModule *vm, const iDataType &type) : mViewModule(vm), mPrimaryDataInfo(new iDataInfo(type))
 {
+	IERROR_ASSERT(vm);
 	IERROR_ASSERT(mPrimaryDataInfo);
 	mSecondaryDataInfo = new iDataInfo; IERROR_ASSERT(mSecondaryDataInfo);
 	mModeLocal = mModeGlobal;
@@ -100,7 +101,7 @@ iDataConsumer::~iDataConsumer()
 	{
 #ifdef I_DEBUG
 #ifdef IVTK_4
-		IERROR_REPORT("Not all DataHandlers have been deleted.");
+		IERROR_LOW("Not all DataHandlers have been deleted.");
 #endif
 #endif
 	}
@@ -131,7 +132,7 @@ const iDataType& iDataConsumer::GetDataType() const
 }
 
 
-bool iDataConsumer::IsDataPresent() const
+bool iDataConsumer::IsThereData() const
 {
 	return this->GetViewModule()->GetReader()->IsThereData(this->GetDataType());
 }
@@ -139,7 +140,7 @@ bool iDataConsumer::IsDataPresent() const
 
 vtkDataSet* iDataConsumer::GetData() const
 {
-	return this->GetViewModule()->GetReader()->GetOutput(this->GetDataType());
+	return this->GetViewModule()->GetReader()->GetData(this->GetDataType());
 }
 
 
