@@ -33,6 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "idatastretch.h"
 #include "idatasubject.h"
+#include "ifileloader.h"
 #include "iviewmodule.h"
 
 //
@@ -44,19 +45,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-iDataLimits::iDataLimits(const iDataSubject *subject, int num, const iString &name, bool resizable, bool namesfixed) : mSubject(subject), mVars(0), mVarsBackup(0), mListedVars(Var()), mIsResizable(resizable), mAreNamesFixed(namesfixed), mMinNumListed(num)
+iDataLimits* iDataLimits::New(const iDataSubject *subject, int num, const iString &name)
+{
+	IERROR_ASSERT(subject);
+	return new iDataLimits(subject,num,name,true,false);
+}
+
+
+iDataLimits::iDataLimits(const iDataSubject *subject, int num, const iString &name, bool resizable, bool namesfixed) : mSubject(subject), mIsResizable(resizable), mAreNamesFixed(namesfixed), mMinNumListed(num)
 {
 	IERROR_ASSERT(mSubject);
 	if(num < 1) 
 	{
-		IERROR_FINISH("Number of vars must be > 0.");
+		IERROR_FATAL("Number of vars must be > 0.");
 	}
 
 	mBlockChecking = false;
 	mBlockNotifications = true; // must block here to avoid a loop
 
-	mNamePrefix = name + " ";
-
 	this->Configure(num,name);  
 	this->AssignVars();  // assign all when there is no data present
 
@@ -103,6 +109,8 @@ void iDataLimits::RestoreVars()
 
 void iDataLimits::Configure(int num, const iString &name)
 {
+	mNamePrefix = name + " ";
+
 	if(num > 0)
 	{
 		while(mListedVars.Size() > num)
@@ -114,7 +122,14 @@ void iDataLimits::Configure(int num, const iString &name)
 		{
 			Var tmp;
 			tmp.Included = true;
-			tmp.Name = mNamePrefix + iString::FromNumber(mListedVars.Size()+1);
+			if(num > 1)
+			{
+				tmp.Name = mNamePrefix + iString::FromNumber(mListedVars.Size()+1);
+			}
+			else
+			{
+				tmp.Name = name;
+			}
 			tmp.Stretch = 0;
 			tmp.Min = 0.1f;
 			tmp.Max = 10.0f;
@@ -173,7 +188,7 @@ int iDataLimits::Invalid(int v) const
 {
 	if(!mBlockChecking)
 	{
-		IERROR_REPORT("Invalid access to a DataLimits member.");
+		IERROR_LOW("Invalid access to a DataLimits member.");
 	}
 	return v;
 }
@@ -183,7 +198,7 @@ float iDataLimits::Invalid(float v) const
 {
 	if(!mBlockChecking)
 	{
-		IERROR_REPORT("Invalid access to a DataLimits member.");
+		IERROR_LOW("Invalid access to a DataLimits member.");
 	}
 	return v;
 }
@@ -193,7 +208,7 @@ const iString& iDataLimits::Invalid(const iString &v) const
 {
 	if(!mBlockChecking)
 	{
-		IERROR_REPORT("Invalid access to a DataLimits member");
+		IERROR_LOW("Invalid access to a DataLimits member");
 	}
 	return v;
 }
@@ -223,8 +238,8 @@ void iDataLimits::AdjustMinMax(Var &v)
 		
 	if(v.UpperLimit > v.Max) v.UpperLimit = v.Max;
 	if(v.UpperLimit < v.Min) v.UpperLimit = v.Min;
-	if(v.LowerLimit > v.Max) v.LowerLimit = v.Max;
 	if(v.LowerLimit < v.Min) v.LowerLimit = v.Min;
+	if(v.LowerLimit > v.Max) v.LowerLimit = v.Max;
 }
 
 
@@ -317,38 +332,8 @@ void iDataLimits::UpdateLowerLimit(float v, int n, float &ll, float &ul)
 }
 
 
-void iDataLimits::RestoreNames()
-{
-	int i;
-	for(i=0; i<mVars.Size(); i++) mVars[i]->Name = mVars[i]->NameSaved;
-	this->NotifyDependencies(-1);
-}
-
-
-void iDataLimits::RestoreLimits()
-{
-	int i;
-    for(i=0; i<mVars.Size(); i++)
-    {
-		mVars[i]->Max = mVars[i]->MaxSaved;
-		mVars[i]->Min = mVars[i]->MinSaved;
-		this->SetUpperLimit(i,mVars[i]->UpperLimit);
-		this->SetLowerLimit(i,mVars[i]->LowerLimit);
-		if(fabs(mVars[i]->UpperLimit-mVars[i]->LowerLimit)/(1.0e-36f+fabs(mVars[i]->UpperLimit)+fabs(mVars[i]->LowerLimit)) < 1.0e-5f)
-		{
-			mVars[i]->LowerLimit = mVars[i]->Min;
-			mVars[i]->UpperLimit = mVars[i]->Max;
-		}
-	}
-	this->NotifyDependencies(-1);
-}
-
-
 void iDataLimits::Initialize(Var &v)
 {
-	v.MinSaved = v.Min;
-	v.MaxSaved = v.Max;
-	v.NameSaved = v.Name;
 	v.LowerLimit = v.Min;
 	v.UpperLimit = v.Max;
 }
@@ -357,13 +342,13 @@ void iDataLimits::Initialize(Var &v)
 void iDataLimits::GetPeriodicities(bool per[3]) const
 {
 	int i;
-	for(i=0; i<3; i++) per[i] = mSubject->IsDirectionPeriodic(i);
+	for(i=0; i<3; i++) per[i] = mSubject->GetLoader()->IsDirectionPeriodic(i);
 }
 
 
 bool iDataLimits::IsBoxPeriodic() const
 {
-	return mSubject->IsBoxPeriodic();
+	return mSubject->GetLoader()->IsBoxPeriodic();
 }
 
 
