@@ -30,25 +30,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IDATALIMITS_H
 
 
+#include <vtkObjectBase.h>
+
+
 #include "iarray.h"
 #include "imath.h"
 #include "iparameter.h"
 #include "istring.h"
 
+#include <vtkSetGet.h>
 
 class iDataSubject;
 class iDataType;
 
 
-class iDataLimits
+class iDataLimits : public vtkObjectBase
 {
 
 	friend class iDataSubject;
 
 public:
 	
-	iDataLimits(const iDataSubject *subject, int num, const iString &name, bool resizable = true, bool namesfixed = false);
-	virtual ~iDataLimits();
+	vtkTypeMacro(iDataLimits,vtkObjectBase);
+	static iDataLimits* New(const iDataSubject *subject = 0, int num = 0, const iString &name = "");
 
 	int GetNumVars() const;
 	int GetStretch(int n) const;
@@ -60,7 +64,7 @@ public:
 	const iString& GetUnit(int n) const;
 	bool GetFixedStretch(int n) const;
 	int GetClass(int n) const;
-	const iString& GetClassName(int n) const;
+	const iString& GetNameForClass(int n) const; // GetClassName conflicts with something under VC++
 
 	void SetMax(int n, float v);
 	void SetMin(int n, float v);
@@ -68,8 +72,6 @@ public:
 	void SetStretch(int n, int v);
 	void SetUpperLimit(int n, float v);
 	void SetLowerLimit(int n, float v);
-	void RestoreNames();
-	void RestoreLimits();
 
 	void ResetVars();
 	void AddVar(int n);
@@ -104,14 +106,16 @@ public:
 
 protected:
 	
+	iDataLimits(const iDataSubject *subject, int num, const iString &name, bool resizable, bool namesfixed);
+	virtual ~iDataLimits();
+
 	struct Var
 	{
 		bool Included, FixedStretch;
 		float Min, Max;
-		float MinSaved, MaxSaved;
 		float LowerLimit, UpperLimit;
 		int Stretch, Class;
-		iString Name, NameSaved, Unit, ClassName;
+		iString Name, Unit, ClassName;
 	};
 
 	virtual void NotifyDependencies(int var);
@@ -203,7 +207,7 @@ inline int iDataLimits::GetClass(int n) const
 }
 
 
-inline const iString& iDataLimits::GetClassName(int n) const
+inline const iString& iDataLimits::GetNameForClass(int n) const
 {
 	static const iString null;
 	if(n>=0 && n<mVars.Size()) return mVars[n]->ClassName; else return this->Invalid(null);
