@@ -52,8 +52,13 @@ namespace iExpressionParser_Private
 
 using namespace iExpressionParser_Private;
 
+iExpressionParser* iExpressionParser::New()
+{
+	return new iExpressionParser;
+}
 
-iExpressionParser::iExpressionParser() : mScalarVariables(Scalar()), mVectorVariables(Vector()), mStack(0.0), mByteCode(0), mBytePosition(0), mImmediates(0.0)
+
+iExpressionParser::iExpressionParser()
 {
 	mStackSize = mStackPointer = 0;
 	mErrorByteCode = mErrorPosition = -1;
@@ -67,6 +72,12 @@ iExpressionParser::~iExpressionParser()
 }
 
 
+void iExpressionParser::Delete()
+{
+	delete this;
+}
+
+
 void iExpressionParser::SetFunction(const iString &function)
 {
 	mFunction = function;
