@@ -107,7 +107,7 @@ bool iFile::Open(OpenMode mode, OpenType type)
 
 	if(mode & _Append) 
 	{
-		om = ios::app;  // append is exclusive
+		om = ios::out | ios::app;  // append is exclusive
 #ifndef VTK_USE_ANSI_STDLIB
 		om |= !ios::nocreate;
 #endif
@@ -158,10 +158,10 @@ bool iFile::ReadLine(iString &s, int max)
 }
 
 
-bool iFile::ReadBlock(char *p, unsigned long length)
+bool iFile::ReadBlock(void *p, unsigned long length)
 {
 	mStream->clear();
-	mStream->read(p,length);
+	mStream->read((char *)p,length);
 	return (mStream->fail()==0 && mStream->eof()==0);
 }
 
@@ -192,12 +192,21 @@ bool iFile::Rewind()
 }
 
 
-bool iFile::IsLoadable(const iString &name)
+bool iFile::IsReadable(const iString &name)
 {
 	iFile F(name);
-	bool ret = F.Open(_Read,_Text);
-	if(ret) F.Close();
-	return ret;
+	if(!F.Open(_Read,_Text)) return false;
+	F.Close();
+	return true;
+}
+
+
+bool iFile::IsWritable(const iString &name)
+{
+	iFile F(name);
+	if(!F.Open(_Append,_Text)) return false;
+	F.Close();
+	return true;
 }
 
 
