@@ -36,6 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubjectcomponent.h"
 
 
+#include "ierror.h"
 #include "ivtk.h"
 
 
@@ -53,7 +54,7 @@ class iGenericSource : public Source, public iViewSubjectComponent
 
 #ifndef IVTK_4
 protected:
-	virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
+	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
 
 	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
 
@@ -71,7 +72,7 @@ public:
 protected:
 
 	iGenericSource(iViewSubject *vo, bool usesLimits);
-	virtual ~iGenericSource(){}
+	virtual ~iGenericSource();
 
 	virtual void ExecuteData(vtkDataObject *output);
 	void ExecuteParent();
@@ -97,8 +98,8 @@ protected:
 	virtual void ExecuteInformation();
 #else
 protected:
-	virtual int ProcessRequest(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
-	virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
+	virtual int ProcessRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
 
 	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
 
@@ -116,7 +117,7 @@ public:
 protected:
 
 	iGenericFilter(iViewSubject *vo, int numInputs, bool ownsOutput, bool usesLimits);
-	virtual ~iGenericFilter(){}
+	virtual ~iGenericFilter();
 
 	virtual void ExecuteData(vtkDataObject *output);
 	void ExecuteParent();
@@ -160,9 +161,10 @@ protected:
 //
 //  Useful macro
 //
-#define IGENERICFILTER_DECLARE(_name_) \
+#define IGENERICFILTER_DECLARE(_name_,_parent_) \
 	public: \
-		static _name_* New(iViewSubject *vo) { return new _name_(vo); } \
+		vtkTypeMacro(_name_,_parent_); \
+		static _name_* New(iViewSubject *vo = 0) { IERROR_ASSERT(vo); return new _name_(vo); } \
 	protected: \
 		_name_(iViewSubject *vo);
 
