@@ -30,145 +30,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IIMAGECOMPOSER_H
 
 
-#include "iviewmodulecomponent.h"
-#include "ierrorstatusholder.h"
-#include "ideletable.h"
+#include "iobject.h"
 
 
 #include "iarray.h"
-#include "icolor.h"
-#include "iimage.h"
-#include "istring.h"
-
-class iImageComposer;
-class iShell;
-
-//
-//  Helper classes
-//
-
-class iImageComposerWindow : public iViewModuleComponent, public iDeletable
-{
-
-public:
-	
-	enum iImageComposerWindowType
-	{
-		UNDEFINED = 0,
-		BACKGROUND = 1,
-		FOREGROUND = 2
-	};
-	
-	void SetViewModule(iViewModule *vm);
-	inline iImageComposerWindowType GetType() const { return mType; }
-	inline const iImageComposer* GetImageComposer() const { return mComposer; }
-
-protected:
-
-	iImageComposerWindow(iViewModule *vm, iImageComposer *ic) : iViewModuleComponent(vm)
-	{ 
-		mType = UNDEFINED;
-		mComposer = ic;
-	}
-	virtual ~iImageComposerWindow(){}
-
-	iImageComposer *mComposer;
-	iImageComposerWindowType mType;
-};
-
-
-class iImageComposerBackgroundWindow : public iImageComposerWindow
-{
-
-public:
-
-	static iImageComposerBackgroundWindow* New(int tx, int ty, iImageComposer *ic);
-
-	inline bool IsEmpty() const { return (this->GetViewModule()==0 && mWallpaperImage.IsEmpty()); }
-
-	int GetWidth() const;
-	int GetHeight() const;
-	int GetTileX() const { return mTileX; }
-	int GetTileY() const { return mTileY; }
-	const iString& GetWallpaperFile() const { return mWallpaperFile; }
-	const iImage& GetWallpaperImage() const { return mWallpaperImage; }
-
-	bool LoadWallpaperImage(const iString &s);
-	
-protected:
-
-	iImageComposerBackgroundWindow(int tx, int ty, iImageComposer *ic);
-	virtual ~iImageComposerBackgroundWindow(){}
-
-	int mTileX, mTileY;
-	iImage mWallpaperImage;
-	iString mWallpaperFile;
-};
-
-
-class iImageComposerForegroundWindow : public iImageComposerWindow
-{
-
-public:
-
-	static iImageComposerForegroundWindow* New(iViewModule *vm, iImageComposer *ic);
-
-	inline bool IsEmpty() const { return (this->GetViewModule() == 0); }
-	inline float GetScale() const { return mScale; }
-	inline int GetPositionX() const { return mPosX; }
-	inline int GetPositionY() const { return mPosY; }
-	inline int GetBorderWidth() const { return mBorderWidth; }
-	inline iColor GetBorderColor() const { return mBorderColor; }
-
-	int GetWidth() const;
-	int GetHeight() const;
-	int GetScaledWidth() const;
-	int GetScaledHeight() const;
-	inline int GetImageWidth() const { return 2*mBorderWidth + this->GetScaledWidth(); }
-	inline int GetImageHeight() const { return 2*mBorderWidth + this->GetScaledHeight(); }
-	
-	void SetScale(float s);
-	void SetPosition(int x, int y);
-	void SetPositionX(int x);
-	void SetPositionY(int y);
-	void SetBorderWidth(int w);
-	void SetBorderColor(const iColor& c);
-
-	void CorrectPosition();
-
-protected:
-
-	iImageComposerForegroundWindow(iViewModule *vm, iImageComposer *ic);
-	virtual ~iImageComposerForegroundWindow(){}
-
-	float mScale;
-	iColor mBorderColor;
-	int mBorderWidth;
-	int mPosX, mPosY;
-	
-	static int mPosQuantum;
-};
-
-//
-//  Main class
-//
-#include "iobject.h"
-#include "icontrolmodulecomponent.h"
-#include "ishellcomponent.h"
 
+class iControlModule;
+class iImageComposerWindow;
+class iImageComposerBackgroundWindow;
+class iImageComposerForegroundWindow;
+//class iShell;
 class iStereoImageArray;
+class iViewModule;
 
 
-class iImageComposer : public iObject, public iControlModuleComponent, public iShellComponent, public iErrorStatusHolder, public iDeletable
+class iImageComposer : public iObject
 {
 
-	friend class iShellFactory;
+	IPOINTER_AS_PART(ControlModule);
 
 public:
 
-	IOBJECT_DECLARE_SELF(iImageComposer,iObject);
-
-	static iImageComposer* New(iControlModule *cm, iShell *s);
+	vtkTypeMacro(iImageComposer,iObject);
+	static iImageComposer* New(iControlModule *cm = 0);
 	static const iObjectType& Type();
 
 	IOBJECT_DECLARE_GETSET1(ScaleBackground,bool);
@@ -186,7 +70,8 @@ public:
 	int GetNumTilesY() const { return mNumTilesY; }
 	static const iObjectKey& KeyNumTiles();
 
-	int GetNumForegroundWindows() const { return mForegroundWindow.Size(); }
+	int GetNumberOfBackgroundWindows() const { return mBackgroundWindows.Size(); }
+	int GetNumberOfForegroundWindows() const { return mForegroundWindows.Size(); }
 	static const iObjectKey& KeyNumForegroundWindows();
 
 	inline iImageComposerBackgroundWindow* GetBackgroundWindow(int i, int j) const
@@ -202,21 +87,32 @@ public:
 	void MoveToBack(int n);
 
 	//
-	//  Useful keys for command-interface 
+	//  Useful keys for command-line interface 
 	//
 	static const iObjectKey& KeyBackgroundWindowViewModule();
+	static const iObjectKey& KeyBackgroundWindowViewModule2();
+	static const iObjectKey& KeyBackgroundWindowViewModule3();
 	static const iObjectKey& KeyBackgroundWindowWallpaperFile();
 
 	static const iObjectKey& KeyForegroundWindowViewModule();
+	static const iObjectKey& KeyForegroundWindowViewModule2();
+	static const iObjectKey& KeyForegroundWindowViewModule3();
 	static const iObjectKey& KeyForegroundWindowPositionX();
 	static const iObjectKey& KeyForegroundWindowPositionY();
 	static const iObjectKey& KeyForegroundWindowScale();
 	static const iObjectKey& KeyForegroundWindowBorderWidth();
 	static const iObjectKey& KeyForegroundWindowBorderColor();
 
+	static const iObjectKey& KeyForegroundWindowZoomSource();
+	static const iObjectKey& KeyForegroundWindowZoom4Line();
+	static const iObjectKey& KeyForegroundWindowZoomHeight();
+	static const iObjectKey& KeyForegroundWindowZoomX();
+	static const iObjectKey& KeyForegroundWindowZoomY();
+
 	//
 	//  Other functions
 	//
+	inline bool InComposing() const { return mInComposing; }
 	void Compose(iViewModule *vm, iStereoImageArray &images);
 	bool IsActive();
 
@@ -226,14 +122,18 @@ public:
 
 protected:
 
-	iImageComposer(iControlModule *cm, iShell *s);
 	virtual ~iImageComposer();
 
+private:
+
+	iImageComposer(iControlModule *cm);
+
 	virtual void PackStateBody(iString &s) const;
 	virtual void UnPackStateBody(const iString &s);
 
-	bool mBlockUpdate;
+	void UnPackingHelper(int n, int j, iImageComposerWindow **win, int *itmp, const iObjectKey &key, const iString &s);
 
+	bool mBlockUpdate, mInComposing;
 	bool mInnerBorder, mScaleBackground;
 	iColor mBorderColor;
 	int mBorderWidth;
@@ -241,24 +141,9 @@ protected:
 	int mTileWidth, mTileHeight;
 	int mNumTilesX, mNumTilesY;
 
-	iImageComposerBackgroundWindow** mBackgroundWindow;
-
-	iArray<iImageComposerForegroundWindow*> mForegroundWindow;
+	iArray<iImageComposerBackgroundWindow*> mBackgroundWindows;
+	iArray<iImageComposerForegroundWindow*> mForegroundWindows;
 };
 
-
-inline void iImageComposerForegroundWindow::SetPositionX(int x)
-{
-	this->SetPosition(x,mPosY);
-	mComposer->ClearCache();
-}
-
-
-inline void iImageComposerForegroundWindow::SetPositionY(int y)
-{
-	this->SetPosition(mPosX,y);
-	mComposer->ClearCache();
-}
-
 #endif // IIMAGECOMPOSER_H
 
