@@ -96,7 +96,7 @@ namespace iMath
 	const float _LargeFloat = 1.0e36f;
 	const int _LargeInt = _IntMax - 777;
 	const float _FloatTolerance = 10.0f*_FloatRes;
-	const double _DoubleTolerance = 10.0*_DoubleRes;
+	const double _DoubleTolerance = 30.0*_DoubleRes;
 
 
 	inline float Deg2Rad(float x)
@@ -173,6 +173,8 @@ namespace iMath
 	{
 		return (v < 0) ? -v : v;
 	}
+
+	bool Intersect3Planes(double *p1, double *p2, double *p3, double *x);
 }
 
 //
@@ -180,7 +182,6 @@ namespace iMath
 //
 #define deg2rad(x)		iMath::Deg2Rad(x)
 #define round(x)		iMath::Round2Int(x)
-#define lround(x)		iMath::Round2Long(x)
 #define pow10(x)		iMath::Pow10(x)
 #define log10(x)		iMath::Log10(x)
 
