@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ierrorstatus.h"
 #include "iobjecthelp.h"
 #include "ipiecewisefunction.h"
 #include "irangecollection.h"
@@ -56,7 +57,14 @@ iObjectType::iObjectType(ClassId c, const char *fullname, const char *shortname)
 	mClass = c;
 	mFullName = fullname;
 	mShortName = shortname;
-	if(!this->IsHidden()) mHelp = new iObjectTypeHelp(this); else mHelp = 0;
+	mHelp = new iObjectTypeHelp(this);
+}
+
+
+iObjectType::iObjectType()
+{
+	mClass = _Any;
+	mHelp = 0;
 }
 
 
@@ -166,7 +174,7 @@ iObjectType::ClassId iObjectTypeRegistry::mTraversalClass = iObjectType::_Any;
 
 iArray<iObjectTypePointer>& iObjectTypeRegistry::List()
 {
-	static iOrderedArray<iObjectTypePointer> list(0,30);
+	static iOrderedArray<iObjectTypePointer> list(30);
 	return list;
 }
 
@@ -178,7 +186,7 @@ const iObjectType* iObjectTypeRegistry::CreateType(iObjectType::ClassId c, const
 	const iObjectType *k;
 	if((k=iObjectTypeRegistry::FindType(tmp->mFullName,true))!=0 || (k=iObjectTypeRegistry::FindType(tmp->mShortName,true))!=0)
 	{
-		IERROR_REPORT("Duplicate type.");
+		IERROR_LOW("Duplicate type.");
 	}
 #endif
 	//
@@ -283,14 +291,7 @@ void iObjectKey::Define(const iObjectType *type, const char *fk, const char *sk,
 	mType = type;
 	mParent = parent;
 
-	if(!this->IsHidden())
-	{
-		mHelp = new iObjectKeyHelp(this);
-	}
-	else
-	{
-		mHelp = 0;
-	}
+	mHelp = new iObjectKeyHelp(this);
 }
 
 	
@@ -311,56 +312,56 @@ bool iObjectKey::IsHidden() const
 
 const iString& iObjectKey::PrefixSeparator()
 {
-	static const iString s = ":";
+	static const iString s(":");
 	return s;
 }
 
 
 const iString& iObjectKey::FieldSeparator()
 {
-	static const iString s = "/";
+	static const iString s("/");
 	return s;
 }
 
 
 const iString& iObjectKey::SubSeparator()
 {
-	static const iString s = ";";
+	static const iString s(";");
 	return s;
 }
 
 
 const iString& iObjectKey::SubSubSeparator()
 {
-	static const iString s = ",";
+	static const iString s(",");
 	return s;
 }
 
 
 const iString& iObjectKey::Delimiter()
 {
-	static const iString s = " ";
+	static const iString s(" ");
 	return s;
 }
 
 
 const iString& iObjectKey::LeftBracket()
 {
-	static const iString s = "[";
+	static const iString s("[");
 	return s;
 }
 
 
 const iString& iObjectKey::RightBracket()
 {
-	static const iString s = "]";
+	static const iString s("]");
 	return s;
 }
 
 
 const iString& iObjectKey::SpecialSeparator()
 {
-	static const iString s = "&&";
+	static const iString s("&&");
 	return s;
 }
 
@@ -461,6 +462,67 @@ bool iObjectKey::operator<(const iObjectKey &s) const
 }
 
 
+int iObjectKey::FindFullMatch(const iString &str, const iString &pat) const
+{
+	int ind = str.Find(pat);
+	//
+	//  We have to be careful with keys - they may produce a match on just a piece
+	//  of another key. So, check that this is the complete key and not a part of 
+	//  another one. I.e., the letter just before the key must be a last letter of either 
+	//  the delimiter or the prefix separator.
+	//
+	while(ind>0 && str[ind-1]!=mLastLetterOfDelimiter && str[ind-1]!=mLastLetterOfPrefixSeparator) ind = str.Find(pat,ind+1);
+	return ind;
+}
+
+
+int iObjectKey::FindInString(const iString &str, int &index) const
+{
+	//
+	//  Search for the un-indexed key first
+	//
+	int ind = this->FindFullMatch(str,mSearchableFullKey);
+	if(ind == -1) 
+	{
+		ind = this->FindFullMatch(str,mSearchableShortKey); 
+	}
+	if(ind >= 0)  // key found
+	{
+		index = -1;
+		return ind;
+	}
+	//
+	//  repeat for the indexed key
+	//
+	ind = this->FindFullMatch(str,mSearchableIndexedFullKey);
+	if(ind == -1) ind = this->FindFullMatch(str,mSearchableIndexedShortKey); 
+	if(ind == -1) //not found
+	{
+		index = -1;
+		return ind;
+	}
+	//
+	//  Get the index
+	//
+	bool ok;
+	iString s = str.Part(ind);
+	int i1 = s.Find(LeftBracket());
+	int i2 = s.Find(RightBracket());
+	if(i1+2 > i2) // wrong order
+	{
+		index = -1;
+		return -1;
+	}
+	index = s.Part(i1+1,i2-i1-1).ToInt(ok) - 1;
+	if(!ok || index<0) // syntax error
+	{
+		index = -1;
+		return -1;
+	}
+	return ind;
+}
+
+
 //
 //  iObjectKeyRegistry implementation
 //
@@ -511,19 +573,20 @@ private:
 
 
 int iObjectKeyRegistry::mTraversalLocation = 0;
+bool iObjectKeyRegistry::mTraversalWithInherited = true;
 const iObjectType* iObjectKeyRegistry::mTraversalType = 0;
 
 
 iArray<iObjectKeyPointer>& iObjectKeyRegistry::List()
 {
-	static iOrderedArray<iObjectKeyPointer> list(0,100);
+	static iOrderedArray<iObjectKeyPointer> list(100);
 	return list;
 }
 
 
 iArray<iObjectKey*>& iObjectKeyRegistry::TempKeys()
 {
-	static iArray<iObjectKey*> list(0);
+	static iArray<iObjectKey*> list;
 	return list;
 }
 
@@ -536,7 +599,7 @@ const iObjectKey* iObjectKeyRegistry::CreateKey(const iObjectType &type, const c
 	const iObjectKey *k;
 	if((k=iObjectKeyRegistry::FindKey(tmp->mPrefixedFullKey,true))!=0 || (k=iObjectKeyRegistry::FindKey(tmp->mPrefixedShortKey,true))!=0) 
 	{
-		IERROR_REPORT("Duplicate key.");
+		IERROR_LOW("Duplicate key.");
 	}
 #endif
 	//
@@ -600,12 +663,14 @@ void iObjectKeyRegistry::ReleaseTempKey(const iObjectKey &key)
 }
 
 
-const iObjectKey* iObjectKeyRegistry::FindKey(const iString &str, bool hidden)
+const iObjectKey* iObjectKeyRegistry::FindKey(const iString &str0, bool hidden)
 {
 	int i, n;
 	const iObjectKey *p;
 	iArray<iObjectKeyPointer> &list = List();
 
+	iString str = str0.Section(iObjectKey::LeftBracket(),0,0);
+
 	n = list.Size();
 	for(i=0; i<n; i++)
 	{
@@ -622,9 +687,10 @@ const iObjectKey* iObjectKeyRegistry::FindKey(const iString &str, bool hidden)
 }
 
 
-void iObjectKeyRegistry::InitTraversal(const iObjectType *type)
+void iObjectKeyRegistry::InitTraversal(const iObjectType *type, bool inherited)
 {
 	mTraversalLocation = 0;
+	mTraversalWithInherited = inherited;
 	mTraversalType = type;
 }
 
@@ -647,7 +713,7 @@ const iObjectKey* iObjectKeyRegistry::GetNextKey(bool hidden)
 		const iObjectType &type = *mTraversalType;
 		while(mTraversalLocation < n)
 		{
-			if(list[mTraversalLocation]->Type()==type && (hidden || !list[mTraversalLocation]->IsHidden())) return list[mTraversalLocation++].GetPointer();
+			if(list[mTraversalLocation]->Type()==type && (hidden || !list[mTraversalLocation]->IsHidden()) && (mTraversalWithInherited || !list[mTraversalLocation]->IsInherited())) return list[mTraversalLocation++].GetPointer();
 			mTraversalLocation++;
 		}
 	}
@@ -675,11 +741,11 @@ void iObject::ReportMissingKeys(bool s)
 
 void iObject::ReportAMissingKey(const iObjectKey &key)
 {
-	if(mMissingKeysStack == 0) IERROR_REPORT((iString("Missing key: ")+key.PrefixedFullName()).ToCharPointer());
+	if(mMissingKeysStack == 0) IERROR_LOW((iString("Missing key: ")+key.PrefixedFullName()).ToCharPointer());
 }
 
 
-iObject::iObject()
+iObject::iObject(const iString &name) : mErrorStatus(name)
 {
 	mUnPackedSomething = false;
 	mCacheInvalid = true;
@@ -691,26 +757,6 @@ iObject::~iObject()
 }
 
 
-const iString& iObject::GetThisClassName() const
-{
-	static const iString name("iObject");
-	return name;
-}
-
-
-bool iObject::IsOfType(const iString &name) const
-{
-	static const iString thisName("iObject");
-	return (name == thisName);
-}
-
-
-void iObject::ReportBadCast(const char *self, const char *file, int line)
-{
-	iConsole::Instance()->DisplayFatalErrorMessage(("Invalid cast to "+iString(self)).ToCharPointer(),file,line);
-}
-
-
 void iObject::ClearCache()
 {
 	mCacheInvalid = true;
@@ -766,67 +812,6 @@ void iObject::CopyState(const iObject *p)
 }
 
 
-int iObject::FindFullMatch(const iString &str, const iString &pat) const
-{
-	int ind = str.Find(pat);
-	//
-	//  We have to be careful with keys - they may produce a match on just a piece
-	//  of another key. So, check that this is the complete key and not a part of 
-	//  another one. I.e., the letter just before the key must be a last letter of either 
-	//  the delimiter or the prefix separator.
-	//
-	while(ind>0 && str[ind-1]!=iObjectKey::mLastLetterOfDelimiter && str[ind-1]!=iObjectKey::mLastLetterOfPrefixSeparator) ind = str.Find(pat,ind+1);
-	return ind;
-}
-
-
-int iObject::FindUnPackKey(const iString &str, const iObjectKey &key, int &index) const
-{
-	//
-	//  Search for the un-indexed key first
-	//
-	int ind = this->FindFullMatch(str,key.mSearchableFullKey);
-	if(ind == -1) 
-	{
-		ind = this->FindFullMatch(str,key.mSearchableShortKey); 
-	}
-	if(ind >= 0)  // key found
-	{
-		index = -1;
-		return ind;
-	}
-	//
-	//  repeat for the indexed key
-	//
-	ind = this->FindFullMatch(str,key.mSearchableIndexedFullKey);
-	if(ind == -1) ind = this->FindFullMatch(str,key.mSearchableIndexedShortKey); 
-	if(ind == -1) //not found
-	{
-		index = -1;
-		return ind;
-	}
-	//
-	//  Get the index
-	//
-	bool ok;
-	iString s = str.Part(ind);
-	int i1 = s.Find(key.LeftBracket());
-	int i2 = s.Find(key.RightBracket());
-	if(i1+2>i2 || s[i2+1]!=*(key.FieldSeparator().ToCharPointer())) // wrong order or the field separator is not following the closing bracket
-	{
-		index = -1;
-		return -1;
-	}
-	index = s.Part(i1+1,i2-i1-1).ToInt(ok) - 1;
-	if(!ok || index<0) // syntax error
-	{
-		index = -1;
-		return -1;
-	}
-	return ind;
-}
-
-
 bool iObjectKey::IsArgumentCompatible(Arg a) const
 {
 	 // offset int and int have compatible types
@@ -839,14 +824,14 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	if(!this->IsArgumentCompatible(a))
 	{
 		// incompatible arguments, exit without doing anything.
-		IERROR_REPORT("Incompatible key argument.");
+		IERROR_LOW("Incompatible key argument.");
 		return true;
 	}
 
 	if(n<0 || (mDim!=0 && ((index<0 && n!=mDim) || (index>=0 && n!=1 && index>=mDim))))  //  dim = 0 disables bound checking 
 	{
 		// incorrect key index, exit without doing anything.
-		IERROR_REPORT("Incorrect key index.");
+		IERROR_LOW("Incorrect key index.");
 		return true;
 	}
 
@@ -854,7 +839,7 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	{
 		if(n == 0)
 		{
-			IERROR_REPORT("Incorrect key index.");
+			IERROR_LOW("Incorrect key index.");
 			return true;
 		}
 		imin = 0;
@@ -864,7 +849,7 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	{
 		if(mDim == 1)
 		{
-			IERROR_REPORT("Incorrect key index.");
+			IERROR_LOW("Incorrect key index.");
 			return true;
 		}
 		imin = index;
@@ -965,7 +950,7 @@ void iObject::PackValue(iString &s, const iObjectKey &key, const iString* val, i
 bool iObject::UnPackValue(const iString &s, const iObjectKey &key, int* val, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2, offset = 0;;
@@ -981,7 +966,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, int* val, int
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToInt(ok) - offset;
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(int)); else IERROR_REPORT("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(int)); else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
@@ -996,7 +981,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, int* val, int
 bool iObject::UnPackValue(const iString &s, const iObjectKey &key, bool* val, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2;
@@ -1011,7 +996,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, bool* val, in
 		{
 			v[i] = (tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToInt(ok) != 0);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else IERROR_REPORT("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
@@ -1026,7 +1011,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, bool* val, in
 bool iObject::UnPackValue(const iString &s, const iObjectKey &key, float* val, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2;
@@ -1041,7 +1026,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, float* val, i
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToFloat(ok);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(float)); else IERROR_REPORT("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(float)); else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
@@ -1056,7 +1041,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, float* val, i
 bool iObject::UnPackValue(const iString &s, const iObjectKey &key, double* val, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2;
@@ -1071,7 +1056,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, double* val,
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToDouble(ok);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(double)); else IERROR_REPORT("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(double)); else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
@@ -1087,7 +1072,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iColor* val,
 {
 	bool ok, ok1;
 	iString s1;
-	int r, g, b, index, ind = FindUnPackKey(s,key,index);
+	int r, g, b, index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2;
@@ -1106,7 +1091,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iColor* val,
 			b = s1.Section(key.SubSubSeparator(),2,2).ToInt(ok1); ok = ok && ok1;
 			v[i] = iColor(r,g,b);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(iColor)); else IERROR_REPORT("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(iColor)); else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
@@ -1121,7 +1106,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iColor* val,
 bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iString* val, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, i1, i2;
@@ -1171,7 +1156,7 @@ void iObject::PackValuePiecewiseFunction(iString &s, const iObjectKey &key, cons
 bool iObject::UnPackValuePiecewiseFunction(const iString &s, const iObjectKey &key, iPiecewiseFunction **f, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, j, i1, i2;
@@ -1207,7 +1192,7 @@ bool iObject::UnPackValuePiecewiseFunction(const iString &s, const iObjectKey &k
 			{
 				if(f[i] != 0) f[i]->Copy(v);
 			}
-			else IERROR_REPORT("Invalid key value.");
+			else IERROR_LOW("Invalid key value.");
 		}
 		v->Delete();
 	}
@@ -1243,7 +1228,7 @@ void iObject::PackValueRangeCollection(iString &s, const iObjectKey &key, const
 bool iObject::UnPackValueRangeCollection(const iString &s, const iObjectKey &key, iRangeCollection **f, int num)
 {
 	bool ok;
-	int index, ind = FindUnPackKey(s,key,index);
+	int index, ind = key.FindInString(s,index);
 	if(ind >=0)
 	{
 		int i, j, i1, i2;
@@ -1278,7 +1263,7 @@ bool iObject::UnPackValueRangeCollection(const iString &s, const iObjectKey &key
 		{
 			for(i=i1; f[i]!=0 && i<i2; i++) f[i]->Copy(v+i);
 		}
-		else IERROR_REPORT("Invalid key value.");
+		else IERROR_LOW("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
