@@ -32,7 +32,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarray.h"
 #include "ierror.h"
 #include "ieventobserver.h"
-#include "ioutputwindow.h"
 #include "iparallel.h"
 #include "iparallelworker.h"
 #include "iviewmodule.h"
@@ -45,7 +44,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkTimerLog.h>
 
 
-#if defined(I_DEBUG) && defined(I_EDITION)
+#if defined(I_DEBUG)
 #include "icontrolmodule.h"
 #include "ishell.h"
 #endif
@@ -59,6 +58,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParallel;
 
 
+#ifdef I_DEBUG
+int iParallelManager::DebugSwitch = 0;
+#endif
+
+
 //
 //  Helper classes
 //
@@ -108,7 +112,7 @@ class iParallelHelper
 
 public:
 
-	iParallelHelper() : mProcTimers(0)
+	iParallelHelper()
 	{
 		mWallTimer = 0;
 	}
@@ -255,8 +259,8 @@ namespace iParallelManager_Private
 		{
 			if(input != 0)
 			{
-				vtkMultiThreader::ThreadInfo *ti = (vtkMultiThreader::ThreadInfo *)input;
-				Data *d = (Data *)ti->UserData;
+				vtkMultiThreader::ThreadInfo *ti = (vtkMultiThreader::ThreadInfo * )input;
+				Data *d = (Data * )ti->UserData;
 				if(d != 0)
 				{
 					ProcessorInfo p;
@@ -292,7 +296,7 @@ iParallelManager* iParallelManager::New(iControlModule *cm)
 }
 
 
-iParallelManager::iParallelManager(iControlModule *cm) : iControlModuleComponent(cm)
+iParallelManager::iParallelManager(iControlModule *cm) : mControlModule(cm)
 {
 #ifdef VTK_USE_PARALLEL
 
@@ -300,8 +304,8 @@ iParallelManager::iParallelManager(iControlModule *cm) : iControlModuleComponent
 	mHelper->Initialize(mMinNumProcs,mMaxNumProcs);
 	this->SetNumberOfProcessors(1);
 
-#if defined(I_DEBUG) && defined(I_EDITION)
-	this->GetControlModule()->GetShell()->OutputDebugMessage("Max # of procs: "+iString::FromNumber(mMaxNumProcs));
+#if defined(I_DEBUG)
+	iConsole::PrintDebugMessage("Max # of procs: "+iString::FromNumber(mMaxNumProcs));
 #endif
 
 	mCount = 0;
@@ -329,12 +333,7 @@ int iParallelManager::ExecuteWorker(iParallelWorker *worker)
 
 	if(mNumProcs > 1)
 	{
-		//
-		//  If we are running in parallel, deposit messages in the queue to avoid potential locking in a shell
-		//
-		iPointerCast<iOutputWindow,vtkOutputWindow>(vtkOutputWindow::GetInstance())->StartMessageQueue();
 		ret = mHelper->ExecuteWorker(worker);
-		iPointerCast<iOutputWindow,vtkOutputWindow>(vtkOutputWindow::GetInstance())->FlashMessageQueue();
 	}
 	else
 	{
@@ -404,7 +403,7 @@ void iParallelManager::StopCounters()
 		if(mHelper->StopTimers()) this->InvokeEvent(InformationEvent,0);
 	}
 #ifdef I_CHECK1
-	if(mCount < 0) IERROR_REPORT("Imbalanced start/stop counters.");
+	if(mCount < 0) IERROR_LOW("Imbalanced start/stop counters.");
 #endif
 #endif
 }
