@@ -34,8 +34,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  iPosition functions
 //
-iPosition::iPosition(iViewModule *vm) : iViewModuleComponent(vm)
+iPosition::iPosition(iViewModule *vm) : mViewModule(vm)
 {
+	IERROR_ASSERT(vm);
 	mX[0] = mX[1] = mX[2] = 0.0;
 	mBoxX[0] = mBoxX[1] = mBoxX[2] = 0.0;
 }
@@ -100,8 +101,9 @@ void iPosition::CutToBounds()
 //
 //  iDistance functions
 //
-iDistance::iDistance(iViewModule *vm, bool isSize) : iViewModuleComponent(vm), mIsSize(isSize)
+iDistance::iDistance(iViewModule *vm, bool isSize) : mViewModule(vm), mIsSize(isSize)
 {
+	IERROR_ASSERT(vm)
 	if(isSize) mX = 1.0; else mX = 0.0;
 }
 
