@@ -29,7 +29,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iruler.h"
 
 
+#include "icamera.h"
 #include "ierror.h"
+#include "ioverlayhelper.h"
+#include "irendertool.h"
 #include "iviewmodule.h"
 
 #include <vtkCamera.h>
@@ -42,26 +45,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iRuler* iRuler::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iRuler(vm);
 }
 
 
-iRuler::iRuler(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iViewModuleComponent(vm)
+iRuler::iRuler(iViewModule *vm) : mOverlayHelper(vm->GetRenderTool()), mViewModule(vm)
 {
 	mStarted = false;
 	mScale = mBaseScale = 1.0;
 	mLineWidth = this->AxisActor->GetProperty()->GetLineWidth();
 	mTickLength = TickLength;
 
-	this->GetLabelTextProperty()->BoldOn();
-	this->GetLabelTextProperty()->ItalicOff();
-	this->GetLabelTextProperty()->ShadowOn();
-	this->GetTitleTextProperty()->BoldOn();
-	this->GetTitleTextProperty()->ItalicOff();
-	this->GetTitleTextProperty()->ShadowOn();
 	this->LabelMappers[0]->SetTextProperty(this->LabelTextProperty);
 	this->LabelMappers[1]->SetTextProperty(this->LabelTextProperty);
+	//this->LabelTextProperty->SetJustificationToCentered();
 	this->LabelTextProperty->SetVerticalJustificationToTop();
+	this->TitleTextProperty->SetJustificationToCentered();
+	this->TitleTextProperty->SetVerticalJustificationToBottom();
 
 	this->SetPoint1(0.25,0.9);
 	this->SetPoint2(0.75,0.9);
@@ -70,9 +71,6 @@ iRuler::iRuler(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iViewModule
 	this->SetNumberOfLabels(2);
 
 	this->PickableOff();
-
-	iColor black;
-	this->SetColor(black);
 }
 
 
@@ -89,56 +87,41 @@ void iRuler::ReleaseGraphicsResources(vtkWindow *win)
 
 int iRuler::RenderOverlay(vtkViewport* viewport)
 {
-	vtkCamera *cam = this->GetCamera(viewport);
+	vtkCamera *cam = mOverlayHelper->GetCamera(viewport);
 	if(cam==0 || cam->GetParallelProjection()==0) return 0;
 
-	int mag = this->GetRenderingMagnification();
-	this->LabelTextProperty->SetFontSize(this->GetFontSize(viewport,mag));
-	
 	return this->vtkAxisActor2D::RenderOverlay(viewport);
 }
 
 
 int iRuler::RenderOpaqueGeometry(vtkViewport* viewport)
 {
-	vtkCamera *cam = this->GetCamera(viewport);
+	vtkCamera *cam = mOverlayHelper->GetCamera(viewport);
 	if(cam==0 || cam->GetParallelProjection()==0) return 0;
 	
-	int mag = this->GetRenderingMagnification();
+	int mag = mOverlayHelper->GetRenderingMagnification();
 
-	double x0[3], x1[3];
-	double dummy = 0.0;
-	
-	int k;
-	double vx[3], vy[3], vz[3];
-	
 	if(mag == 1)
 	{
-		cam->GetViewUp(vy);
-		cam->GetDirectionOfProjection(vz);
-		for(k=0; k<3; k++) vz[k] = -vz[k];
-		
-		vtkMath::Cross(vy,vz,vx);
-		
-		viewport->SetWorldPoint(vx[0],vx[1],vx[2],1.0);
-		viewport->WorldToDisplay();
-		viewport->GetDisplayPoint(x0);
-		viewport->SetWorldPoint(-vx[0],-vx[1],-vx[2],1.0);
-		viewport->WorldToDisplay();
-		viewport->GetDisplayPoint(x1);
-		
-		double d = sqrt(vtkMath::Distance2BetweenPoints(x1,x0));
-		viewport->DisplayToNormalizedDisplay(d,dummy);
-		
 		if(!mStarted)
 		{
 			mStarted = true;
 			mBaseScale = cam->GetParallelScale();
 		}
+
+		float s;
+		if(cam->GetParallelProjection() != 0)
+		{
+			s = cam->GetParallelScale()/mBaseScale;
+		}
+		else
+		{
+			s = cam->GetDistance()*(1.0e-35+tan(0.5*iMath::Deg2Rad(cam->GetViewAngle())))/mBaseScale;
+		}
 		
-		float s = cam->GetParallelScale()/mBaseScale;
-		mDx = 0.5*d*s;
-		mDx = (mDx > 0.3) ? 0.3 : mDx;
+		double as[2];
+		viewport->GetAspect(as);
+		mDx = 0.5/mBaseScale*as[1]/as[0];
 
 		if(!this->GetViewModule()->GetOpenGLCoordinates()) s *= this->GetViewModule()->GetBoxSize();
 		this->SetRange(0.0,s);
@@ -153,7 +136,7 @@ int iRuler::RenderOpaqueGeometry(vtkViewport* viewport)
 	else
 	{
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
 		
 		this->SetPoint1(mag*(0.5-mDx)-winij[0],mag*0.9-winij[1]);
 		this->SetPoint2(mag*(0.5+mDx)-winij[0],mag*0.9-winij[1]);
@@ -162,24 +145,35 @@ int iRuler::RenderOpaqueGeometry(vtkViewport* viewport)
 		this->SetTickLength(mag*mTickLength);
 	}
 	
+	this->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+	this->LabelTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+	this->TitleTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+
+	this->GetOverlayHelper()->UpdateTextProperty(this->LabelTextProperty);
+	this->GetOverlayHelper()->UpdateTextProperty(this->TitleTextProperty);
+
 	this->vtkAxisActor2D::RenderOpaqueGeometry(viewport);
-	
+
+	//
+	//  This must be after RenderOpaqueGeometry
+	//
+	this->LabelTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag));
+	this->TitleTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag*1.2));
+	this->TitleMapper->GetTextProperty()->ShallowCopy(this->TitleTextProperty);
+	int *s = viewport->GetSize();
+	this->TitleActor->SetPosition(0.5*s[0],0.91*s[1]);
+
 	return 1;
 }
 
 
-void iRuler::SetColor(iColor &c)
-{ 
-	this->GetProperty()->SetColor(c.ToVTK());
-	this->GetLabelTextProperty()->SetColor(c.ToVTK());
-	this->GetTitleTextProperty()->SetColor(c.ToVTK());
-}
-
-
 void iRuler::SetBaseScale(float s)
 {
-	mStarted = true;
-	mBaseScale = s;
+	if(s > 0.0)
+	{
+		mStarted = true;
+		mBaseScale = s;
+	}
 }
 
 
@@ -191,6 +185,18 @@ void iRuler::SetScale(float s)
 		mBaseScale = this->GetViewModule()->GetRenderer()->GetActiveCamera()->GetParallelScale();
 	}
 
-	if(!this->GetViewModule()->GetOpenGLCoordinates()) s /= this->GetViewModule()->GetBoxSize();
-	this->GetViewModule()->GetRenderer()->GetActiveCamera()->SetParallelScale(s*mBaseScale);
+	if(s > 0.0)
+	{
+		if(!this->GetViewModule()->GetOpenGLCoordinates()) s /= this->GetViewModule()->GetBoxSize();
+		mOverlayHelper->GetRenderTool()->GetCamera()->GetDevice()->SetParallelScale(s*mBaseScale);
+	}
 }
+
+
+void iRuler::SetTitle(const iString &title)
+{
+	mTitle = title;
+	this->vtkAxisActor2D::SetTitle(title.ToCharPointer());
+	if(mTitle.IsEmpty()) this->TitleVisibilityOff(); else this->TitleVisibilityOn();
+}
+
