@@ -53,7 +53,7 @@ int iValue::cval[999];
 void ReportUnallowedPath()
 {
 #ifdef I_CHECK1
-	IERROR_REPORT("Bug in iScript: unallowed path.");
+	IERROR_LOW("Bug in iScript: unallowed path.");
 #endif
 	exit(-1);
 }
@@ -76,25 +76,25 @@ void ReportUnallowedPath()
 //
 
 
-#ifdef I_CHECK1
-
 iValue::iValue(iScript *w, const iString &n, ValueType t, ValueMethod m)
 { 
 	ReferenceCount = 1; 
 	Script = w; Name = n, Type = t; Method = m; 
+#ifdef I_CHECK1
 	counterAtCreation = counterCreate;
 	if(counterCreate < 999) cval[counterCreate] = 1;
 	counterCreate++;
+#endif
 }
 
 
 iValue::~iValue()
 { 
+#ifdef I_CHECK1
 	if(counterAtCreation < 999) cval[counterAtCreation] = 0;
 	counterDestroy++;
-}
-
 #endif
+}
 
 
 //
@@ -108,7 +108,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 	{
 	case _Value_BL: 
 		{ 
-			iValue_BL *v = (iValue_BL *)v0; 
+			iValue_BL *v = static_cast<iValue_BL *>(v0); 
 			if(!ref || v->Method!=_ByValue) 
 			{
 				return iValue::New(v->Script,v->Name,v->Method,v->Value,v->Pointer,v->Function); 
@@ -120,7 +120,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 		}
 	case _Value_IS: 
 		{ 
-			iValue_IS *v = (iValue_IS *)v0; 
+			iValue_IS *v = static_cast<iValue_IS *>(v0); 
 			if(!ref || v->Method!=_ByValue) 
 			{
 				return iValue::New(v->Script,v->Name,v->Method,v->Value,v->Pointer,v->Function); 
@@ -132,7 +132,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 		}
 	case _Value_RS: 
 		{ 
-			iValue_RS *v = (iValue_RS *)v0; 
+			iValue_RS *v = static_cast<iValue_RS *>(v0); 
 			if(!ref || v->Method!=_ByValue) 
 			{
 				return iValue::New(v->Script,v->Name,v->Method,v->Value,v->Pointer,v->Function); 
@@ -144,7 +144,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 		}
 	case _Value_RP: 
 		{ 
-			iValue_RP *v = (iValue_RP *)v0; 
+			iValue_RP *v = static_cast<iValue_RP *>(v0); 
 			if(!ref || v->Method!=_ByValue) 
 			{
 				return iValue::New(v->Script,v->Name,v->Method,v->Value,v->Pointer,v->Function); 
@@ -156,7 +156,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 		}
 	case _Value_ST: 
 		{ 
-			iValue_ST *v = (iValue_ST *)v0; 
+			iValue_ST *v = static_cast<iValue_ST *>(v0); 
 			if(!ref || v->Method!=_ByValue) 
 			{
 				return iValue::New(v->Script,v->Name,v->Method,v->Value,v->Pointer,v->Function,v->Quoted); 
@@ -168,7 +168,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 		}
 	case _Value_VA: 
 		{ 
-			iValue_VA *v = (iValue_VA *)v0;
+			iValue_VA *v = static_cast<iValue_VA *>(v0);
 			iValue** arr = 0;
 			if(v->Size>0 && v->Array!=0)
 			{
@@ -214,7 +214,7 @@ iValue* iValue::NewReal(iScript *w)
 iValue* iValue::NewArray(iScript *w, int size)
 {
 	if(size < 0) size = 0;
-	return iValue::New(w,"",iValue::_ByValue,size,(iValue*)0,(iValue**)0);
+	return iValue::New(w,"",iValue::_ByValue,size,static_cast<iValue*>(0),static_cast<iValue**>(0));
 }
 
 iValue* iValue::NewIndex(iScript *w)
@@ -263,7 +263,7 @@ iString iValue::GetValueAsText() const
 	{
 	case _Value_ST: 
 		{
-			if(this->GetValue(s)) return s; else return "undefined";
+			if(this->GetValue(s)) return "\""+s+"\""; else return "undefined";
 		}
 	case _Value_BL: 
 		{
@@ -292,19 +292,22 @@ iString iValue::GetValueAsText() const
 	case _Value_VA: 
 		{
 			int i;
-			for(i=1; i<=((iValue_VA*)this)->GetSize() && i<=10; i++)
+			s = "(";
+			const iValue_VA *self = static_cast<const iValue_VA*>(this);
+			for(i=1; i<=self->GetSize() && i<=10; i++)
 			{
-				if(((iValue_VA*)this)->GetComponent(i) != 0)
+				if(i > 1) s += ",";
+				if(self->GetComponent(i) != 0)
 				{
-					s += ((iValue_VA*)this)->GetComponent(i)->GetValueAsText();
+					s += self->GetComponent(i)->GetValueAsText();
 				}
 				else
 				{
 					s += "undefined";
 				}
-				s += " ";
 			}
-			if(((iValue_VA*)this)->GetSize() > 10) s += "..."; 
+			if(self->GetSize() > 10) s += ",..."; 
+			s += ")";
 			return s;
 		}
 	default: { ReportUnallowedPath(); return ""; }
@@ -338,7 +341,9 @@ iString iValue::GetTypeAsText() const
 		}
 	case _Value_VA: 
 		{
-			return "array[" + iString::FromNumber(((iValue_VA*)this)->GetSize()) + "]";
+			iString s;
+			if(static_cast<const iValue_VA*>(this)->GetComponent(1) != 0) s += static_cast<const iValue_VA*>(this)->GetComponent(1)->GetTypeAsText() + " ";
+			return s + "array[" + iString::FromNumber(static_cast<const iValue_VA*>(this)->GetSize()) + "]";
 		}
 	default: { ReportUnallowedPath(); return ""; }
 	}
@@ -354,9 +359,9 @@ void iValue::Delete()
 //
 //  BL value
 //
-iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, bool v, bool *p, bool (*f)(iScript*))
+iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, bool v, bool *p, bool (*f)(iScript * ))
 {
-	return (iValue*)new iValue_BL(w,n,m,v,p,f);
+	return new iValue_BL(w,n,m,v,p,f);
 }
 
 
@@ -408,9 +413,9 @@ bool iValue_BL::GetValue(bool &v) const
 //
 //  IS value
 //
-iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, int v, int *p, int (*f)(iScript*))
+iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, int v, int *p, int (*f)(iScript* ))
 {
-	return (iValue*)new iValue_IS(w,n,m,v,p,f);
+	return new iValue_IS(w,n,m,v,p,f);
 }
 
 
@@ -498,9 +503,9 @@ bool iValue_IS::GetValue(double &v) const
 //
 //  RS value
 //
-iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, double v, double *p, double (*f)(iScript*))
+iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, double v, double *p, double (*f)(iScript * ))
 {
-	return (iValue *)new iValue_RS(w,n,m,v,p,f);
+	return new iValue_RS(w,n,m,v,p,f);
 }
 
 
@@ -596,9 +601,9 @@ bool iValue_RS::GetValue(float &v) const
 //
 //  FP value
 //
-iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, double* v, double* *p, double* (*f)(iScript*))
+iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, double* v, double* *p, double* (*f)(iScript * ))
 {
-	return (iValue *)new iValue_RP(w,n,m,v,p,f);
+	return new iValue_RP(w,n,m,v,p,f);
 }
 
 
@@ -618,7 +623,7 @@ bool iValue_RP::AssignValue(Assignment r, iValue *v)
 {
 	if(v->GetType()==_Value_RP && r==_Absolute) 
 	{ 
-		this->Value = ((iValue_RP *)v)->Value; 
+		this->Value = static_cast<iValue_RP*>(v)->Value; 
 		return true; 
 	} 
 	else return false;
@@ -630,9 +635,9 @@ bool iValue_RP::GetValue(void *p) const
 	if(p == 0) return false;
 	switch (Method)
 	{
-	case _ByValue:    { *(double* *)p = Value; return true; }
-	case _ByPointer:  { if(Pointer != 0) { *(double* *)p = *Pointer; return true; } else return false; }
-	case _ByFunction: { *(double* *)p = Function(Script); return true; }
+	case _ByValue:    { *(double * *)p = Value; return true; }
+	case _ByPointer:  { if(Pointer != 0) { *(double * *)p = *Pointer; return true; } else return false; }
+	case _ByFunction: { *(double * *)p = Function(Script); return true; }
 	default: { ReportUnallowedPath(); return false; }
 	}
 }
@@ -647,9 +652,9 @@ bool iValue_RP::GetValue(double* &v) const
 //
 //  ST value
 //
-iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p, iString (*f)(iScript*), bool q)
+iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p, iString (*f)(iScript * ), bool q)
 {
-	return (iValue *)new iValue_ST(w,n,m,v,p,f,q);
+	return new iValue_ST(w,n,m,v,p,f,q);
 }
 
 
@@ -669,7 +674,7 @@ bool iValue_ST::AssignValue(Assignment r, iValue *v)
 {
 	if(v->GetType()==_Value_ST && r==_Absolute) 
 	{ 
-		this->Value = ((iValue_ST *)v)->Value; 
+		this->Value = static_cast<iValue_ST*>(v)->Value; 
 		return true; 
 	} 
 	else return false;
@@ -699,7 +704,7 @@ bool iValue_ST::GetValue(iString &v) const
 //
 iValue* iValue::New(iScript *w, const iString &n, ValueMethod m, int s, iValue* i, iValue **a, iValue* (*f)(iScript*,int))
 {
-	return (iValue *)new iValue_VA(w,n,m,s,i,a,f);
+	return new iValue_VA(w,n,m,s,i,a,f);
 }
 
 
@@ -751,11 +756,12 @@ bool iValue_VA::AssignValue(Assignment r, iValue *v)
 	{
 	case _Value_VA:
 		{
-			if(r==_Absolute && this->Array!=0 && ((iValue_VA *)v)->Array!=0 && this->Size==((iValue_VA *)v)->Size)
+			iValue_VA *other = static_cast<iValue_VA*>(v);
+			if(r==_Absolute && this->Array!=0 && other->Array!=0 && this->Size==other->Size)
 			{
 				for(j=0; j<this->Size; j++)
 				{
-					if(this->Array[j]!=0 && ((iValue_VA *)v)->Array[j]!=0) this->Array[j]->AssignValue(r,((iValue_VA *)v)->Array[j]); 
+					if(this->Array[j]!=0 && other->Array[j]!=0) this->Array[j]->AssignValue(r,other->Array[j]); 
 				}
 				return true;
 			}
@@ -786,9 +792,9 @@ bool iValue_VA::GetValue(void *p) const
 
 	switch (Method)
 	{
-	case _ByValue:    { if(Array!=0 && Array[i-1]!=0) { *(iValue **)p = Array[i-1]; return true; } else return false; }
+	case _ByValue:    { if(Array!=0 && Array[i-1]!=0) { *(iValue * *)p = Array[i-1]; return true; } else return false; }
 	case _ByPointer:  { return false; }
-	case _ByFunction: { *(iValue **)p = Function(Script,i-1); return true; }
+	case _ByFunction: { *(iValue * *)p = Function(Script,i-1); return true; }
 	default: { ReportUnallowedPath(); return false; }
 	}
 }
@@ -934,27 +940,27 @@ iOperation* iOperation::New(iOperation *o0)
 	{
 	case _Operation_DC_SV: 
 		{
-			iOperation_DC_SV *o = (iOperation_DC_SV*)o0;
+			iOperation_DC_SV *o = static_cast<iOperation_DC_SV*>(o0);
 			return iOperation::New(o->Script,o->Prefix,o->Command,o->OutputCode,o->StatementPrefix,o->Relative,iValue::New(o->Value),o->UserType);
 		}
 	case _Operation_FC_LB: 
 		{
-			iOperation_FC_LB *o = (iOperation_FC_LB*)o0;
+			iOperation_FC_LB *o = static_cast<iOperation_FC_LB*>(o0);
 			return iOperation::New(o->Script,o->Prefix,o->Command,o->OutputCode,o->Point,iValue::New(o->Index),iValue::New(o->Count),o->Class,o->UserType);
 		}
 	case _Operation_SF_V0: 
 		{
-			iOperation_SF_V0 *o = (iOperation_SF_V0*)o0;
+			iOperation_SF_V0 *o = static_cast<iOperation_SF_V0*>(o0);
 			return iOperation::New(o->Script,o->Prefix,o->Command,o->OutputCode,o->Function,o->UserType);
 		}
 	case _Operation_SF_V1: 
 		{
-			iOperation_SF_V1 *o = (iOperation_SF_V1*)o0;
+			iOperation_SF_V1 *o = static_cast<iOperation_SF_V1*>(o0);
 			return iOperation::New(o->Script,o->Prefix,o->Command,o->OutputCode,o->Relative,iValue::New(o->Value),o->Function,o->UserType);
 		}
 	case _Operation_AF_V1: 
 		{
-			iOperation_AF_V1 *o = (iOperation_AF_V1*)o0;
+			iOperation_AF_V1 *o = static_cast<iOperation_AF_V1*>(o0);
 			return iOperation::New(o->Script,o->Prefix,o->Command,o->OutputCode,iValue::New(o->Index),o->Relative,iValue::New(o->Value),o->Function,o->UserType);
 		}
 	default: { ReportUnallowedPath(); return 0; }
@@ -974,6 +980,11 @@ iOperation::iOperation(iScript *w, const iString &p, const iString &s, int o, Op
 }
 
 
+iOperation::~iOperation()
+{
+}
+
+
 bool iOperation::AssignVariableValue(const iString &n, iValue::Assignment r, iValue *v, iValue *i)
 {
 	if(Script != 0) return Script->AssignVariableValue(n,r,v,i); else return false;
@@ -985,7 +996,7 @@ bool iOperation::AssignVariableValue(const iString &n, iValue::Assignment r, iVa
 //
 iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, const iString &sp, iValue::Assignment r, iValue *v, unsigned char u)
 {
-	return (iOperation *)new iOperation_DC_SV(w,p,c,o,sp,r,v,u);
+	return new iOperation_DC_SV(w,p,c,o,sp,r,v,u);
 }
 
 
@@ -1000,7 +1011,7 @@ bool iOperation_DC_SV::Exec()
 //
 iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, EntryPoint q, iValue* i, iValue *n, int l, unsigned char u)
 {
-	return (iOperation *)new iOperation_FC_LB(w,p,c,o,q,i,n,l,u);
+	return new iOperation_FC_LB(w,p,c,o,q,i,n,l,u);
 }
 
 
@@ -1098,9 +1109,9 @@ void iOperation_FC_LB::SetValue(iValue* v)
 //
 // Type SF_V0 operation creator & executor
 //
-iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, void (*f)(iScript*), unsigned char u)
+iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, void (*f)(iScript * ), unsigned char u)
 {
-	return (iOperation *)new iOperation_SF_V0(w,p,c,o,f,u);
+	return new iOperation_SF_V0(w,p,c,o,f,u);
 }
 
 
@@ -1116,7 +1127,7 @@ bool iOperation_SF_V0::Exec()
 //
 iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, iValue::Assignment r, iValue *v, void (*f)(iScript*,iValue*,iValue::Assignment), unsigned char u)
 {
-	return (iOperation *)new iOperation_SF_V1(w,p,c,o,r,v,f,u);
+	return new iOperation_SF_V1(w,p,c,o,r,v,f,u);
 }
 
 
@@ -1143,7 +1154,7 @@ void iOperation_SF_V1::SetValue(iValue* v)
 //
 iOperation* iOperation::New(iScript *w, const iString &p, const iString &c, int o, iValue *i, iValue::Assignment r, iValue *v, void (*f)(iScript*,iValue*,iValue*,iValue::Assignment), unsigned char u)
 {
-	return (iOperation *)new iOperation_AF_V1(w,p,c,o,i,r,v,f,u);
+	return new iOperation_AF_V1(w,p,c,o,i,r,v,f,u);
 }
 
 
@@ -1204,7 +1215,7 @@ void iOperation_AF_V1::Delete()
 //
 int iScript::mCounter = 0;
 
-iScript::iScript(iScript *parent) : mAliasWords(AliasWord()), mPrefixWords(""), mDummyWords(""), mParameterWords(0), mVariable(0), mCommand(0), mCode(0), mCompilerStack(StackEntry()), mObservers(0)
+iScript::iScript(iScript *parent) : mErrorStatus("Script")
 {
 	mParent = parent;
 	mAllowChildAccess = false;  //  children can only access my vars if this is true
@@ -1231,7 +1242,7 @@ iScript::iScript(iScript *parent) : mAliasWords(AliasWord()), mPrefixWords(""),
 	mEntryPointIteration = -1;
 	mEntryPointIterationCount = 0;
 
-	mParser = new iExpressionParser; IERROR_ASSERT(mParser);
+	mParser = iExpressionParser::New(); IERROR_ASSERT(mParser);
 
 	//
 	//  Standard parameters
@@ -1273,7 +1284,7 @@ iScript::~iScript()
 	for(i=0; i<mParameterWords.Size(); i++) mParameterWords[i]->Delete();
 	for(i=0; i<mNumCommandWords; i++) mCommand[i]->Delete();
 
-	delete mParser;
+	mParser->Delete();
 
 	while(mObservers.Size() > 0) mObservers.RemoveLast()->SetScript(0);
 
@@ -1285,7 +1296,7 @@ iScript::~iScript()
 		int i;
 		for(i=0; i<999; i++) if (iValue::cval[i] != 0)
 		{
-			IERROR_REPORT("Uncollected values.");
+			IERROR_LOW("Uncollected values.");
 		}
 	}
 #endif
@@ -1522,7 +1533,7 @@ bool iScript::AssignVariableValue(const iString &n, iValue::Assignment r, iValue
 		//
 		if(i!=0 && mVariable[j]->Type==iValue::_Value_VA) 
 		{
-			((iValue_VA*)mVariable[j])->SetIndex(i);
+			static_cast<iValue_VA*>(mVariable[j])->SetIndex(i);
 		}
 		if(mVariable[j]->AssignValue(r,v)) { mLastChangedVariable = j; return true; } 
 		break;
@@ -1602,7 +1613,7 @@ void iScript::RunStop(bool compileOnly)
 		mCommandLastSize = mCommand.Size() - mNumCommandWords;
 	}
 
-	for(i=0; i<mObservers.Size(); i++) mObservers[i]->OnScriptStop(this->GetErrorStatus()->GetMessage());
+	for(i=0; i<mObservers.Size(); i++) mObservers[i]->OnScriptStop(this->GetErrorStatus()->Message());
 }
 
 
@@ -1730,7 +1741,7 @@ void iScript::ExecuteOneLine()
 	//
 	if(mCode[mCodeEntryPoint]->Type == iOperation::_Operation_FC_LB)
 	{
-		iOperation_FC_LB *op = (iOperation_FC_LB *)mCode[mCodeEntryPoint];
+		iOperation_FC_LB *op = static_cast<iOperation_FC_LB*>(mCode[mCodeEntryPoint]);
 		op->Exec();
 
 		//
@@ -1766,7 +1777,7 @@ void iScript::ExecuteOneLine()
 			if(mActive || l==mActivator) // I am a match for the activator, so execute
 			{
 				checkGate = true;
-				if(!((iOperation_FC_LB *)mCode[l])->Done) 
+				if(!static_cast<iOperation_FC_LB*>(mCode[l])->Done) 
 				{ 
 					mCodeEntryPoint = l; 
 					mNextLine = mCode[mCodeEntryPoint]->LineInScript;
@@ -1775,7 +1786,7 @@ void iScript::ExecuteOneLine()
 				else 
 				{
 					mEntryPointIteration = -1;
-					mEntryPointIterationCount = ((iOperation_FC_LB *)mCode[l])->intCount;
+					mEntryPointIterationCount = static_cast<iOperation_FC_LB*>(mCode[l])->intCount;
 					if(this->CheckAbort(mEntryPointIteration,mEntryPointIterationCount))
 					{
 						this->GetErrorStatus()->SetAbort(-1);
@@ -1919,7 +1930,7 @@ void iScript::CompileOneLine()
 	//  Remove '=' signs - they are just for aestetics. Remove extra white spaces if appeared.
 	//
 	
-	while((i=commandText.Find('='))>=0 && commandText.Part(0,i).Contains('"')%2==0) commandText[i] = ' ';
+	while((i=commandText.Find('='))>=0 && commandText.Part(0,i).Contains('"')%2==0) commandText.Replace(i,1," ");
 	commandText.ReduceWhiteSpace();
 
 	//
@@ -2029,11 +2040,11 @@ TEST:
 			}
 		case iOperation::_Operation_SF_V1: 
 			{ 
-				ok = ((iOperation_SF_V1 *)mCommand[comind])->Relative & 1; break; 
+				ok = static_cast<iOperation_SF_V1*>(mCommand[comind])->Relative & 1; break; 
 			}
 		case iOperation::_Operation_AF_V1: 
 			{ 
-				ok = ((iOperation_AF_V1 *)mCommand[comind])->Relative & 1; break; 
+				ok = static_cast<iOperation_AF_V1*>(mCommand[comind])->Relative & 1; break; 
 			}
 		default:
 			{
@@ -2073,11 +2084,11 @@ TEST:
 			}
 		case iOperation::_Operation_SF_V1: 
 			{ 
-				ok = (((iOperation_SF_V1 *)mCommand[comind])->Relative & 2) != 0; break; 
+				ok = (static_cast<iOperation_SF_V1*>(mCommand[comind])->Relative & 2) != 0; break; 
 			}
 		case iOperation::_Operation_AF_V1: 
 			{ 
-				ok = (((iOperation_AF_V1 *)mCommand[comind])->Relative & 2) != 0; break; 
+				ok = (static_cast<iOperation_AF_V1*>(mCommand[comind])->Relative & 2) != 0; break; 
 			}
 		default:
 			{
@@ -2133,7 +2144,7 @@ TEST:
 			//
 			//  Check that the whole array assignment is allowed
 			//
-			ok = ((iOperation_AF_V1*)mCommand[comind])->Value==0 || isArray || ((iOperation_AF_V1*)mCommand[comind])->Value->Type == iValue::_Value_VA; 
+			ok = static_cast<iOperation_AF_V1*>(mCommand[comind])->Value==0 || isArray || static_cast<iOperation_AF_V1*>(mCommand[comind])->Value->Type == iValue::_Value_VA; 
 			if(!ok) this->GetErrorStatus()->Set("Whole array assignment is not allowed."); 
 			break; 
 		}
@@ -2201,7 +2212,7 @@ TEST:
 				//
 				//  Is the value configured properly?
 				//
-				if(((iOperation_DC_SV *)mCommand[comind])->Value!=0 && ((iOperation_DC_SV *)mCommand[comind])->Value->Method != iValue::_ByValue)
+				if(static_cast<iOperation_DC_SV*>(mCommand[comind])->Value!=0 && static_cast<iOperation_DC_SV*>(mCommand[comind])->Value->Method != iValue::_ByValue)
 				{
 					this->GetErrorStatus()->Set("Script is incorrectly configured. Declared variables must have Method=iValue::_ByValue.");
 					ok = false; break;
@@ -2216,7 +2227,7 @@ TEST:
 					//
 					//  Simple variable 
 					//
-					valtmp = iValue::New(((iOperation_DC_SV *)mCommand[comind])->Value);
+					valtmp = iValue::New(static_cast<iOperation_DC_SV*>(mCommand[comind])->Value);
 				}
 				else
 				{
@@ -2240,7 +2251,7 @@ TEST:
 					//
 					for(i=0; i<n && ok; i++)
 					{
-						arr[i] = iValue::New(((iOperation_DC_SV *)mCommand[comind])->Value);
+						arr[i] = iValue::New(static_cast<iOperation_DC_SV*>(mCommand[comind])->Value);
 						if(arr[i] == 0) ok = false;
 					}
 					//
@@ -2307,7 +2318,7 @@ TEST:
 			//
 			//  If there is no count, there should be no value
 			//
-			if(((iOperation_FC_LB *)mCommand[comind])->Count == 0)
+			if(static_cast<iOperation_FC_LB*>(mCommand[comind])->Count == 0)
 			{
 				ok = pv.IsEmpty();
 			}
@@ -2324,7 +2335,7 @@ TEST:
 			//  A special case is an assignment of the unquoted string - this allows to make very complex commands
 			//  by outsourcing complete parsing to a function. Quote the string if it is unquoted.
 			//
-			if(((iOperation_SF_V1*)mCommand[comind])->Value!=0 && ((iOperation_SF_V1*)mCommand[comind])->Value->Type==iValue::_Value_ST && !((iValue_ST*)((iOperation_SF_V1*)mCommand[comind])->Value)->Quoted)
+			if(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value!=0 && static_cast<iOperation_SF_V1*>(mCommand[comind])->Value->Type==iValue::_Value_ST && !static_cast<iValue_ST*>(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value)->Quoted)
 			{
 				//
 				//  Replace double quotes in the value string with single quotes (you task is to insure that there is no mix-up)
@@ -2367,23 +2378,23 @@ TEST:
 	{
 	case iOperation::_Operation_FC_LB: 
 		{ 
-			if(((iOperation_FC_LB*)mCommand[comind])->Count != 0)
+			if(static_cast<iOperation_FC_LB*>(mCommand[comind])->Count != 0)
 			{
-				ok = iValue::AreTypesCompatible(((iOperation_FC_LB*)mCommand[comind])->Count,val);
+				ok = iValue::AreTypesCompatible(static_cast<iOperation_FC_LB*>(mCommand[comind])->Count,val);
 			}
 			break; 
 		}
 	case iOperation::_Operation_SF_V1: 
 		{ 
-			if(((iOperation_SF_V1*)mCommand[comind])->Value != 0)
+			if(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value != 0)
 			{
-				ok = iValue::AreTypesCompatible(((iOperation_SF_V1*)mCommand[comind])->Value,val);
+				ok = iValue::AreTypesCompatible(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value,val);
 			}
 			break; 
 		}
 	case iOperation::_Operation_AF_V1: 
 		{ 
-			if(((iOperation_AF_V1*)mCommand[comind])->Value != 0)
+			if(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value != 0)
 			{
 				//
 				//  Decide whether this is a full array assignment, or a single component.
@@ -2394,18 +2405,18 @@ TEST:
 				//
 				if(arrComponent == 0)
 				{
-					ok = iValue::AreTypesCompatible(((iOperation_AF_V1*)mCommand[comind])->Value,val);
-					arrComponent = iValue::New(((iOperation_AF_V1*)mCommand[comind])->Index);  
+					ok = iValue::AreTypesCompatible(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value,val);
+					arrComponent = iValue::New(static_cast<iOperation_AF_V1*>(mCommand[comind])->Index);  
 					arrComponent->AssignValue(iValue::_Absolute,1);  // cannot have zero component in the script command
 				}
 				else
 				{
-					if(((iOperation_AF_V1*)mCommand[comind])->Value->Type == iValue::_Value_VA)
+					if(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value->Type == iValue::_Value_VA)
 					{
 						//
 						//  Full array assignment
 						//
-						iValue *valtmp = ((iValue_VA*)((iOperation_AF_V1*)mCommand[comind])->Value)->GetComponent(arrComponent);
+						iValue *valtmp = static_cast<iValue_VA*>(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value)->GetComponent(arrComponent);
 						if(valtmp != 0) ok = iValue::AreTypesCompatible(valtmp,val); else ok = false;
 					}
 					else 
@@ -2414,7 +2425,7 @@ TEST:
 						//  Single component assignment to an array that cannot be assigned as a whole
 						//  (was declared with a single-valued iValue)
 						//
-						ok = iValue::AreTypesCompatible(((iOperation_AF_V1*)mCommand[comind])->Value,val);
+						ok = iValue::AreTypesCompatible(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value,val);
 					}
 				}
 			}
@@ -2440,25 +2451,25 @@ TEST:
 	//
 	if(val!=0 && val->Type==iValue::_Value_VA)
 	{
-		int n = ((iValue_VA *)val)->Size;
+		int n = static_cast<iValue_VA*>(val)->Size;
 		int s;
 
 		switch(mCommand[comind]->Type)
 		{
 		case iOperation::_Operation_SF_V1: 
 			{
-				if(((iOperation_SF_V1*)mCommand[comind])->Value != 0)
+				if(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value != 0)
 				{
-					s = ((iValue_VA *) ((iOperation_SF_V1*)mCommand[comind])->Value)->Size;
+					s = static_cast<iValue_VA*>(static_cast<iOperation_SF_V1*>(mCommand[comind])->Value)->Size;
 					ok = (n==0 || s==0 || n==s);
 				}
 				break; 
 			}
 		case iOperation::_Operation_AF_V1: 
 			{
-				if(((iOperation_AF_V1*)mCommand[comind])->Value != 0)
+				if(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value != 0)
 				{
-					s = ((iValue_VA *) ((iOperation_AF_V1*)mCommand[comind])->Value)->Size;
+					s = static_cast<iValue_VA*>(static_cast<iOperation_AF_V1*>(mCommand[comind])->Value)->Size;
 					ok = (n==0 || s==0 || n==s);
 				}
 				break; 
@@ -2489,28 +2500,28 @@ TEST:
 		{
 		case iOperation::_Operation_DC_SV: 
 			{ 
-				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,((iOperation_DC_SV *)mCommand[comind])->StatementPrefix,((iOperation_DC_SV *)mCommand[comind])->Relative,iValue::New(((iOperation_DC_SV *)mCommand[comind])->Value)); 
+				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,static_cast<iOperation_DC_SV*>(mCommand[comind])->StatementPrefix,static_cast<iOperation_DC_SV*>(mCommand[comind])->Relative,iValue::New(static_cast<iOperation_DC_SV*>(mCommand[comind])->Value)); 
 				break; 
 			}
 		case iOperation::_Operation_FC_LB: 
 			{ 
-				if(((iOperation_FC_LB *)mCommand[comind])->Index != 0) ((iOperation_FC_LB *)mCommand[comind])->Index->Register();
-				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,((iOperation_FC_LB *)mCommand[comind])->Point,((iOperation_FC_LB *)mCommand[comind])->Index,val,((iOperation_FC_LB *)mCommand[comind])->Class); 
+				if(static_cast<iOperation_FC_LB*>(mCommand[comind])->Index != 0) static_cast<iOperation_FC_LB*>(mCommand[comind])->Index->Register();
+				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,static_cast<iOperation_FC_LB*>(mCommand[comind])->Point,static_cast<iOperation_FC_LB*>(mCommand[comind])->Index,val,static_cast<iOperation_FC_LB*>(mCommand[comind])->Class); 
 				break; 
 			}
 		case iOperation::_Operation_SF_V0: 
 			{ 
-				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,((iOperation_SF_V0 *)mCommand[comind])->Function); 
+				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,static_cast<iOperation_SF_V0*>(mCommand[comind])->Function); 
 				break; 
 			}
 		case iOperation::_Operation_SF_V1: 
 			{ 
-				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,valueRelative,val,((iOperation_SF_V1 *)mCommand[comind])->Function); 
+				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,valueRelative,val,static_cast<iOperation_SF_V1*>(mCommand[comind])->Function); 
 				break; 
 			}
 		case iOperation::_Operation_AF_V1: 
 			{ 
-				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,arrComponent,valueRelative,val,((iOperation_AF_V1 *)mCommand[comind])->Function); 
+				tmp = iOperation::New(this,mCommand[comind]->Prefix,mCommand[comind]->Command,mCommand[comind]->OutputCode,arrComponent,valueRelative,val,static_cast<iOperation_AF_V1*>(mCommand[comind])->Function); 
 				break; 
 			}
 		default: 
@@ -2537,20 +2548,20 @@ TEST:
 			}
 		case iOperation::_Operation_FC_LB: 
 			{ 
-				if(((iOperation_FC_LB *)mCode[mCodeEntryPoint])->Count != 0) ((iOperation_FC_LB *)mCode[mCodeEntryPoint])->Count->AssignValue(iValue::_Absolute,val); // assign a value if it exists
+				if(static_cast<iOperation_FC_LB*>(mCode[mCodeEntryPoint])->Count != 0) static_cast<iOperation_FC_LB*>(mCode[mCodeEntryPoint])->Count->AssignValue(iValue::_Absolute,val); // assign a value if it exists
 				break; 
 			}
 		case iOperation::_Operation_SF_V1: 
 			{ 
-				((iOperation_SF_V1 *)mCode[mCodeEntryPoint])->Relative = valueRelative;
-				((iOperation_SF_V1 *)mCode[mCodeEntryPoint])->Value->AssignValue(iValue::_Absolute,val); // this is an assignment to the rhs, not to the value itself
+				static_cast<iOperation_SF_V1*>(mCode[mCodeEntryPoint])->Relative = valueRelative;
+				static_cast<iOperation_SF_V1*>(mCode[mCodeEntryPoint])->Value->AssignValue(iValue::_Absolute,val); // this is an assignment to the rhs, not to the value itself
 				break; 
 			}
 		case iOperation::_Operation_AF_V1: 
 			{ 
-				((iOperation_AF_V1 *)mCode[mCodeEntryPoint])->Relative = valueRelative;
-				((iOperation_AF_V1 *)mCode[mCodeEntryPoint])->Index->AssignValue(iValue::_Absolute,arrComponent); 
-				((iOperation_AF_V1 *)mCode[mCodeEntryPoint])->Value->AssignValue(iValue::_Absolute,val); // this is an assignment to the rhs, not to the value itself
+				static_cast<iOperation_AF_V1*>(mCode[mCodeEntryPoint])->Relative = valueRelative;
+				static_cast<iOperation_AF_V1*>(mCode[mCodeEntryPoint])->Index->AssignValue(iValue::_Absolute,arrComponent); 
+				static_cast<iOperation_AF_V1*>(mCode[mCodeEntryPoint])->Value->AssignValue(iValue::_Absolute,val); // this is an assignment to the rhs, not to the value itself
 				break; 
 			}
 		default: 
@@ -2776,13 +2787,13 @@ iValue* iScript::TransformSingleTokenToValue(const iString &pv0, bool acceptArra
 						}
 						ind->Delete();  // index is not needed any more
 
-						int size = ((iValue_VA*)v)->Size;
+						int size = static_cast<iValue_VA*>(v)->Size;
 						if(size>0 && (iv<=0 || iv>size))
 						{
 							this->GetErrorStatus()->Set("Array index value is outside the array range.");
 							return 0;
 						}
-						val = ((iValue_VA*)v)->GetComponent(iv);
+						val = static_cast<iValue_VA*>(v)->GetComponent(iv);
 					}
 					else val = v;
 
@@ -2949,7 +2960,7 @@ iValue* iScript::TransformExpressionToValue(const iString &pv0, bool NotUsed(acc
 			case iValue::_Value_RP:
 			case iValue::_Value_VA:
 				{
-					if(((iValue_VA*)v)->Size!=3 && ((iValue_VA*)v)->Size!=0)
+					if(static_cast<iValue_VA*>(v)->Size!=3 && static_cast<iValue_VA*>(v)->Size!=0)
 					{
 						this->GetErrorStatus()->Set("Only 3-component arrays (vectors) can be used in expressions.");
 						return 0;
