@@ -36,13 +36,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ISCRIPT_H
 
 
-#include "ideletable.h"
-#include "ierrorstatusholder.h"
+#include <vtkObjectBase.h>
 
 
 #include "iarray.h"
 #include "istring.h"
 
+#include <vtkSetGet.h>
+
 //
 //  Define the base class for possible values.
 //  All values are accessed transparently via the base class - in a VTK style.
@@ -53,7 +54,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class iScript;
 
-class iValue : public iDeletable
+class iValue
 {
 
 friend class iScript;
@@ -101,15 +102,15 @@ public:
 	};
 
 	// BL creator
-	static iValue* New(iScript *w, const iString &n, ValueMethod m, bool v, bool *p = 0, bool (*f)(iScript*) = 0);
+	static iValue* New(iScript *w, const iString &n, ValueMethod m, bool v, bool *p = 0, bool (*f)(iScript* ) = 0);
 	// IS creator
-	static iValue* New(iScript *w, const iString &n, ValueMethod m, int v, int *p = 0, int (*f)(iScript*) = 0);
+	static iValue* New(iScript *w, const iString &n, ValueMethod m, int v, int *p = 0, int (*f)(iScript* ) = 0);
 	// FS creator
-	static iValue* New(iScript *w, const iString &n, ValueMethod m, double v, double *p = 0, double (*f)(iScript*) = 0);
+	static iValue* New(iScript *w, const iString &n, ValueMethod m, double v, double *p = 0, double (*f)(iScript* ) = 0);
 	// FP creator
-	static iValue* New(iScript *w, const iString &n, ValueMethod m, double* v, double* *p = 0, double* (*f)(iScript*) = 0);
+	static iValue* New(iScript *w, const iString &n, ValueMethod m, double* v, double* *p = 0, double* (*f)(iScript* ) = 0);
 	// ST creator
-	static iValue* New(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p = 0, iString (*f)(iScript*) = 0, bool q = true);
+	static iValue* New(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p = 0, iString (*f)(iScript* ) = 0, bool q = true);
 	// VA creator
 	static iValue* New(iScript *w, const iString &n, ValueMethod m, int s, iValue* i, iValue **a, iValue* (*f)(iScript*,int) = 0);
 
@@ -127,8 +128,8 @@ public:
 	virtual iString GetValueAsText() const;
 	virtual iString GetTypeAsText() const;
 
-	static bool AreTypesCompatible(iValue *, iValue *);
-	static bool AreTypesCompatible(ValueType t, iValue *);
+	static bool AreTypesCompatible(iValue *v1, iValue *v2);
+	static bool AreTypesCompatible(ValueType t, iValue *v);
 
 	inline ValueType GetType() const { return Type; }
 	inline ValueMethod GetMethod() const { return Method; }
@@ -139,20 +140,20 @@ public:
 
 	virtual bool SetMethod(ValueMethod m) = 0;
 
-	virtual bool AssignValue(Assignment r, iValue *) = 0;
+	virtual bool AssignValue(Assignment r, iValue *v) = 0;
 	virtual bool AssignValue(Assignment, bool){ return false; }
 	virtual bool AssignValue(Assignment, int){ return false; }
 	virtual bool AssignValue(Assignment, double){ return false; }
 
-	virtual bool GetValue(void *) const  = 0;
+	virtual bool GetValue(void *v) const  = 0;
 	virtual bool GetValue(bool &) const { return false; }
 	virtual bool GetValue(int &) const { return false; }
 	virtual bool GetValue(float &) const { return false; }
 	virtual bool GetValue(double &) const { return false; }
 	virtual bool GetValue(double* &) const { return false; }
 	virtual bool GetValue(iString &) const { return false; }
-	virtual bool GetValue(int, int *) const { return false; }
-	virtual bool GetValue(int, double *) const { return false; }
+	virtual bool GetValue(int, int * ) const { return false; }
+	virtual bool GetValue(int, double * ) const { return false; }
 
 	virtual void Register(){ ReferenceCount++; }
 	inline int GetReferenceCount() const { return ReferenceCount; }
@@ -165,22 +166,14 @@ public:
 
 protected:
 
+	iValue(iScript *w, const iString &n, ValueType t, ValueMethod m);
+	virtual ~iValue();
+
 	int ReferenceCount;
 	iScript *Script;
 	iString Name;
 	ValueType Type;
 	ValueMethod Method;
-
-#ifdef I_CHECK1
-	iValue(iScript *w, const iString &n, ValueType t, ValueMethod m);
-	virtual ~iValue();
-#else
-	iValue(iScript *w, const iString &n, ValueType t, ValueMethod m)
-	{ 
-		ReferenceCount = 1; Script = w; Name = n, Type = t; Method = m; 
-	}
-	virtual ~iValue(){}
-#endif
 };
 //
 //  Value type BL: 
@@ -198,15 +191,15 @@ public:
 	virtual bool SetMethod(ValueMethod m);
 	virtual void SetNumericValue(bool v){ Value = v; Method = _ByValue; }
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 	virtual bool AssignValue(Assignment r, bool b);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(bool &) const;
 
 protected:
 
-	iValue_BL(iScript *w, const iString &n, ValueMethod m, bool v, bool *p, bool (*f)(iScript*)) : iValue(w,n,_Value_BL,m)
+	iValue_BL(iScript *w, const iString &n, ValueMethod m, bool v, bool *p, bool (*f)(iScript* )) : iValue(w,n,_Value_BL,m)
 	{ 
 		Value = v; 
 		Pointer = p; 
@@ -215,7 +208,7 @@ protected:
 
 	bool Value;
 	bool* Pointer;
-	bool (*Function)(iScript*);
+	bool (*Function)(iScript* );
 
 };
 //
@@ -234,11 +227,11 @@ public:
 	virtual bool SetMethod(ValueMethod m);
 	virtual void SetNumericValue(int v){ Value = v; Method = _ByValue; }
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 	virtual bool AssignValue(Assignment r, int i);
 	virtual bool AssignValue(Assignment r, double f);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(bool &) const;
 	virtual bool GetValue(int &) const;
 	virtual bool GetValue(float &) const;
@@ -246,7 +239,7 @@ public:
 
 protected:
 
-	iValue_IS(iScript *w, const iString &n, ValueMethod m, int v, int *p, int (*f)(iScript*)) : iValue(w,n,_Value_IS,m)
+	iValue_IS(iScript *w, const iString &n, ValueMethod m, int v, int *p, int (*f)(iScript* )) : iValue(w,n,_Value_IS,m)
 	{ 
 		Value = v; 
 		Pointer = p; 
@@ -255,7 +248,7 @@ protected:
 
 	int Value;
 	int* Pointer;
-	int (*Function)(iScript*);
+	int (*Function)(iScript* );
 
 };
 //
@@ -274,11 +267,11 @@ public:
 	virtual bool SetMethod(ValueMethod m);
 	virtual void SetNumericValue(double v){ Value = v; }
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 	virtual bool AssignValue(Assignment r, int i);
 	virtual bool AssignValue(Assignment r, double f);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(bool &) const;
 	virtual bool GetValue(int &) const;
 	virtual bool GetValue(float &) const;
@@ -286,7 +279,7 @@ public:
 
 protected:
 
-	iValue_RS(iScript *w, const iString &n, ValueMethod m, double v, double *p, double (*f)(iScript*)) : iValue(w,n,_Value_RS,m)
+	iValue_RS(iScript *w, const iString &n, ValueMethod m, double v, double *p, double (*f)(iScript* )) : iValue(w,n,_Value_RS,m)
 	{ 
 		Value = v; 
 		Pointer = p; 
@@ -295,7 +288,7 @@ protected:
 
 	double Value;
 	double* Pointer;
-	double (*Function)(iScript*);
+	double (*Function)(iScript* );
 };
 //
 //  Value type RP: 
@@ -313,14 +306,14 @@ public:
 	virtual bool SetMethod(ValueMethod m);
 	virtual void SetNumericValue(double *v){ Value = v; }
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(double* &p) const;
 
 protected:
 
-	iValue_RP(iScript *w, const iString &n, ValueMethod m, double* v, double* *p, double* (*f)(iScript*)) : iValue(w,n,_Value_RP,m)
+	iValue_RP(iScript *w, const iString &n, ValueMethod m, double* v, double* *p, double* (*f)(iScript* )) : iValue(w,n,_Value_RP,m)
 	{ 
 		Value = v; 
 		Pointer = p; 
@@ -329,7 +322,7 @@ protected:
 
 	double* Value;
 	double** Pointer;
-	double* (*Function)(iScript*);
+	double* (*Function)(iScript* );
 };
 //
 //  Value type ST: 
@@ -347,16 +340,16 @@ public:
 	virtual bool SetMethod(ValueMethod m);
 	virtual void SetNumericValue(const iString &v){ Value = v; }
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(iString &p) const;
 
 	bool IsQuoted() const { return Quoted; }
 
 protected:
 
-	iValue_ST(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p, iString (*f)(iScript*), bool q) : iValue(w,n,_Value_ST,m)
+	iValue_ST(iScript *w, const iString &n, ValueMethod m, const iString &v, iString *p, iString (*f)(iScript* ), bool q) : iValue(w,n,_Value_ST,m)
 	{ 
 		Value = v; 
 		Pointer = p; 
@@ -366,7 +359,7 @@ protected:
 
 	iString Value;
 	iString* Pointer;
-	iString (*Function)(iScript*);
+	iString (*Function)(iScript* );
 	bool Quoted;
 };
 //
@@ -388,19 +381,19 @@ public:
 
 	inline int GetSize() const { return Size; }
 	inline iValue* GetIndex() const { return Index; }
-	virtual iValue* GetComponent(iValue *) const;
+	virtual iValue* GetComponent(iValue *v) const;
 	virtual iValue* GetComponent(int i) const;
 
 	void SetIndex(iValue *i);
 
-	virtual bool AssignValue(Assignment r, iValue *);
+	virtual bool AssignValue(Assignment r, iValue *v);
 
-	virtual bool GetValue(void *) const;
+	virtual bool GetValue(void *p) const;
 	virtual bool GetValue(bool &) const;
 	virtual bool GetValue(int &) const;
 	virtual bool GetValue(double &) const;
-	virtual bool GetValue(int, int *) const;
-	virtual bool GetValue(int, double *) const;
+	virtual bool GetValue(int, int *v) const;
+	virtual bool GetValue(int, double *v) const;
 
 protected:
 
@@ -429,13 +422,15 @@ protected:
 //   - AF similar to SF, but have array syntax (e.f. Set var[N] = V calls F(N,V))
 //
 
-class iOperation : public iDeletable
+class iOperation
 {
 
 friend class iScript;
 
 public:
 
+	virtual void Delete(){ delete this; }
+
 	//
 	//  Operation Type constants
 	//
@@ -472,7 +467,7 @@ public:
 	// FC_LB creator
 	static iOperation* New(iScript *w, const iString &p, const iString &c, int o, EntryPoint q, iValue *i, iValue *n, int l, unsigned char u = 0);
 	// SF_V0 creator
-	static iOperation* New(iScript *w, const iString &p, const iString &c, int o, void (*f)(iScript*), unsigned char u = 0);
+	static iOperation* New(iScript *w, const iString &p, const iString &c, int o, void (*f)(iScript* ), unsigned char u = 0);
 	// SF_V1 creator
 	static iOperation* New(iScript *w, const iString &p, const iString &c, int o, iValue::Assignment r, iValue* v, void (*f)(iScript*,iValue*,iValue::Assignment), unsigned char u = 0);
 	// AF_V1 creator
@@ -484,7 +479,7 @@ public:
 protected:
 
 	virtual iValue* GetValue() const { return 0; }
-	virtual void SetValue(iValue*){};
+	virtual void SetValue(iValue* ){}
 	virtual bool AssignVariableValue(const iString &n, iValue::Assignment r, iValue *v, iValue *i = 0);
 	virtual bool Exec() = 0;
 
@@ -497,7 +492,7 @@ protected:
 	int LineInScript;
 
 	iOperation(iScript *w, const iString &p, const iString &s, int o, OperationType t, unsigned char u = 0);
-	virtual ~iOperation(){}
+	virtual ~iOperation();
 };
 //***************************************************************
 //
@@ -606,14 +601,14 @@ friend class iOperation;
 
 protected:
 
-	iOperation_SF_V0(iScript *w, const iString &p, const iString &s, int o, void (*f)(iScript*), unsigned char u) : iOperation(w,p,s,o,_Operation_SF_V0,u)
+	iOperation_SF_V0(iScript *w, const iString &p, const iString &s, int o, void (*f)(iScript* ), unsigned char u) : iOperation(w,p,s,o,_Operation_SF_V0,u)
 	{ 
 		Function = f; 
 	}
 
 	virtual bool Exec();
 
-	void (*Function)(iScript*);
+	void (*Function)(iScript* );
 };
 //
 //  Operation type SF_V1: 
@@ -690,17 +685,22 @@ protected:
 //
 //*******************************************************
 //
+#include "ipointermacro.h"
+
+class iErrorStatus;
 class iExpressionParser;
 class iScriptObserver;
 
 
-class iScript : public iErrorStatusHolder, public iDeletable
+class iScript : public vtkObjectBase
 {
 	
 	friend class iValue;
 	friend class iOperation; // iOperation must have access to the errorMessage string
 	friend class iScriptObserver;
 
+	IPOINTER_AS_USER(ErrorStatus);
+
 public:
 	
 	//
@@ -721,6 +721,8 @@ public:
 		iString Alias;
 	};
 	
+	vtkTypeMacro(iScript,vtkObjectBase);
+
 	void SetText(const iString &s);
 	inline const iString& GetText() const { return mText; }
 	
@@ -805,8 +807,8 @@ protected:
 	void CreateAliasWord(const iString&, const iString&);
 	void CreateDummyWord(const iString&);
 	void CreatePrefixWord(const iString&);
-	void CreateCommandWord(iOperation*);
-	void CreateParameterWord(iValue *);
+	void CreateCommandWord(iOperation *op);
+	void CreateParameterWord(iValue *val);
 
 	bool mCaseSensitive, mArraysAreReal;
 	bool mAllowChildAccess;
@@ -823,8 +825,8 @@ private:
 	//
 	//  Observers
 	//
-	void AddObserver(iScriptObserver *);
-	void RemoveObserver(iScriptObserver *);
+	void AddObserver(iScriptObserver *obs);
+	void RemoveObserver(iScriptObserver *obs);
 
 	bool mActive, mBlock;
 	int mActivator, mErrorLocation;
@@ -880,12 +882,7 @@ inline bool iScript::IsScriptWordFirstLetter(char c)
 class iScriptObserver
 {
 	
-	friend class iScript;
-
-protected:
-
-	iScriptObserver(iScript *s);
-	virtual ~iScriptObserver();
+public:
 
 	void SetScript(iScript *parent);
 
@@ -895,6 +892,11 @@ protected:
 	void OnScriptEndLine(int line, const iString &text);
 	bool OnScriptCheckAbort(int cur, int num, int level);
 
+protected:
+
+	iScriptObserver(iScript *s);
+	virtual ~iScriptObserver();
+
 	virtual void OnScriptStartBody() = 0;
 	virtual void OnScriptStopBody(const iString &error) = 0;
 	virtual void OnScriptBeginLineBody(int line, const iString &text) = 0;
