@@ -29,7 +29,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 #include "ierror.h"
-#include "itune.h"
 
 #include <math.h>
 #include <stdio.h>
@@ -75,7 +74,7 @@ public:
 	{
 		if(mRef > 1) return;
 		this->SetSize(arr->mLen);
-		iTune::CopyCharPointers(arr->mData,mData,mLen);
+		memcpy(arr->mData,mData,mLen);
 	}
 
 	inline char* GetPointer(int i) const { return mData+i; }
@@ -118,7 +117,7 @@ iString::iString(const char *s, int l)
 		mLen = strlen(s); 
 		if(l>=0 && l<mLen) mLen = l;
 		mArr->SetSize(ARRSIZE(mLen));
-		iTune::CopyCharPointers(mArr->GetPointer(0),(const char *)s,mLen+1); 
+		memcpy(mArr->GetPointer(0),(const char *)s,mLen+1); 
 	}
 	else 
 	{
@@ -231,7 +230,7 @@ iString& iString::operator+=(const iString &str)
 		//
 		//  Enough memory is already allocated, we save here
 		//
-		iTune::CopyCharPointers(mArr->GetPointer(mLen),str.mArr->GetPointer(0),str.mLen+1);
+		memcpy(mArr->GetPointer(mLen),str.mArr->GetPointer(0),str.mLen+1);
 	}
 	else
 	{
@@ -241,8 +240,8 @@ iString& iString::operator+=(const iString &str)
 		iCharArray *tmp;
 		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
 		tmp->SetSize(newsize);
-		iTune::CopyCharPointers(tmp->GetPointer(0),mArr->GetPointer(0),mLen);
-		iTune::CopyCharPointers(tmp->GetPointer(mLen),str.mArr->GetPointer(0),str.mLen+1);
+		memcpy(tmp->GetPointer(0),mArr->GetPointer(0),mLen);
+		memcpy(tmp->GetPointer(mLen),str.mArr->GetPointer(0),str.mLen+1);
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
@@ -262,12 +261,6 @@ char iString::operator[](int i) const
 }
 
 
-char& iString::operator[](int i)
-{
-	if(i < 0) return *(mArr->GetPointer(mLen+i)); else return *(mArr->GetPointer(i));
-}
-
-
 bool iString::operator==(const iString &str) const
 {
 	if(mLen != str.mLen) return false;
@@ -379,11 +372,11 @@ void iString::Replace(int index, int length, const iString &str)
 	if(newsize<=mArr->GetSize() && mArr->GetReferenceCount()==1)  
 	{
 		//
-		//  Enough memory is already allocated, we save here - but we need to use MoveCharPointers
-		//  rather than CopyCharPointers because the regions are overlapping
+		//  Enough memory is already allocated, we save here - but we need to use memmove
+		//  rather than memcpy because the regions are overlapping
 		//
-		iTune::MoveCharPointers(mArr->GetPointer(index+str.mLen),mArr->GetPointer(index+length),1+mLen-index-length);
-		iTune::MoveCharPointers(mArr->GetPointer(index),str.mArr->GetPointer(0),str.mLen);
+		memmove(mArr->GetPointer(index+str.mLen),mArr->GetPointer(index+length),1+mLen-index-length);
+		memmove(mArr->GetPointer(index),str.mArr->GetPointer(0),str.mLen);
 	}
 	else
 	{
@@ -393,9 +386,9 @@ void iString::Replace(int index, int length, const iString &str)
 		iCharArray *tmp;
 		tmp = iCharArray::New(); IERROR_ASSERT(tmp);
 		tmp->SetSize(newsize);
-		if(index > 0) iTune::CopyCharPointers(tmp->GetPointer(0),mArr->GetPointer(0),index);
-		iTune::CopyCharPointers(tmp->GetPointer(index),str.mArr->GetPointer(0),str.mLen);
-		iTune::CopyCharPointers(tmp->GetPointer(index+str.mLen),mArr->GetPointer(index+length),1+mLen-index-length);
+		if(index > 0) memcpy(tmp->GetPointer(0),mArr->GetPointer(0),index);
+		memcpy(tmp->GetPointer(index),str.mArr->GetPointer(0),str.mLen);
+		memcpy(tmp->GetPointer(index+str.mLen),mArr->GetPointer(index+length),1+mLen-index-length);
 		mArr->UnRegister();
 		mArr = tmp;
 #ifdef I_DEBUG
@@ -469,7 +462,7 @@ iString iString::FromNumber(int d, const char *format)
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
-		IERROR_FINISH("Array out of bounds.");
+		IERROR_FATAL("Array out of bounds.");
 	}
 #endif
 	return iString(s);
@@ -484,7 +477,7 @@ iString iString::FromNumber(long d, const char *format)
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
-		IERROR_FINISH("Array out of bounds.");
+		IERROR_FATAL("Array out of bounds.");
 	}
 #endif
 	return iString(s);
@@ -499,7 +492,7 @@ iString iString::FromNumber(float d, const char *format)
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
-		IERROR_FINISH("Array out of bounds.");
+		IERROR_FATAL("Array out of bounds.");
 	}
 #endif
 	return iString(s);
@@ -514,7 +507,7 @@ iString iString::FromNumber(double d, const char *format)
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
-		IERROR_FINISH("Array out of bounds.");
+		IERROR_FATAL("Array out of bounds.");
 	}
 #endif
 	return iString(s);
@@ -529,7 +522,7 @@ iString iString::FromNumber(void *d)
 #ifdef I_CHECK1
 	if(strlen(s) > n)
 	{
-		IERROR_FINISH("Array out of bounds.");
+		IERROR_FATAL("Array out of bounds.");
 	}
 #endif
 	return iString(s);
