@@ -34,6 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ifile.h"
 #include "iobject.h"
 #include "iobjecthelp.h"
+#include "iparticledatasubject.h"
 #include "iversion.h"
 
 #include <vtkCriticalSection.h>
@@ -42,10 +43,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #define I_CHECK_MISSING_REFERENCES
 
-#if defined(I_DEVEL) && defined(_WIN32)
-void qWarning(const char *msg, ...);
-#endif
-
 
 namespace iHelpFactory_Private
 {
@@ -68,7 +65,7 @@ namespace iHelpFactory_Private
 		//  Thread-safe
 		//
 		dataCompressorMutex->Lock();
-		dataCompressor->Uncompress((unsigned char*)data,csize,destData,usize);
+		dataCompressor->Uncompress((unsigned char *)data,csize,destData,usize);
 		dataCompressorMutex->Unlock();
 		destData[usize] = 0;
 	}
@@ -117,7 +114,7 @@ namespace iHelpFactory_Private
 #ifdef I_DEBUG
 			if(ss && !sorted)
 			{
-				IERROR_REPORT("Help data are not sorted.");
+				IERROR_LOW("Help data are not sorted.");
 			}
 #endif
 		}
@@ -213,7 +210,7 @@ namespace iHelpFactory_Private
 		//
 		iString ws, wlist;
 
-		iFile f(outroot+".h");
+		iFile f("Code/"+outroot+".h");
 		if(!f.Open(iFile::_Write,iFile::_Text))  return;
 
 		f.WriteLine("//LICENSE A");
@@ -246,7 +243,7 @@ namespace iHelpFactory_Private
 				//
 				usize = strlen(data[i].Buffer);
 				cmax = dataCompressor->GetMaximumCompressionSpace(usize);
-				csize = dataCompressor->Compress((const unsigned char*)data[i].Buffer,usize,(unsigned char*)ws.GetWritePointer(cmax),cmax);
+				csize = dataCompressor->Compress((const unsigned char *)data[i].Buffer,usize,(unsigned char*)ws.GetWritePointer(cmax),cmax);
 
 				//
 				//  Add list entry
@@ -323,6 +320,42 @@ namespace iHelpFactory_Private
 		return GetData(tag,data,num,sorted);
 	}
 
+	void CreateTypeReference(const iObjectType *type, iString &text, bool hidden, bool extraType, bool inherited = true)
+	{
+		iString stmp;
+		const iObjectKey *key;
+		iHelpDataBuffer *dtmp1, *dtmp2;
+
+		iObjectKeyRegistry::InitTraversal(type,inherited);
+		while((key=iObjectKeyRegistry::GetNextKey(hidden)) != 0) if(key->GetHelp()->GetText() != "#") // if not for internal use
+		{
+			dtmp1 = iHelpFactory::FindData(key->GetHelp()->GetTag(),iHelpFactory::_All,false);
+			stmp = dtmp1->GetHTML(true);
+			if(stmp[0] == '&')
+			{
+				//
+				//  Reference
+				//
+				dtmp2 = iHelpFactory::FindData(stmp.ToCharPointer(2),iHelpFactory::_All,true);
+#ifdef I_DEBUG
+				if(dtmp2->GetTitle().IsEmpty())
+				{
+					IERROR_LOW("Referenced item is missing a title.");
+				}
+#endif
+				stmp = iString("<br>See <a href=\"") + dtmp2->GetTag() + "\">" + dtmp2->GetTitle() + "</a>.";
+				delete dtmp2;
+			}
+			else
+			{
+				stmp = "<br>" + stmp;
+			}
+
+			text += iHelpFactory::FormKeyDescription(*key,stmp,true,!extraType);
+			delete dtmp1;
+		}
+	}
+
 	//
 	//  Chapter components (they are small, so are kept here
 	//
@@ -332,7 +365,7 @@ namespace iHelpFactory_Private
 	const char *cnTags[] = { "ug.cn.i", "ug.cn.ms", "ug.cn.ev", "ug.cn.cl", "ug.cn.ef", 0 };
 	const iHelpFactory::ChapterInfo ugControls("ug.cn","Controlling IFrIT",cnTags);
 
-	const char *ffTags[] = { "ug.ff.i", "ug.ff.us", "ug.ff.uv", "ug.ff.ut", "ug.ff.bp", "ug.ff.hv", "ug.ff.hp", 0 };
+	const char *ffTags[] = { "ug.ff.i", "ug.ff.us", "ug.ff.uv", "ug.ff.ut", "ug.ff.bp", 0 };
 	const iHelpFactory::ChapterInfo ugFormats("ug.ff","File Formats",ffTags);
 
 	const char *asTags[] = { "ug.as.i", "ug.as.f", 0 };
@@ -353,7 +386,7 @@ namespace iHelpFactory_Private
 	const char *clTags[] = { "sr.cl.i", 0 };
 	const iHelpFactory::ChapterInfo ugCLShell("sr.cl","Command-line Shell Reference",clTags);
 
-	const char *ggTags[] = { "sr.gg.i", "sr.gg.ds", "sr.gg.da", "sr.gg.dc", "sr.gg.dd", "sr.gg.de", "sr.gg.df", "sr.gg.di", "sr.gg.dk", "sr.gg.dp", "sr.gg.dr", "sr.gg.hcw", "sr.gg.hfo", "sr.gg.hmc", "sr.gg.hme", 0 };
+	const char *ggTags[] = { "sr.gg.i", "sr.gg.ds", "sr.gg.da", "sr.gg.dc", "sr.gg.dd", "sr.gg.de", "sr.gg.df", "sr.gg.di", "sr.gg.dk", "sr.gg.dp", "sr.gg.dr", "sr.gg.hcw", "sr.gg.hfo", "sr.gg.hmc", "sr.gg.hme", "sr.gg.cl", 0 };
 	const iHelpFactory::ChapterInfo ugGGShell("sr.gg","GUI Shell Reference",ggTags);
 
 	const char *orTags[] = { "or.i.i", "or.i.r", 0 };
@@ -439,11 +472,11 @@ const iString iHelpDataBuffer::GetExtraTag(int type) const
 		}
 	case _BeginExtraTag:
 		{
-			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]=='[')) return "<extra type="+iString(mData.Extra+2)+">"; else return none;
+			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]=='[')) return iString(iHelpFactory::IsTagPrivate(mData.Extra+2)?"<private>":"") + "<extra type="+iString(mData.Extra+2)+">"; else return none;
 		}
 	case _EndExtraTag:
 		{
-			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]==']')) return "</extra>"; else return none;
+			if(mData.Extra!=0 && mData.Extra[0]=='-' && (mData.Extra[1]=='-' || mData.Extra[1]==']')) return "</extra>" + iString(iHelpFactory::IsTagPrivate(mData.Extra+2)?"</private>":""); else return none;
 		}
 	default:
 		{
@@ -463,7 +496,7 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 
 	if(level > 9)
 	{
-		IERROR_REPORT("References are looped.");
+		IERROR_LOW("References are looped.");
 		return new iHelpDataBuffer(null,true);
 	}
 
@@ -484,8 +517,11 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 
 	if(tmp == 0)
 	{
-#if defined(I_DEVEL) && defined(_WIN32)
-		if(strstr(tag,".-") == 0) qWarning("Missing help data: %s\n",tag);
+#if defined(I_DEBUG) && defined (I_CHECK_MISSING_REFERENCES)
+		if(iString(tag).Contains(".-") == 0)
+		{
+			IERROR_LOW(("Missing reference:"+iString(tag)).ToCharPointer());
+		}
 #endif
 		return new iHelpDataBuffer(null,true);
 	}
@@ -510,27 +546,58 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 }
 
 
-void iHelpFactory::CreateUserGuide(bool full)
+#ifdef I_DEBUG
+void iHelpFactory::CreateUserGuide(UGForm form)
 {
 	static const iString afterPartTitle("<p>&nbsp;");
 	iString text, stmp;
-	iHelpDataBuffer *dtmp1, *dtmp2;
+	iHelpDataBuffer *dtmp1;
+
+	if(form == _Publish)
+	{
+		iHelpFactory::CreateUserGuide(iHelpFactory::_Public);
+		iHelpFactory::CreateUserGuide(iHelpFactory::_Private);
+		system("Work\\scripts\\createug.csh");
+		return;
+	}
 
 	iString kind;
-	if(full)
+	switch(form)
 	{
-		kind = "Full";
-	}
-	else
-	{
-		kind = "Base";
+	case _Base:
+		{
+			kind = "Base";
+			break;
+		}
+	case _Public:
+		{
+			kind = "Public";
+			break;
+		}
+	case _Private:
+		{
+			kind = "Private";
+			break;
+		}
 	}
 
 	//
 	//  Create the title page
 	//
-	stmp = "<html><head><title>Title page</title></head><body><center><img src=\"../images/genie2.png\"><p><img src=\"images/_logoug.png\" alt=\"<h1>IFrIT<br>User Guide</h1>\"><p><h2>by</h2><h1>Nick Gnedin and IFrIT</h1><p>&nbsp;<p>&nbsp;<p>&nbsp;<p><h3>IFrIT Version " + iVersion::GetVersion().Section(".",0,1) + "</center>";
-	if(full) stmp += "<p><center><h3>(Including All Extensions)</h3></center>";
+	stmp = "<html><head><title>Title page</title></head><body><center><img src=\"../images/genie2.png\"><p><img src=\"images/_logoug.png\" alt=\"<h1>IFrIT<br>User Guide</h1>\"><p><h2>by</h2><h1>Nick Gnedin and IFrIT</h1><p>&nbsp;<p>&nbsp;<p>&nbsp;<p><h3>IFrIT Version " + iVersion::GetVersion() + "</center>";
+	switch(form)
+	{
+	case _Public:
+		{
+			stmp += "<p><center><h3>(Including Public Extensions)</h3></center>";
+			break;
+		}
+	case _Private:
+		{
+			stmp += "<p><center><h3>(Including All Extensions)</h3></center>";
+			break;
+		}
+	}
 
 	//
 	//  Create preface
@@ -602,7 +669,6 @@ void iHelpFactory::CreateUserGuide(bool full)
 	//  Create object reference
 	//
 	const iObjectType *type;
-	const iObjectKey *key;
 	
 	text += "<center><a name=\"ug\"><h1>Object Reference</h1></a></center>\n";
 	text += afterPartTitle;
@@ -623,7 +689,7 @@ void iHelpFactory::CreateUserGuide(bool full)
 	text += "</ul>\n";
 
 	text += "<p><a name=\"or.vis\"><b>View objects</b></a>:<ul>\n";
-	iObjectTypeRegistry::InitTraversal(iObjectType::_Visual);
+	iObjectTypeRegistry::InitTraversal(iObjectType::_View);
 	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
 	{
 		text += FormTypeReference(*type,true);
@@ -638,47 +704,84 @@ void iHelpFactory::CreateUserGuide(bool full)
 	}
 	text += "</ul>\n";
 	
+	//
+	//  Data objects are special
+	//
+	text += "<p><a name=\"ordat\"><b>Data objects and data types</b></a>";
+	text += "<p>Names of data objects are derived from the corresponding names of data types by adding \"Data-\" in front. The following data objects are available:<ul>\n";
+	iObjectTypeRegistry::InitTraversal(iObjectType::_Data);
+	while((type=iObjectTypeRegistry::GetNextType(false))!=0)
+	{
+		if(type->GetHelp() != 0) text += type->GetHelp()->GetExtraTag(_BeginExtraTag);
+		text += "<li><b>" + type->FullName() + "</b> object (short form: <b>" + type->ShortName() + "</b>)";
+		if(type->GetHelp() != 0)
+		{
+			text += type->GetHelp()->GetExtraTag(_IconTag) + "<br>" + type->GetHelp()->GetHTML();
+		}
+		text += "</li>";
+		if(type->GetHelp() != 0) text += type->GetHelp()->GetExtraTag(_EndExtraTag);
+	}
+	text += "</ul>\n";
+	text += "All Data objects have the same set of <a href=\"or.d-a\">propeties</a>\n";
+	
 	text += "<p><hr><p>\n";
 
+	//
+	//  Include all objects except data objects.
+	//
 	bool extraType;
 	iObjectTypeRegistry::InitTraversal();
-	while((type=iObjectTypeRegistry::GetNextType(false)) != 0)
+	while((type=iObjectTypeRegistry::GetNextType(false)) != 0) if(type->Class() != iObjectType::_Data)
 	{
 		extraType = !type->GetHelp()->GetExtraTag(_BeginExtraTag).IsEmpty();
-
 		text += type->GetHelp()->GetExtraTag(_BeginExtraTag) + "<p>" + "<a name=\"or."+type->ShortName()+"\"><h2>" + type->FullName() + " object "  + type->GetHelp()->GetExtraTag(_IconTag) + "</h2><br>" + type->GetHelp()->GetHTML() + "<p>Short form: <b>" + type->ShortName() + "</b><p>Available properties:<p><ul>\n";
 
-		iObjectKeyRegistry::InitTraversal(type);
+		CreateTypeReference(type,text,false,extraType);
+
+		text += "</ul><p><hr>" + type->GetHelp()->GetExtraTag(_EndExtraTag) + "<p>\n";
+	}
+
+	//
+	//  Include the Data object.
+	//
+	text += "<p><a name=\"or.d-a\"><h2>Properties of Data Objects</h2></a><br>All data objects support the following common properties.<ul>\n";
+	CreateTypeReference(&iDataSubject::Type(),text,true,false);
+	text += "</ul>\n";
+
+	//
+	//  Include the ParticleData object.
+	//
+	text += "<p>All particle data objects also support additional properties:<ul>";
+	CreateTypeReference(&iParticleDataSubject::Type(),text,true,false);
+	text += "</ul>\n";
+
+	//
+	//  Include special properties of specific Data objects.
+	//
+	text += "<p>Some data objects can also have properties that are specific just for them:<ul>";
+
+	const iObjectKey *key;
+	iObjectTypeRegistry::InitTraversal();
+	while((type=iObjectTypeRegistry::GetNextType(false)) != 0) if(type->Class() == iObjectType::_Data)
+	{
+		iObjectKeyRegistry::InitTraversal(type,false);
+		bool hasKeys = false;
 		while((key=iObjectKeyRegistry::GetNextKey(false)) != 0) if(key->GetHelp()->GetText() != "#") // if not for internal use
 		{
-			dtmp1 = FindData(key->GetHelp()->GetTag(),_All,false);
-			stmp = dtmp1->GetHTML(true);
-			if(stmp[0] == '&')
-			{
-				//
-				//  Reference
-				//
-				dtmp2 = FindData(stmp.ToCharPointer(2),_All,true);
-#ifdef I_DEBUG
-				if(dtmp2->GetTitle().IsEmpty())
-				{
-					IERROR_REPORT("Referenced item is missing a title.");
-				}
-#endif
-				stmp = iString("<br>See <a href=\"") + dtmp2->mData.Tag + "\">" + dtmp2->GetTitle() + "</a>.";
-				delete dtmp2;
-			}
-			else
-			{
-				stmp = "<br>" + stmp;
-			}
-
-			text += FormKeyDescription(*key,stmp,true,!extraType);
-			delete dtmp1;
+			hasKeys = true;
 		}
 
-		text += "</ul><p><hr><p>" + type->GetHelp()->GetExtraTag(_EndExtraTag) + "\n";
+		if(hasKeys)
+		{
+			extraType = !type->GetHelp()->GetExtraTag(_BeginExtraTag).IsEmpty();
+			text += type->GetHelp()->GetExtraTag(_BeginExtraTag) + "<li><a name=\"or."+type->ShortName()+"\"><b>" + type->FullName() + " object "  + type->GetHelp()->GetExtraTag(_IconTag) + "</b>(short form: <b>" + type->ShortName() + "</b>)<br>" + type->GetHelp()->GetHTML() + "<br>Available properties:<ul>\n";
+
+			CreateTypeReference(type,text,false,extraType,false);
+
+			text += "</ul>" + type->GetHelp()->GetExtraTag(_EndExtraTag) + "</li><p>\n";
+		}
 	}
+	text += "</ul>\n";
 
 	//
 	//  Create appendices
@@ -694,6 +797,7 @@ void iHelpFactory::CreateUserGuide(bool full)
 #if defined(I_DEBUG) && defined (I_CHECK_MISSING_REFERENCES)
 	int i = -1;
 	bool ok = true;
+	iString mr;
 	while((i = text.Find("<a href=\"",i+1)) > -1)
 	{
 		stmp = text.Part(i+9).Section("\"",0,0);
@@ -702,9 +806,7 @@ void iHelpFactory::CreateUserGuide(bool full)
 			dtmp1 = FindData(stmp.ToCharPointer(),_All,true);
 			if(dtmp1->IsNull())
 			{
-#if defined(I_DEVEL) && defined(_WIN32)
-				qWarning("Missing reference: %s\n",stmp.ToCharPointer());
-#endif
+				mr += stmp + ",";
 				ok = false;
 			}
 			delete dtmp1;
@@ -712,35 +814,52 @@ void iHelpFactory::CreateUserGuide(bool full)
 	}
 	if(!ok)
 	{
-		cout << "Missing references." << endl;
-		exit(1);
+		IERROR_LOW(("Missing references: "+mr).ToCharPointer());
 	}
 #endif
 
 	//
 	//  Define what to create
 	//
-	if(full)
+	switch(form)
 	{
-		//
-		//  If extra info is included, remove special <extra type=...> </extra> tags 
-		//
-		text.RemoveFormatting("<extra type=",">");
-		text.Replace("</extra>","");
-	}
-	else
-	{
-		//
-		//  If extra info is not included, remove everything between <extra type=...> and </extra> tags 
-		//
-		text.RemoveFormatting("<extra type=","</extra>");
+	case _Base:
+		{
+			//
+			//  Remove everything between <extra type=...> and </extra> tags 
+			//
+			text.RemoveFormatting("<extra type=","</extra>");
+			//
+			//  No break, keep going
+			//
+		}
+	case _Public:
+		{
+			//
+			//  Remove everything between <private> and </private> tags 
+			//
+			text.RemoveFormatting("<private>","</private>");
+			break;
+		}
+	case _Private:
+		{
+			//
+			//  If extra info is included, remove special <extra type=...> </extra> and <private></private> tags 
+			//
+			text.RemoveFormatting("<extra type=",">");
+			text.Replace("</extra>","");
+			text.Replace("<private>","");
+			text.Replace("</private>","");
+			break;
+		}
 	}
 
 	//
 	//  Create the html file
 	//
-	WriteFile("Work/docs/ug"+kind+".html","<html><title>&copy; 2005-2006 by Nick Gnedin</title><body>"+text+"</body></html>");
+	WriteFile("Work/docs/ug"+kind+".html","<html><title>&copy; 2005-2007 by Nick Gnedin</title><body>"+text+"</body></html>");
 }
+#endif
 
 
 void iHelpFactory::CreateTopicList(iString &text)
@@ -917,6 +1036,16 @@ const iString iHelpFactory::FormKeyDescription(const iObjectKey &key, const iStr
 //
 //  Explicitly configued members
 //
+bool iHelpFactory::IsTagPrivate(const char *tag)
+{
+#if IEXTENSION_INCLUDED(IEXTENSION_HART)
+	static const char *hTag = "HART";
+	if(strcmp(tag,hTag) == 0) return true;
+#endif
+	return false;
+}
+
+
 void iHelpFactory::InterpretExtraElements(iString &text, const iString &tag)
 {
 	if(tag.IsEmpty() || tag=="HART")
@@ -926,6 +1055,24 @@ void iHelpFactory::InterpretExtraElements(iString &text, const iString &tag)
 		text.Replace("</extra>","");
 #else
 		text.RemoveFormatting("<extra type=HART>","</extra>");
+#endif
+	}
+	if(tag.IsEmpty() || tag=="GADGET")
+	{
+#if IEXTENSION_INCLUDED(IEXTENSION_GADGET)
+		text.Replace("<extra type=GADGET>","");
+		text.Replace("</extra>","");
+#else
+		text.RemoveFormatting("<extra type=GADGET>","</extra>");
+#endif
+	}
+	if(tag.IsEmpty() || tag=="VTK")
+	{
+#if IEXTENSION_INCLUDED(IEXTENSION_VTK)
+		text.Replace("<extra type=VTK>","");
+		text.Replace("</extra>","");
+#else
+		text.RemoveFormatting("<extra type=VTK>","</extra>");
 #endif
 	}
 }
@@ -939,6 +1086,14 @@ const iString& iHelpFactory::GetIconTag(const char *extra)
 	static const iString hTag("<img src=\"images::hart.png\">");
 	if(extra!=0 && ((extra[0]=='-' && strcmp(extra+2,"HART")==0) || strcmp(extra,"HART")==0)) return hTag;
 #endif
+#if IEXTENSION_INCLUDED(IEXTENSION_GADGET)
+	static const iString gTag("<img src=\"images::gadget.png\">");
+	if(extra!=0 && ((extra[0]=='-' && strcmp(extra+2,"GADGET")==0) || strcmp(extra,"GADGET")==0)) return gTag;
+#endif
+#if IEXTENSION_INCLUDED(IEXTENSION_VTK)
+	static const iString vtkTag("<img src=\"images::vtk.png\">");
+	if(extra!=0 && ((extra[0]=='-' && strcmp(extra+2,"VTK")==0) || strcmp(extra,"VTK")==0)) return vtkTag;
+#endif
 
 	return none;
 }
