@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Main class
 //
-ibgDialogSubject::ibgDialogSubject(iggDialog *owner, const ibgWindowSubject* /*base*/, unsigned int mode, const iImage *icon, const iString &title) : ibgWindowSubject(owner?owner->GetShell():0), mIcon(icon), mTitle(title)
+ibgDialogSubject::ibgDialogSubject(iggDialog *owner, const ibgWindowSubject* /*base*/, unsigned int mode, const iImage *icon, const iString &title) : ibgWindowSubject(owner?owner->GetShell():0)
 {
 	IERROR_ASSERT(owner);
 	mOwner = owner;
