@@ -35,7 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggmainwindow.h"
 
 
-ibgExtensionWindowSubject::ibgExtensionWindowSubject(iggExtensionWindow *ew, bool) : ibgWindowSubject(ew?ew->GetShell():0)
+ibgExtensionWindowSubject::ibgExtensionWindowSubject(iggExtensionWindow *ew) : ibgWindowSubject(ew?ew->GetShell():0)
 {
 	mExtensionWindow = ew; IERROR_ASSERT(ew);
 	mExtensionWindow->GetMainWindow()->Register(this);
