@@ -141,7 +141,7 @@ bool ibgRenderWindowSubject::IsInteractorPresent()
 {
 	if(mInteractor == 0)
 	{
-		mInteractor = iPointerCast<iggRenderWindowInteractor,vtkRenderWindowInteractor>(mOwner->GetInteractor());
+		mInteractor = iRequiredCast<iggRenderWindowInteractor>(INFO,mOwner->GetInteractor());
 	}
 	return mInteractor != 0;
 }
