@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 bool ibgWindowSubject::mIsBlocked = false;
 
 
-ibgWindowSubject::ibgWindowSubject(iShell *shell) : iShellComponent(shell)
+ibgWindowSubject::ibgWindowSubject(iShell *shell) : mShell(shell)
 {
 	mWindowHelper = 0;
 	mIsBeingDeleted = false;
