@@ -32,6 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icontrolmodule.h"
 #include "ierror.h"
 #include "iinteractoreventrecorder.h"
+#include "ioutputchannel.h"
 #include "iviewmodule.h"
 
 #include "iclcommandinterpreter.h"
@@ -41,10 +42,43 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkRenderWindowInteractor.h>
 
 
-iclShell::iclShell(int argc, char **argv) : iShell(argc,argv)
+class iclOutputChannel : public iOutputChannel
 {
-	mType = "cl";
 
+public:
+
+	iclOutputChannel(iShell *s) : iOutputChannel(s)
+	{
+	}
+
+protected:
+
+	virtual void DisplayBody(iConsole::MessageType type, const iString &message, const char *file, int line)
+	{
+		iString text = this->FormPlainTextMessage(type,message,file,line);
+
+		switch(type)
+		{
+		case iConsole::_Info:
+			{
+				cout << text.ToCharPointer();
+				break;
+			}
+		case iConsole::_Warning:
+		case iConsole::_LowError:
+		case iConsole::_HighError:
+		case iConsole::_FatalError:
+			{
+				cerr << text.ToCharPointer();
+				break;
+			}
+		}
+	}
+};
+
+
+iclShell::iclShell(int argc, char **argv) : iShell("cl",argc,argv)
+{
 	mInterpreter = 0; // must be constructed when the shell is complete.
 	mContinue = false;
 }
@@ -70,38 +104,31 @@ void iclShell::PrepareForConstruction()
 void iclShell::ConstructorBody()
 {
 	mInterpreter = new iclCommandInterpreter(this); IERROR_ASSERT(mInterpreter);
+	iOutputChannel::SetInstance(new iclOutputChannel(this));
 }
 
   
 void iclShell::DestructorBody()
 {
-	delete mInterpreter;
+	mInterpreter->Stop();
+	mInterpreter->Delete();
 }
 
 
-void iclShell::LoadStateFile(const iString &fname)
+void iclShell::PrepareToLoadStateFile()
 {
-	if(fname.IsEmpty()) return;
-
-	if(!mControlModule->LoadStateFromFile(fname)) this->OutputStartupMessage("Unable to load the state file.\nDefault values of parameters will be used.");
-}
-
-
-void iclShell::OutputStartupMessage(const iString &message)
-{
-	cerr << message.ToCharPointer() << endl;
 }
 
 
 void iclShell::Start()
 {
 	int i;
-	for(i=0; i<mControlModule->GetNumberOfViewModules(); i++)
+	for(i=0; i<this->ControlModule()->GetNumberOfViewModules(); i++)
 	{
-		mControlModule->GetViewModule(i)->GetInteractor()->Disable();
-		mControlModule->GetViewModule(i)->SetAntialiasing(true);
+		this->ControlModule()->GetViewModule(i)->GetInteractor()->Disable();
+		this->ControlModule()->GetViewModule(i)->SetAntialiasing(true);
 	}
-	mControlModule->Render();  // render all windows
+	this->ControlModule()->Render();  // render all windows
 	mInterpreter->Start();
 
 	mContinue = true;
@@ -121,10 +148,10 @@ void iclShell::RunBody()
 	//
 	while(mContinue && mInterpreter->Exec()==0)
 	{
-		mControlModule->GetViewModule()->GetInteractor()->Enable();
-		mControlModule->GetViewModule()->GetEventRecorder()->SetInteractor(0); // does not work with this shell
-		mControlModule->GetViewModule()->GetInteractor()->Start();
-		mControlModule->GetViewModule()->GetInteractor()->Disable();
+		this->ControlModule()->GetViewModule()->GetInteractor()->Enable();
+		this->ControlModule()->GetViewModule()->GetEventRecorder()->SetInteractor(0); // does not work with this shell
+		this->ControlModule()->GetViewModule()->GetInteractor()->Start();
+		this->ControlModule()->GetViewModule()->GetInteractor()->Disable();
 	}
 }
 
@@ -138,7 +165,7 @@ bool iclShell::AnalyseOneExtendedCommandLineOption(const struct Option&)
 //
 //  State saving
 //
-bool iclShell::LoadShellStateFromFile(iFile &)
+bool iclShell::LoadShellStateFromFileBody(iFile &)
 {
 	//
 	//  Nothing to do here
@@ -147,7 +174,7 @@ bool iclShell::LoadShellStateFromFile(iFile &)
 }
 
 
-bool iclShell::SaveShellStateToFile(iFile &) const
+bool iclShell::SaveShellStateToFileBody(iFile &) const
 {
 	//
 	//  Nothing to do here
@@ -155,12 +182,3 @@ bool iclShell::SaveShellStateToFile(iFile &) const
 	return true;
 }
 
-
-#ifdef I_DEBUG
-void iclShell::OutputDebugMessage(const iString &message) const
-{
-	cout << message.ToCharPointer() << endl;
-}
-
-#endif
-
