@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-#define curScript		iPointerCast<iggControlScript,iScript>(me)
+#define curScript	iRequiredCast<iggControlScript>(INFO,me)
 
 
 iggControlScript::iggControlScript(iControlModule *cm, iScript *parent) : iControlScript(cm,parent)
@@ -68,7 +68,9 @@ void iggControlScript::OutputText(const iString &s)
 	}
 	else
 	{
-		IERROR_REPORT("CommandInterpreter is not connected.");
+		iString ws(s);
+		ws.ReformatHTMLToText();
+		iConsole::Display(iConsole::_Info,ws);
 	}
 }
 
@@ -81,7 +83,9 @@ void iggControlScript::OutputError(const iString &s)
 	}
 	else
 	{
-		IERROR_REPORT("CommandInterpreter is not connected.");
+		iString ws(s);
+		ws.ReformatHTMLToText();
+		iConsole::Display(iConsole::_LowError,ws);
 	}
 }
 
