@@ -34,19 +34,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatareader.h"
 #include "idatasubject.h"
 #include "ierror.h"
+#include "ifieldviewsubject.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 #include "iviewobject.h"
-#include "iviewsubject.h"
 
+#include "iggextensionwindow.h"
 #include "iggmainwindow.h"
 #include "iggpageobject.h"
 
+//
+//  Templates
+//
+#include "iarraytemplate.h"
+
 
 //
 //  Base class
 //
-iggDataTypeProvider::iggDataTypeProvider(iShell *s) : iShellComponent(s)
+iggDataTypeProvider::iggDataTypeProvider(iShell *s) : iggElement(s)
 {
 }
 
@@ -58,12 +64,12 @@ iggDataTypeProvider::~iggDataTypeProvider()
 
 const iObjectKey& iggDataTypeProvider::Translate(const iObjectKey &key) const
 {
-	if(key.Type() == iDataSubject::Type())
+	if(key.Type().Class() == iObjectType::_Data)
 	{
 		iDataSubject *subject = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetSubject(this->GetActiveDataType());
 		if(subject == 0) return key;
 
-		const iObjectKey *p = iObjectKeyRegistry::FindKey(key.RetypedKey(subject->RealType()));
+		const iObjectKey *p = iObjectKeyRegistry::FindKey(key.RetypedKey(subject->GetObjectType()));
 		if(p == 0) return key; else return *p;
 	}
 	else
@@ -122,7 +128,18 @@ iggKeywordDataTypeProvider::iggKeywordDataTypeProvider(const iString &keywords,
 	mActiveIndex = 0;
 	mInfoPointer = new iDataInfo; IERROR_ASSERT(mInfoPointer);
 
-	iDataType::FindAllTypesByKeywords(*mInfoPointer,keywords);
+	if(keywords.IsEmpty())
+	{
+		*mInfoPointer = iDataInfo::Any();
+	}
+	else
+	{
+		iDataType::FindTypesByKeywords(*mInfoPointer,keywords);
+		if(mInfoPointer->Count() == 0)
+		{
+			IERROR_FATAL("No data types found.");
+		}
+	}
 }
 
 
@@ -134,7 +151,7 @@ iggKeywordDataTypeProvider::~iggKeywordDataTypeProvider()
 
 bool iggKeywordDataTypeProvider::IsThereDataType() const
 {
-	return (iData::None() != this->GetActiveDataType());
+	return (!this->GetActiveDataType().IsNull());
 }
 
 
@@ -166,6 +183,7 @@ void iggKeywordDataTypeProvider::SetActiveDataTypeIndex(int v)
 	if(mActiveIndex!=v && v>=0 && v<mInfoPointer->Count())
 	{
 		mActiveIndex = v;
+		mParent->GetMainWindow()->GetExtensionWindow()->UpdateOnDataType(this->GetActiveDataType());
 		mParent->UpdateWidget();
 	}
 }
@@ -185,11 +203,118 @@ const iDataType& iggKeywordDataTypeProvider::GetActiveDataType() const
 	}
 	else
 	{
-		return iData::None();
+		return iDataType::Null();
 	}
 }
 
 
+//
+//  DataTypeProvider that uses other iggKeywordDataTypeProvider(s) to provide data types.
+//
+iggCompositeDataTypeProvider::iggCompositeDataTypeProvider(iggWidget *parent) : iggKeywordDataTypeProvider("",parent)
+{
+	mCurrentIndex = -1;
+}
+
+
+iggCompositeDataTypeProvider::~iggCompositeDataTypeProvider()
+{
+}
+
+
+void iggCompositeDataTypeProvider::AddProvider(iggKeywordDataTypeProvider *p)
+{
+	IERROR_ASSERT(p);
+	mProviders.Add(p);
+	mCurrentIndex = mProviders.MaxIndex();
+}
+
+
+void iggCompositeDataTypeProvider::SetCurrentIndex(int n)
+{
+	//
+	//  Allow an index of -1 to reset this class to the provider-less state
+	//
+	if(n>=-1 && n<mProviders.Size()) mCurrentIndex = n;
+}
+
+
+iggKeywordDataTypeProvider* iggCompositeDataTypeProvider::GetCurrentProvider() const
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		return mProviders[mCurrentIndex];
+	}
+	else return 0; 
+}
+
+
+iggKeywordDataTypeProvider* iggCompositeDataTypeProvider::GetProvider(int n) const
+{
+	if(n>=0 && n<mProviders.Size())
+	{
+		return mProviders[n];
+	}
+	else return 0; 
+}
+
+
+void iggCompositeDataTypeProvider::FindAvailableData()
+{
+	int i;
+	for(i=0; i<mProviders.Size(); i++) mProviders[i]->FindAvailableData();
+}
+
+
+bool iggCompositeDataTypeProvider::IsThereDataType() const
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		return mProviders[mCurrentIndex]->IsThereDataType();
+	}
+	else return false;
+}
+
+
+int iggCompositeDataTypeProvider::GetActiveDataTypeIndex() const
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		return mProviders[mCurrentIndex]->GetActiveDataTypeIndex();
+	}
+	else return -1;
+}
+
+
+void iggCompositeDataTypeProvider::SetActiveDataTypeIndex(int v)
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		mProviders[mCurrentIndex]->SetActiveDataTypeIndex(v);
+	}
+}
+
+
+const iDataInfo& iggCompositeDataTypeProvider::GetDataInfo() const
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		return mProviders[mCurrentIndex]->GetDataInfo();
+	}
+	else return iDataInfo::None();
+}
+
+
+const iDataType& iggCompositeDataTypeProvider::GetActiveDataType() const
+{
+	if(mCurrentIndex>=0 && mCurrentIndex<mProviders.Size())
+	{
+		return mProviders[mCurrentIndex]->GetActiveDataType();
+	}
+	else return iDataType::Null();
+}
+
+
 //
 //  DataTypeProvider for a ViewSubject
 //
@@ -215,6 +340,7 @@ void iggViewSubjectDataTypeProvider::SetActiveDataTypeIndex(int v)
 	if(v != mPage->GetViewObject()->GetActiveDataTypeIndex())
 	{
 		mPage->GetViewObject()->SetActiveDataTypeIndex(v);
+		mPage->GetMainWindow()->GetExtensionWindow()->UpdateOnDataType(this->GetActiveDataType());
 		mPage->GetMainWindow()->UpdateAll();
 	}
 }
@@ -235,27 +361,23 @@ const iDataType& iggViewSubjectDataTypeProvider::GetActiveDataType() const
 //
 //  DataTypeProvider that returns scalar data
 //
-iggScalarFieldDataTypeProvider::iggScalarFieldDataTypeProvider(iggPageObject *page) : iggViewSubjectDataTypeProvider(page)
+iggScalarDataTypeProvider::iggScalarDataTypeProvider(iggPageObject *page) : iggViewSubjectDataTypeProvider(page)
 {
 }
 
 
-iggScalarFieldDataTypeProvider::~iggScalarFieldDataTypeProvider()
-{
-}
-
-
-const iDataInfo& iggScalarFieldDataTypeProvider::GetDataInfo() const
+const iDataInfo& iggScalarDataTypeProvider::GetDataInfo() const
 {
 #ifdef I_CHECK1
 	IERROR_REPORT_BUG;
 #endif
-	return mPage->GetViewObject()->GetPrimaryDataInfo();
+	return iDataInfo::None();
 }
 
 
-const iDataType& iggScalarFieldDataTypeProvider::GetActiveDataType() const
+const iDataType& iggScalarDataTypeProvider::GetActiveDataType() const
 {
-	return iDataType::ReSpecifyType(mPage->GetViewObject()->GetDataType(),"ScalarField");
+	iFieldViewSubject *fs = iFieldViewSubject::SafeDownCast(mPage->GetViewObject()->GetViewSubject());
+	if(fs != 0) return fs->GetScalarDataType(); else return iDataType::Null();
 }
 
