@@ -37,6 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggmainwindow.h"
 #include "iggmenuwindow.h"
 #include "iggparameter.h"
+#include "iggshell.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgdialogsubject.h"
@@ -48,30 +49,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Main class
 //
-iggDialog::iggDialog(iShell *shell, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext) : iShellComponent(shell)
+iggDialog::iggDialog(iShell *shell, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(shell)
 {
 	mMainWindow = 0;
-	this->Define(0,mode,icon,title,helpkey,cols,withclose,closetext);
+	this->Define(0,mode,icon,title,helpkey,cols,closetext);
 }
 
 
-iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext) : iShellComponent(mw==0?0:mw->GetShell())
+iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(mw==0?0:mw->GetShell())
 {
 	IERROR_ASSERT(mw);
 	mMainWindow = mw->GetMainWindow();
-	this->Define(mw->GetSubject(),mode,icon,title,helpkey,cols,withclose,closetext);
+	this->Define(mw->GetSubject(),mode,icon,title,helpkey,cols,closetext);
 }
 
 
-iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext) : iShellComponent(pd==0?0:pd->GetShell())
+iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext) : iggElement(pd==0?0:pd->GetShell())
 {
 	IERROR_ASSERT(pd);
 	mMainWindow = pd->GetMainWindow();
-	this->Define(pd->GetSubject(),mode,icon,title,helpkey,cols,withclose,closetext);
+	this->Define(pd->GetSubject(),mode,icon,title,helpkey,cols,closetext);
 }
 
 
-void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext)
+void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext)
 {
 	mSubject = iggSubjectFactory::CreateDialogSubject(this,base,mode,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_ASSERT(mSubject);
 	if(mMainWindow != 0) mMainWindow->Register(mSubject);
@@ -79,18 +80,20 @@ void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iI
 	if(cols < 1)
 	{
 		cols = 1;
-		IERROR_REPORT("Incorrect number of columns in iggDialog frame.");
+		IERROR_LOW("Incorrect number of columns in iggDialog frame.");
 	}
 
 	mMode = mode;
 
-	if(withclose)
+	if(closetext!=0 && (closetext[0]!=0 || !iDynamicCast<iggShell,iShell>(INFO,this->GetShell())->IsWindowManagerModern()))
 	{
 		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_ASSERT(tmp);
 		mSubject->SetFrame(tmp->GetSubject());
 		mFrame = new iggFrame(tmp,cols); IERROR_ASSERT(mFrame);
 		tmp->AddLine(mFrame,3);
-		tmp->AddLine((iggWidget *)0,new iggWidgetDialogCloseButton(this,tmp,closetext),(iggWidget *)0);
+		iggFrame *tmp1 = new iggFrame("",tmp);
+		tmp1->AddLine(new iggWidgetDialogCloseButton(this,tmp1,(closetext[0]==0)?"Close":closetext));
+		tmp->AddLine(static_cast<iggWidget*>(0),tmp1,static_cast<iggWidget*>(0));
 		tmp->SetColStretch(0,10);
 		tmp->SetColStretch(2,10);
 		if((mMode & iggParameter::_DialogNoTitleBar) != 0)
@@ -157,7 +160,7 @@ void iggDialog::Show(bool s)
 {
 	if(mFrame == 0)
 	{
-		IERROR_REPORT("No frame was set for this dialog.");
+		IERROR_LOW("No frame was set for this dialog.");
 		return;
 	}
 
@@ -182,7 +185,7 @@ void iggDialog::UpdateDialog()
 {
 	if(mFrame == 0)
 	{
-		IERROR_REPORT("No frame was set for this dialog.");
+		IERROR_LOW("No frame was set for this dialog.");
 		return;
 	}
 	mFrame->UpdateWidget();
