@@ -110,7 +110,7 @@ namespace iggDialogAnimatingProgress_Private
 using namespace iggDialogAnimatingProgress_Private;
 
 
-iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Animating...",0,4,false), iScriptObserver(0)
+iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Animating...",0,4,0), iScriptObserver(0)
 {
 	mFrame->AddLine(new iggWidgetTextArea("%bAnimating the scene...",mFrame),4);
 	
@@ -159,6 +159,8 @@ void iggDialogAnimatingProgress::OnScriptStartBody()
     mCancelled = false;
 	this->Pause(false);
 
+	mLastImageIndex = mLastRecord = mLastFrame = -1;
+
 	this->DisplayInfo();
 
 	this->Show(true);
@@ -187,12 +189,25 @@ void iggDialogAnimatingProgress::OnScriptEndLineBody(int, const iString &)
 void iggDialogAnimatingProgress::DisplayInfo()
 {
 	bool nr;
-	int cr, cf;
-
+	int cr, cf, cii = mCurrentViewModule->GetWriter()->GetCurrentAnimationImageIndex();
+	
 	mCurrentViewModule->GetAnimator()->GetInfo(nr,cr,cf);
-	mCurrentImageNumber->SetText(iString::FromNumber(mCurrentViewModule->GetWriter()->GetCurrentAnimationImageIndex(),"%5d"));
-	mCurrentRecord->SetText(iString::FromNumber(cr,"%4d"));
-	mCurrentFrame->SetText(iString::FromNumber(cf,"%4d"));
+
+	if(cii != mLastImageIndex)
+	{
+		mLastImageIndex = cii;
+		mCurrentImageNumber->SetText(iString::FromNumber(cii,"%5d"));
+	}
+	if(cr != mLastRecord)
+	{
+		mLastRecord = cr;
+		mCurrentRecord->SetText(iString::FromNumber(cr,"%4d"));
+	}
+	if(cf != mLastFrame)
+	{
+		mLastFrame = cf;
+		mCurrentFrame->SetText(iString::FromNumber(cf,"%4d"));
+	}
 }
 
 
