@@ -88,7 +88,7 @@ namespace iggDialogCommandLine_Private
 			this->Script()->Run(text,true,false);
 			if(this->Script()->GetErrorStatus()->IsError())
 			{
-				msg = this->Script()->GetErrorStatus()->GetMessage();
+				msg = this->Script()->GetErrorStatus()->Message();
 				para = this->Script()->GetCurrentLine();
 				index = this->Script()->GetErrorLocation();
 			}
@@ -113,7 +113,7 @@ namespace iggDialogCommandLine_Private
 			}
 
 			mCurLine = 0;
-			iPointerCast<iggControlScript,iControlScript>(this->Script())->AttachCommandInterpreter(this);
+			iRequiredCast<iggControlScript>(INFO,this->Script())->AttachCommandInterpreter(this);
 
 			for(i=0; i<mNumLines; i++)
 			{
@@ -122,7 +122,7 @@ namespace iggDialogCommandLine_Private
 
 			this->Exec();
 
-			iPointerCast<iggControlScript,iControlScript>(this->Script())->AttachCommandInterpreter(0);
+			iRequiredCast<iggControlScript>(INFO,this->Script())->AttachCommandInterpreter(0);
 			//
 			//  After execution
 			//
@@ -137,13 +137,13 @@ namespace iggDialogCommandLine_Private
 			this->Script()->GetErrorStatus()->Clear(); // need to do this explicitly, otherwise it is never cleared after the first error
 
 			mCurLine = 0;
-			iPointerCast<iggControlScript,iControlScript>(this->Script())->AttachCommandInterpreter(this);
+			iRequiredCast<iggControlScript>(INFO,this->Script())->AttachCommandInterpreter(this);
 
 			this->DislayLineOfText("<nobr><b>"+mCurCode+"</b></nobr>",_CommandInterpreterTextTypeCode);
 
 			this->ExecLine(mCurCode);
 
-			iPointerCast<iggControlScript,iControlScript>(this->Script())->AttachCommandInterpreter(0);
+			iRequiredCast<iggControlScript>(INFO,this->Script())->AttachCommandInterpreter(0);
 			//
 			//  After execution
 			//
@@ -175,7 +175,7 @@ namespace iggDialogCommandLine_Private
 				}
 			default:
 				{
-					IERROR_REPORT("Ivalid text type.");
+					IERROR_LOW("Ivalid text type.");
 				}
 			}
 		}
@@ -320,7 +320,7 @@ namespace iggDialogCommandLine_Private
 
 	public:
 
-		CommandSingleLineEditor(CommandInterpreter *ci, iggDialogCommandLine *dialog, iggFrame *parent) : iggWidget(parent), mHistory(iString(),100)
+		CommandSingleLineEditor(CommandInterpreter *ci, iggDialogCommandLine *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mInterpreter = ci;
 			mDialog = dialog;
@@ -471,7 +471,7 @@ namespace iggDialogCommandLine_Private
 			int i, n;
             iString fn;
 
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentScript);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentScript);
 			fn = this->GetMainWindow()->GetFileName("Save script file",mOldFileName,"Script file (*.ics)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ics") fn += ".ics";
 
@@ -510,13 +510,13 @@ namespace iggDialogCommandLine_Private
 
 	public:
 
-		ViewScriptDialog(CommandInterpreter *ci, iggDialogCommandLine *parent) : iggDialog(parent,_DialogModal,0,"View Script Text",0,3,false)
+		ViewScriptDialog(CommandInterpreter *ci, iggDialogCommandLine *parent) : iggDialog(parent,_DialogModal,0,"View Script Text",0,3)
 		{
 			mInterpreter = ci;
 			mBrowser = new iggWidgetTextBrowser(false,true,mFrame);
 
 			mFrame->AddLine(mBrowser,3);
-			mFrame->AddLine(new SaveScriptButton(ci,this,mFrame),(iggWidget *)0,new iggWidgetDialogCloseButton(this,mFrame));
+			mFrame->AddLine(new SaveScriptButton(ci,this,mFrame),static_cast<iggWidget*>(0),new iggWidgetDialogCloseButton(this,mFrame));
 			mFrame->SetRowStretch(0,10);
 			mFrame->SetColStretch(1,10);
 
@@ -552,7 +552,7 @@ namespace iggDialogCommandLine_Private
 using namespace iggDialogCommandLine_Private;
 
 
-iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("comline.png"),"Command Line","sr.gg.dc",1,false)
+iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("comline.png"),"Command Line","sr.gg.dc",1,0)
 {
 	iggWidgetTextBrowser *b = new iggWidgetTextBrowser(true,false,mFrame);
 	CommandInterpreter *ci = new CommandInterpreter(b);
@@ -598,7 +598,7 @@ iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(pa
 	//  Bottom line of buttons
 	//
 	tmp = new iggFrame(mFrame,4);
-	tmp->AddLine(new iggWidgetLaunchButton(mViewScriptDialog,"Show script",tmp),new ResetScriptButton(ci,tmp),(iggWidget *)0,new iggWidgetDialogCloseButton(this,tmp));
+	tmp->AddLine(new iggWidgetLaunchButton(mViewScriptDialog,"Show script",tmp),new ResetScriptButton(ci,tmp),static_cast<iggWidget*>(0),new iggWidgetDialogCloseButton(this,tmp));
 	tmp->SetColStretch(2,10);
 
 	mFrame->AddLine(tmp);
@@ -612,7 +612,7 @@ iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(pa
 iggDialogCommandLine::~iggDialogCommandLine()
 {
 	delete mViewScriptDialog;
-	delete mInterpreter;
+	mInterpreter->Delete();
 }
 
 
