@@ -210,7 +210,7 @@ namespace iggDialogDataExplorer_Private
 
 	public:
 
-		ExploredVariablesList(iggDialogDataExplorer *de, iggFrame *parent) : iggWidgetListView(true,parent), mVariables(Variable())
+		ExploredVariablesList(iggDialogDataExplorer *de, iggFrame *parent) : iggWidgetListView(true,parent)
 		{
 			mDataExplorer = de;
 			mMaxNameLength = -1;
@@ -716,6 +716,8 @@ namespace iggDialogDataExplorer_Private
 			int i, n = v.Size();
 			iDataExplorer::Info d;
 
+			this->GetMainWindow()->Block(true);
+
 			//
 			//  Compute the global range first
 			//
@@ -757,6 +759,8 @@ namespace iggDialogDataExplorer_Private
 				//
 				if(i < n-1) mSubject->BlendForegroundOntoBackground(v[i].Opacity);
 			}
+
+			this->GetMainWindow()->Block(false);
 		}
 
 		virtual void DrawForegroundBody()
@@ -946,7 +950,7 @@ namespace iggDialogDataExplorer_Private
 				}
 			default:
 				{
-					IERROR_FINISH("Invalid type");
+					IERROR_FATAL("Invalid type");
 				}
 			}
 		}
@@ -988,7 +992,7 @@ namespace iggDialogDataExplorer_Private
 				}
 			default:
 				{
-					IERROR_FINISH("Invalid type");
+					IERROR_FATAL("Invalid type");
 				}
 			}
 			mNeedsBaloonHelp = false;
@@ -1130,7 +1134,7 @@ namespace iggDialogDataExplorer_Private
 					}
 				default:
 					{
-						IERROR_REPORT("Invalid choice.");
+						IERROR_LOW("Invalid choice.");
 						p = 0;
 					}
 				}
@@ -1221,9 +1225,9 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 {
 	iggFrame *box1, *box2, *tmp1, *tmp2;
 
-	mStretch = 1;
+	this->SetStretch(iParameter::_StretchLog);
 
-	mProvider = new iggKeywordDataTypeProvider("ScalarField,ParticleSet",this->GetFrame()); IERROR_ASSERT(mProvider);
+	mProvider = new iggKeywordDataTypeProvider("",this->GetFrame()); IERROR_ASSERT(mProvider);
 
 	mFlashFrame = new iggFrameFlip(mFrame);
 	tmp1 = new iggFrame(mFlashFrame,2);
@@ -1242,7 +1246,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 	Area *area = new Area(this,el,tmp1);
 	el->CreatePropertiesDialog(area);
 	tmp1->AddLine(area);
-	tmp1->AddLine(new iggFrameHistogramAreaExtra(area,tmp1));
+	tmp1->AddLine(new iggFrameHistogramAreaExtra(area,tmp1,false));
 	tmp1->AddLine(new StretchComboBox(this,el,tmp1));
 	tmp1->SetRowStretch(0,10);
 
@@ -1298,7 +1302,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 	tmp1->AddLine(b1);
 	tmp1->AddSpace(10);
 	box2->AddLine(tmp1,al);
-	box2->AddLine((iggWidget*)0,dts);
+	box2->AddLine(static_cast<iggWidget*>(0),dts);
 
 //	mFrame->AddLine(box1,box2);
 	mFrame->AddLine(mFlashFrame,2);
