@@ -79,7 +79,7 @@ namespace iggDialogEventRecorder_Private
 		virtual void Execute()
 		{
 			iString fn, oldfn = mDialog->GetEventRecorder()->GetFileName();
-			if(oldfn.IsEmpty()) oldfn = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentBase);
+			if(oldfn.IsEmpty()) oldfn = this->GetShell()->GetEnvironment(_EnvironmentBase);
 			fn = this->GetMainWindow()->GetFileName("Open record file",oldfn,"Event record (*.ier)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ier") fn += ".ier";
 
@@ -148,7 +148,7 @@ namespace iggDialogEventRecorder_Private
 				}
 			default:
 				{
-					IERROR_FINISH("Incorrect button type.");
+					IERROR_FATAL("Incorrect button type.");
 				}
 			}
 			mButton->SetIcon(*mIconOff);
