@@ -192,7 +192,7 @@ using namespace iggDialogHelp_Private;
 //
 //  Main class
 //
-iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Help","sr.gg.dh",2,false)
+iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Help","sr.gg.dh",2)
 {
 	HelpBrowser *hb = new HelpBrowser(this,mFrame);
 	TopicList *tc = new TopicList(hb,mFrame);
@@ -200,8 +200,8 @@ iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Hel
 
 	iggFrame *tmp = new iggFrame(mFrame,5);
 	mFrame->AddLine(tmp,2);
-	tmp->AddLine(new NavigationButton(-1,mBrowser,tmp),new NavigationButton(1,mBrowser,tmp),new NavigationButton(0,mBrowser,tmp),(iggWidget *)0,new iggWidgetDialogCloseButton(this,tmp));
-	tmp->AddLine(new iggWidgetTextArea("Back",tmp),new iggWidgetTextArea("Forward",tmp),new iggWidgetTextArea("Home",tmp),(iggWidget *)0,(iggWidget *)0);
+	tmp->AddLine(new NavigationButton(-1,mBrowser,tmp),new NavigationButton(1,mBrowser,tmp),new NavigationButton(0,mBrowser,tmp),static_cast<iggWidget*>(0),new iggWidgetDialogCloseButton(this,tmp));
+	tmp->AddLine(new iggWidgetTextArea("Back",tmp),new iggWidgetTextArea("Forward",tmp),new iggWidgetTextArea("Home",tmp),static_cast<iggWidget*>(0),static_cast<iggWidget*>(0));
 	tmp->SetColStretch(3,10);
 
 	mFrame->AddLine(tc->Self(),mBrowser->Self());
