@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icontrolmodule.h"
 #include "iimagecomposer.h"
+#include "iimagecomposerwindows.h"
 #include "iimagefactory.h"
 #include "imath.h"
 #include "ishell.h"
@@ -42,6 +43,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetkeybutton.h"
 #include "iggwidgetkeycolorselection.h"
 #include "iggwidgetkeyselectionbox.h"
+#include "iggwidgetkeyslider.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgwidgetareasubject.h"
@@ -94,7 +96,7 @@ namespace iggDialogImageComposer_Private
 			//  Is there a foreground window? Search them backwards, as the later
 			//  windows are higher
 			//
-			n = ic->GetNumForegroundWindows();
+			n = ic->GetNumberOfForegroundWindows();
 			for(i=n-1; i>=0; i--) //  later added windows are on top, so loop in the reverse order
 			{
 				fw = ic->GetForegroundWindow(i);
@@ -128,6 +130,7 @@ namespace iggDialogImageComposer_Private
 			{
 				mDialog->SetCurrentBackgroundWindow(i+j*ic->GetNumTilesX());
 				mSubject->RequestPainting();
+				this->UpdateDependents();
 			}
 		}
 
@@ -142,6 +145,7 @@ namespace iggDialogImageComposer_Private
 				fw->SetPosition(fw->GetPositionX()+mPosX-mOldPosX,fw->GetPositionY()+mPosY-mOldPosY);
 				mIsMovingForegroundWindow = false;
 				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				this->UpdateDependents();
 			}
 		}
 
@@ -262,9 +266,8 @@ namespace iggDialogImageComposer_Private
 	
 		virtual void DrawForegroundBody()
 		{
-			static const iColor white = iColor(255,255,255);
-			int i, x, y, w, h, v, n;
-			iColor c;
+			int i, x, y, w, h, v, n, bw;
+			iColor bc;
 			iImageComposerForegroundWindow *fw;
 
 			//
@@ -275,12 +278,15 @@ namespace iggDialogImageComposer_Private
 			//
 			//  Draw
 			//
-			n = ic->GetNumForegroundWindows();
+			n = ic->GetNumberOfForegroundWindows();
 			int cfw = mDialog->GetCurrentForegroundWindow();
 			for(i=0; i<n; i++)
 			{
 				fw = ic->GetForegroundWindow(i);
 
+				//
+				//  Compute window parameters
+				//
 				if(i==cfw && mIsMovingForegroundWindow)
 				{
 					x = round(mScaleFactor*(fw->GetPositionX()+mPosX-mOldPosX));
@@ -308,7 +314,32 @@ namespace iggDialogImageComposer_Private
 				x += mStartX;
 				y += mStartY;
 				v = fw->GetViewModule()->GetWindowNumber();
-				this->DrawWindow(x,y,w,h,fw->GetViewModule()->GetBackgroundColor(),1+int(mScaleFactor*fw->GetBorderWidth()),fw->GetBorderColor(),v,0,i==mDialog->GetCurrentForegroundWindow());
+				bw = 1 + int(mScaleFactor*fw->GetBorderWidth()); if(fw->GetBorderWidth() == 0) bw = 0;
+				bc = fw->GetBorderColor();
+
+				//
+				//  Is there a zoom source?
+				//
+				if(fw->GetZoomSource() != 0)
+				{
+					int zx = mStartX + round(mScaleFactor*(fw->GetZoomSource()->GetContentsX()+(fw->GetZoomX()-0.5*fw->GetZoomWidth())*fw->GetZoomSource()->GetContentsWidth()));
+					int zy = mStartY + round(mScaleFactor*(fw->GetZoomSource()->GetContentsY()+(fw->GetZoomY()-0.5*fw->GetZoomHeight())*fw->GetZoomSource()->GetContentsHeight()));
+					int zw = round(mScaleFactor*fw->GetZoomWidth()*fw->GetZoomSource()->GetContentsWidth());
+					int zh = round(mScaleFactor*fw->GetZoomHeight()*fw->GetZoomSource()->GetContentsHeight());
+
+					this->DrawWindowBase(zx,zy,zw,zh,iColor::Invalid(),bw,bc);
+
+					int wx, wy;
+					if(fw->GetCoordinatesForZoomLine(0,wx,wy,x+bw/2,y+bw/2,w-bw+1,h-bw+1)) mSubject->DrawLine(zx+bw/2,zy+bw/2,wx,wy,bc,bw);
+					if(fw->GetCoordinatesForZoomLine(1,wx,wy,x+bw/2,y+bw/2,w-bw+1,h-bw+1)) mSubject->DrawLine(zx+zw-1-bw/2,zy+bw/2,wx,wy,bc,bw);
+					if(fw->GetCoordinatesForZoomLine(2,wx,wy,x+bw/2,y+bw/2,w-bw+1,h-bw+1)) mSubject->DrawLine(zx+bw/2,zy+zh-1-bw/2,wx,wy,bc,bw);
+					if(fw->GetCoordinatesForZoomLine(3,wx,wy,x+bw/2,y+bw/2,w-bw+1,h-bw+1)) mSubject->DrawLine(zx+zw-1-bw/2,zy+zh-1-bw/2,wx,wy,bc,bw);
+				}
+
+				//
+				//  Draw the window itself
+				//
+				this->DrawWindow(x,y,w,h,fw->GetViewModule()->GetBackgroundColor(),bw,bc,v,0,i==mDialog->GetCurrentForegroundWindow());
 			}
 
 			if(!ic->IsActive())
@@ -326,8 +357,6 @@ namespace iggDialogImageComposer_Private
 		//
 		void DrawWindow(int x, int y, int w, int h, const iColor &c, int b, const iColor &bc, int v, const iImage* image, bool focus)
 		{
-			static const iColor black = iColor(0,0,0);
-
 			this->DrawWindowBase(x,y,w,h,c,b,bc);
 
 			int x1 = x + b;
@@ -348,10 +377,10 @@ namespace iggDialogImageComposer_Private
 				int j;
 				for(j=0; j<4; j++)
 				{
-					mSubject->DrawLine(x1+j,y1+j,x2-j,y1+j,black,1,true);
-					mSubject->DrawLine(x1+j,y2-j,x2-j,y2-j,black,1,true);
-					mSubject->DrawLine(x1+j,y1+j,x1+j,y2-j,black,1,true);
-					mSubject->DrawLine(x2-j,y1+j,x2-j,y2-j,black,1,true);
+					mSubject->DrawLine(x1+j,y1+j,x2-j,y1+j,iColor::Black(),1,true);
+					mSubject->DrawLine(x1+j,y2-j,x2-j,y2-j,iColor::Black(),1,true);
+					mSubject->DrawLine(x1+j,y1+j,x1+j,y2-j,iColor::Black(),1,true);
+					mSubject->DrawLine(x2-j,y1+j,x2-j,y2-j,iColor::Black(),1,true);
 				}
 			}
 		}
@@ -364,11 +393,17 @@ namespace iggDialogImageComposer_Private
 				mSubject->DrawRectangle(x+w-b,y    ,x+w-1,y+h-1,bc,bc,0);
 				mSubject->DrawRectangle(x    ,y    ,x+w-1,y+b-1,bc,bc,0);
 				mSubject->DrawRectangle(x    ,y+h-b,x+w-1,y+h-1,bc,bc,0);
-				mSubject->DrawRectangle(x+b  ,y+b  ,x+w-b-1,y+h-b-1,bc,c,0);
+				if(c.IsValid()) mSubject->DrawRectangle(x+b  ,y+b  ,x+w-b-1,y+h-b-1,bc,c,0);
 			}
 			else
 			{
-				mSubject->DrawRectangle(x,y,x+w-1,y+h-1,bc,c,b);
+				if(c.IsValid()) mSubject->DrawRectangle(x,y,x+w-1,y+h-1,bc,c,b); else if(b == 1)
+				{
+					mSubject->DrawLine(x    ,y    ,x    ,y+h-1,bc,1);
+					mSubject->DrawLine(x+w-1,y    ,x+w-1,y+h-1,bc,1);
+					mSubject->DrawLine(x    ,y    ,x+w-1,y    ,bc,1);
+					mSubject->DrawLine(x    ,y+h-1,x+w-1,y+h-1,bc,1);
+				}
 			}
 		}
 
@@ -419,9 +454,10 @@ namespace iggDialogImageComposer_Private
 
 	public:
 
-		WindowListComboBox(bool bg, const iString &title, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidget(parent)
+		WindowListComboBox(bool bg, int comp, const iString &title, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
+			mComponent = (comp>0 && comp<3) ? comp : 0;
 			mBackground = bg;
 			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,title);
 			this->SetBaloonHelp("Assign a visualization window to a background tile");
@@ -435,7 +471,7 @@ namespace iggDialogImageComposer_Private
 			if(mSubject->Count() != val+1)
 			{
 				mSubject->Clear();
-				if(mBackground) mSubject->InsertItem("None"); else mSubject->InsertItem("Select...");
+				if(mBackground || mComponent>0) mSubject->InsertItem("None"); else mSubject->InsertItem("Select...");
 				for(i=0; i<val; i++) mSubject->InsertItem("Window #"+iString::FromNumber(i+1));
 				mSubject->SetValue(0);
 			}
@@ -444,13 +480,28 @@ namespace iggDialogImageComposer_Private
 				if(mDialog->GetCurrentBackgroundWindow() < 0) this->Enable(false); else
 				{
 					this->Enable(true);
-					if(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule() == 0)
+					if(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule(mComponent) == 0)
 					{
 						mSubject->SetValue(0);
 					}
 					else
 					{
-						mSubject->SetValue(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule()->GetWindowNumber()+1);
+						mSubject->SetValue(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
+					}
+				}
+			}
+			else if(mComponent > 0)
+			{
+				if(mDialog->GetCurrentForegroundWindow() < 0) this->Enable(false); else
+				{
+					this->Enable(true);
+					if(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule(mComponent) == 0)
+					{
+						mSubject->SetValue(0);
+					}
+					else
+					{
+						mSubject->SetValue(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule(mComponent)->GetWindowNumber()+1);
 					}
 				}
 			}
@@ -464,22 +515,40 @@ namespace iggDialogImageComposer_Private
 				{
 					if(v == 0)
 					{
-						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(0);
+						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(0,mComponent);
 					}
 					else
 					{
-						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(this->GetShell()->GetControlModule()->GetViewModule(v-1));
+						mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->SetViewModule(this->GetShell()->GetControlModule()->GetViewModule(v-1),mComponent);
 					}
 				}
 			}
-			else if(v > 0)
+			else
 			{
-				mDialog->GetImageComposer()->AddForegroundWindow(this->GetShell()->GetControlModule()->GetViewModule(v-1));
-				mDialog->SetCurrentForegroundWindow(mDialog->GetImageComposer()->GetNumForegroundWindows()-1);
+				if(mComponent == 0)
+				{
+					if(v > 0)
+					{
+						mDialog->GetImageComposer()->AddForegroundWindow(this->GetShell()->GetControlModule()->GetViewModule(v-1));
+						mDialog->SetCurrentForegroundWindow(mDialog->GetImageComposer()->GetNumberOfForegroundWindows()-1);
+					}
+				}
+				else
+				{
+					if(v == 0)
+					{
+						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->SetViewModule(0,mComponent);
+					}
+					else
+					{
+						mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->SetViewModule(this->GetShell()->GetControlModule()->GetViewModule(v-1),mComponent);
+					}
+				}
 			}
 		}
 
 		bool mBackground;
+		int mComponent;
 		ibgWidgetComboBoxSubject *mSubject;
 		iggDialogImageComposer *mDialog;
 	};
@@ -508,7 +577,7 @@ namespace iggDialogImageComposer_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentBase);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentBase);
 			fn = this->GetMainWindow()->GetFileName("Open image file",mOldFileName,"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
 
 			if(mDialog->GetCurrentBackgroundWindow()>=0 && !mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->LoadWallpaperImage(fn))
@@ -539,13 +608,14 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->Enable(mDialog->GetImageComposer()->GetNumForegroundWindows()>0);
+			this->Enable(mDialog->GetImageComposer()->GetNumberOfForegroundWindows()>0);
 		}
 
 		virtual void Execute()
 		{
 			mDialog->GetImageComposer()->RemoveForegroundWindow(mDialog->GetCurrentForegroundWindow());
-			if(mDialog->GetImageComposer()->GetNumForegroundWindows() == 0) this->Enable(false);
+			mDialog->SetCurrentForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			if(mDialog->GetImageComposer()->GetNumberOfForegroundWindows() == 0) this->Enable(false);
 		}
 
 		iggDialogImageComposer *mDialog;
@@ -608,10 +678,134 @@ namespace iggDialogImageComposer_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			this->Enable(mDialog->GetImageComposer()->GetNumForegroundWindows()>0);
+			if(mDialog->GetCurrentForegroundWindow() >= 0)
+			{
+				this->Enable(true);
+				this->iggFrame::UpdateWidgetBody();
+			}
+			else this->Enable(false);
+		}
+
+		iggDialogImageComposer *mDialog;
+	};
+
+	//
+	//  Frame box with extra VisualModule selections for pseudo-color composition
+	//
+	class PseudoColorBox : public iggFrame
+	{
+
+	public:
+
+		PseudoColorBox(bool bg, iggDialogImageComposer *dialog, iggFrame *parent) : iggFrame("Pseudo color",parent,2)
+		{
+			mDialog = dialog;
+			mBackground = bg;
+			this->AddLine(new iggWidgetTextArea("Green channel",this),new WindowListComboBox(bg,1,"",dialog,this));
+			this->AddLine(new iggWidgetTextArea("Blue channel",this),new WindowListComboBox(bg,2,"",dialog,this));
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			if(mBackground)
+			{
+				this->Enable(mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())!=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule()!=0);
+			}
+			else
+			{
+				this->Enable(mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())!=0 && mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->GetViewModule()!=0);
+			}
 			this->iggFrame::UpdateWidgetBody();
 		}
 
+		bool mBackground;
+		iggDialogImageComposer *mDialog;
+	};
+
+	//
+	//  Zoom source list combo box
+	//
+	class ZoomSourceListComboBox : public iggWidget
+	{
+
+	public:
+
+		ZoomSourceListComboBox(const iString &title, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidget(parent)
+		{
+			mNumBG = mNumFG = 0;
+			mDialog = dialog;
+			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,title);
+			this->SetBaloonHelp("Attach this window to another window as a zoom");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			int nbg = mDialog->GetImageComposer()->GetNumberOfBackgroundWindows();
+			int nfg = mDialog->GetImageComposer()->GetNumberOfForegroundWindows();
+
+			if(mNumFG!=nfg || mNumBG!=nbg)
+			{
+				mNumBG = nbg;
+				mNumFG = nfg;
+				mSubject->Clear();
+				mSubject->InsertItem("None");
+
+				int i;
+				iImageComposer *c = mDialog->GetImageComposer();
+				iImageComposerBackgroundWindow *wbg;
+				for(i=0; i<nbg; i++)
+				{
+					wbg = c->GetBackgroundWindow(i);
+					mSubject->InsertItem("Background ("+iString::FromNumber(wbg->GetTileX()+1)+","+iString::FromNumber(wbg->GetTileY()+1)+")");
+				}
+				for(i=0; i<nfg; i++)
+				{
+					mSubject->InsertItem("Foreground #"+iString::FromNumber(i+1));
+				}
+			}
+
+			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			if(w==0 || w->GetZoomSource()==0)
+			{
+				mSubject->SetValue(0);
+			}
+			else
+			{
+				int v = w->GetZoomSource()->GetId();
+				if(v < 0) mSubject->SetValue(-v); else mSubject->SetValue(v+mNumBG);
+			}
+		}
+
+		virtual void OnInt1Body(int v)
+		{
+			iImageComposerForegroundWindow *w = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+			if(w == 0)
+			{
+				IERROR_LOW("Current foreground window not set.");
+				return;
+			}
+
+			if(v == 0)
+			{
+				w->SetZoomSource(0);
+			}
+			else if(v <= mNumBG)
+			{
+				w->SetZoomSource(mDialog->GetImageComposer()->GetBackgroundWindow(v-1));
+			}
+			else
+			{
+				w->SetZoomSource(mDialog->GetImageComposer()->GetForegroundWindow(v-mNumBG-1));
+				this->UpdateWidget();
+			}
+		}
+
+		int mNumBG, mNumFG;
+		ibgWidgetComboBoxSubject *mSubject;
 		iggDialogImageComposer *mDialog;
 	};
 };
@@ -664,13 +858,17 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	tmp->AddLine(b,2);
 
 	b = new iggFrame("Current tile...",tmp);
-	mBackgroundWindowsList = new WindowListComboBox(true,"Assign window",this,b);
+	mBackgroundWindowsList = new WindowListComboBox(true,0,"Assign window",this,b);
 	mBackgroundWindowsList->AddDependent(mArea);
 	mBackgroundWindowsList->Enable(false);
 	wid = new LoadWallpaperButton(this,b);
-	wid->AddDependent(mArea);
+	wid->AddBuddy(mArea);
+	PseudoColorBox *psb = new PseudoColorBox(true,this,b);
+	mBackgroundWindowsList->AddDependent(psb);
+	mArea->AddDependent(psb);
 	b->AddLine(mBackgroundWindowsList);
 	b->AddLine(wid);
+	b->AddLine(psb);
 
 	tmp->AddLine(b,2);
 	tmp->AddSpace(10);
@@ -679,15 +877,20 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	wid = new iggWidgetKeySpinBox(0,100,"",0,iImageComposer::KeyBorderWidth(),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
-	tmp2->AddLine(new iggWidgetTextArea("Border width",tmp2),wid);
+	tmp2->AddLine(new iggWidgetTextArea("Border width  ",tmp2),wid);
 	iggWidgetKeyColorSelection *bc = new iggWidgetKeyColorSelection(iImageComposer::KeyBorderColor(),tmp2,true);
 	bc->SetText("Set");
 	bc->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Border color",tmp2),bc);
+	tmp2->AddLine(new iggWidgetTextArea("Border color  ",tmp2),bc);
 	wid = new iggWidgetKeyCheckBox("Draw border between tiles",iImageComposer::KeyInnerBorder(),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
 	tmp2->AddLine(wid,2);
+	wid = new iggWidgetKeyCheckBox("Scale background to tile size",iImageComposer::KeyScaleBackground(),tmp2);
+	wid->AddDependent(mArea);
+	wid->AddDependent(mLabel);
+	tmp2->AddLine(wid,2);
+	tmp2->SetColStretch(1,10);
 
 	tmp->AddLine(tmp2);
 	tmp->AddSpace(10);
@@ -698,7 +901,7 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	tmp = new iggFrame(book);
 	book->AddPage("Foreground",0,tmp);
 
-	wid = new WindowListComboBox(false,"Add new window",this,tmp);
+	wid = new WindowListComboBox(false,0,"Add new window",this,tmp);
 	wid->AddDependent(mArea);
 
 	tmp->AddLine(wid);
@@ -718,9 +921,34 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	mIndexHolders[2] = new iggWidgetKeyColorSelection(iImageComposer::KeyForegroundWindowBorderColor(),b,true,0);
 	mIndexHolders[2]->AddDependent(mArea);
 	b->AddLine(new iggWidgetTextArea("Border color",b),mIndexHolders[2]);
+	psb = new PseudoColorBox(false,this,b);
+	wid->AddDependent(psb);
+	mArea->AddDependent(psb);
+	b->AddLine(psb,2);
+
+	tmp2 = new iggFrame("Show as zoom",b,2);
+	wid = new ZoomSourceListComboBox("",this,tmp2);
+	wid->AddDependent(mArea);
+	tmp2->AddLine(new iggWidgetTextArea("Source",tmp2),wid);
+	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),_RenderModeNoRender,tmp2,0);
+	mIndexHolders[3]->AddDependent(mArea);
+	tmp2->AddLine(new iggWidgetTextArea("Center X",tmp2),mIndexHolders[3]);
+	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),_RenderModeNoRender,tmp2,0);
+	mIndexHolders[4]->AddDependent(mArea);
+	tmp2->AddLine(new iggWidgetTextArea("Center Y",tmp2),mIndexHolders[4]);
+	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomHeight(),_RenderModeNoRender,tmp2,0);
+	mIndexHolders[5]->AddDependent(mArea);
+	tmp2->AddLine(new iggWidgetTextArea("Height",tmp2),mIndexHolders[5]);
+	mIndexHolders[6] = new iggWidgetKeyCheckBox("Use 4-line zoom",iImageComposer::KeyForegroundWindowZoom4Line(),tmp2,0);
+	mIndexHolders[6]->AddDependent(mArea);
+	tmp2->AddLine(mIndexHolders[6],2);
+
+	b->AddSpace(2);
+	b->AddLine(tmp2,2);
 
 	tmp->AddLine(b);
 	tmp->AddSpace(10);
+
 	mFrame->SetColStretch(0,10);
 
 	this->ResizeContents(700,500);
@@ -742,17 +970,17 @@ void iggDialogImageComposer::SetCurrentForegroundWindow(int w)
 {
 	int i;
 
-	if(w>=0 && w<this->GetImageComposer()->GetNumForegroundWindows())
+	if(w>=0 && w<this->GetImageComposer()->GetNumberOfForegroundWindows())
 	{
 		this->GetImageComposer()->MoveToBack(w);
-		mCurrentForegroundWindow = this->GetImageComposer()->GetNumForegroundWindows() - 1;
-		for(i=0; i<3; i++)
+		mCurrentForegroundWindow = this->GetImageComposer()->GetNumberOfForegroundWindows() - 1;
+		for(i=0; i<mNumIndexHolders; i++)
 		{
 			mIndexHolders[i]->SetIndex(mCurrentForegroundWindow);
-			mIndexHolders[i]->UpdateWidget();
 		}
 	}
 	else mCurrentForegroundWindow = -1;
+	this->UpdateDialog();
 }
 
 
