@@ -62,7 +62,9 @@ protected:
 
 	int mCurrentBackgroundWindow, mCurrentForegroundWindow;
 	iggWidget *mArea, *mLabel, *mBackgroundWindowsList;
-	iggWidgetKeyHandlerBase *mIndexHolders[3];
+
+	static const int mNumIndexHolders = 7;
+	iggWidgetKeyHandlerBase *mIndexHolders[mNumIndexHolders];
 };
 
 #endif  //  IGGDIALOGIMAGECOMPOSER_H
