@@ -73,7 +73,7 @@ namespace iggDialogPaletteEditor_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentPalette);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentPalette);
 			fn = this->GetMainWindow()->GetFileName("Open palette file",mOldFileName,"Palette file (*.ipf)");
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ipf") fn += ".ipf";
 
@@ -120,7 +120,7 @@ namespace iggDialogPaletteEditor_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentPalette);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentPalette);
 			fn = this->GetMainWindow()->GetFileName("Save palette file",mOldFileName,"Palette file (*.ipf)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ipf") fn += ".ipf";
 
@@ -166,14 +166,13 @@ namespace iggDialogPaletteEditor_Private
 			return mEditor->GetCurrentPalette();
 		}
 
-	protected:
-
-		virtual void UpdateWidgetBody()
+		virtual int GetCurrentPaletteIndex() const
 		{
-			mCurrentPaletteIndex = mEditor->GetCurrentPaletteIndex();
-			this->iggFramePaletteSelectionBase::UpdateWidgetBody();
+			return mEditor->GetCurrentPaletteIndex();
 		}
 
+	protected:
+
 		virtual void SetCurrentPaletteIndexBody(int n)
 		{
 			mEditor->SetCurrentPaletteIndex(n);
@@ -436,7 +435,7 @@ void iggDialogPaletteEditor::Apply(bool ask)
 	{
 		this->GetShell()->GetControlModule()->GetPalette(mCurrentPaletteIndex)->Copy(mCurrentPalette);
 		iggFramePaletteSelectionBase::UpdateAll();
-		this->GetShell()->GetControlModule()->Render(_RenderModeAll);
+		this->GetShell()->GetControlModule()->Render(_RenderOptionAll);
 		mApplyButton->Enable(false);
 	}
 }
