@@ -220,5 +220,5 @@ iggDialogParallelController::iggDialogParallelController(iggMainWindow *mw) : ig
 
 void iggDialogParallelController::UpdateDisplay()
 {
-	iPointerCast<PerformanceDisplay,iggWidget>(mDisplay)->UpdateWidget();
+	iDynamicCast<PerformanceDisplay,iggWidget>(INFO,mDisplay)->UpdateWidget();
 }
