@@ -29,8 +29,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogperformancemeter.h"
 
 
+#include "icommoneventobservers.h"
 #include "icontrolmodule.h"
-#include "ieventobserver.h"
 #include "iimagefactory.h"
 #include "ishell.h"
 #include "isystem.h"
@@ -146,10 +146,10 @@ iggDialogPerformanceMeter::iggDialogPerformanceMeter(iggMainWindow *parent) : ig
 	iggWidgetNumberDisplay *tm = new iggWidgetNumberDisplay("",mFrame);
 	tm->Display(iSystem::GetMemoryLimit(),1);
 
-	mFrame->AddLine((iggWidget *)0,1,new iggWidgetTextArea("Render time",mFrame),2,new iggWidgetTextArea("Update time",mFrame),2,new iggWidgetTextArea("Memory used",mFrame),2);
+	mFrame->AddLine(static_cast<iggWidget*>(0),1,new iggWidgetTextArea("Render time",mFrame),2,new iggWidgetTextArea("Update time",mFrame),2,new iggWidgetTextArea("Memory used",mFrame),2);
 	mFrame->AddLine(new iggWidgetTextArea("Current",mFrame),new ValueDisplay(this,false,0,mFrame),new iggWidgetTextArea("sec",mFrame),new ValueDisplay(this,false,1,mFrame),new iggWidgetTextArea("sec",mFrame),new ValueDisplay(this,false,2,mFrame),new iggWidgetTextArea("MB",mFrame));
-	mFrame->AddLine(new iggWidgetTextArea("Maximum",mFrame),(iggWidget *)0,(iggWidget *)0,new ValueDisplay(this,true,1,mFrame),new iggWidgetTextArea("sec",mFrame),new ValueDisplay(this,true,2,mFrame),new iggWidgetTextArea("MB",mFrame));
-	mFrame->AddLine(new iggWidgetTextArea("Available",mFrame),1,(iggWidget *)0,4,tm,1,new iggWidgetTextArea("MB",mFrame),1);
+	mFrame->AddLine(new iggWidgetTextArea("Maximum",mFrame),static_cast<iggWidget*>(0),static_cast<iggWidget*>(0),new ValueDisplay(this,true,1,mFrame),new iggWidgetTextArea("sec",mFrame),new ValueDisplay(this,true,2,mFrame),new iggWidgetTextArea("MB",mFrame));
+	mFrame->AddLine(new iggWidgetTextArea("Available",mFrame),1,static_cast<iggWidget*>(0),4,tm,1,new iggWidgetTextArea("MB",mFrame),1);
 	mFrame->AddSpace(10);
 
 	mFrame->SetColStretch(0,10);
