@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "icontrolmodule.h"
+#include "idataformatter.h"
 #include "iimagefactory.h"
 #include "imarker.h"
 #include "ipicker.h"
@@ -173,16 +174,16 @@ void iggDialogPickerWindow::DisplayData(const iPicker *picker)
 		iString name, valu, unit, s;
 
 		lnmax = 0;
-		for(i=0; i<picker->GetNumReportLines(); i++)
+		for(i=0; i<picker->GetDataFormatter()->GetNumReportLines(); i++)
 		{
-			picker->GetReport(i,name,valu,unit);
+			picker->GetDataFormatter()->GetReport(i,name,valu,unit);
 			if(lnmax < name.Length()) lnmax = name.Length();
 		}
 		for(i=0; i<lnmax; i++) s += ".";
 
-		for(i=0; i<picker->GetNumReportLines(); i++)
+		for(i=0; i<picker->GetDataFormatter()->GetNumReportLines(); i++)
 		{
-			picker->GetReport(i,name,valu,unit);
+			picker->GetDataFormatter()->GetReport(i,name,valu,unit);
 			mInfo->AppendTextLine(name+s.Part(0,lnmax-name.Length()),valu+(unit.IsEmpty()?"":"  ["+unit+"]"));
 		}
 
