@@ -76,9 +76,10 @@ namespace iggDialogRenderingProgress_Private
 using namespace iggDialogRenderingProgress_Private;
 
 
-iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Rendering...",0,1,false)
+iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Rendering...",0,1)
 {
 	mBlockParent = true;  // no explicit blocking required, since it is a semi-modal dialog
+	mIsParentBlocked = false;
 
 	iggFrame*tmp;
 
@@ -103,7 +104,6 @@ iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) :
 	mFrame->AddLine(mRemarkFrame);
 
 	mCancelled = true;
-	mShown = false;
 	mPreviousTime = 0.0;
 	mTimer = vtkTimerLog::New(); IERROR_ASSERT(mTimer);
 }
@@ -115,12 +115,14 @@ iggDialogRenderingProgress::~iggDialogRenderingProgress()
 }
 
 
-void iggDialogRenderingProgress::Start()
+void iggDialogRenderingProgress::Start(bool interactive)
 {
 	mTimer->StartTimer();
-	mCancelled = mShown = false;
+	mCancelled = false;
 	mPreviousTime = 0.0;
 
+	mInteractive = interactive;
+
 	mElapsedTime->SetText("  0.0");
 	mFlipper->Reset();
 	mButtonFrame->Show(true);
@@ -138,17 +140,17 @@ void iggDialogRenderingProgress::KeepWorking()
 
 	if(t > 0.1)
 	{
-		if(mBlockParent) mMainWindow->Block(true);
+		if(mBlockParent && !mIsParentBlocked)
+		{
+			mMainWindow->Block(true);
+			mIsParentBlocked = true;
+		}
 	}
 
-	if((!mShown && t>1.0) || (mShown && dt>0.1))
+	if(t>1.0 && dt>0.1 && !mInteractive)
     {
-		if(!mShown) 
-		{
-			if(mBlockParent) this->GetMainWindow()->Block(true);
-			mShown = true;
-			this->Show(true);
-		}
+		if(!this->IsVisible()) this->Show(true);
+
 		mFlipper->Advance();
 		mElapsedTime->SetText(iString::FromNumber(t,"%6.1lf"));
 		mPreviousTime = t;
@@ -170,7 +172,11 @@ void iggDialogRenderingProgress::Finish()
 {
 	mCancelled = false;
 	this->Show(false);
-	if(mBlockParent) mMainWindow->Block(false);
+	if(mBlockParent && mIsParentBlocked)
+	{
+		mMainWindow->Block(false);
+		mIsParentBlocked = false;
+	}
 }
 
 bool iggDialogRenderingProgress::CanBeClosed()
