@@ -66,6 +66,151 @@ using namespace iParameter;
 #include "iarraytemplate.h"
 
 
+//
+//  Helper class
+//
+class iggDialogScriptDebuggerEditor : public iggWidgetTextEditor
+{
+
+public:
+
+	iggDialogScriptDebuggerEditor(iggDialogScriptDebugger *d, iggFrame *parent) : iggWidgetTextEditor(0U,parent)
+	{
+		mDebugger = d; 
+		mBreakPointButtons[0] = mBreakPointButtons[1] = 0;
+
+		mMarkBefore = true;
+		mBreakPointColor = iColor(210,180,120);
+
+		//
+		//  Syntax highlighting
+		//
+		mSubject->HighlightSyntax(true);
+		mSubject->HighlightComments("#",iColor(0,120,0));
+		mSubject->HighlightStrings(iColor(120,0,0));
+
+		mSubject->AddCategory(iColor(0,0,200));
+		mSubject->AddCategory(iColor(170,0,170));
+
+		iAnimatorScript *s = this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetScript();
+		int i, n = s->GetNumberOfReservedWords();
+		for(i=0; i<n; i++)
+		{
+			if(s->IsParameterWord(s->GetReservedWord(i)))
+			{
+				mSubject->AddKeyword(s->GetReservedWord(i),1);
+			}
+			else
+			{
+				mSubject->AddKeyword(s->GetReservedWord(i),0);
+			}
+		}
+
+		//
+		//  Search capabilities
+		//
+		mFindPara = mFindIndex = 0;
+	}
+
+	void AttachBreakPointButton(int n, iggWidget *w)
+	{
+		if(n>=0 && n<2) mBreakPointButtons[n] = w;
+	}
+
+	void SetMarkBefore(bool s)
+	{
+		mMarkBefore = s;
+	}
+
+	void FindNext(const iString &text, bool cs, bool wo, bool forward)
+	{
+		if(!mSubject->Find(text,cs,wo,forward,mFindPara,mFindIndex))
+		{
+			mFindPara = mFindIndex = 0;
+		}
+		else mFindIndex++;
+	}
+
+	virtual void SetText(const iString &text)
+	{
+		this->iggWidgetTextEditor::SetText(text);
+		this->OnTextChanged();
+	}
+
+	void ShowError(iAnimatorScript *s)
+	{
+		mSubject->Select(s->GetCurrentLine(),s->GetErrorLocation(),s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
+	}
+
+	void ShowLine(bool before, iAnimatorScript *s)
+	{
+		if(before == mMarkBefore) mSubject->Select(s->GetCurrentLine(),0,s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
+	}
+
+	void ClearSelection()
+	{
+		mSubject->Select(-1,0,0,0);
+	}
+
+	void SetBreakPoint(bool s)
+	{
+		int line, index;
+		mSubject->GetCursorPosition(line,index);
+		iString ws = mSubject->GetLine(line);
+		ws.ReduceWhiteSpace();
+		if(s && ws.Length()>0 && ws[0]!='#') mSubject->SetLineColor(line,mBreakPointColor); else mSubject->UnSetLineColor(line);
+		this->OnCursorPositionChanged(line,index);
+	}
+
+	bool IsBreakPoint(int line = -1) const
+	{
+		if(line < 0)
+		{
+			int index;
+			mSubject->GetCursorPosition(line,index);
+		}
+		return mSubject->GetLineColor(line) == mBreakPointColor;
+	}
+
+protected:
+
+	virtual void UpdateWidgetBody()
+	{
+		const iString &text(mDebugger->GetAnimator()->GetScript()->GetText());
+		if(mSubject->GetText() != text)
+		{
+			mDebugger->Debug(false);
+			mSubject->SetText(text);
+		}
+		this->iggWidgetTextEditor::UpdateWidgetBody();
+	}
+
+	virtual void OnTextChanged()
+	{
+		const iString &text(mDebugger->GetAnimator()->GetScript()->GetText());
+		if(mSubject->GetText() != text)
+		{
+			mDebugger->GetAnimator()->GetScript()->SetText(mSubject->GetText());
+		}
+		mDebugger->Debug(false);
+	}
+
+	virtual void OnCursorPositionChanged(int para, int /*index*/)
+	{
+		bool b = this->IsBreakPoint(para);
+
+		if(mBreakPointButtons[0] != 0) mBreakPointButtons[0]->Enable(!b);
+		if(mBreakPointButtons[1] != 0) mBreakPointButtons[1]->Enable(b);
+	}
+
+	bool mMarkBefore;
+	iggWidget *mBreakPointButtons[2];
+	int mFindPara, mFindIndex;
+	iggDialogScriptDebugger *mDebugger;
+	iColor mBreakPointColor;
+};
+
+
 namespace iggDialogScriptDebugger_Private
 {
 	//
@@ -105,151 +250,6 @@ namespace iggDialogScriptDebugger_Private
 	const int _RunStateFrameStep = 3;
 	const int __NumRunStates = 4;
 
-	//
-	//  Main editor
-	//
-	class Editor : public iggWidgetTextEditor
-	{
-		
-	public:
-		
-		Editor(iggDialogScriptDebugger *d, iggFrame *parent) : iggWidgetTextEditor(0U,parent)
-		{
-			mDebugger = d; 
-			mBreakPointButtons[0] = mBreakPointButtons[1] = 0;
-
-			mMarkBefore = true;
-			mBreakPointColor = iColor(210,180,120);
-
-			//
-			//  Syntax highlighting
-			//
-			mSubject->HighlightSyntax(true);
-			mSubject->HighlightComments("#",iColor(0,120,0));
-			mSubject->HighlightStrings(iColor(120,0,0));
-
-			mSubject->AddCategory(iColor(0,0,200));
-			mSubject->AddCategory(iColor(170,0,170));
-
-			iAnimatorScript *s = this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetScript();
-			int i, n = s->GetNumberOfReservedWords();
-			for(i=0; i<n; i++)
-			{
-				if(s->IsParameterWord(s->GetReservedWord(i)))
-				{
-					mSubject->AddKeyword(s->GetReservedWord(i),1);
-				}
-				else
-				{
-					mSubject->AddKeyword(s->GetReservedWord(i),0);
-				}
-			}
-
-			//
-			//  Search capabilities
-			//
-			mFindPara = mFindIndex = 0;
-		}
-
-		void AttachBreakPointButton(int n, iggWidget *w)
-		{
-			if(n>=0 && n<2) mBreakPointButtons[n] = w;
-		}
-
-		void SetMarkBefore(bool s)
-		{
-			mMarkBefore = s;
-		}
-
-		void FindNext(const iString &text, bool cs, bool wo, bool forward)
-		{
-			if(!mSubject->Find(text,cs,wo,forward,mFindPara,mFindIndex))
-			{
-				mFindPara = mFindIndex = 0;
-			}
-			else mFindIndex++;
-		}
-
-		virtual void SetText(const iString &text)
-		{
-			this->iggWidgetTextEditor::SetText(text);
-			this->OnTextChanged();
-		}
-
-		void ShowError(iAnimatorScript *s)
-		{
-			mSubject->Select(s->GetCurrentLine(),s->GetErrorLocation(),s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
-		}
-
-		void ShowLine(bool before, iAnimatorScript *s)
-		{
-			if(before == mMarkBefore) mSubject->Select(s->GetCurrentLine(),0,s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
-		}
-
-		void ClearSelection()
-		{
-			mSubject->Select(-1,0,0,0);
-		}
-
-		void SetBreakPoint(bool s)
-		{
-			int line, index;
-			mSubject->GetCursorPosition(line,index);
-			iString ws = mSubject->GetLine(line);
-			ws.ReduceWhiteSpace();
-			if(s && ws.Length()>0 && ws[0]!='#') mSubject->SetLineColor(line,mBreakPointColor); else mSubject->UnSetLineColor(line);
-			this->OnCursorPositionChanged(line,index);
-		}
-	
-		bool IsBreakPoint(int line = -1) const
-		{
-			if(line < 0)
-			{
-				int index;
-				mSubject->GetCursorPosition(line,index);
-			}
-			return mSubject->GetLineColor(line) == mBreakPointColor;
-		}
-
-	protected:
-
-		virtual void UpdateWidgetBody()
-		{
-			const iString &text(mDebugger->GetAnimator()->GetScript()->GetText());
-			if(mSubject->GetText() != text)
-			{
-				mDebugger->Debug(false);
-				mSubject->SetText(text);
-			}
-			this->iggWidgetTextEditor::UpdateWidgetBody();
-		}
-
-		virtual void OnTextChanged()
-		{
-			const iString &text(mDebugger->GetAnimator()->GetScript()->GetText());
-			if(mSubject->GetText() != text)
-			{
-				mDebugger->GetAnimator()->GetScript()->SetText(mSubject->GetText());
-			}
-			mDebugger->Debug(false);
-		}
-
-		virtual void OnCursorPositionChanged(int para, int /*index*/)
-		{
-			bool b = this->IsBreakPoint(para);
-
-			if(mBreakPointButtons[0] != 0) mBreakPointButtons[0]->Enable(!b);
-			if(mBreakPointButtons[1] != 0) mBreakPointButtons[1]->Enable(b);
-		}
-
-		bool mMarkBefore;
-		iggWidget *mBreakPointButtons[2];
-		int mFindPara, mFindIndex;
-		iggDialogScriptDebugger *mDebugger;
-		iColor mBreakPointColor;
-	};
-
-
 	//
 	//  Find dialog and its classes
 	//
@@ -302,7 +302,7 @@ namespace iggDialogScriptDebugger_Private
 
 	public:
 
-		FindButton(Editor *ed, FindText *t, FindCheckBox *cs, FindCheckBox *wo, FindCheckBox *bs, iggFrame *parent) : iggWidgetSimpleButton("Next",parent)
+		FindButton(iggDialogScriptDebuggerEditor *ed, FindText *t, FindCheckBox *cs, FindCheckBox *wo, FindCheckBox *bs, iggFrame *parent) : iggWidgetSimpleButton("Next",parent)
 		{
 			mEditor = ed;
 			mText = t;
@@ -316,10 +316,10 @@ namespace iggDialogScriptDebugger_Private
 
 		virtual void Execute()
 		{
-			mEditor->FindNext(mText->GetText(),mCaseCheckBox->IsDown(),mWordCheckBox->IsDown(),!mBackCheckBox->IsDown());
+			mEditor->FindNext(mText->GetText(),mCaseCheckBox->IsChecked(),mWordCheckBox->IsChecked(),!mBackCheckBox->IsChecked());
 		}
 
-		Editor *mEditor;
+		iggDialogScriptDebuggerEditor *mEditor;
 		FindText *mText;
 		FindCheckBox *mCaseCheckBox, *mWordCheckBox, *mBackCheckBox;
 	};
@@ -330,7 +330,7 @@ namespace iggDialogScriptDebugger_Private
 		
 	public:
 
-		FindDialog(Editor *ed, iggMenuWindow *mw) : iggDialog(mw,_DialogModal,iImageFactory::FindIcon("searchfind.png"),"Find",0,2)
+		FindDialog(iggDialogScriptDebuggerEditor *ed, iggMenuWindow *mw) : iggDialog(mw,_DialogModal,iImageFactory::FindIcon("searchfind.png"),"Find",0,2)
 		{
 			FindText *t = new FindText(mFrame);
 			FindCheckBox *cs = new FindCheckBox("Case sensitive",mFrame);
@@ -385,7 +385,7 @@ namespace iggDialogScriptDebugger_Private
 				}
 			default:
 				{
-					IERROR_FINISH("Incorrectly configured Script Debugger.");
+					IERROR_FATAL("Incorrectly configured Script Debugger.");
 				}
 			}
 		}
@@ -461,7 +461,7 @@ namespace iggDialogScriptDebugger_Private
 
 	public:
 
-		MarkLineCheckBox(Editor *ed, iggFrame *parent) : iggWidgetSimpleCheckBox("Mark line after it is executed.",parent)
+		MarkLineCheckBox(iggDialogScriptDebuggerEditor *ed, iggFrame *parent) : iggWidgetSimpleCheckBox("Mark line after it is executed.",parent)
 		{
 			mEditor = ed; 
 			this->SetBaloonHelp("Toggle whether a current line is marked before or after it is executed","Usually, debuggers mark a line of code to be executed next. If this box is checked, Script Debugger will mark the current line <b>after</b> rather than <b>before</b> it is executed.");
@@ -474,7 +474,7 @@ namespace iggDialogScriptDebugger_Private
 			mEditor->SetMarkBefore(!s);
 		}
 
-		Editor *mEditor;
+		iggDialogScriptDebuggerEditor *mEditor;
 	};
 
 
@@ -483,7 +483,7 @@ namespace iggDialogScriptDebugger_Private
 
 	public:
 
-		SetBreakPointButton(bool set, Editor *ed, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
+		SetBreakPointButton(bool set, iggDialogScriptDebuggerEditor *ed, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
 		{
 			mIsSet = set;
 			mEditor = ed;
@@ -508,7 +508,7 @@ namespace iggDialogScriptDebugger_Private
 		}
 
 		bool mIsSet;
-		Editor *mEditor;
+		iggDialogScriptDebuggerEditor *mEditor;
 	};
 }
 
@@ -540,8 +540,7 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	//
 	mGlobalFrame->SetPadding(true);
 
-	Editor *ed = new Editor(this,mGlobalFrame);
-	mEditor = ed;
+	mEditor = new iggDialogScriptDebuggerEditor(this,mGlobalFrame);
 	mGlobalFrame->AddLine(mEditor);
 
 	mDebugFrame = new iggFrame("Debugging tools",mGlobalFrame,2);
@@ -572,7 +571,7 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	tmp->AddLine(new DelaySlider(this,tmp));
 	tmp->AddLine(new DummySceneCheckBox(this,tmp));
 #ifdef I_DEBUG
-	tmp->AddLine(new MarkLineCheckBox(ed,tmp));
+	tmp->AddLine(new MarkLineCheckBox(mEditor,tmp));
 #endif
 
 	tmp1 = new iggFrame("Variables",mDebugFrame);
@@ -589,7 +588,7 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	//
 	//  Helper dialogs
 	//
-	mFindDialog = new FindDialog(ed,this);
+	mFindDialog = new FindDialog(mEditor,this);
 
 	mTimer = vtkTimerLog::New();
 
@@ -656,7 +655,7 @@ void iggDialogScriptDebugger::Debug(bool s)
 		mRunState = _RunStatePaused;
 		this->GetAnimator()->SetUseScript(true);
 		this->GetAnimator()->Start();
-		iPointerCast<Editor,iggWidgetTextEditor>(mEditor)->ShowLine(true,this->GetAnimator()->GetScript());
+		mEditor->ShowLine(true,this->GetAnimator()->GetScript());
 	}
 	else
 	{
@@ -680,20 +679,20 @@ void iggDialogScriptDebugger::OnScriptStopBody(const iString &error)
 	{
 		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Run time error:\n")+error,_PopupWindowWarning);
 	}
-	iPointerCast<Editor,iggWidgetTextEditor>(mEditor)->ClearSelection();
+	mEditor->ClearSelection();
 }
 
 
 void iggDialogScriptDebugger::OnScriptBeginLineBody(int , const iString &)
 {
 	mInsideALine = true;
-	iPointerCast<Editor,iggWidgetTextEditor>(mEditor)->ShowLine(false,this->GetAnimator()->GetScript());
+	mEditor->ShowLine(false,this->GetAnimator()->GetScript());
 }
 
 
 void iggDialogScriptDebugger::OnScriptEndLineBody(int , const iString &)
 {
-	iPointerCast<Editor,iggWidgetTextEditor>(mEditor)->ShowLine(true,this->GetAnimator()->GetScript());
+	mEditor->ShowLine(true,this->GetAnimator()->GetScript());
 	mInsideALine = false;
 }
 
@@ -731,10 +730,9 @@ void iggDialogScriptDebugger::SetRunState(int n)
 			}
 		case _RunStateExecute:
 			{
-				Editor *ed = iPointerCast<Editor,iggWidgetTextEditor>(mEditor);
 				while(mDebugging && mRunState==_RunStateExecute && this->GetAnimator()->Continue())
 				{
-					if(ed->IsBreakPoint(this->GetAnimator()->GetScript()->GetCurrentLine()))
+					if(mEditor->IsBreakPoint(this->GetAnimator()->GetScript()->GetCurrentLine()))
 					{
 						mRunState = _RunStatePaused;
 						this->UpdateButtons();
@@ -783,8 +781,8 @@ bool iggDialogScriptDebugger::CheckSyntax(bool silent)
 	s->Run(true);
 	if(s->GetErrorStatus()->IsError())
 	{
-		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetCurrentLine()+1)+"\n"+s->GetErrorMessage(),_PopupWindowError);
-		iPointerCast<Editor,iggWidgetTextEditor>(mEditor)->ShowError(s);
+		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetCurrentLine()+1)+"\n"+s->GetErrorStatus()->Message(),_PopupWindowError);
+		mEditor->ShowError(s);
 		return false;
 	}
 	else
@@ -896,7 +894,7 @@ void iggDialogScriptDebugger::LoadFromFile(const iString &filename)
 	{
 		if(mCurrentFileName.IsEmpty())
 		{
-			fn = this->GetFileName("Open script file",this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)");
+			fn = this->GetFileName("Open script file",this->GetShell()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)");
 		}
 		else
 		{
@@ -940,11 +938,11 @@ void iggDialogScriptDebugger::SaveToFile(const iString &filename)
 	{
 		if(mCurrentFileName.IsEmpty())
 		{
-			fn = this->GetFileName("Open script file",this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)");
+			fn = this->GetFileName("Save script file",this->GetShell()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)",false);
 		}
 		else
 		{
-			fn = this->GetFileName("Open script file",mCurrentFileName,"Animation script file (*.ias)");
+			fn = this->GetFileName("Save script file",mCurrentFileName,"Animation script file (*.ias)",false);
 		}
 	}
 	else
@@ -1059,7 +1057,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 
 	if(id < 0)
 	{
-		IERROR_REPORT("Invalid menu item id.");
+		IERROR_LOW("Invalid menu item id.");
 	}
 
 	if(id <= _MenuFileMax)
@@ -1095,7 +1093,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT("Invalid menu item id.");
+				IERROR_LOW("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1121,7 +1119,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT("Invalid menu item id.");
+				IERROR_LOW("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1148,13 +1146,12 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		case _MenuDebugToggleBreakPoint:
 			{
-				Editor *ed = iPointerCast<Editor,iggWidgetTextEditor>(mEditor);
-				ed->SetBreakPoint(!ed->IsBreakPoint());
+				mEditor->SetBreakPoint(!mEditor->IsBreakPoint());
 				break;
 			}
 		default:
 			{
-				IERROR_REPORT("Invalid menu item id.");
+				IERROR_LOW("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1176,12 +1173,12 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT("Invalid menu item id.");
+				IERROR_LOW("Invalid menu item id.");
 			}
 		}
 		return;
 	}
 
-	IERROR_REPORT("Invalid menu item id.");
+	IERROR_LOW("Invalid menu item id.");
 }
 
