@@ -51,7 +51,7 @@ using namespace iggParameter;
 //
 //  Base Frame class
 //
-iggFrameBase::iggFrameBase(iggFrameBase *parent) : iggWidget(parent), mChildren(100)
+iggFrameBase::iggFrameBase(iggFrameBase *parent) : iggWidget(parent)
 {
 	this->Define();
 }
@@ -339,7 +339,7 @@ void iggFrame::AddLine(iggWidget *child1, int nc1, iggWidget *child2, int nc2, i
 {
 	if((child1!=0 && child1->GetParent()!=this) || (child2!=0 && child2->GetParent()!=this) || (child3!=0 && child3->GetParent()!=this) || (child4!=0 && child4->GetParent()!=this) || (child5!=0 && child5->GetParent()!=this) || (child6!=0 && child6->GetParent()!=this) || (child7!=0 && child7->GetParent()!=this))
 	{
-		IERROR_REPORT("Incorrect parenting in iggFrame class,");
+		IERROR_LOW("Incorrect parenting in iggFrame class,");
 		return;
 	}
 	
@@ -422,9 +422,9 @@ void iggFrame::FlipThroughAllChildren()
 //
 //  FrameBook class
 //
-iggFrameBook::iggFrameBook(iggFrameBase *parent, bool withFeedback) : iggFrameBase(parent), mPages(Page())
+iggFrameBook::iggFrameBook(iggFrameBase *parent, bool withFeedback, bool tabsOnTop) : iggFrameBase(parent)
 {
-	mSubject = iggSubjectFactory::CreateFrameBookSubject(this,withFeedback);
+	mSubject = iggSubjectFactory::CreateFrameBookSubject(this,withFeedback,tabsOnTop);
 
 	mNeedsBaloonHelp = false;
 }
@@ -450,7 +450,7 @@ void iggFrameBook::OpenPage(int i)
 	}
 	else
 	{
-		IERROR_REPORT("Trying to open an non-existent page.");
+		IERROR_LOW("Trying to open an non-existent page.");
 	}
 }
 
@@ -461,7 +461,7 @@ void iggFrameBook::AddPage(const iString &title, const iImage *image, iggFrame *
 
 	if(frame->GetParent() != this)
 	{
-		IERROR_FINISH("Icorrect parenting in iggFrameBook.");
+		IERROR_FATAL("Icorrect parenting in iggFrameBook.");
 	}
 
 	frame->SetPadding(true);
@@ -502,7 +502,7 @@ void iggFrameBook::SetTabMode(int m)
 {
 	int n;
 
-	if(m<0 || m>2) IERROR_FINISH("Invalid Book tab mode.");
+	if(m<0 || m>2) IERROR_FATAL("Invalid Book tab mode.");
 
 	for(n=0; n<mPages.Size(); n++)
 	{
@@ -538,12 +538,13 @@ void iggFrameBook::FlipThroughAllChildren()
 //
 //  FrameFlip class 
 //
-iggFrameFlip::iggFrameFlip(iggFrameBase *parent, bool expanding) : iggFrameBase(parent), mLayers(0)
+iggFrameFlip::iggFrameFlip(iggFrameBase *parent, bool expanding) : iggFrameBase(parent)
 {
 	mSubject = iggSubjectFactory::CreateFrameFlipSubject(this,expanding);
 	mNeedsBaloonHelp = false;
-}
 
+	mCurrentLayer = -1;
+}
 
 int iggFrameFlip::Count() const
 {
@@ -553,7 +554,11 @@ int iggFrameFlip::Count() const
 
 void iggFrameFlip::ShowLayer(int i)
 {
-	if(i>=0 && i<mLayers.Size()) mSubject->ShowLayer(i);
+	if(i>=0 && i<mLayers.Size())
+	{
+		mSubject->ShowLayer(i);
+		mCurrentLayer = i;
+	}
 }
 
 
@@ -561,7 +566,7 @@ void iggFrameFlip::AddLayer(iggFrame *page)
 {
 	if(page->GetParent() != this)
 	{
-		IERROR_FINISH("Icorrect parenting in iggFrameFlip.");
+		IERROR_FATAL("Icorrect parenting in iggFrameFlip.");
 	}
 
 	mLayers.Add(page);
@@ -585,10 +590,10 @@ void iggFrameFlip::FlipThroughAllChildren()
 //
 //  FrameScroll class
 //
-iggFrameScroll::iggFrameScroll(iggFrameBase *parent, bool withHor) : iggFrameBase(parent)
+iggFrameScroll::iggFrameScroll(iggFrameBase *parent, bool withHor, int numcol, bool withVer) : iggFrameBase(parent)
 {
-	mSubject = iggSubjectFactory::CreateFrameScrollSubject(this,withHor);
-	mContents = new iggFrame(this,1);
+	mSubject = iggSubjectFactory::CreateFrameScrollSubject(this,withHor,withVer);
+	mContents = new iggFrame(this,numcol);
 	mSubject->AttachContents(mContents);
 	mContents->ClearLaidOutFlag(this);
 
