@@ -97,7 +97,7 @@ iggFrameCurrentInstance::iggFrameCurrentInstance(bool withnone, const iString &t
 	
 	if(mMaxKey.Argument()!=iObjectKey::_OffsetInt || mMaxKey.Dimension()!=1 || mMaxKey.UnprefixedFullName().Find("Max")==-1)
 	{
-		IERROR_FINISH("Widget iggFrameCurrentInstance is congifured incorrectly.");
+		IERROR_FATAL("Widget iggFrameCurrentInstance is congifured incorrectly.");
 	}
 
 	if(mIsSpinBox)
@@ -139,14 +139,14 @@ void iggFrameCurrentInstance::UpdateChildren()
 			//
 			if(mIsSpinBox)
 			{
-				iggWidgetKeySpinBox *b = iPointerCast<iggWidgetKeySpinBox,iggWidgetKeySelectionBox>(mBox);
+				iggWidgetKeySpinBox *b = iDynamicCast<iggWidgetKeySpinBox,iggWidgetKeySelectionBox>(INFO,mBox);
 				if(mWithNone) b->SetRange(0,1+max); else b->SetRange(1,1+max);
 			}
 			else
 			{
 				int i;
 
-				iggWidgetKeyComboBox *b = iPointerCast<iggWidgetKeyComboBox,iggWidgetKeySelectionBox>(mBox);
+				iggWidgetKeyComboBox *b = iDynamicCast<iggWidgetKeyComboBox,iggWidgetKeySelectionBox>(INFO,mBox);
 				b->Clear();
 				if(mWithNone) b->InsertItem("None");
 				for(i=0; i<=max; i++) b->InsertItem((iString(mItemText)+"#"+iString::FromNumber(i+1)).ToCharPointer());
@@ -154,5 +154,5 @@ void iggFrameCurrentInstance::UpdateChildren()
 		}
 		iggFrame::UpdateChildren();
 	}
-	else IERROR_REPORT("iggFrameCurrentInstance::UpdateChildren() failed.");
+	else IERROR_LOW("iggFrameCurrentInstance::UpdateChildren() failed.");
 }
