@@ -34,6 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "ierror.h"
+#include "iimagefactory.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
@@ -42,6 +43,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetkeyselectionbox.h"
 #include "iggwidgetotherbutton.h"
 
+#include "ibgwidgetbuttonsubject.h"
 #include "ibgwidgethelper.h"
 #include "ibgwidgetselectionboxsubject.h"
 
@@ -61,7 +63,7 @@ namespace iggFrameDataTypeSelector_Private
 		{
 			mSelector = selector;
 			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,title,true);
-			this->SetBaloonHelp("Select the type of data to work with","This control selects the type of the data that is affected by the controls on this page.");
+			this->SetBaloonHelp("Select the type of data to work with","This control selects the type of data that is affected by the widgets on this page.");
         }
 
 	protected:
@@ -77,6 +79,7 @@ namespace iggFrameDataTypeSelector_Private
 				mSubject->InsertItem(info->Type(i).GetTextName());
 			}
 			mSubject->SetValue(mSelector->GetCurrentDataTypeIndex());
+			this->Enable(info->Count() > 1);
 		}
 
 		void OnInt1Body(int v)
@@ -114,6 +117,68 @@ namespace iggFrameDataTypeSelector_Private
 
 		iggFrameDataTypeSelector *mSelector;
 	};
+
+
+	class RestrictButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		RestrictButton(iggFrameDataTypeSelector *selector, iggFrame *parent) : iggWidgetSimpleButton("",parent,true)
+		{
+			mAllIcon = iImageFactory::FindIcon("singleline.png");
+			mSetIcon = iImageFactory::FindIcon("multiline.png");
+			if(mAllIcon==0 || mSetIcon==0)
+			{
+				IERROR_LOW("Icon images are not found.");
+			}
+
+			mSubject->SetFlat(true);
+
+			mSelector = selector;
+			this->SetBaloonHelp("Restrict the list to types with loaded data","This button toggles showing all types or only types with data actually loaded into memory.");
+        }
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			switch(mSelector->GetMode())
+			{
+			case _ListDataTypesWithData:
+				{
+					if(mSetIcon != 0) mSubject->SetIcon(*mSetIcon);
+					break;
+				}
+			default:
+				{
+					if(mAllIcon != 0) mSubject->SetIcon(*mAllIcon);
+					break;
+				}
+			}
+		}
+
+		virtual void Execute()
+		{
+			switch(mSelector->GetMode())
+			{
+			case _ListDataTypesWithData:
+				{
+					mSelector->SetMode(_ListDataTypesAll);
+					break;
+				}
+			default:
+				{
+					mSelector->SetMode(_ListDataTypesWithData);
+					break;
+				}
+			}
+			this->UpdateWidget();
+		}
+
+		const iImage *mAllIcon, *mSetIcon;
+		iggFrameDataTypeSelector *mSelector;
+	};
 };
 
 
@@ -122,28 +187,42 @@ using namespace iggFrameDataTypeSelector_Private;
 
 iggFrameDataTypeSelector::iggFrameDataTypeSelector(iggDataTypeProvider *provider, bool withapply, const iString &title, iggFrameBase *parent, int mode) : iggFrame(parent)
 {
+	const bool hor = true;
+
 	mMode = mode;
 	mProvider = provider; IERROR_ASSERT(provider);
 	mCurrentDataTypeIndex = 0;
 	mInfoPointer = new iDataInfo;
 
-	mBase = new iggFrame(title,this,2);
-	this->AddLine(mBase);
+	if(hor)
+	{
+		mBase = new iggFrame(this,3);
+		mBase->AddSpace(1); // improves the layout
+	}
+	else
+	{
+		mBase = new iggFrame(title,this,3);
+		mBase->AddSpace(1); // improves the layout
+	}
 
-	mBase->AddSpace(1); // improves the layout
-
-	iggWidget *cb = new DataTypeComboBox("",this,mBase);
+	iggWidget *cb = new DataTypeComboBox(hor?title:"",this,mBase);
+	RestrictButton *rb = 0;
+	if(mode == iggParameter::_ListDataTypesAll) rb = new RestrictButton(this,mBase);
 
 	if(withapply)
 	{
 		iggWidget *ab = new ApplyButton(this,mBase);
-		mBase->AddLine(cb,ab);
+		mBase->AddLine(cb,ab,rb);
 		cb->AddDependent(ab);
 	}
 	else
 	{
-		mBase->AddLine(cb,2);
+		mBase->AddLine(cb,2,rb,1);
 	}
+	mBase->AddSpace(1); // improves the layout
+	mBase->SetColStretch(0,10);
+	this->AddLine(mBase);
+
 	mAutoApplying = !withapply;
 
 	cb->UpdateWidget();
@@ -211,6 +290,16 @@ const iDataInfo* iggFrameDataTypeSelector::GetDataInfo()
 }
 
 
+void iggFrameDataTypeSelector::SetMode(int m)
+{
+	if(m>=_ListDataTypesAll && m<=_ListDataTypesWithVariables)
+	{
+		mMode = m;
+		mBase->UpdateWidget();
+	}
+}
+
+
 void iggFrameDataTypeSelector::SetCurrentDataTypeIndex(int v)
 {
 	mCurrentDataTypeIndex = v;
@@ -249,7 +338,7 @@ void iggFrameDataTypeSelector::Apply()
 			this->UpdateWidget();
 		}
 
-		this->GetShell()->GetControlModule()->Render(_RenderModeClones);
+		this->GetShell()->GetControlModule()->Render(_RenderOptionClones);
 	}
 }
 
