@@ -45,7 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
-iggFrameDataTypeWidgetList::iggFrameDataTypeWidgetList(const iString &title, iggFrame *parent) : iggFrame(title,parent), mEntries(0,50)
+iggFrameDataTypeWidgetList::iggFrameDataTypeWidgetList(const iString &title, iggFrame *parent) : iggFrame(title,parent)
 {
 	mBox = new iggFrameScroll(this);
 	this->AddLine(mBox);
@@ -60,21 +60,20 @@ iggFrame* iggFrameDataTypeWidgetList::EntryParent() const
 
 void iggFrameDataTypeWidgetList::UpdateList()
 {
-	int i, n;
+	int i;
 
 	//
 	//  This is expensive to update, make sure it does not update needlessly
 	//
 	if(!mNeedsUpdate) return;
 
-	n = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetNumberOfDataTypes();
-
 	//
 	//  This frame assumes that all readers have the same set of included DataType(s)
 	//
-	for(i=mEntries.Size(); i<n; i++) if(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetDataType(i).IsPrimary())
+	const iDataInfo &all(iDataInfo::Any());
+	for(i=mEntries.Size(); i<all.Count(); i++)
 	{
-		mEntries.Add(this->CreateEntry(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetDataType(i)));
+		mEntries.Add(this->CreateEntry(all.Type(i)));
 		mBox->GetContents()->AddLine(mEntries.Last());
 	}
 }
@@ -94,7 +93,7 @@ const iObjectKey& iggFrameDataTypeWidgetList::Translate(const iObjectKey &key, c
 		iDataSubject *subject = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetSubject(type);
 		if(subject == 0) return key;
 
-		const iObjectKey *p = iObjectKeyRegistry::FindKey(key.RetypedKey(subject->RealType()));
+		const iObjectKey *p = iObjectKeyRegistry::FindKey(key.RetypedKey(subject->GetObjectType()));
 		if(p == 0) return key; else return *p;
 	}
 	else
