@@ -46,12 +46,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 #include "iarraytemplate.h"
 #include "ibuffertemplate.h"
-
+#include "iggreloadingtemplate.h"
 
 iggFrameDataVariableList::iggFrameDataVariableList(const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index, const iObjectKey *indkey) : iggFrame(parent,1), mKey(key), mActivationKey(actkey)
 {
-	mProvider = provider; IERROR_ASSERT(provider);
-
 	//
 	//  Decide, whether we are doing a ComboBox or a RadioBox
 	//
@@ -61,6 +59,29 @@ iggFrameDataVariableList::iggFrameDataVariableList(const iggDataTypeProvider *pr
 	tmp->AddLine(mBoxCombo);
 	mWidgetRadio = mBoxRadio = new iggWidgetKeyRadioBox(1,title,0,key,this,index,indkey);
 
+	this->Define(provider);
+}
+
+
+iggFrameDataVariableList::iggFrameDataVariableList(const iDataInfo &info, const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index, const iObjectKey *indkey) : iggFrame(parent,1), mKey(key), mActivationKey(actkey)
+{
+	//
+	//  Decide, whether we are doing a ComboBox or a RadioBox
+	//
+	iggFrame *tmp = new iggFrame(title,this);
+	mWidgetCombo = tmp;
+	mBoxCombo = new iggReloading<iggWidgetKeyComboBox>(info,provider,"",0,key,tmp,index,indkey);
+	tmp->AddLine(mBoxCombo);
+	mWidgetRadio = mBoxRadio = new iggReloading<iggWidgetKeyRadioBox>(info,provider,1,title,0,key,this,index,indkey);
+
+	this->Define(provider);
+}
+
+
+void iggFrameDataVariableList::Define(const iggDataTypeProvider *provider)
+{
+	mProvider = provider; IERROR_ASSERT(provider);
+
 	mBoxCombo->AttachDataTypeProvider(provider);
 	mBoxRadio->AttachDataTypeProvider(provider);
 
@@ -99,7 +120,7 @@ void iggFrameDataVariableList::Complete(int extraoffset)
 	}
 	else 
 	{
-		IERROR_REPORT("Cannot complete FrameDataVariableList twice.");
+		IERROR_LOW("Cannot complete FrameDataVariableList twice.");
 	}
 }
 
@@ -112,7 +133,7 @@ void iggFrameDataVariableList::UpdateList()
 
 	if(!mCompleted)
 	{
-		IERROR_REPORT("FrameDataVariableList must be completed before the first update.");
+		IERROR_LOW("FrameDataVariableList must be completed before the first update.");
 		return;
 	}
 
@@ -127,7 +148,7 @@ void iggFrameDataVariableList::UpdateList()
 	//
 	if(!this->GetShell()->GetControlModule()->QueryValue(keyNumVars,n))
 	{
-		IERROR_REPORT("Unable to query the number of variables.");
+		IERROR_LOW("Unable to query the number of variables.");
 		return;
 	}
 
@@ -165,7 +186,7 @@ void iggFrameDataVariableList::UpdateChildren()
 {
 	if(!mCompleted)
 	{
-		IERROR_REPORT("FrameDataVariableList must be completed before the first update.");
+		IERROR_LOW("FrameDataVariableList must be completed before the first update.");
 		return;
 	}
 
@@ -195,7 +216,7 @@ void iggFrameDataVariableList::InsertItem(const iString &text)
 	}
 	else
 	{
-		IERROR_REPORT("Cannot insert items in the completed FrameDataVariableList.");
+		IERROR_LOW("Cannot insert items in the completed FrameDataVariableList.");
 	}
 }
 
