@@ -97,7 +97,7 @@ namespace iggFrameDoubleButton_Private
 			mReadyIcon = iImageFactory::FindIcon("ready.png");
 			if(mDelayIcon==0 || mReadyIcon==0)
 			{
-				IERROR_REPORT("Icon images are not found.");
+				IERROR_LOW("Icon images are not found.");
 			}
 
 			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToggleButton,"",1);
@@ -156,7 +156,7 @@ namespace iggFrameDoubleButton_Private
 			{
 				iString ws;
 				this->GetShell()->GetControlModule()->PackCommand(ws,iMarker::KeyPosition(true),x,3);
-				this->GetShell()->GetControlModule()->Execute(ws,true,0,mConcreteParent->GetWindowNumber());
+				this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),iParameter::_DefaultOption,mConcreteParent->GetWindowNumber());
 
 				this->GetMainWindow()->UpdateAll();
 			}
@@ -260,23 +260,23 @@ void iggFrameCreateDeleteButton::UpdateWidgetBody()
 //
 //  Move the focal point to position of a given object type.
 //
-iggFrameMoveFocalPointButton::iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker) : iggFrameDoubleButton(parent,3)
+iggFrameMoveFocalPointButton::iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker, bool stretching) : iggFrameDoubleButton(parent,3)
 {
-	this->Define(withmarker);
+	this->Define(withmarker,stretching);
 }
 
 
-iggFrameMoveFocalPointButton::iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker) : iggFrameDoubleButton(title,parent,3)
+iggFrameMoveFocalPointButton::iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker, bool stretching) : iggFrameDoubleButton(title,parent,3)
 {
-	this->Define(withmarker);
+	this->Define(withmarker,stretching);
 }
 
 
-void iggFrameMoveFocalPointButton::Define(bool withmarker)
+void iggFrameMoveFocalPointButton::Define(bool withmarker, bool stretching)
 {
 	this->AddLine(new Button("Make it a focal point",this,1),new AtOnceButton(this));
 	if(withmarker) this->AddLine(new PlaceMarkerButton(this),2);
-	this->SetColStretch(2,10);
+	if(stretching) this->SetColStretch(0,10); else this->SetColStretch(2,10);
 
 	mMoveInstantly = false;
 }
