@@ -73,6 +73,38 @@ namespace iggFrameHistogramAreaExtra_Private
 		ibgWidgetButtonSubject *mSubject;
 		iggWidgetHistogramArea *mArea;
 	};
+
+
+	class ShowInFullResolutionCheckBox : public iggWidget
+	{
+
+	public:
+
+		ShowInFullResolutionCheckBox(iggWidgetHistogramArea *area, iggFrame *parent) : iggWidget(parent)
+		{
+			mArea = area;
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Full resoluton (may be slow)",1);
+
+			this->SetBaloonHelp("Show histogram with full resolution (slow for large data sets)");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->Show(mArea->SupportsFullResolution());
+			mSubject->SetDown(mArea->GetFullResolution());
+		}
+
+		virtual void OnVoid1Body()
+		{
+			mArea->SetFullResolution(mSubject->IsDown());
+			mArea->UpdateWidget();
+		}
+
+		ibgWidgetButtonSubject *mSubject;
+		iggWidgetHistogramArea *mArea;
+	};
 };
 
 
@@ -82,7 +114,7 @@ using namespace iggFrameHistogramAreaExtra_Private;
 //
 //  Main class
 //
-iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent) : iggFrame(parent,3)
+iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent, bool withFull) : iggFrame(parent,4)
 {
 	mArea = area; IERROR_ASSERT(area);
 	mArea->AddExtra(this);
@@ -90,7 +122,17 @@ iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *a
 	mDisplayMin = new iggWidgetNumberDisplay("",this);
 	mDisplayMax = new iggWidgetNumberDisplay("",this);
 	this->AddLine(mDisplayMin,new iggWidgetTextArea("<-- range -->",this),mDisplayMax);
-	this->AddLine(new ShowInLogCheckBox(area,this),3);
+	iggFrame *tmp = new iggFrame(this,3);
+	if(withFull)
+	{
+		tmp->AddLine(new ShowInLogCheckBox(area,tmp),static_cast<iggWidget*>(0),new ShowInFullResolutionCheckBox(area,tmp));
+	}
+	else
+	{
+		tmp->AddLine(new ShowInLogCheckBox(area,tmp));
+	}
+	tmp->SetColStretch(1,10);
+	this->AddLine(tmp,3);
 	this->SetColStretch(1,10);
 }
 
