@@ -71,12 +71,13 @@ void iggFramePaletteSelection::SetIndex(int i)
 
 void iggFramePaletteSelection::SetCurrentPaletteIndexBody(int i)
 {
-	mDummy->PushValue(i);
+	mDummy->SetValue(i);
 }
 
 
-iPalette* iggFramePaletteSelection::GetCurrentPalette() const
+int iggFramePaletteSelection::GetCurrentPaletteIndex() const
 {
-	return this->GetShell()->GetControlModule()->GetPalette(iMath::Abs(mCurrentPaletteIndex)-1);
+	mDummy->UpdateWidget();
+	return mDummy->GetValue();
 }
 
