@@ -151,7 +151,7 @@ namespace iggFramePaletteSelectionBase_Private
 
 		virtual void OnInt1Body(int n)
 		{
-			mFrame->SetCurrentPaletteIndex((mOffset+n)*(mReverseBox->IsDown()?-1:1));
+			mFrame->SetCurrentPaletteIndex((mOffset+n)*(mReverseBox->IsChecked()?-1:1));
 		}
 
 		int mOffset;
@@ -177,7 +177,7 @@ namespace iggFramePaletteSelectionBase_Private
 		{
 			if(mDialog!=0 && mList!=0)
 			{
-				iPointerCast<iggDialogPaletteEditor,iggDialog>(mDialog)->SetCurrentPaletteIndex(mList->GetValue());
+				iDynamicCast<iggDialogPaletteEditor,iggDialog>(INFO,mDialog)->SetCurrentPaletteIndex(mList->GetValue());
 			}
 			iggWidgetLaunchButton::OnVoid1Body();
 		}
@@ -192,8 +192,6 @@ using namespace iggFramePaletteSelectionBase_Private;
 
 iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent) : iggFrame("Current palette",parent,3)
 {
-	mCurrentPaletteIndex = 1;
-
 	PaletteView *view = new PaletteView(this);
 	IsReversedCheckBox *rb = new IsReversedCheckBox(this);
 	PaletteList *list = new PaletteList(rb,withbrightness,this);
@@ -221,12 +219,11 @@ iggFramePaletteSelectionBase::~iggFramePaletteSelectionBase()
 
 void iggFramePaletteSelectionBase::SetCurrentPaletteIndex(int n)
 {
-	if(n>-this->GetShell()->GetControlModule()->GetNumberOfPalettes() && n<this->GetShell()->GetControlModule()->GetNumberOfPalettes())
+	if(n>=-this->GetShell()->GetControlModule()->GetNumberOfPalettes() && n<=this->GetShell()->GetControlModule()->GetNumberOfPalettes())
 	{
-		mCurrentPaletteIndex = n;
 		this->SetCurrentPaletteIndexBody(n);
 	}
-	else IERROR_REPORT("Incorrect palette number.");
+	else IERROR_LOW("Incorrect palette number.");
 }
 
 
@@ -245,3 +242,9 @@ iPointerArray<iggFramePaletteSelectionBase>& iggFramePaletteSelectionBase::List(
 	return list;
 }
 
+
+iPalette* iggFramePaletteSelectionBase::GetCurrentPalette() const
+{
+	return this->GetShell()->GetControlModule()->GetPalette(iMath::Abs(this->GetCurrentPaletteIndex())-1);
+}
+
