@@ -141,7 +141,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 			}
 			else
 			{
-				IERROR_REPORT("Unable to query PiecewiseFunctionControls.");
+				IERROR_LOW("Unable to query PiecewiseFunctionControls.");
 			}
 		}
 		
