@@ -31,11 +31,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icontrolmodule.h"
 #include "ierror.h"
-#include "iobject.h"
 #include "ishell.h"
+#include "iviewsubject.h"
 
 #include "iggframedoublebutton.h"
 #include "iggwidgetkeylineedit.h"
+#include "iggwidgetkeyselectionbox.h"
 #include "iggwidgetkeyslider.h"
 #include "iggwidgetotherbutton.h"
 
@@ -50,7 +51,7 @@ namespace iggFramePosition_Private
 		
 	public:
 		
-		MoveFocalPointFrame(const iObjectKey &key, iggFrame *parent) : iggFrameMoveFocalPointButton(parent,false), mKey(key)
+		MoveFocalPointFrame(const iObjectKey &key, iggFrame *parent) : iggFrameMoveFocalPointButton(parent,false,true), mKey(key)
 		{
 		}
 
@@ -58,7 +59,7 @@ namespace iggFramePosition_Private
 		{
 			if(!this->GetShell()->GetControlModule()->QueryValue(mKey,x,3))
 			{
-				IERROR_REPORT("Unable to query the position value.");
+				IERROR_LOW("Unable to query the position value.");
 			}
 		}
 
@@ -66,6 +67,36 @@ namespace iggFramePosition_Private
 
 		const iObjectKey &mKey;
 	};
+
+	class MoveToWidget : public iggWidgetKeyComboBox
+	{
+
+	public:
+
+		MoveToWidget(const iObjectKey &key, iggFrame *parent) : iggWidgetKeyComboBox("",1,key,parent)
+		{
+			this->InsertItem("Move to...");
+			this->InsertItem("  Picked point");
+			this->InsertItem("  Focal point");
+			this->InsertItem("  Box center");
+
+			this->SetActionKey(true);
+		}
+
+		virtual bool ExecuteControl(bool final, int val)
+		{
+			bool ret = this->iggWidgetKeyComboBox::ExecuteControl(final,val);
+			this->UpdateWidgetBody();
+			return ret;
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->UpdateValue(-1);
+		}
+	};
 };
 
 
@@ -76,12 +107,18 @@ iggFramePosition::iggFramePosition(const iString &title, const iObjectKey &key,
 {
 	if(key.Argument()!=iObjectKey::_Double || key.Dimension()!=3)
 	{
-		IERROR_FINISH("iggFramePosition is configured incorrectly.");
+		IERROR_FATAL("iggFramePosition is configured incorrectly.");
 	}
 
-	this->AddLine(new iggWidgetKeyPositionSlider(5,"%b%+X",key,_RenderModeUseGlobal,this,0));
-	this->AddLine(new iggWidgetKeyPositionSlider(5,"%b%+Y",key,_RenderModeUseGlobal,this,1));
-	this->AddLine(new iggWidgetKeyPositionSlider(5,"%b%+Z",key,_RenderModeUseGlobal,this,2));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+X",key,_RenderModeUseGlobal,this,0));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Y",key,_RenderModeUseGlobal,this,1));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Z",key,_RenderModeUseGlobal,this,2));
+
+	const iObjectKey *p = iObjectKeyRegistry::FindKey(iViewSubject::KeyMoveTo().RetypedKey(key.Type()));
+	if(p != 0)
+	{
+		this->AddLine(new MoveToWidget(*p,this));
+	}
 
 	if(withFocalPointMove)
 	{
