@@ -36,6 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 
 #include "iggframeposition.h"
+#include "iggmainwindow.h"
 #include "iggwidgetkeyhandler.h"
 #include "iggwidgetotherbutton.h"
 
@@ -81,7 +82,7 @@ namespace iggFramePushControls_Private
 				}
 			default:
 				{
-					IERROR_REPORT("Invalid direction.");
+					IERROR_LOW("Invalid direction.");
 				}
 			}
 		}
@@ -149,7 +150,7 @@ namespace iggFramePushControls_Private
 				for(i=0; i<3; i++) x[i] += mStep*d*n[i];
 				iString ws;
 				this->GetShell()->GetControlModule()->PackCommand(ws,mPositionKey,x,3);
-				this->GetShell()->GetControlModule()->Execute(ws,true,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+				this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 			}
 		}
 
