@@ -160,7 +160,7 @@ namespace iggFrameRangeMapping_Private
  			}
 			else
 			{
-				IERROR_REPORT("Unable to query RangeMapping.");
+				IERROR_LOW("Unable to query RangeMapping.");
 			}
 		}
 		
