@@ -29,6 +29,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggmenuwindow.h"
 
 
+#include "idirectory.h"
+#include "ifile.h"
 #include "ierror.h"
 
 #include "iggframetopparent.h"
@@ -39,7 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggsubjectfactory.h"
 
 
-iggMenuWindow::iggMenuWindow(iShell *shell) : iShellComponent(shell)
+iggMenuWindow::iggMenuWindow(iShell *shell) : iggElement(shell)
 {
 	mMainWindow = 0;
 	mMenuSubject = 0;
@@ -47,7 +49,7 @@ iggMenuWindow::iggMenuWindow(iShell *shell) : iShellComponent(shell)
 }
 
 
-iggMenuWindow::iggMenuWindow(iggMainWindow *mainWindow) : iShellComponent(mainWindow?mainWindow->GetShell():0)
+iggMenuWindow::iggMenuWindow(iggMainWindow *mainWindow) : iggElement(mainWindow?mainWindow->GetShell():0)
 {
 	IERROR_ASSERT(mainWindow);
 	mMainWindow = mainWindow;
@@ -75,9 +77,32 @@ void iggMenuWindow::Show(bool s)
 }
 
 
-iString iggMenuWindow::GetFileName(const iString &header, const iString &file, const iString &selection, bool onlyexisting)
+iString iggMenuWindow::GetFileName(const iString &header, const iString &file, const iString &selection, bool reading)
 {
-	return mMenuSubject->GetFileName(header,file,selection,onlyexisting);
+	iString res(mMenuSubject->GetFileName(header,file,selection,reading));
+	if(!res.IsEmpty())
+	{
+		iDirectory::ExpandFileName(res);
+		if(mMainWindow != 0)
+		{
+			if(reading)
+			{
+				if(!iFile::IsReadable(res))
+				{
+					mMainWindow->PopupWindow("The file is not readable.");
+					res.Clear();
+				}
+			}
+			else
+			{
+				if(iFile::IsWritable(res))
+				{
+					if(mMainWindow->PopupWindow("Do you want to overwrite the existing file?",iggParameter::_PopupWindowWarning,"Ok","Cancel") == 1) res.Clear();
+				}
+			}
+		}
+	}
+	return res;
 }
 
 
