@@ -32,11 +32,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 
 
-iggPage::iggPage(iggFrameBase *parent, bool withbook) : iggFrame(parent)
+iggPage::iggPage(iggFrameBase *parent, bool withbook, bool feedback) : iggFrame(parent)
 {
 	if(withbook)
 	{
-		mBook = new iggFrameBook(this); IERROR_ASSERT(mBook);
+		mBook = new iggFrameBook(this,feedback); IERROR_ASSERT(mBook);
 		this->AddLine(mBook);
 	}
 	else mBook = 0;
