@@ -29,14 +29,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggpagecrosssection.h"
 
 
+#include "icamera.h"
 #include "icontrolmodule.h"
 #include "icrosssectionviewsubject.h"
 #include "ierror.h"
 #include "iimagefactory.h"
+#include "irendertool.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
 #include "iggdatatypeprovider.h"
+#include "iggframeattachposition.h"
 #include "iggframecurrentinstance.h"
 #include "iggframedatavariablelist.h"
 #include "iggframedoublebutton.h"
@@ -101,7 +104,7 @@ namespace iggPageCrossSection_Private
 
 	public:
 		
-		PositionSlider(iggFrame *parent) : iggWidgetKeyPositionSlider(5,"Position",iCrossSectionViewSubject::KeyPos(true),_RenderModeImmediate,parent)
+		PositionSlider(iggFrame *parent) : iggWidgetKeyPositionSlider(8,"Position",iCrossSectionViewSubject::KeyLocation(true),_RenderModeImmediate,parent)
 		{
 			mDownsampleBuddy = 0;
 			mSelfChecking = true;
@@ -121,7 +124,7 @@ namespace iggPageCrossSection_Private
 			if(mDownsampleBuddy->IsDown())
 			{
 				int oldrf, mod = -1;
-				if(this->GetExecuteFlags() & _ModuleModeAll) mod = -2;
+				if(this->GetExecuteFlags() & _ModuleOptionAll) mod = -2;
 
 				this->GetShell()->GetControlModule()->QueryValue(iCrossSectionViewSubject::KeySampleRate(),oldrf);
 				int newrf = round(oldrf*sqrt(10.0*this->GetShell()->GetControlModule()->GetUpdateTime(mod)));
@@ -138,7 +141,7 @@ namespace iggPageCrossSection_Private
 		{
 			iString ws;
 			this->GetShell()->GetControlModule()->PackCommand(ws,iCrossSectionViewSubject::KeySampleRate(),1);
-			this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
 			iggWidgetKeyPositionSlider::OnVoid1Body();
 		}
 
@@ -167,7 +170,7 @@ namespace iggPageCrossSection_Private
 		ScanBoxButton(iggFrame *parent) : iggWidgetSimpleButton("Scan",parent)
 		{
 			this->SetBaloonHelp("Moves the cross section accross the bunding box in a given number of seconds","When this button is clicked, the current cross section moves accross the bounding box with the speed specified by the number of seconds.");
-			mDuration = 5.0;
+			mSteps = 10;
 		}
 
 		void SetBuddy(PositionSlider *buddy)
@@ -175,11 +178,13 @@ namespace iggPageCrossSection_Private
 			mBuddy = buddy;
 		}
 
-		void SetDuration(float v)
+		void SetNumberOfSteps(int v)
 		{
-			if(v > 0.0) mDuration = v;
+			if(v > 1) mSteps = v;
 		}
 
+		inline int GetNumberOfSteps() const { return mSteps; }
+
 	protected:
 
 		virtual void UpdateWidgetBody()
@@ -197,47 +202,40 @@ namespace iggPageCrossSection_Private
 
 		virtual void Execute()
 		{
-			int v, min, max;
-			double op, cp;
-			bool r = false;
-			float t1, t = 0.0;
-			int mod = -1;
-			if(iggWidgetKeyHandlerBase::GetGlobalExecuteFlags() & _ModuleModeAll) mod = -2;
-
 			if(mBuddy == 0)
 			{
-				IERROR_REPORT("PositionSlider buddy must be set.");
+				IERROR_LOW("PositionSlider buddy must be set.");
 				return;
 			}
 			
+			int min, max;
 			mBuddy->GetRange(min,max);
 
-			this->GetShell()->GetControlModule()->QueryValue(iCrossSectionViewSubject::KeyPos(true),op);
-			
-			cp = -1.0;
-			while(!r && t<mDuration)
+			//
+			//  Optimization: direct access
+			//
+			iCrossSectionViewSubject *obj = this->GetShell()->GetControlModule()->GetViewModule()->GetCrossSectionViewSubject();
+			if(obj == 0) return;
+
+			double op = obj->GetLocation();
+
+			int i;
+			bool r = false;
+			for(i=0; i<mSteps && !r; i++)
 			{
-				v = min + round(0.5*(max-min)*(cp+1.0));
-				mBuddy->Drive(v);
-				
-				this->GetShell()->GetControlModule()->QueryValue(iCrossSectionViewSubject::KeyOverTheEdgeFlag(),r);
-				
-				t1 = this->GetShell()->GetControlModule()->GetUpdateTime(mod);
-				if(t1 < 0.1f) t1 = 0.1f;
-				t += t1;
-				cp += 2.0/mDuration*t1;
+				mBuddy->Drive(round(min+float(max-min)*i/(mSteps-1)));
+				r = obj->GetOverTheEdgeFlag();
 			}
 			
-			iString ws;
-			this->GetShell()->GetControlModule()->PackCommand(ws,iCrossSectionViewSubject::KeyPos(true),op);
-			this->GetShell()->GetControlModule()->PackCommand(ws,iCrossSectionViewSubject::KeySampleRate(),1);
-			this->GetShell()->GetControlModule()->Execute(ws,true,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			obj->SetLocation(op);
+			obj->SetSampleRate(1);
+			this->GetShell()->GetControlModule()->Render();
 
 			mBuddy->UpdateWidget();
 		}
 
 		PositionSlider *mBuddy;
-		float mDuration;
+		int mSteps;
 	};
 
 
@@ -250,27 +248,47 @@ namespace iggPageCrossSection_Private
 		{
 			mButton = button;
 
-			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,1,1000,"the box in",1);
-			mSubject->SetValue(5);
-			mButton->SetDuration(5.0);
+			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,2,1000,"the box in",1);
+			mSubject->SetValue(10);
 
-			this->SetBaloonHelp("Number of seconds to scan the box in","Set the number of seconds to scan the box with a cross section in.");
+			this->SetBaloonHelp("Number of steps to scan the box in","Set the number of steps to scan the box with a cross section in.");
 		}
 
 	protected:
 
 		virtual void UpdateWidgetBody()
 		{
+			mSubject->SetValue(mButton->GetNumberOfSteps());
 		}
 
 		virtual void OnInt1Body(int v)
 		{
-			mButton->SetDuration(float(v));
+			mButton->SetNumberOfSteps(v);
 		}
 
 		ScanBoxButton *mButton;
 		ibgWidgetSpinBoxSubject *mSubject;
 	};
+
+
+	class OrthogonalizeViewButton : public iggWidgetSimpleButton
+	{
+		
+	public:
+		
+		OrthogonalizeViewButton(iggFrame *parent) : iggWidgetSimpleButton("Orthogonalize view",parent)
+		{
+			this->SetBaloonHelp("Re-orient the view along the principal directions","This button re-orients the view along the nearest principal directions (X, Y, or Z).");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			this->GetShell()->GetControlModule()->GetViewModule()->GetRenderTool()->GetCamera()->OrthogonalizeView();
+			this->GetShell()->GetControlModule()->GetViewModule()->Render();
+		}
+	};
 };
 
 
@@ -293,7 +311,7 @@ iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(p
 	iggWidget *show = new iggWidgetShowButton(iCrossSectionViewSubject::Type(),page0);
 	iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeyCrossSectionCurrent(),iViewModule::KeyCrossSectionMax(),page0);
 	ci1->AddDependent(this);
-	page0->AddLine(show,(iggWidget *)0,ci1);
+	page0->AddLine(show,static_cast<iggWidget*>(0),ci1);
 	page0->AddSpace(2);
 	//
 	//  Paint with and Direction
@@ -327,6 +345,11 @@ iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(p
 	cp->SetDownsampleBuddy(dc);
 	page0->AddLine(cp,2);
 	page0->AddLine(dc);
+
+	page0->AddSpace(2);
+	page0->AddLine(new iggFrameAttachPosition(cp,iCrossSectionViewSubject::KeyAttachToMarker(),"",page0,true),1);
+	page0->AddLine(new OrthogonalizeViewButton(page0));
+
 	page0->AddSpace(10);
 
 	page0->SetColStretch(1,10);
@@ -400,7 +423,7 @@ iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(p
 	pf = new iggFrame(page3,3);
 	ScanBoxButton *sb = new ScanBoxButton(pf);
 	sb->SetBuddy(cp);
-	pf->AddLine(sb,new ScanDurationSpinBox(sb,pf),new iggWidgetTextArea("seconds",pf));
+	pf->AddLine(sb,new ScanDurationSpinBox(sb,pf),new iggWidgetTextArea("steps",pf));
 	page3->AddLine(pf);
 	page3->AddSpace(2);
 
