@@ -29,12 +29,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggpagedata.h"
 
 
+#include "ibasicdatasubjects.h"
 #include "icontrolmodule.h"
 #include "idata.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatastretch.h"
-#include "idatasubject.h"
 #include "ierror.h"
 #include "iexpressionparser.h"
 #include "iimagefactory.h"
@@ -49,13 +49,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframedatatypewidgetlist.h"
 #include "iggframedatavariablelist.h"
 #include "iggmainwindow.h"
+#include "iggreloading.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetkeybutton.h"
 #include "iggwidgetkeylineedit.h"
 #include "iggwidgetkeyselectionbox.h"
 #include "iggwidgetkeyslider.h"
 #include "iggwidgetotherbutton.h"
-#include "iggwidgetreloading.h"
 
 #include "ibgwidgetareasubject.h"
 #include "ibgwidgetbuttonsubject.h"
@@ -71,6 +71,7 @@ using namespace iParameter;
 //  Templates
 //
 #include "iarraytemplate.h"
+#include "iggreloadingtemplate.h"
 #include "iggwidgetkeylineedittemplate.h"
 #include "iggwidgetkeyslidertemplate.h"
 
@@ -95,7 +96,7 @@ namespace iggPageData_Private
 
 		virtual void QueryValue(iString &val) const
 		{
-			IERROR_REPORT("This function should never be called.");
+			IERROR_LOW("This function should never be called.");
 		}
 
 		virtual void UpdateValue(iString val)
@@ -112,8 +113,9 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsExpandButton(bool out, const iggPageData *page, iggFrame *parent, int index) : iggWidgetSimpleButton("",parent,true), mPage(page)
+		LimitsExpandButton(bool min, bool out, const iggPageData *page, iggFrame *parent, int index) : iggWidgetSimpleButton("",parent,true), mPage(page)
 		{
+			mIsMin = min;
 			mOut = out;
 			mIndex = index;
 
@@ -128,16 +130,16 @@ namespace iggPageData_Private
 		{
 			iString ws;
 			
-			if(mPage->GetProvider()->IsThereDataType())
+			if(mPage->GetProvider(0)->IsThereDataType())
 			{
 				int n, s;
 				float fmin, fmax;
 
-				const iObjectKey &keyNumVars = mPage->GetProvider()->Translate(iDataSubject::KeyNumVars());
-				const iObjectKey &keyStretch = mPage->GetProvider()->Translate(iDataSubject::KeyStretch());
-				const iObjectKey &keyName = mPage->GetProvider()->Translate(iDataSubject::KeyName());
-				const iObjectKey &keyMin = mPage->GetProvider()->Translate(iDataSubject::KeyMin());
-				const iObjectKey &keyMax = mPage->GetProvider()->Translate(iDataSubject::KeyMax());
+				const iObjectKey &keyNumVars = mPage->GetProvider(0)->Translate(iDataSubject::KeyNumVars());
+				const iObjectKey &keyStretch = mPage->GetProvider(0)->Translate(iDataSubject::KeyStretch());
+				const iObjectKey &keyName = mPage->GetProvider(0)->Translate(iDataSubject::KeyName());
+				const iObjectKey &keyMin = mPage->GetProvider(0)->Translate(iDataSubject::KeyMin());
+				const iObjectKey &keyMax = mPage->GetProvider(0)->Translate(iDataSubject::KeyMax());
 
 				if(this->GetShell()->GetControlModule()->QueryValue(keyNumVars,n) && n>mIndex && this->GetShell()->GetControlModule()->QueryValue(keyStretch,mIndex,s,n,-1,-1) && this->GetShell()->GetControlModule()->QueryValue(keyMin,mIndex,fmin,n) && this->GetShell()->GetControlModule()->QueryValue(keyMax,mIndex,fmax,n))
 				{
@@ -149,15 +151,15 @@ namespace iggPageData_Private
 
 					if(mOut)
 					{
-						if(s==_StretchLog && fmax-fmin>3.0f) d = 1.0f; else d = 0.5f*(fmax-fmin);
+						if(s==_StretchLog && fmax-fmin>2.0f) d = 1.0f; else d = 0.5f*(fmax-fmin);
 					}
 					else
 					{
 
-						if(s==_StretchLog && fmax-fmin>3.0f) d = -1.0f; else d = -0.25f*(fmax-fmin);
+						if(s==_StretchLog && fmax-fmin>4.0f) d = -1.0f; else d = -0.25f*(fmax-fmin);
 
-						const iObjectKey &keyLL = mPage->GetProvider()->Translate(iDataSubject::KeyLowerLimit());
-						const iObjectKey &keyUL = mPage->GetProvider()->Translate(iDataSubject::KeyUpperLimit());
+						const iObjectKey &keyLL = mPage->GetProvider(0)->Translate(iDataSubject::KeyLowerLimit());
+						const iObjectKey &keyUL = mPage->GetProvider(0)->Translate(iDataSubject::KeyUpperLimit());
 
 						float fmid, fll, ful;
 						if(this->GetShell()->GetControlModule()->QueryValue(keyLL,mIndex,fll,n) && this->GetShell()->GetControlModule()->QueryValue(keyMax,mIndex,ful,n))
@@ -170,18 +172,24 @@ namespace iggPageData_Private
 						}
 					}
 
-					fmin = (fmin>-iMath::_LargeFloat || d<0.0f) ? iDataStretch::ResetStretch(fmin-d,s) : iDataStretch::ResetStretch(fmin,s);
-					fmax = (fmax< iMath::_LargeFloat || d<0.0f) ? iDataStretch::ResetStretch(fmax+d,s) : iDataStretch::ResetStretch(fmax,s);
+					if(mIsMin)
+					{
+						fmin = (fmin>-iMath::_LargeFloat || d<0.0f) ? iDataStretch::ResetStretch(fmin-d,s) : iDataStretch::ResetStretch(fmin,s);
+						this->GetShell()->GetControlModule()->PackCommand(ws,keyMin,mIndex,fmin);
+					}
+					else
+					{
+						fmax = (fmax< iMath::_LargeFloat || d<0.0f) ? iDataStretch::ResetStretch(fmax+d,s) : iDataStretch::ResetStretch(fmax,s);
+						this->GetShell()->GetControlModule()->PackCommand(ws,keyMax,mIndex,fmax);
+					}
 
-					this->GetShell()->GetControlModule()->PackCommand(ws,keyMax,mIndex,fmax);
-					this->GetShell()->GetControlModule()->PackCommand(ws,keyMin,mIndex,fmin);
-					this->GetShell()->GetControlModule()->Execute(ws,!mOut,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+					this->GetShell()->GetControlModule()->Execute(ws,!mOut && this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 					mParent->UpdateWidget();
 				}
 			}
 		}
 
-		bool mOut;
+		bool mIsMin, mOut;
 		int mIndex;
 		const iggPageData *mPage;
 	};
@@ -194,7 +202,8 @@ namespace iggPageData_Private
 		
 		LimitsStretchComboBox(const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyStretchComboBox(iDataSubject::KeyStretch(),parent,index,0), mPage(page)
 		{
-			this->AttachDataTypeProvider(mPage->GetProvider());
+			this->AttachDataTypeProvider(mPage->GetProvider(0));
+			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
 		}
 
 	protected:
@@ -204,13 +213,13 @@ namespace iggPageData_Private
 			//
 			//  Optimization - direct access
 			//
-			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
+			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider(0)->GetActiveDataType());
 			if(mIndex < lim->GetNumVars()) this->iggWidgetKeyComboBox::UpdateWidgetBody();
 		}
 
 		virtual void OnInt1Body(int i)
 		{
-			if(mPage->GetProvider()->IsThereDataType())
+			if(mPage->GetProvider(0)->IsThereDataType())
 			{
 				iggWidgetKeyComboBox::OnInt1Body(i);
 				mParent->UpdateWidget();
@@ -228,14 +237,15 @@ namespace iggPageData_Private
 		
 		LimitsNameEdit(const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyTextLineEdit(false,"Name",iDataSubject::KeyName(),_RenderModeUseGlobal,parent,index,0), mPage(page)
 		{
-			this->AttachDataTypeProvider(mPage->GetProvider());
+			this->AttachDataTypeProvider(mPage->GetProvider(0));
+			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
 		}
 
 	protected:
 
 		virtual void UpdateWidgetBody()
 		{
-			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
+			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider(0)->GetActiveDataType());
 			if(lim != 0) this->Show(!lim->AreNamesFixed()); else this->Show(false);
 			//
 			//  Optimization - direct access
@@ -246,7 +256,7 @@ namespace iggPageData_Private
 
 		virtual void OnVoid1Body()
 		{
-			if(mPage->GetProvider()->IsThereDataType())
+			if(mPage->GetProvider(0)->IsThereDataType())
 			{
 				iggWidgetKeyTextLineEdit::OnVoid1Body();
 				mParent->UpdateWidget();
@@ -262,8 +272,10 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsRangeSlider(bool low, const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyVariableLimitsSlider(page->GetProvider(),6,low?"Min":"Max",low?iDataSubject::KeyLowerLimit():iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,parent,index), mPage(page)
+		LimitsRangeSlider(bool low, const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyVariableLimitsSlider(page->GetProvider(0),7,low?"Min":"Max",low?iDataSubject::KeyLowerLimit():iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,parent,index), mPage(page)
 		{
+			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+			mSubject->FreezeNumberOfDigits(true);
 		}
 
 	protected:
@@ -273,12 +285,13 @@ namespace iggPageData_Private
 			//
 			//  Optimization - direct access
 			//
-			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
+			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider(0)->GetActiveDataType());
 			if(mIndex < lim->GetNumVars())
 			{
 				mMin = lim->GetMin(mIndex);
 				mMax = lim->GetMax(mIndex);
 				mStretch = lim->GetStretch(mIndex);
+				if(lim->GetClass(mIndex) > 999) this->SetStep(1.0f);
 				mResolution = this->ComputeResolution();
 				this->SetRange(0,mResolution);
 				this->iggWidgetKeyFloatSlider::UpdateWidgetBody();
@@ -294,7 +307,7 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsFrameBox(const iggPageData *page, iggFrame *parent, int index) : iggFrame("",parent,3), mPage(page)
+		LimitsFrameBox(const iggPageData *page, iggFrame *parent, int index) : iggFrame("",parent,4), mPage(page)
 		{
 			mIndex = index;
 			mNeedsBaloonHelp = false;
@@ -302,10 +315,10 @@ namespace iggPageData_Private
 			LimitsRangeSlider *vls1 = new LimitsRangeSlider(true,mPage,this,index);
 			LimitsRangeSlider *vls2 = new LimitsRangeSlider(false,mPage,this,index);
 			vls1->AddBuddy(vls2);
-			this->AddLine(vls1,2,new LimitsExpandButton(false,mPage,this,index),1);
-			this->AddLine(vls2,2,new LimitsExpandButton(true,mPage,this,index),1);
+			this->AddLine(vls1,2,new LimitsExpandButton(true,true,mPage,this,index),1,new LimitsExpandButton(true,false,mPage,this,index),1);
+			this->AddLine(vls2,2,new LimitsExpandButton(false,false,mPage,this,index),1,new LimitsExpandButton(false,true,mPage,this,index),1);
 			mStretchBox = new LimitsStretchComboBox(mPage,this,index);
-			this->AddLine(mStretchBox,1,new LimitsNameEdit(mPage,this,index),2);
+			this->AddLine(mStretchBox,1,new LimitsNameEdit(mPage,this,index),3);
 			this->SetColStretch(1,10);
 		}
 
@@ -316,15 +329,15 @@ namespace iggPageData_Private
 //			int n;
 //			iString s;
 			
-			if(mPage->GetProvider()->IsThereDataType())
+			if(mPage->GetProvider(0)->IsThereDataType())
 			{
-				const iObjectKey &keyNumVars = mPage->GetProvider()->Translate(iDataSubject::KeyNumVars());
-				const iObjectKey &keyName = mPage->GetProvider()->Translate(iDataSubject::KeyName());
+				const iObjectKey &keyNumVars = mPage->GetProvider(0)->Translate(iDataSubject::KeyNumVars());
+				const iObjectKey &keyName = mPage->GetProvider(0)->Translate(iDataSubject::KeyName());
 
 				//
 				//  Optimization - direct access
 				//
-				iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
+				iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider(0)->GetActiveDataType());
 				if(mIndex < lim->GetNumVars())
 //				if(this->GetShell()->GetControlModule()->QueryValue(keyNumVars,n) && mIndex<n && this->GetShell()->GetControlModule()->QueryValue(keyName,mIndex,s,n))
 				{
@@ -356,7 +369,7 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsFrameSet(const iggPageData *page, iggFrame *parent) : iggFrameScroll(parent,false), mPage(page), mBoxes(0)
+		LimitsFrameSet(const iggPageData *page, iggFrame *parent) : iggFrameScroll(parent,false), mPage(page)
 		{
 			mNeedsBaloonHelp = false;
 		}
@@ -370,8 +383,7 @@ namespace iggPageData_Private
 			//
 			if(!mNeedsUpdate) return;
 
-			const iObjectKey &keyNumVars = mPage->GetProvider()->Translate(iDataSubject::KeyNumVars());
-
+			const iObjectKey &keyNumVars = mPage->GetProvider(0)->Translate(iDataSubject::KeyNumVars());
 			if(this->GetShell()->GetControlModule()->QueryValue(keyNumVars,n) && n>mBoxes.Size())
 			{
 				for(i=mBoxes.Size(); i<n; i++)
@@ -398,7 +410,7 @@ namespace iggPageData_Private
 
 	public:
 
-		FixedLimitsFrame(iggFrame *parent) : iggFrameDataTypeWidgetList("Fix limits for data types:",parent)
+		FixedLimitsFrame(iggFrame *parent) : iggFrameDataTypeWidgetList("Fix ranges for data types:",parent)
 		{
 			this->UpdateList();
 		}
@@ -407,7 +419,7 @@ namespace iggPageData_Private
 
 		virtual iggWidget* CreateEntry(const iDataType &type) const
 		{
-			return new iggWidgetReloadingCheckBox(type,type.GetTextName(),this->Translate(iDataSubject::KeyFixedLimits(),type),this->EntryParent());
+			return new iggWidgetKeyCheckBox(type.GetTextName(),this->Translate(iDataSubject::KeyFixedLimits(),type),this->EntryParent());
 		}
 	};
 
@@ -422,6 +434,7 @@ namespace iggPageData_Private
 
 		ShiftingSlider(const iString &title, const iObjectKey &key, iggFrame *parent, int index) : iggWidgetKeyDoubleSlider(-1.0,1.0,200,0,5,title,key,_RenderModeUseGlobal,parent,index)
 		{
+			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
 		}
 
 	protected:
@@ -434,7 +447,7 @@ namespace iggPageData_Private
 			if(final || this->GetRenderMode()==_RenderModeImmediate)
 			{
 				this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->ShiftData();
-				this->GetShell()->GetControlModule()->Execute("",true,(iggWidgetKeyHandlerBase::GetGlobalExecuteFlags()==0)?(_ObjectModeCurrent|_ModuleModeCurrent|_RenderModeClones):iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+				this->GetShell()->GetControlModule()->Execute("",this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 			}
 			return true;
 		}
@@ -644,11 +657,11 @@ namespace iggPageData_Private
 
 	public:
 
-		CalculatorDialog(iggWidgetKeyTextLineEdit *le, iggMainWindow *mw) : iggDialog(mw,_DialogModal,0,"Array Calculator","sr.gg.da",2)
+		CalculatorDialog(const iDataInfo &info, iggWidgetKeyTextLineEdit *le, iggMainWindow *mw) : iggDialog(mw,_DialogModal,0,"Array Calculator","sr.gg.da",2), mInfo(info)
 		{
 			mLineEdit = le;
 
-			mParser = new iExpressionParser; IERROR_ASSERT(mParser);
+			mParser = iExpressionParser::New(); IERROR_ASSERT(mParser);
 
 			mParser->SetScalarVariableValue("Var1",1.0);
 			mParser->SetScalarVariableValue("Var2",1.0);
@@ -723,22 +736,19 @@ namespace iggPageData_Private
 
 		virtual ~CalculatorDialog()
 		{
-			delete mParser;
+			mParser->Delete();
 		}
 
 		virtual void Show(bool s)
 		{
-			iString line;
-
-			mLineEdit->QueryValue(line);
-			mCalculatorLineEdit->SetText(line);
-			iggDialog::Show(s);
-
-			if(mCalculatorLineEdit->GetText() != line)
+			if(s)
 			{
-				this->GetMainWindow()->RequestReloadData(iData::UniformScalars());
+				iString line;
+				mLineEdit->QueryValue(line);
+				mCalculatorLineEdit->SetText(line);
 			}
-
+			
+			iggDialog::Show(s);
 		}
 
 		virtual const iString& GetToolTip() const
@@ -753,22 +763,20 @@ namespace iggPageData_Private
 		{
 			iString line = mCalculatorLineEdit->GetText();
 
-			if(line.IsEmpty())
-			{
-				mLineEdit->ExecuteControl(true);
-				this->GetShell()->GetControlModule()->Render(_RenderModeClones);
-				mFrame->GetMainWindow()->UpdateAll();
-				return true;
-			}
-			
-			if(mParser->CheckSyntax(line))
+			if(line.IsEmpty() || mParser->CheckSyntax(line))
 			{
 				double tmp[3];
-				if(mParser->GetScalarResult(tmp[0]))
+				if(line.IsEmpty() || mParser->GetScalarResult(tmp[0]))
 				{
-					mLineEdit->SetText(line);
-					mLineEdit->ExecuteControl(true);
-					mFrame->GetMainWindow()->UpdateAll();
+					iString oldLine;
+					mLineEdit->QueryValue(oldLine);
+					if(oldLine != line)
+					{
+						mLineEdit->SetText(line);
+						mLineEdit->ExecuteControl(true);
+						this->GetMainWindow()->RequestReloadData(mInfo);
+						this->GetMainWindow()->UpdateAll();
+					}
 					return true;
 				}
 				else if(mParser->GetVectorResult(tmp))
@@ -792,271 +800,283 @@ namespace iggPageData_Private
 		}
 
 		iString mLine;
+		const iDataInfo &mInfo;
 		iExpressionParser *mParser;
 		iggWidgetKeyTextLineEdit *mLineEdit;
 		CalculatorLineEdit *mCalculatorLineEdit;
 	};
+
+
+	class ReloadingPushButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		ReloadingPushButton(const iString &title, iggFrame *parent) : iggWidgetSimpleButton(title,parent)
+		{
+			iString tt = "Click this button to reload the current data set.";
+			this->SetBaloonHelp(tt);
+		}
+
+	protected:
+
+
+		virtual void UpdateWidgetBody()
+		{
+			this->Enable(this->GetMainWindow()->GetReloadDataInfo().Count()>0 && this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsThereData(this->GetMainWindow()->GetReloadDataInfo()));
+		}
+
+		virtual void Execute()
+		{
+			this->GetMainWindow()->ReloadData();
+			this->Enable(false);
+		}
+	};
 };
 
 
 using namespace iggPageData_Private;
 
 
-iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent)
+iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 {
 	const iImage *icon = iImageFactory::FindIcon("data.png");
 
-	mInfoBuffer = new iDataInfo[__NumData]; IERROR_ASSERT(mInfoBuffer);
-	mProvider = new iggKeywordDataTypeProvider("ScalarField",this); IERROR_ASSERT(mProvider);
+	mInfoBuffer = new iDataInfo[__NumDataWith]; IERROR_ASSERT(mInfoBuffer);
+	mProvider = new iggCompositeDataTypeProvider(this); IERROR_ASSERT(mProvider);
+	mProvider->AddProvider(new iggKeywordDataTypeProvider("scalars",this));
+	mProvider->AddProvider(new iggKeywordDataTypeProvider("particles",this));
 
-	mInfoBuffer[_DataOnBoundaryCondition] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors() + iData::BasicParticles();
-	mInfoBuffer[_DataOnVoxelLocation] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors();
-	mInfoBuffer[_DataOnCellToPointMode] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors();
-	mInfoBuffer[_DataOnParticlesDownsample] = iData::BasicParticles();
-	mInfoBuffer[_DataOnParticlesOrderInFileIsAttribute] = iData::BasicParticles();
+	iDataType::FindTypesByKeywords(mInfoBuffer[_DataWithParticleDownsampling],"particles");
+	mInfoBuffer[_DataWithBoundaryCondition] = mInfoBuffer[_DataWithParticleDownsampling] + iUniformScalarsDataSubject::DataType() + iUniformVectorsDataSubject::DataType() + iUniformTensorsDataSubject::DataType();
+	mInfoBuffer[_DataWithVariableCalculation] = iUniformScalarsDataSubject::DataType();
 
 	this->GetMainWindow()->GetExtensionWindow()->AddReloadingDataTypes(this);
 
 	//
-	//  Main page
+	//  Common page
 	// ************************************************
 	//
 	iggFrame *page0 = new iggFrame(mBook,1);
-	mBook->AddPage("Settings",icon,page0);
-	//
-	//  Book
-	//
-	iggFrameBook *sb = new iggFrameBook(page0);
-	page0->AddLine(sb);
-	//
-	//  Global page
-	//
-	iggFrame *sbpage0 = new iggFrame(sb,2);
-	sb->AddPage("Global",icon,sbpage0);
-	
-	sbpage0->AddLine(new iggFrameBoxSize(sbpage0));
-	sbpage0->AddSpace(2);
+	mBook->AddPage("Common",icon,page0);
+	{
+		//
+		//  Book
+		//
+		iggFrameBook *sb = new iggFrameBook(page0);
+		page0->AddLine(sb);
+		{
+			//
+			//  Global page
+			//
+			iggFrame *sbpage0 = new iggFrame(sb,2);
+			sb->AddPage("Global",icon,sbpage0);
+			{
+				sbpage0->AddLine(new iggFrameBoxSize(sbpage0));
+				sbpage0->AddSpace(2);
 
-	iggWidgetKeyRadioBox *orb = new iggWidgetKeyRadioBox(1,"Optimize for...",0,iControlModule::KeyOptimizationMode(),sbpage0);
-	orb->InsertItem("Speed");
-	orb->InsertItem("Memory");
-	orb->InsertItem("Quality");
-	sbpage0->AddLine(orb);
-	sbpage0->AddSpace(2);
+				iggWidgetKeyRadioBox *orb = new iggWidgetKeyRadioBox(1,"Optimize for...",0,iControlModule::KeyOptimizationMode(),sbpage0);
+				orb->InsertItem("Speed");
+				orb->InsertItem("Memory");
+				orb->InsertItem("Quality");
+				sbpage0->AddLine(orb);
+				sbpage0->AddSpace(2);
 
-	iggWidgetReloadingRadioBox *bc = new iggWidgetReloadingRadioBox(mInfoBuffer[_DataOnBoundaryCondition],"Boundary conditions",iDataReader::KeyBoundaryConditions(),sbpage0);
-	bc->InsertItem("Periodic");
-	bc->InsertItem("Wall");
-	sbpage0->AddLine(bc);
-	sbpage0->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",sbpage0));
-	sbpage0->AddSpace(2);
+				iggWidgetKeyRadioBox *bc = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[_DataWithBoundaryCondition],0,1,"Boundary conditions",0,iDataReader::KeyBoundaryConditions(),sbpage0);
+				bc->InsertItem("Periodic");
+				bc->InsertItem("Wall");
+				sbpage0->AddLine(bc);
+				sbpage0->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",sbpage0));
+				sbpage0->AddSpace(2);
+
+				ReloadingPushButton *rb = new ReloadingPushButton("Reload data",sbpage0);
+				rb->AddDependent(bc);
+				sbpage0->AddLine(rb);
+				sbpage0->AddSpace(10);
+				sbpage0->SetColStretch(1,10);
+			}
+			//
+			//  Shift page
+			//
+			iggFrame *sbpage1 = new iggFrame(sb,2);
+			sb->AddPage("Shift data",icon,sbpage1);
+			{
+				iggFrame *sh = new iggFrame(sbpage1);
+				sh->AddLine(new ShiftingSlider("%bX",iDataReader::KeyShiftData(),sh,0));
+				sh->AddLine(new ShiftingSlider("%bY",iDataReader::KeyShiftData(),sh,1));
+				sh->AddLine(new ShiftingSlider("%bZ",iDataReader::KeyShiftData(),sh,2));
+				sbpage1->AddLine(sh);
+				sbpage1->AddSpace(10);
+				sbpage1->SetColStretch(0,10);
+				sbpage1->SetColStretch(1,3);
+			}		
+			//
+			//  Erase page
+			//
+			iggFrame *sbpage2 = new iggFrame(sb,2);
+			sb->AddPage("Erase",icon,sbpage2);
+			{
+				ErasePushButton *eb = new ErasePushButton("Erase selected data",sbpage2);
+				sbpage2->AddLine(new EraseFrame(eb,sbpage2));
+				sbpage2->AddLine(eb);
+				sbpage2->AddSpace(2);
+				sbpage2->SetRowStretch(0,10);
+				sbpage2->SetColStretch(0,10);
+				sbpage2->SetColStretch(1,10);
+			}
+			//
+			//  Fixed/adjustable page
+			//
+			iggFrame *sbpage3 = new iggFrame(sb,2);
+			sb->AddPage("Ranges",icon,sbpage3);
+			{
+				sbpage3->AddLine(new FixedLimitsFrame(sbpage3));
+				sbpage3->AddSpace(10);
+				sbpage3->SetRowStretch(0,8);
+				sbpage3->SetColStretch(1,10);
+			}
+		}
+	}
 
-	iggWidgetReloadingPushButton *rb = new iggWidgetReloadingPushButton("Reload data",sbpage0);
-	rb->AddDependent(bc);
-	sbpage0->AddLine(rb);
-	sbpage0->AddSpace(10);
-	sbpage0->SetColStretch(1,10);
 	//
 	//  Field data page
-	//
-	iggFrame *sbpage1 = new iggFrame(sb,2);
-	sb->AddPage("Field data",icon,sbpage1);
-
-//	sbpage1->AddLine(new iggWidgetKeyCheckBox("Readjust limits to correspond to the data file.",iDataReader::KeyAdjustableLimits(),sbpage1));
-
-	iggWidgetReloadingRadioBox *vl = new iggWidgetReloadingRadioBox(mInfoBuffer[_DataOnVoxelLocation],"Voxel location",iDataReader::KeyVoxelLocation(),sbpage1);
-	vl->InsertItem("Vertex of a cell");
-	vl->InsertItem("Center of a cell");
-	sbpage1->AddLine(vl);
-	sbpage1->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",sbpage1));
-
-	iggWidgetReloadingRadioBox *cp = new iggWidgetReloadingRadioBox(mInfoBuffer[_DataOnCellToPointMode],"Cell-to-point method",iDataReader::KeyCellToPointMode(),sbpage1);
-	cp->InsertItem("Fourier shift (slow)");
-	cp->InsertItem("8-point average");
-	cp->InsertItem("8-point median");
-	cp->InsertItem("8-point minimum");
-	cp->InsertItem("8-point maximum");
-	cp->InsertItem("Corner projection");
-	sbpage1->AddLine(cp);
-	sbpage1->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",sbpage1));
-
-	sbpage1->AddSpace(10);
-	sbpage1->SetColStretch(1,10);
-	//
-	//  Particle data page
-	//
-	iggFrame *sbpage2 = new iggFrame(sb,2);
-	sb->AddPage("Particle data",icon,sbpage2);
-
-	iggFrame *df = new iggFrame("Downsample particles",sbpage2,2);
-
-	iggWidgetReloadingSlider *dl = new iggWidgetReloadingSlider(mInfoBuffer[_DataOnParticlesDownsample],1,30,2,"Factor",iDataReader::KeyParticlesDownsampleFactor(),df);
-	df->AddLine(dl,2);
-	df->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",df));
-
-	iggWidgetReloadingRadioBox *db = new iggWidgetReloadingRadioBox(mInfoBuffer[_DataOnParticlesDownsample],"Downsample mask",iDataReader::KeyParticlesDownsampleMode(),df);
-	db->InsertItem("Regular");
-	db->InsertItem("Random");
-	db->InsertItem("Head of file");
-	db->InsertItem("Tail of file");
-	df->AddLine(db);
-	df->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",df));
-	df->SetColStretch(1,10);
-
-	sbpage2->AddLine(df);
-	sbpage2->AddSpace(10);
-
-	sbpage2->AddLine(new iggWidgetReloadingCheckBox(mInfoBuffer[_DataOnParticlesOrderInFileIsAttribute],"Include the particle number as an attribute",iDataReader::KeyParticlesOrderInFileIsAttribute(),sbpage2));
-	sbpage2->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",sbpage2));
-
-	sbpage2->AddSpace(10);
-	sbpage2->SetColStretch(1,10);
-
-	//
-	//  Limits page
 	// ************************************************
 	//
 	iggFrame *page1 = new iggFrame(mBook,1);
-	mBook->AddPage("Limits",icon,page1);
-	//
-	//  Book
-	//
-	iggFrameBook *lb = new iggFrameBook(page1);
-	page1->AddLine(lb);
-	//
-	//  Scalar limits page
-	//
-	iggFrame *lbpage0 = new iggFrame(lb,1);
-	lb->AddPage("Scalar limits",icon,lbpage0);
+	mBook->AddPage("Field data",icon,page1);
+	{
+		//
+		//  Book
+		//
+		iggFrameBook *fb = new iggFrameBook(page1);
+		page1->AddLine(fb);
+		{
+			//
+			//  Limits page
+			//
+			iggFrame *fbpage1 = new iggFrame(fb,1);
+			fb->AddPage("Limits",icon,fbpage1);
+			{
+				fbpage1->AddLine(new LimitsFrameSet(this,fbpage1));
+			}
+			//
+			//  Placement page
+			//
+			iggFrame *fbpage2 = new iggFrame(fb,2);
+			fb->AddPage("Placement",icon,fbpage2);
+			{
+				iggWidgetKeyRadioBox *vl = new iggWidgetKeyRadioBox(1,"Voxel location",0,iDataReader::KeyVoxelLocation(),fbpage2);
+				vl->InsertItem("Vertex of a cell (\"point data\")");
+				vl->InsertItem("Center of a cell (\"cell data\")");
+				fbpage2->AddLine(vl);
 
-	lbpage0->AddLine(new LimitsFrameSet(this,lbpage0));
-	//
-	//  Fixed/adjustable page
-	//
-	iggFrame *lbpage1 = new iggFrame(lb,2);
-	lb->AddPage("Fixed/Adjustable",icon,lbpage1);
+				iggWidgetTextArea *tmp = new iggWidgetTextArea("  Dimension to fit",fbpage2);
+				fbpage2->AddLine(tmp);
+				iggWidgetKeyRadioBox *fb = new iggWidgetKeyRadioBox(1,"into bounding box",2,iDataReader::KeyScaledDimension(),fbpage2);
+				fb->InsertItem("Longest");
+				fb->InsertItem("Shortest");
+				fb->InsertItem("X");
+				fb->InsertItem("Y");
+				fb->InsertItem("Z");
+				fbpage2->AddLine(fb);
+				fbpage2->AddSpace(10);
 
-	lbpage1->AddLine(new FixedLimitsFrame(lbpage1));
-	lbpage1->AddSpace(10);
-	lbpage1->SetRowStretch(0,8);
-	lbpage1->SetColStretch(1,10);
+				fbpage2->SetColStretch(1,10);
+			}		
+			//
+			//  Operate page
+			//
+			iggFrame *fbpage3 = new iggReloading<iggFrame>(mInfoBuffer[_DataWithVariableCalculation],mProvider->GetProvider(0),fb,2);
+			fb->AddPage("Operate",icon,fbpage3);
+			{
+				iggFrameDataVariableList *ol = new iggFrameDataVariableList(mInfoBuffer[_DataWithVariableCalculation],mProvider->GetProvider(0),"Assign result to...",iUniformScalarsDataSubject::KeyVariableCalculatorOutput(),0,fbpage3);
+				ol->Complete();
+				iggFrame *of = new iggFrame(fbpage3,1);
+				of->AddSpace(10);
+				iggWidgetKeyTextLineEdit *oe = new iggWidgetKeyTextLineEdit(true,"= ",iUniformScalarsDataSubject::KeyVariableCalculatorFunction(),_RenderModeNoRender,of);
+				of->AddLine(oe);
+				of->AddSpace(10);
+				fbpage3->AddLine(ol,of);
+				fbpage3->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",fbpage3));
+				fbpage3->AddSpace(2);
+
+				CalculatorDialog *cd = new CalculatorDialog(mInfoBuffer[_DataWithVariableCalculation],oe,this->GetMainWindow());
+				fbpage3->AddLine(new iggWidgetLaunchButton(cd,"Launch calculator",fbpage3,true));
+				fbpage3->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",fbpage3));
+
+				fbpage3->AddSpace(10);
+				fbpage3->SetColStretch(1,10);
+				fbpage3->SetColStretch(2,3);
+			}
+		}
+	}
 
 	//
-	//  Placement page
+	//  Particle data page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,3);
-	mBook->AddPage("Placement",icon,page2);
-
-	if(false)
+	iggFrame *page2 = new iggFrame(mBook,1);
+	mBook->AddPage("Particle data",icon,page2);
 	{
 		//
 		//  Book
 		//
 		iggFrameBook *pb = new iggFrameBook(page2);
-		page2->AddLine(pb,2);
-		//
-		//  Shift page
-		//
-		iggFrame *pbpage0 = new iggFrame(pb,2);
-		pb->AddPage("Shift",icon,pbpage0);
-		
-		pbpage0->AddLine(new ShiftingSlider("%bX",iDataReader::KeyShiftData(),pbpage0,0));
-		pbpage0->AddLine(new ShiftingSlider("%bY",iDataReader::KeyShiftData(),pbpage0,1));
-		pbpage0->AddLine(new ShiftingSlider("%bZ",iDataReader::KeyShiftData(),pbpage0,2));
-		
-		pbpage0->AddSpace(10);
-		pbpage0->SetColStretch(0,10);
-		pbpage0->SetColStretch(1,3);
-		//
-		//  Fit page
-		//
-		iggFrame *pbpage1 = new iggFrame(pb,2);
-		pb->AddPage("Fit",icon,pbpage1);
-		
-		iggWidgetKeyRadioBox *fb = new iggWidgetKeyRadioBox(1,"Dimension to fit into the bounding box",0,iDataReader::KeyScaledDimension(),pbpage1);
-		fb->InsertItem("Longest");
-		fb->InsertItem("Shortest");
-		fb->InsertItem("X");
-		fb->InsertItem("Y");
-		fb->InsertItem("Z");
-		pbpage1->AddLine(fb);
-		
-		pbpage1->AddSpace(10);
-		pbpage1->SetColStretch(1,10);
+		page2->AddLine(pb);
+		{
+			//
+			//  Downsample page
+			//
+			iggFrame *pbpage0 = new iggFrame(pb,2);
+			pb->AddPage("Downsample",icon,pbpage0);
+			{
+				iggWidgetKeyIntSlider *dl = new iggReloading<iggWidgetKeyIntSlider>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),1,100,3,"Factor",iParticleDataSubject::KeyDownsampleFactor(),_RenderModeNoRender,pbpage0);
+				dl->AttachDataTypeProvider(mProvider->GetProvider(1));
+
+				pbpage0->AddLine(dl,2);
+				pbpage0->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage0));
+
+				iggWidgetKeyRadioBox *db = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),1,"Downsample mask",0,iParticleDataSubject::KeyDownsampleMode(),pbpage0);
+				db->InsertItem("Regular");
+				db->InsertItem("Regular 2D");
+				db->InsertItem("Regular 3D");
+				db->InsertItem("Random");
+				db->InsertItem("Head of file");
+				db->InsertItem("Tail of file");
+				db->AttachDataTypeProvider(mProvider->GetProvider(1));
+				pbpage0->AddLine(db);
+				pbpage0->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage0));
+				pbpage0->SetColStretch(1,10);
+
+				pbpage0->AddSpace(10);
+				pbpage0->SetColStretch(1,10);
+			}
+			//
+			//  Operate page
+			//
+			iggFrame *pbpage1 = new iggFrame(pb,2);
+			pb->AddPage("Operate",icon,pbpage1);
+			{
+				iggWidgetKeyCheckBox *oa = new iggReloading<iggWidgetKeyCheckBox>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),"Include the particle number as an attribute",iParticleDataSubject::KeyOrderIsAttribute(),pbpage1);
+				oa->AttachDataTypeProvider(mProvider->GetProvider(1));
+				pbpage1->AddLine(oa);
+				pbpage1->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage1));
+
+				pbpage1->AddSpace(2);
+
+				iggFrameDataVariableList *al = new iggFrameDataVariableList(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),"Compute density of...",iParticleDataSubject::KeyDensityAttribute(),0,pbpage1);
+				al->InsertItem("Do not compute");
+				al->InsertItem("Particle number");
+				al->Complete();
+
+				pbpage1->AddLine(al);
+				pbpage1->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage1));
+
+				pbpage1->AddSpace(10);
+				pbpage1->SetColStretch(1,10);
+			}
+		}
 	}
-	else
-	{
-		//
-		//  No book - all on one page
-		//
-		//
-		//  Shift page
-		//
-		iggFrame *sh = new iggFrame("Shift data",page2);
-		sh->AddLine(new ShiftingSlider("%bX",iDataReader::KeyShiftData(),sh,0));
-		sh->AddLine(new ShiftingSlider("%bY",iDataReader::KeyShiftData(),sh,1));
-		sh->AddLine(new ShiftingSlider("%bZ",iDataReader::KeyShiftData(),sh,2));
-		page2->AddLine(sh,2);
-		page2->AddSpace(2);
-		//
-		//  Fit page
-		//
-		iggWidgetKeyRadioBox *fb = new iggWidgetKeyRadioBox(1,"Dimension to fit into the bounding box",2,iDataReader::KeyScaledDimension(),page2);
-		fb->InsertItem("Longest");
-		fb->InsertItem("Shortest");
-		fb->InsertItem("X");
-		fb->InsertItem("Y");
-		fb->InsertItem("Z");
-		page2->AddLine(fb);
-		
-		page2->AddSpace(10);
-		page2->SetColStretch(1,10);
-		page2->SetColStretch(2,3);
-	}		
-
-	//
-	//  Erase page
-	// ************************************************
-	//
-	iggFrame *page3 = new iggFrame(mBook,2);
-	mBook->AddPage("Erase",icon,page3);
-
-	//
-	//  No book - all on one page
-	//
-	ErasePushButton *eb = new ErasePushButton("Erase selected data",page3);
-	page3->AddLine(new EraseFrame(eb,page3));
-	page3->AddLine(eb);
-
-	page3->AddSpace(10);
-	page3->SetRowStretch(0,10);
-	page3->SetColStretch(1,10);
-
-	//
-	//  Transform page
-	// ************************************************
-	//
-	iggFrame *page4 = new iggFrame(mBook,2);
-	mBook->AddPage("Operate on scalar data",icon,page4);
-
-	iggFrameDataVariableList *ol = new iggFrameDataVariableList(mProvider,"Assign result to...",iDataReader::KeyScalarFieldCalculatorOutputVariable(),0,page4,0);
-	ol->Complete();
-	iggFrame *of = new iggFrame(page4,1);
-	of->AddSpace(10);
-	iggWidgetKeyTextLineEdit *oe = new iggWidgetKeyTextLineEdit(true,"= ",iDataReader::KeyScalarFieldCalculatorFunction(),_RenderModeNoRender,of);
-	of->AddLine(oe);
-	of->AddSpace(10);
-	page4->AddLine(ol,of);
-	page4->AddSpace(2);
-
-	CalculatorDialog *cd = new CalculatorDialog(oe,this->GetMainWindow());
-	page4->AddLine(new iggWidgetLaunchButton(cd,"Launch calculator",page4));
-	page4->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",page4));
-
-	page4->AddSpace(10);
-	page4->SetColStretch(1,10);
-	page4->SetColStretch(2,3);
 }
 
 
@@ -1082,15 +1102,40 @@ iggFrame* iggPageData::CreateFlipFrame(iggFrameBase *parent) const
 
 void iggPageData::UpdateOnDataLoad()
 {
-	mProvider->FindAvailableData();
+	this->GetProvider()->FindAvailableData();
 }
 
 
 void iggPageData::AddReloadingType(int key, const iDataType &type)
 {
-	if(key>=0 && key<__NumData)
+	if(key>=0 && key<__NumDataWith)
 	{
 		mInfoBuffer[key] += type;
 	}
 }
 
+
+iggKeywordDataTypeProvider* iggPageData::GetProvider(int n) const
+{
+	if(n>=0 && n<2) return mProvider->GetProvider(n); else
+	{
+		if(mProvider->GetCurrentProvider() == 0)
+		{
+			IERROR_FATAL("iggPageData is configured incorrectly.");
+			return 0;
+		}
+		else return mProvider->GetCurrentProvider();
+	}
+}
+
+
+void iggPageData::OnInt1Body(int i)
+{
+	i--;
+	if(i != mProvider->GetCurrentIndex())
+	{
+		mProvider->SetCurrentIndex(i);
+		if(mFlipFrame != 0) mFlipFrame->UpdateWidget();
+	}
+}
+
