@@ -43,6 +43,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewobjectfamily.h"
 
 #include "iggdatatypeprovider.h"
+#include "iggextensionwindow.h"
 #include "iggframecurrentinstance.h"
 #include "iggframedatavariablelist.h"
 #include "iggframefunctionmapping.h"
@@ -102,7 +103,7 @@ namespace iggPageParticles_Private
 			}
 			else
 			{
-				IERROR_REPORT("Failed querying iParticlesViewSubject::KeyCurrentGroup() key.");
+				IERROR_LOW("Failed querying iParticlesViewSubject::KeyCurrentGroup() key.");
 				return 0;
 			}
 		}
@@ -111,7 +112,7 @@ namespace iggPageParticles_Private
 		{
 			iString ws;
 			this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyCurrentGroup(),c);
-			this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
 		}
 
 		virtual void OnAddRange()
@@ -140,10 +141,10 @@ namespace iggPageParticles_Private
 			if(this->GetShell()->GetControlModule()->QueryValue(iParticlesViewSubject::KeyAttributeToSplit(),att))
 			{
 				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyAttributeToSplit(),-1);
-				this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+				this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
 				ws.Clear();
 				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyAttributeToSplit(),att);
-				this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+				this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
 				if(mDependent != 0) mDependent->UpdateWidget();
 			}
 		}
@@ -185,20 +186,16 @@ namespace iggPageParticles_Private
 	//
 	//  Special provider
 	//
-	class ParticleSetTypeProvider : public iggDataTypeProvider
+	class ParticleTypeProvider : public iggDataTypeProvider
 	{
 
 	public:
 
-		ParticleSetTypeProvider(iggPageParticles *page) : iggDataTypeProvider((page==0)?0:page->GetShell())
+		ParticleTypeProvider(iggPageParticles *page) : iggDataTypeProvider((page==0)?0:page->GetShell())
 		{
 			mPage = page; IERROR_ASSERT(page);
 		}
 
-		virtual ~ParticleSetTypeProvider()
-		{
-		}
-
 		virtual int GetActiveDataTypeIndex() const
 		{
 			return mPage->GetParticlesObject()->GetActiveDataTypeIndex();
@@ -208,19 +205,15 @@ namespace iggPageParticles_Private
 		{
 			if(v != this->GetActiveDataTypeIndex())
 			{
-				mPage->SetCurrentParticleSet(v);
+				mPage->SetCurrentParticles(v);
+				mPage->GetMainWindow()->GetExtensionWindow()->UpdateOnDataType(this->GetActiveDataType());
 				mPage->GetMainWindow()->UpdateAll();
 			}
 		}
 		
 		virtual const iDataInfo& GetDataInfo() const
 		{
-			static iDataInfo info;
-			if(info.Count() == 0)
-			{
-				iDataType::FindAllTypesByKeywords(info,"ParticleSet");
-			}
-			return info;
+			return mPage->GetParticlesObject()->GetPrimaryDataInfo();
 		}
 
 		virtual const iDataType& GetActiveDataType() const
@@ -236,21 +229,28 @@ namespace iggPageParticles_Private
 using namespace iggPageParticles_Private;
 
 
-iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeParticles), mIcons(0)
+iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeParticles)
 {
 	int i;
 
 	const iImage *icon = iImageFactory::FindIcon("part.png");
 
-	mIcons.Add(iImageFactory::FindIcon("part.png"));
-
-	mCurrentParticleSet = this->GetParticlesObject()->GetActiveDataTypeIndex();
+	mCurrentParticles = this->GetParticlesObject()->GetActiveDataTypeIndex();
 
 	//
 	//  Replace provider
 	//
 	delete mProvider;
-	mProvider = new ParticleSetTypeProvider(this); IERROR_ASSERT(mProvider);
+	mProvider = new ParticleTypeProvider(this); IERROR_ASSERT(mProvider);
+
+	mIcons.Add(iImageFactory::FindIcon("part.png"));
+	const iDataInfo &di(mProvider->GetDataInfo());
+	const iImage *image;
+	for(i=1; i<di.Count(); i++)
+	{
+		image = this->GetMainWindow()->GetExtensionWindow()->GetSpecialParticleIcon(di.Type(i));
+		if(image == 0) mIcons.Add(icon); else mIcons.Add(image);
+	}
 
 	//
 	//  Main page
@@ -263,7 +263,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	//
 	iggFrameCurrentInstance *ci = new iggFrameCurrentInstance(false,"Group","Group",iParticlesViewSubject::KeyCurrentGroup(),iParticlesViewSubject::KeyMaxGroup(),page0);
 	ci->AddDependent(this);
-	page0->AddLine(new iggWidgetShowButton(iParticlesViewSubject::Type(),page0),(iggWidget *)0,ci);
+	page0->AddLine(new iggWidgetShowButton(iParticlesViewSubject::Type(),page0),static_cast<iggWidget*>(0),ci);
 	page0->AddSpace(2);
 	//
 	//  Method & color normals
@@ -294,6 +294,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	tmp->AddLine(new AdjustSizeSliderButton(ss,false,tmp),new AdjustSizeSliderButton(ss,true,tmp),new iggWidgetTextArea("Expand/shrink the lower limit",tmp));
 	tmp->SetColStretch(3,10);
 	page0->AddLine(tmp);
+	page0->AddLine(new iggWidgetKeyCheckBox("Scale particles automatically",iParticleGroup::KeyAutoScaled(),page0));
 	page0->AddSpace(10);
 
 	page0->SetColStretch(1,10); 
@@ -505,15 +506,28 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 }
 
 
-void iggPageParticles::SetCurrentParticleSet(int n)
+void iggPageParticles::SetCurrentParticles(int n)
 {
-	if(n>=0 && n<=this->GetParticlesObject()->GetNumberOfTypes())
+	if(n>=0 && n<this->GetParticlesObject()->GetNumberOfTypes())
 	{
-		mCurrentParticleSet = n;
+		mCurrentParticles = n;
 		iString ws;
 		this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyParticlesCurrent(),n);
 		this->GetShell()->GetControlModule()->Execute(ws,false);
-		this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[n]);
+#ifdef I_CHECK
+		if(mIcons.Size() != this->GetParticlesObject()->GetNumberOfTypes())
+		{
+			IERROR_LOW("Bug in iggPageParticles: incompating mIcons array.");
+		}
+#endif
+		if(n>=0 && n<mIcons.Size())
+		{
+			this->GetMainWindow()->UpdateParticleWidgets(mIcons[n]);
+		}
+		else
+		{
+			this->GetMainWindow()->UpdateParticleWidgets(mIcons[0]);
+		}
 	}
 }
 
@@ -526,11 +540,11 @@ void iggPageParticles::AddIcon(const iImage *image)
 
 void iggPageParticles::UpdateWidgetBody()
 {
-	if(mCurrentParticleSet != this->GetParticlesObject()->GetActiveDataTypeIndex())
+	if(mCurrentParticles != this->GetParticlesObject()->GetActiveDataTypeIndex())
 	{
-		this->SetCurrentParticleSet(this->GetParticlesObject()->GetActiveDataTypeIndex());
+		this->SetCurrentParticles(this->GetParticlesObject()->GetActiveDataTypeIndex());
 	}
-//	this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[mCurrentParticleSet]);
+//	this->GetMainWindow()->UpdateParticleWidgets(mIcons[mCurrentParticles]);
 	this->iggPage::UpdateWidgetBody();
 }
 
