@@ -149,7 +149,7 @@ namespace iggPageSurface_Private
 				}
 			default:
 				{
-					IERROR_REPORT("Incorrect button in MethodRadioBox.");
+					IERROR_LOW("Incorrect button in MethodRadioBox.");
 				}
 			}
 		}
@@ -331,7 +331,7 @@ namespace iggPageSurface_Private
 			
 			if(!this->AreTwoInstancesConsistent())
 			{
-				IERROR_REPORT("Two isosurafces instances are not compatible or are not isosurfaces.");
+				IERROR_LOW("Two isosurafces instances are not compatible or are not isosurfaces.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
@@ -353,7 +353,7 @@ namespace iggPageSurface_Private
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmin,2,-1,mSpinBox1->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmax,2,-1,mSpinBox2->GetValue()-1)) 
 			{
-				IERROR_REPORT("Unable to query Surface object.");
+				IERROR_LOW("Unable to query Surface object.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
@@ -374,7 +374,7 @@ namespace iggPageSurface_Private
 
 			if((m==_SurfaceMethodIsoSurface) && (fabs(lstp)<0.01))
 			{
-				IERROR_REPORT("Cannot create new isosurface: the two limits are too close.");
+				IERROR_LOW("Cannot create new isosurface: the two limits are too close.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
@@ -406,7 +406,7 @@ namespace iggPageSurface_Private
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyPosition(true),p,3);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeySize(true),s);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyPlaneDirection(),d,3);
-					this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+					this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
 				}
 			}
 			
@@ -443,7 +443,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	iggWidget *show = new iggWidgetShowButton(iSurfaceViewSubject::Type(),page0top);
 	iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),page0top);
 	ci1->AddDependent(this);
-	page0top->AddLine(show,(iggWidget *)0,(iggWidget *)0,ci1);
+	page0top->AddLine(show,static_cast<iggWidget*>(0),static_cast<iggWidget*>(0),ci1);
 	page0top->AddSpace(2);
 	//
 	//  Method & flip normals
@@ -459,7 +459,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	//
 	//  Opacity
 	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),_RenderModeUseGlobal,page0top,0);
+	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),_RenderModeUseGlobal,page0top);
 	page0top->AddLine(os,3);
 	iggWidgetAllInstancesCheckBox *li = new iggWidgetAllInstancesCheckBox(page0top);
 	li->AddDependent(os);
@@ -523,7 +523,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	iggFrame *mspage1 = new iggFrame(msflip);
 	msflip->AddLayer(mspage1);
 
-	iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewSubject::KeyPosition(true),iSurfaceViewSubject::KeyPlaneDirection(),iSurfaceViewSubject::KeySize(true),iSurfaceViewSubject::KeyAttachProbeToMarker(),iSurfaceViewSubject::KeyProbePositionToPickedPoint(),mspage1);
+	iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewSubject::KeyPosition(true),iSurfaceViewSubject::KeyPlaneDirection(),iSurfaceViewSubject::KeySize(true),mspage1);
 	mb->SetObjectBuddy(sc);
 	mspage1->AddLine(sc);
 
