@@ -119,7 +119,7 @@ iggPageTensorField::iggPageTensorField(iggFrameBase *parent) : iggPageObject(par
 	iggFrame *pbpage0 = new iggFrame(pb,3);
 	pb->AddPage("Palette",icon,pbpage0);
 
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarFieldProvider,"Paint with...",iTensorFieldViewSubject::KeyColorBy(),&iTensorFieldViewSubject::KeyConnectedToScalars(),pbpage0);
+	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarProvider,"Paint with...",iTensorFieldViewSubject::KeyColorBy(),&iTensorFieldViewSubject::KeyConnectedToScalars(),pbpage0);
 	pl->InsertItem("None");
 	pl->Complete();
 	pbpage0->AddLine(pl);
