@@ -132,7 +132,7 @@ namespace iggPageVectorField_Private
 				}
 			default:
 				{
-					IERROR_REPORT("Incorrect button in MethodRadioBox.");
+					IERROR_LOW("Incorrect button in MethodRadioBox.");
 				}
 			}
 		}
@@ -208,7 +208,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageObject(par
 	iggFrame *pbpage0 = new iggFrame(pb,3);
 	pb->AddPage("Palette",icon,pbpage0);
 
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarFieldProvider,"Paint with...",iVectorFieldViewSubject::KeyColorBy(),&iVectorFieldViewSubject::KeyConnectedToScalars(),pbpage0);
+	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarProvider,"Paint with...",iVectorFieldViewSubject::KeyColorBy(),&iVectorFieldViewSubject::KeyConnectedToScalars(),pbpage0);
 	pl->InsertItem("Vector magnitude");
 	pl->InsertItem("Vorticity");
 	pl->InsertItem("Divergence");
@@ -290,7 +290,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageObject(par
 	iggFrame *sbpage1 = new iggFrame(sb,2);
 	sb->AddPage("Source",icon,sbpage1);
 
-	iggFrameObjectControls *sc = new iggFrameObjectControls("Source",iVectorFieldViewSubject::KeySourcePosition(true),iVectorFieldViewSubject::KeySourceDirection(),iVectorFieldViewSubject::KeySourceSize(true),iVectorFieldViewSubject::KeyAttachSourceToMarker(),iVectorFieldViewSubject::KeySourcePositionToPickedPoint(),sbpage1);
+	iggFrameObjectControls *sc = new iggFrameObjectControls("Source",iVectorFieldViewSubject::KeyPosition(true),iVectorFieldViewSubject::KeySourceDirection(),iVectorFieldViewSubject::KeySourceSize(true),sbpage1);
 	lt->SetObjectBuddy(sc);
 
 	sbpage1->AddLine(sc);
