@@ -48,11 +48,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ivtk.h"
 #include "iwriter.h"
 
+#include "iggcommoneventobservers.h"
 #include "iggdatatypeprovider.h"
 #include "iggdialoganimatingprogress.h"
+#include "iggdialogauto.h"
 #include "iggdialogimagecomposer.h"
 #include "iggdialogscriptdebugger.h"
-#include "iggeventobserver.h"
 #include "iggextensionfactory.h"
 #include "iggframedatatypeselector.h"
 #include "iggframedatavariablelist.h"
@@ -72,6 +73,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetkeytrackball.h"
 #include "iggwidgetotherbutton.h"
 #include "iggwidgetmisc.h"
+#include "iggwidgettext.h"
 
 #include "ibgwidgetareasubject.h"
 #include "ibgwidgetbuttonsubject.h"
@@ -138,7 +140,7 @@ namespace iggPageView_Private
 		
 		ColorBarFrame(iggWidgetKeyCheckBox *autobox, const iString &title, const iObjectKey &key, iggFrame *parent) : iggFrame(title,parent,1), mKey(key)
 		{
-			mProvider = new iggKeywordDataTypeProvider("ScalarField",this); 
+			mProvider = new iggKeywordDataTypeProvider("scalars",this); 
 
 			mAutomaticBox = autobox;
 			autobox->AddDependent(this);
@@ -170,6 +172,7 @@ namespace iggPageView_Private
 			//  Are we enabled?
 			//
 			bool b;
+			mAutomaticBox->UpdateWidget();
 			mAutomaticBox->QueryValue(b);
 			this->Enable(!b);
 
@@ -237,7 +240,7 @@ namespace iggPageView_Private
 
 			if(this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetErrorStatus()->IsError())
 			{
-				this->GetMainWindow()->PopupWindow("Animation completed with the following error message:\n"+this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetErrorStatus()->GetMessage());
+				this->GetMainWindow()->PopupWindow("Animation completed with the following message:\n"+this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetErrorStatus()->Message());
 			}
 		}
 	};
@@ -376,7 +379,7 @@ namespace iggPageView_Private
 
 	public:
 
-		ViewButton(iggWidgetImageArea *view, iggFrame *parent) : iggWidgetLaunchButton((iggDialog *)0,"View",parent,true), mView(view)
+		ViewButton(iggWidgetImageArea *view, iggFrame *parent) : iggWidgetLaunchButton(static_cast<iggDialog*>(0),"View",parent,true), mView(view)
 		{
 			mDialog = mWindow = new ViewImageDialog(this->GetMainWindow(),mView->GetImage());
 		}
@@ -403,12 +406,67 @@ namespace iggPageView_Private
 	//
 	//  Window manipulation widgets
 	//
+	//
+	//  A small dialog with the list of existing windows
+	//
+	class WindowList : public iggWidgetListView
+	{
+
+	public:
+
+		WindowList(iggFrame *parent) : iggWidgetListView(false,parent)
+		{
+			this->SetBaloonHelp("Select the current window","This control selects a visualization window to be the \"current\" one. The current window is labeled by a marker placed in the upper left corner of the window, and is the window controled by the widgets.");
+        }
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			int i, n = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
+			if(n != this->Count())
+			{
+				this->Clear();
+				iString ws;
+				for(i=0; i<n; i++)
+				{
+					ws = "Window " + iString::FromNumber(i+1);
+					if(this->GetShell()->GetControlModule()->GetViewModule(i)->IsClone())
+					{
+						ws += " (Clone of #" + iString::FromNumber(this->GetShell()->GetControlModule()->GetViewModule(i)->GetCloneOfWindow()+1) + ")";
+					}
+					this->InsertItem(ws);
+				}
+			}
+			this->Select(this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex(),this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex());
+		}
+
+		virtual void OnCursorPositionChanged(int para, int index)
+		{
+			if(this->GetShell()->GetControlModule()->SetCurrentViewModuleIndex(para)) this->GetMainWindow()->UpdateAll();
+		}
+	};
+
+
+	class WindowListDialog : public iggDialogAuto
+	{
+
+	public:
+
+		WindowListDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Windows",1)
+		{
+			mFrame->AddLine(new WindowList(mFrame));
+			this->ResizeContents(100,200);
+		}
+	};
+
+
 	class WindowNumberComboBox : public iggWidget
 	{
 
 	public:
 
-		WindowNumberComboBox(iggFrame *parent) : iggWidget(parent)
+		WindowNumberComboBox(iggFrame *parent, iggPageView *page) : iggWidget(parent), mPage(page)
 		{
 			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"Set current window");
 			this->SetBaloonHelp("Select the current window","This control selects a visualization window to be the \"current\" one. The current window is labeled by a marker placed in the upper left corner of the window, and is the window controled by the widgets.");
@@ -418,6 +476,8 @@ namespace iggPageView_Private
 
 		virtual void UpdateWidgetBody()
 		{
+			mPage->GetWindowListDialog()->UpdateDialog();
+
 			mSubject->Clear();
 
 			int i, n = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
@@ -431,6 +491,7 @@ namespace iggPageView_Private
 		}
 
 		ibgWidgetComboBoxSubject *mSubject;
+		iggPageView *mPage;
 	};
 
 
@@ -439,7 +500,7 @@ namespace iggPageView_Private
 
 	public:
 
-		DialogWait(bool create, iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Working...",0,3,false)
+		DialogWait(bool create, iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Working...",0,3,0)
 		{
 			mFlipper = new iggWidgetLogoFlipper(mFrame);
 			mFrame->AddLine(0,mFlipper);
@@ -488,7 +549,7 @@ namespace iggPageView_Private
 					this->SetBaloonHelp("Clone the current window","This button creates a clone of the current visualization window. The clone shares the data with the parent window, and at birth has the same values of all parameters for all visualization objects. It does have a separate set of visualization objects however, so the parameters of the parent and the clone window can be changed independently.");
 					break;
 				}
-			default: IERROR_FINISH("Incorrect button type");
+			default: IERROR_FATAL("Incorrect button type");
 			}
         }
 
@@ -612,7 +673,7 @@ namespace iggPageView_Private
 		{
 			if(mSubject->IsDown())
 			{
-				iggWidgetKeyHandlerBase::SetGlobalExecuteFlags(_ObjectModeCurrent|_ModuleModeAll|_RenderModeAuto);
+				iggWidgetKeyHandlerBase::SetGlobalExecuteFlags(_ModuleOptionAll|_RenderOptionAll);
 			}
 			else
 			{
@@ -793,25 +854,33 @@ namespace iggPageView_Private
 	//
 	//  A small dialog with the line edit to set the ruler scale exactly
 	//
-	class RulerScaleDialog : public iggDialog
+	class RulerScaleDialog : public iggDialogAuto, public iggRenderWindowObserver
 	{
 
 	public:
 
-		RulerScaleDialog(iggMainWindow *parent) : iggDialog(parent,0U,0,"Ruler Scale",0,1,false)
+		RulerScaleDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Ruler Scale",2), iggRenderWindowObserver(mFrame)
 		{
-			mFrame->AddLine(new iggWidgetKeyFloatLineEdit("Scale",iViewModule::KeyRulerScale(),_RenderModeUseGlobal,mFrame));
+			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyRulerScale(),_RenderModeUseGlobal,mFrame));
+			mFrame->AddLine(new iggWidgetTextArea("Title",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyRulerTitle(),_RenderModeUseGlobal,mFrame));
 			mFrame->AddSpace(10);
 		}
+
+	protected:
+
+		virtual void OnRenderWindowModified()
+		{
+			this->UpdateDialog();
+		}
 	};
 
 
-	class ShowRulerCheckBox : public iggWidgetKeyCheckBox, public iggRenderWindowObserver
+	class ShowRulerCheckBox : public iggWidgetKeyCheckBox
 	{
 
 	public:
 
-		ShowRulerCheckBox(iggFrame *parent) : iggWidgetKeyCheckBox("Ruler",iViewModule::KeyRuler(),parent), iggRenderWindowObserver(parent)
+		ShowRulerCheckBox(iggFrame *parent) : iggWidgetKeyCheckBox("Ruler",iViewModule::KeyRuler(),parent)
 		{
 			mDialog = new RulerScaleDialog(this->GetMainWindow());
 		}
@@ -823,11 +892,6 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual void OnRenderWindowModified()
-		{
-			mDialog->UpdateDialog();
-		}
-
 		void OnVoid1Body()
 		{
 			if(mDialog != 0) mDialog->Show(mSubject->IsDown());
@@ -841,16 +905,17 @@ namespace iggPageView_Private
 	//
 	//  A small dialog with several widgets to set the record label parameters
 	//
-	class RecordLabelDialog : public iggDialog
+	class RecordLabelDialog : public iggDialogAuto
 	{
 
 	public:
 
-		RecordLabelDialog(iggMainWindow *parent) : iggDialog(parent,0U,0,"Record Label Properties",0,3,false)
+		RecordLabelDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Record Label Properties",3)
 		{
-			mFrame->AddLine(new iggWidgetTextArea("Name",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelName(),_RenderModeUseGlobal,mFrame),(iggWidget *)0);
-			mFrame->AddLine(new iggWidgetTextArea("Unit",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelUnit(),_RenderModeUseGlobal,mFrame),(iggWidget *)0);
-			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelScale(),_RenderModeUseGlobal,mFrame),(iggWidget *)0);
+			mFrame->AddLine(new iggWidgetTextArea("Name",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelName(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Unit",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelUnit(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelScale(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Offset",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelOffset(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
 			mFrame->AddLine(new iggWidgetKeySpinBox(0,7,"Number of digits after the point",0,iViewModule::KeyLabelDigits(),mFrame),3);
 			mFrame->AddSpace(10);
 		}
@@ -964,7 +1029,7 @@ namespace iggPageView_Private
 				}
 				iString ws;
 				this->GetShell()->GetControlModule()->PackCommand(ws,iCamera::KeyClippingRange(),cr,2);
-				this->GetShell()->GetControlModule()->Execute(ws,true);
+				this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender());
 			}
 		}
 
@@ -1016,22 +1081,28 @@ namespace iggPageView_Private
 	};
 
 
-	class StepOnPath : public iggWidgetKeyIntSlider
+	class StepOnPath : public iggWidgetKeyIntSlider, public iggRenderWindowObserver
 	{
 
 	public:
 
-		StepOnPath(iggFrame *parent) : iggWidgetKeyIntSlider(0,100,5,"Step on path",iAnimator::KeyPositionOnPath(),_RenderModeUseGlobal,parent)
+		StepOnPath(iggFrame *parent) : iggWidgetKeyIntSlider(0,100,5,"Step on path",iAnimator::KeyPositionOnPath(),_RenderModeUseGlobal,parent), iggRenderWindowObserver(parent)
 		{
 		}
 
 	protected:
 
+		virtual void OnRenderWindowModified()
+		{
+			this->iggRenderWindowObserver::mParent->UpdateWidget();
+			this->GetMainWindow()->ProcessEvents();
+		}
+
 		virtual void UpdateWidgetBody()
 		{
 			iAnimator *an = this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator();
 			this->Enable(an->GetMode() == 4);
-			iPointerCast<iggAnimatorEventObserver,iAnimatorEventObserver>(an->GetObserver())->AddDependent(this);
+			iRequiredCast<iggAnimatorEventObserver>(INFO,an->GetObserver())->AddDependent(this);
 			this->SetRange(0,this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetNumberOfCameraPathSteps()-1);
 			this->iggWidgetKeyIntSlider::UpdateWidgetBody();
 		}
@@ -1046,6 +1117,23 @@ namespace iggPageView_Private
 		PlayDemo(iggFrame *parent) : iggWidgetKeyToolButton("",iAnimator::KeyCameraPathDemo(),parent)
 		{
 			mSubject->SetIcon(*iImageFactory::FindIcon("moveright.png"));
+			mInDemo = false;
+		}
+
+		virtual bool ExecuteControl(bool final, bool val)
+		{
+			mInDemo = !mInDemo;
+			if(mInDemo)
+			{
+				mSubject->SetIcon(*iImageFactory::FindIcon("er_stop.png"));
+				return this->iggWidgetKeyToolButton::ExecuteControl(final,val);
+			}
+			else
+			{
+				mSubject->SetIcon(*iImageFactory::FindIcon("moveright.png"));
+				this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->StopCameraPathDemo();
+				return true;
+			}
 		}
 
 	protected:
@@ -1054,6 +1142,8 @@ namespace iggPageView_Private
 		{
 			this->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetMode() == 4);
 		}
+
+		bool mInDemo;
 	};
 
 	//
@@ -1088,7 +1178,7 @@ namespace iggPageView_Private
 
 	public:
 
-		WindowSizeDialog(iggMainWindow *parent) : iggDialog(parent,_DialogModal,0,"Visualization Window Size",0,2,true,"Set")
+		WindowSizeDialog(iggMainWindow *parent) : iggDialog(parent,_DialogModal,0,"Visualization Window Size",0,2,"Set")
 		{
 			mBox[0] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
 			mBox[1] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
@@ -1134,6 +1224,31 @@ namespace iggPageView_Private
 	//
 	//  Misc buttons
 	//
+	class ShowLogCheckBox : public iggWidgetSimpleCheckBox
+	{
+
+	public:
+
+		ShowLogCheckBox(iggFrame *parent) : iggWidgetSimpleCheckBox("Show log  ",parent)
+		{
+			this->SetChecked(true);
+			this->SetBaloonHelp("Show the log window","This check box shows/hides the log window");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->SetChecked(this->GetMainWindow()->IsLogVisible());
+		}
+
+		virtual void OnChecked(bool s)
+		{
+			this->GetMainWindow()->ShowLog(s);
+		}
+	};
+
+
 	class ClearLogButton : public iggWidgetSimpleButton
 	{
 
@@ -1185,6 +1300,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 	const iImage *icon = iImageFactory::FindIcon("view.png");
 
 	mWindowSizeDialog = new WindowSizeDialog(this->GetMainWindow());
+	mWindowListDialog = new WindowListDialog(this->GetMainWindow());
 
 	//
 	//  Main page
@@ -1220,6 +1336,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		fb->AddLine(new ShowRulerCheckBox(fb));
 		fb->AddLine(new iggWidgetKeyCheckBox("Color bars",iViewModule::KeyColorBars(),fb));
 		fb->AddLine(new iggWidgetKeyCheckBox("Measuring box",iViewModule::KeyMeasuringBox(),fb));
+		fb->AddLine(new iggWidgetKeyCheckBox("Alignment axes",iViewModule::KeyCameraAlignmentLabel(),fb));
 
 		iggFrame *fb2 = new iggFrame(page0,1);
 		iggWidgetKeyRadioBox *isb = new iggWidgetKeyRadioBox(1,"Interactor style",0,iViewModule::KeyInteractorStyle(),fb2);
@@ -1227,11 +1344,15 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		isb->InsertItem("Joystick");
 		isb->InsertItem("Flight");
 		isb->InsertItem("Keyboard");
-		iggWidgetKeyColorSelection *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb2,false);
-		wid->SetText("Background color");
-		if(this->GetMainWindow()->GetDialogImageComposer() != 0) wid->AddDependent(this->GetMainWindow()->GetDialogImageComposer()->GetArea());
 		fb2->AddLine(isb);
-		fb2->AddLine(wid);
+
+		iggFrame *fb3 = new iggFrame("Background",fb2,1);
+		iggWidgetKeyColorSelection *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb3,true);
+		if(this->GetMainWindow()->GetDialogImageComposer() != 0) wid->AddDependent(this->GetMainWindow()->GetDialogImageComposer()->GetArea());
+		fb3->AddLine(wid);
+		fb3->AddLine(new iggWidgetKeyFileNameButton("Load wallpaper image","Load image","Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)",iViewModule::KeyBackgroundImage(),fb3));
+		fb2->AddLine(fb3);
+
 		page0->AddLine(fb,fb2);
 
 		page0->AddSpace(10);
@@ -1417,10 +1538,18 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggWidgetKeyRadioBox *ao = new iggWidgetKeyRadioBox(1,"Animation output",0,iViewModule::KeyAnimationOutput(),tmp);
 			ao->InsertItem("Series of images");
 #ifndef IVTK_4
+
+#ifdef IVTK_SUPPORTS_MPEG
 			ao->InsertItem("MPEG2 movie");
+#ifdef IVTK_501
+			ao->SetItem("MPEG2 movie",1,false); //  disable MPEG generation for VTK 5.0.1 due to a bug in vtkMPEGWriter
+#endif
+#endif
+
 #ifdef IVTK_SUPPORTS_AVI
 			ao->InsertItem("AVI movie");
 #endif
+
 #endif
 			tmp->AddLine(ao);
 			tmp->AddSpace(10);
@@ -1486,7 +1615,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			abpage2->AddLine(new iggWidgetKeyCheckBox("Use script",iAnimator::KeyUseScript(),abpage2));
 			abpage2->AddLine(new iggWidgetKeyCheckBox("Inherit settings from widgets",iAnimator::KeyInheritSettings(),abpage2));
-			abpage2->AddLine(new iggWidgetKeyTextLineEdit(false,"Current script",iAnimator::KeyScriptFileName(),_RenderModeNoRender,abpage2));
+			abpage2->AddLine(new iggWidgetKeyTextLineEdit(true,"Current script",iAnimator::KeyScriptFileName(),_RenderModeNoRender,abpage2));
 			abpage2->AddLine(new iggWidgetLaunchButton(this->GetMainWindow()->GetDialogScriptDebugger(),"Launch script debugger",abpage2));
 
 			abpage2->AddSpace(10);
@@ -1648,14 +1777,11 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			mcb->AddSpace(10);
 
-			mbpage0->AddLine(msb,(iggWidget *)0,mcb);
+			mbpage0->AddLine(msb,static_cast<iggWidget*>(0),mcb);
 
-			iggFrame *mfc = new iggFrame("Colors",mbpage0,1);
+			iggFrame *mfc = new iggFrame(mbpage0,1);
 			iggWidgetKeyColorSelection *mcc = new iggWidgetKeyColorSelection(iMarker::KeyColor(),mfc,false);
-			mcc->SetText("Marker");
-			mfc->AddLine(mcc);
-			mcc = new iggWidgetKeyColorSelection(iMarker::KeyTextColor(),mfc,false);
-			mcc->SetText("Caption");
+			mcc->SetText("Color");
 			mfc->AddLine(mcc);
 
 			iggFramePosition *mpos = new MarkerPositionFrame(mbpage0);
@@ -1734,7 +1860,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		mBook->AddPage("Windows",icon,page4);
 
 		iggFrame *wfb = new iggFrame("Windows",page4,1);
-		WindowNumberComboBox *wnb = new WindowNumberComboBox(wfb);
+		WindowNumberComboBox *wnb = new WindowNumberComboBox(wfb,this);
 		wfb->AddLine(wnb);
 		CreateWindowButton *wcb1 = new CreateWindowButton(_ModuleTypeNew,wfb);
 		wcb1->AddDependent(wnb);
@@ -1746,6 +1872,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		wcb3->AddDependent(wnb);
 		wfb->AddLine(wcb3);
 		DeleteWindowButton *wdb = new DeleteWindowButton(wfb);
+		wdb->AddDependent(wnb);
 		wfb->AddLine(wdb);
 		wcb1->AddDependent(wdb);
 		wcb2->AddDependent(wdb);
@@ -1774,6 +1901,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 iggPageView::~iggPageView()
 {
 	delete mWindowSizeDialog;
+	delete mWindowListDialog;
 }
 
 
@@ -1785,9 +1913,10 @@ void iggPageView::UpdateMarkerWidgets()
 
 iggFrame* iggPageView::CreateFlipFrame(iggFrameBase *parent) const
 {
-	iggFrame *tmp = new iggFrame(parent,2);
+	iggFrame *tmp = new iggFrame(parent,3);
+	tmp->AddSpace(1);
+	tmp->AddLine(0,new ShowLogCheckBox(tmp),new ClearLogButton(tmp));
 	tmp->AddSpace(1);
-	tmp->AddLine(0,new ClearLogButton(tmp));
 	tmp->SetColStretch(0,10);
 	return tmp;
 }
