@@ -34,6 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishell.h"
 #include "iviewmodule.h"
 #include "ivolumeviewsubject.h"
+#include "ivtk.h"
 
 #include "iggdatatypeprovider.h"
 #include "iggframedatavariablelist.h"
@@ -41,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframematerialproperties.h"
 #include "iggframepaletteselection.h"
 #include "iggframereplicate.h"
+#include "iggmainwindow.h"
 #include "iggwidgetkeybutton.h"
 #include "iggwidgetkeyselectionbox.h"
 #include "iggwidgetkeyslider.h"
@@ -91,7 +93,7 @@ namespace iggPageVolume_Private
 
 			iString ws;
 			this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeySize(),iv,2);
-			this->GetShell()->GetControlModule()->Execute(ws,true,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 		}
 
 		virtual void OnVoid2Body()
@@ -100,7 +102,7 @@ namespace iggPageVolume_Private
 
 			iString ws;
 			this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeySize(),iv,2);
-			this->GetShell()->GetControlModule()->Execute(ws,true,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 		}
 
 		virtual void OnVoid3Body()
@@ -109,35 +111,43 @@ namespace iggPageVolume_Private
 
 			iString ws;
 			this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeySize(),iv,2);
-			this->GetShell()->GetControlModule()->Execute(ws,true,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
+			this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 		}
 
 		ibgWidgetButtonSubject *mSubject1, *mSubject2, *mSubject3;
 	};
 
 
-	class MethodBox : public iggWidgetKeyRadioBox
+	class MethodBox : public iggWidgetKeyComboBox
 	{
 
 	public:
 
-		MethodBox(iggFrame *parent) : iggWidgetKeyRadioBox(1,"Method",0,iVolumeViewSubject::KeyMethod(),parent)
+		MethodBox(iggFrame *parent) : iggWidgetKeyComboBox("",0,iVolumeViewSubject::KeyMethod(),parent)
 		{
-			this->InsertItem("Ray casting");
-			this->InsertItem("2D textures");
-			this->InsertItem("3D textures");
-			this->InsertItem("VolumePro board");
+			this->InsertItem("A volume rendering method");
 		}
 
 	protected:
 
 		virtual void UpdateWidgetBody()
 		{
+			int i;
+			iString s;
+			//
+			//  Optimization: direct access
+			//
 			iVolumeViewSubject *vo = this->GetShell()->GetControlModule()->GetViewModule()->GetVolumeViewSubject();
-			this->SetItem("3D textures",2,vo->Has3DTexture());
-			this->SetItem("VolumePro board",3,vo->HasVolumePro());
 
-			this->iggWidgetKeyRadioBox::UpdateWidgetBody();
+			this->Clear();
+			i = 0;
+			while(!(s = vo->GetMethodName(i)).IsEmpty())
+			{
+				this->SetItem(s,i,vo->IsMethodAvailable(i));
+				i++;
+			}
+
+			this->iggWidgetKeyComboBox::UpdateWidgetBody();
 		}
 	};
 };
@@ -165,23 +175,18 @@ iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,iParam
 	//
 	//  Field & method
 	//
+	iggFrame *tmp = new iggFrame("Method",page0);
+	tmp->AddLine(new MethodBox(tmp));
+	page0->AddLine(tmp);
+
 	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Field",iVolumeViewSubject::KeyVar(),0,page0,0);
 	pl->Complete();
 	pl->AddDependent(show);
+#ifdef VTK_USE_VOLUMEPRO
+	page0->AddLine(pl,new iggPageVolume_Private::WindowSizeFrame(page0));
+#else
 	page0->AddLine(pl);
-	page0->AddSpace(10);
-	//
-	//  Method
-	//
-	MethodBox *rm = new MethodBox(page0);
-	if(this->GetShell()->GetControlModule()->GetViewModule()->GetVolumeViewSubject()->HasVolumePro())
-	{
-		page0->AddLine(rm,new iggPageVolume_Private::WindowSizeFrame(page0));
-	}
-	else
-	{
-		page0->AddLine(rm);
-	}
+#endif
 	page0->AddSpace(10);
 
 	page0->SetColStretch(2,10);
@@ -256,26 +261,22 @@ iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,iParam
 	//
 	//  Ray casting settings
 	//
-	iggFrame *rc = new iggFrame("Ray casting settings",page4,2);
-	iggWidgetKeyRadioBox *cm = new iggWidgetKeyRadioBox(1,"Composite method",0,iVolumeViewSubject::KeyCompositeMethod(),rc);
-	cm->InsertItem("Interpolate first");
-	cm->InsertItem("Classify first");
+	iggFrame *rc = new iggFrame("Rendering settings",page4,2);
 	iggWidgetKeyRadioBox *it = new iggWidgetKeyRadioBox(1,"Interpolation type",0,iVolumeViewSubject::KeyInterpolationType(),rc);
 	it->InsertItem("Nearest neighbor");
 	it->InsertItem("Linear");
-	iggWidgetKeyRadioBox *bm = new iggWidgetKeyRadioBox(1,"Blend mode",0,iVolumeViewSubject::KeyBlendMode(),rc);
+	iggWidgetKeyRadioBox *bm = new iggWidgetKeyRadioBox(1,"Blending mode",0,iVolumeViewSubject::KeyBlendMode(),rc);
 	bm->InsertItem("Composite");
 	bm->InsertItem("Maximum intensity");
-	rc->AddLine(cm,it);
-	rc->AddLine(bm);
+	rc->AddLine(it,bm);
 	page4->AddLine(rc);
 	page4->AddSpace(10);
 
-	iggFrame *rs = new iggFrame("Resample settings",page4,1);
-	iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0,20,1,4,"Resample in XY",iVolumeViewSubject::KeyXYResample(),_RenderModeUseGlobal,rs);
+	iggFrame *rs = new iggFrame("Downsampling settings",page4,1);
+	iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Image downsampling",iVolumeViewSubject::KeyImageDownsampleFactor(),_RenderModeUseGlobal,rs);
 	fs->SetStretch(3,10);
 	rs->AddLine(fs);
-	fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Resample in Z ",iVolumeViewSubject::KeyZResample(),_RenderModeUseGlobal,rs);
+	fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Depth downsampling",iVolumeViewSubject::KeyDepthDownsampleFactor(),_RenderModeUseGlobal,rs);
 	fs->SetStretch(3,10);
 	rs->AddLine(fs);
 
