@@ -29,10 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggrenderwindow.h"
 
 
+#include "icommoneventobservers.h"
 #include "icontrolmodule.h"
 #include "ierror.h"
-#include "ieventobserver.h"
 #include "iopengl.h"
+#include "irendertool.h"
 #include "iviewmodule.h"
 
 #include "iggmainwindow.h"
@@ -40,6 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgmainwindowsubject.h"
 #include "ibgrenderwindowsubject.h"
+#include "ibgwindowhelper.h"
 
 #include <vtkMapper.h>
 
@@ -57,11 +59,10 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
-bool iggRenderWindow::mRenderIntoMemory = false;
-
-
-iggRenderWindow::iggRenderWindow(iViewModule *vm) : iViewModuleComponent(vm), iShellComponent(vm?vm->GetControlModule()->GetShell():0)
+iggRenderWindow::iggRenderWindow(iViewModule *vm) : mViewModule(vm)
 {
+	IERROR_ASSERT(vm);
+
 	mSubject = iggSubjectFactory::CreateRenderWindowSubject(this); IERROR_ASSERT(mSubject);
 
 	mInitialized = mResizing = mMoving = false;
@@ -77,8 +78,8 @@ iggRenderWindow::iggRenderWindow(iViewModule *vm) : iViewModuleComponent(vm), iS
 	//  Connect to Main Window
 	//
 	mMainWindow = 0;
-	const iggShell *s = iPointerCast<const iggShell,iShell>(this->GetShell());
-	if(s!=0 && s->GetMainWindow()!=0) this->AttachToMainWindow(s->GetMainWindow());
+	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetViewModule()->GetControlModule()->GetShell());
+	if(s->GetMainWindow() !=0 ) this->AttachToMainWindow(s->GetMainWindow());
 
 	glPolygonOffset(1.0,1.0);
 }
@@ -86,8 +87,11 @@ iggRenderWindow::iggRenderWindow(iViewModule *vm) : iViewModuleComponent(vm), iS
 
 iggRenderWindow::~iggRenderWindow()
 {
-	const iggShell *s = iPointerCast<const iggShell,iShell>(this->GetShell());
-	if(s!=0 && s->GetMainWindow()!=0)
+	//
+	//  Cannot use mMainWindow here, since it could have been deleted already.
+	//
+	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetViewModule()->GetControlModule()->GetShell());
+	if(s->GetMainWindow() != 0)
 	{
 		s->GetMainWindow()->UnRegister(mSubject);
 	}
@@ -114,7 +118,7 @@ void iggRenderWindow::Initialize()
 		this->MakeCurrent();
 		this->OpenGLInit();
 
-		mSubject->Initialize(!mRenderIntoMemory);
+		mSubject->Initialize(this->GetOffScreenRendering()==0);
 		
 		this->Mapped = 1;
 		mInitialized = true;
@@ -139,7 +143,7 @@ void iggRenderWindow::Render()
 {
 	if(!mInitialized) this->Initialize();
 
-	if(mRenderIntoMemory)
+	if(this->GetOffScreenRendering() != 0)
 	{
 		this->RenderIntoMemory();
 		return;
@@ -280,25 +284,64 @@ void iggRenderWindow::SetSizeBody(int w, int h)
 }
 
 
+void iggRenderWindow::SetBorders(int arg) 
+{
+	if(this->Borders==arg || !mInitialized) return;
+	
+	mSubject->SetBorder(arg != 0);
+	if(arg != 0)
+	{
+		mSubject->GetHelper()->RestoreIcon();
+	}
+
+	this->Borders = arg;
+	this->Modified();
+}
+
+
 void iggRenderWindow::SetFullScreen(int arg) 
 {
 	//
 	// We do not need to do anything if the FullScreen mode
 	// is already set to the specified value. 
 	//
-	if(this->FullScreen==arg || !this->mInitialized) return;
+	if(this->FullScreen==arg || !mInitialized) return;
 	
-	mSubject->SetFullScreen(arg != 0);
+	if(this->GetViewModule()->GetRenderTool()->GetFullScreenMode() > 0)
+	{
+		if(arg != 0) mSubject->GetHelper()->SaveWindowGeometry();
+		mSubject->SetFullScreen(arg != 0);
+		if(arg == 0)
+		{
+			mSubject->GetHelper()->RestoreWindowGeometry();
+			mSubject->GetHelper()->RestoreIcon();
+		}
 
-	// set the mode 
-	this->FullScreen = arg;
-	this->Modified();
+		this->FullScreen = arg;
+		this->Modified();
+
+		if(arg!=0 && this->GetViewModule()->GetRenderTool()->GetFullScreenMode()==2)
+		{
+			if(this->GetMainWindow()->PopupWindow(this,"Is the window placement correct?",iggParameter::_PopupWindowMessage,"Ok","Cancel") == 1)
+			{
+				mSubject->SetFullScreen(0);
+				mSubject->GetHelper()->RestoreWindowGeometry();
+				mSubject->GetHelper()->RestoreIcon();
+				this->FullScreen = 0;
+				this->Modified();
+			}
+		}
+	}
+	else
+	{
+		this->GetMainWindow()->PopupWindow(this,"Full screen mode is not permitted in this set-up.");
+	}
 }
 
 
 int* iggRenderWindow::GetScreenSize()
 {
-	iPointerCast<iggShell,iShell>(this->GetShell())->GetDesktopDimensions(mScreenSize[0],mScreenSize[1]);
+	iRequiredCast<iggShell>(INFO,this->GetViewModule()->GetControlModule()->GetShell())->GetDesktopDimensions(mScreenSize[0],mScreenSize[1]);
 	return mScreenSize;
 }
 
@@ -359,9 +402,11 @@ void iggRenderWindow::RenderIntoMemory()
 	//  QGLWidget::renderPixmap does nor render textures under Unix - force polygonal mode for xsections
 	//
 	this->GetViewModule()->ForceCrossSectionToUsePolygonalMethod(true);
+
 	//
 	//  Need to reset all existing display lists
 	//
+	int gim = vtkMapper::GetGlobalImmediateModeRendering();
 	vtkMapper::GlobalImmediateModeRenderingOn();
 
 	//
@@ -378,10 +423,32 @@ void iggRenderWindow::RenderIntoMemory()
 	//
 	//  Put them back so that Magnifier could read them
 	//
-	this->SetPixelData(0,0,size[0]-1,size[1]-1,image.DataPointer(),1);
+	switch(image.Depth())
+	{
+	case 3:
+		{
+			this->SetPixelData(0,0,size[0]-1,size[1]-1,image.DataPointer(),!db);
+			break;
+		}
+	case 4:
+		{
+			this->SetRGBACharPixelData(0,0,size[0]-1,size[1]-1,image.DataPointer(),!db);
+			break;
+		}
+	default:
+		{
+			IERROR_HIGH("Unable to render off-screen for unknown reason.");
+		}
+	}
 	this->DoubleBuffer = db;
 
-	vtkMapper::GlobalImmediateModeRenderingOff();
+	vtkMapper::SetGlobalImmediateModeRendering(gim);
 	this->GetViewModule()->ForceCrossSectionToUsePolygonalMethod(false);
 }
 
+
+void iggRenderWindow::OnCloseAttempt()
+{
+	this->GetMainWindow()->PopupWindow(this,"Render Window can not be closed. Use window controls in the main window to delete Render Windows.");
+}
+
