@@ -43,12 +43,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iggParameter;
 
 
-iggRenderWindowInteractor::iggRenderWindowInteractor(iShell *shell) : iShellComponent(shell)
+iggRenderWindowInteractor::iggRenderWindowInteractor(iShell *shell) : mShell(shell)
 {
 	this->Enabled = 0;
 }
 
 
+iggRenderWindowInteractor::~iggRenderWindowInteractor()
+{
+}
+
+
 //
 // We never allow the iggRenderWindowInteractor to control 
 // the event loop. The application always has the control. 
@@ -96,13 +101,13 @@ void iggRenderWindowInteractor::Start()
 
 int iggRenderWindowInteractor::CreateTimer(int n)
 {
-	return iPointerCast<iggRenderWindow,vtkRenderWindow>(this->RenderWindow)->GetSubject()->CreateTimer(n);
+	return iRequiredCast<iggRenderWindow>(INFO,this->RenderWindow)->GetSubject()->CreateTimer(n);
 }
 
 
 int iggRenderWindowInteractor::DestroyTimer()
 {
-	return iPointerCast<iggRenderWindow,vtkRenderWindow>(this->RenderWindow)->GetSubject()->DestroyTimer();
+	return iRequiredCast<iggRenderWindow>(INFO,this->RenderWindow)->GetSubject()->DestroyTimer();
 }
 
 
@@ -110,7 +115,7 @@ void iggRenderWindowInteractor::OnTimer()
 {
 	if(!this->Enabled) return;
 
-	iPointerCast<vtkInteractorStyle,vtkInteractorObserver>(this->InteractorStyle)->OnTimer();
+	iRequiredCast<vtkInteractorStyle>(INFO,this->InteractorStyle)->OnTimer();
 }
 
 
@@ -196,6 +201,12 @@ void iggRenderWindowInteractor::OnKeyPress(char key, int b)
 	{
 		RenderWindow->SetFullScreen(!RenderWindow->GetFullScreen());
 	}
+#ifdef I_DEBUG
+	else if(key=='B' || key=='b')
+	{
+		RenderWindow->SetBorders(!RenderWindow->GetBorders());
+	}
+#endif
 	else
 	{
 		this->SetControlKey(b & _MouseControlKey);
@@ -211,6 +222,6 @@ void iggRenderWindowInteractor::OnKeyPress(char key, int b)
 //
 void iggRenderWindowInteractor::UserCallback()
 {
-	iPointerCast<iggRenderWindow,vtkRenderWindow>(RenderWindow)->GetViewModule()->DumpImages();
+	iRequiredCast<iggRenderWindow>(INFO,RenderWindow)->GetViewModule()->DumpImages();
 }
 
