@@ -80,7 +80,7 @@ void iggRenderWindowObserver::UpdateConnection()
 //
 //  Helper class
 //
-iggRenderWindowObserverHelper::iggRenderWindowObserverHelper(iggRenderWindowObserver *owner, iggFrame *frame)
+iggRenderWindowObserverHelper::iggRenderWindowObserverHelper(iggRenderWindowObserver *owner, iggFrame *frame) : iEventObserver(frame?frame->GetShell():0)
 {
 	IERROR_ASSERT(frame);
 	IERROR_ASSERT(owner);
@@ -116,7 +116,7 @@ void iggRenderWindowObserverHelper::UpdateConnection()
 }
 
 
-void iggRenderWindowObserverHelper::Execute(vtkObject *caller, unsigned long event, void * /*callData*/)
+void iggRenderWindowObserverHelper::ExecuteBody(vtkObject *caller, unsigned long event, void *)
 {
 #ifdef I_CHECK1
 	if(caller != mWindow)
