@@ -36,6 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierrorstatus.h"
 #include "ieventobserver.h"
 #include "ifile.h"
+#include "ioutputchannel.h"
 #include "iversion.h"
 #include "iviewmodule.h"
 #include "ivtk.h"
@@ -47,6 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggrenderwindow.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetmisc.h"
+#include "iggwidgetprogressbar.h"
 
 #include "ibgdialogsubject.h"
 #include "ibgextensionwindowsubject.h"
@@ -56,7 +58,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgshellsubject.h"
 #include "ibgwindowhelper.h"
 
-#if defined(I_DEBUG) && defined(I_EDITION)
+#if defined(I_DEBUG)
 #include <vtkTimerLog.h>
 #endif
 
@@ -66,69 +68,118 @@ using namespace iggParameter;
 using namespace iParameter;
 
 
-namespace iggShell_Private
+class iggDialogFlashWindow : public iggDialog
 {
-	class DialogFlashWindow : public iggDialog
+
+public:
+
+	iggDialogFlashWindow(iShell *shell) : iggDialog(shell,_DialogUnattached|_DialogBlocking|_DialogNoTitleBar,0,"",0,3,0)
 	{
+		mFrame->AddLine(new iggWidgetTextArea("%b%+   IFrIT - Ionization FRont Interactive Tool   ",mFrame),3);
+		mFrame->AddLine(new iggWidgetTextArea("Version "+iVersion::GetVersion(),mFrame),3);
+		mFrame->AddLine(new iggWidgetTextArea(iEdition::GetEditionName(),mFrame),3);
 
-	public:
+		mFlipper = new iggWidgetLogoFlipper(mFrame);
+		mFrame->AddLine(0,mFlipper,0);
 
-		DialogFlashWindow(iShell *shell) : iggDialog(shell,_DialogUnattached|_DialogBlocking|_DialogNoTitleBar,0,"",0,3,false)
-		{
-			mFrame->AddLine(new iggWidgetTextArea("%b%+   IFrIT - Ionization FRont Interactive Tool   ",mFrame),3);
-			mFrame->AddLine(new iggWidgetTextArea("Version "+iVersion::GetVersion(),mFrame),3);
-			mFrame->AddLine(new iggWidgetTextArea(iEdition::GetEditionName(),mFrame),3);
+		mMessage = new iggWidgetTextArea("Starting...",mFrame);
+		mFrame->AddLine(mMessage,3);
 
-			mFlipper = new iggWidgetLogoFlipper(mFrame);
-			mFrame->AddLine(0,mFlipper,0);
+		this->ResizeContents(100,100);
+	}
 
-			mMessage = new iggWidgetTextArea("Starting...",mFrame);
-			mFrame->AddLine(mMessage,3);
+	virtual void Show(bool s)
+	{
+		mFlipper->Reset();
+		iggDialog::Show(s);
+	}
 
-			this->ResizeContents(100,100);
-		}
+	void OnInitAtom()
+	{
+		mFlipper->Advance();
+	}
 
-		virtual void Show(bool s)
-		{
-			mFlipper->Reset();
-			iggDialog::Show(s);
-		}
+	void PlaceOnDesktop(int dw, int dh)
+	{
+		int wg[4];
+		mSubject->GetWindowGeometry(wg,true);
+		wg[0] = (dw-wg[2]-20)/2;
+		wg[1] = (dh-wg[3]-20)/2;
+		mSubject->SetWindowGeometry(wg);
+	}
 
-		void OnInitAtom()
-		{
-			mFlipper->Advance();
-		}
+	void DisplayMessage(const iString &text)
+	{
+		mMessage->SetText(text);
+	}
 
-		void PlaceOnDesktop(int dw, int dh)
-		{
-			int wg[4];
-			mSubject->GetWindowGeometry(wg,true);
-			wg[0] = (dw-wg[2]-20)/2;
-			wg[1] = (dh-wg[3]-20)/2;
-			mSubject->SetWindowGeometry(wg);
-		}
+protected:
 
-		void DisplayMessage(const iString &text)
-		{
-			mMessage->SetText(text);
-		}
+	virtual bool CanBeClosed()
+	{
+		return false; // cannot be closed
+	}
 
-	protected:
-
-		virtual bool CanBeClosed()
-		{
-			return false; // cannot be closed
-		}
-
-		iggWidgetTextArea *mMessage;
-		iggWidgetLogoFlipper *mFlipper;
-	};
+	iggWidgetTextArea *mMessage;
+	iggWidgetLogoFlipper *mFlipper;
 };
 
 
-iggShell::iggShell(const iString &type, int argc, char **argv) : iShell(argc,argv)
+class iggOutputChannel : public iOutputChannel
+{
+
+public:
+
+	iggOutputChannel(iggMainWindow *mw) : iOutputChannel(mw->GetShell())
+	{
+		mMainWindow = mw;
+	}
+
+protected:
+
+	virtual void DisplayBody(iConsole::MessageType type, const iString &message, const char *file, int line)
+	{
+		iString m(message);
+		if(file != 0) m += iString("\nFile: ") + file + "\nLine: " + iString::FromNumber(line);
+
+		switch(type)
+		{
+		case iConsole::_Info:
+			{
+				mMainWindow->WriteToLog("",message);
+				break;
+			}
+		case iConsole::_Warning:
+			{
+				mMainWindow->PopupWindow(message,iggParameter::_PopupWindowMessage);
+				break;
+			}
+		case iConsole::_LowError:
+			{
+				mMainWindow->WriteToLog("Error",m,iColor(255,0,0)); 
+				break; 
+			}
+		case iConsole::_HighError:
+			{
+				mMainWindow->PopupWindow(m,iggParameter::_PopupWindowWarning);
+				break;
+			}
+		case iConsole::_FatalError:
+			{
+				mMainWindow->PopupWindow(m,iggParameter::_PopupWindowError);
+				break;
+			}
+		}
+	}
+
+private:
+
+	iggMainWindow *mMainWindow;
+};
+
+
+iggShell::iggShell(const iString &type, int argc, char **argv) : iShell(type,argc,argv)
 {
-	mType = type;
 	mSubject = iggSubjectFactory::CreateShellSubject(this,argc,argv);
 	if(mSubject == 0) exit(1);
 
@@ -136,7 +187,7 @@ iggShell::iggShell(const iString &type, int argc, char **argv) : iShell(argc,arg
 	//  Default settings
 	//
 	mShowFlashWindow = true;
-	mAccept8BitDisplay = mStartDocked = false;
+	mAccept8BitDisplay = mStartDocked = mUseOldWindowManager = mSmallDesktop = false;
 
 	mMainWindow = 0; // very important!!! This tells other components that the main
 					 // window does not exist yet.
@@ -150,12 +201,14 @@ void iggShell::Exit()
 }
 
 
-#ifdef I_DEBUG
-void iggShell::OutputDebugMessage(const iString &message) const
+bool iggShell::IsDesktopSmall(bool vert) const
 {
-	mSubject->OutputDebugMessage(message);
+	if(mSmallDesktop) return true;
+
+	int w, h;
+	mSubject->GetDesktopDimensions(w,h);
+	if(vert) return (h < 900); else return (w < 1200);
 }
-#endif
 
 
 void iggShell::GetDesktopDimensions(int &w, int &h) const
@@ -164,22 +217,17 @@ void iggShell::GetDesktopDimensions(int &w, int &h) const
 }
 
 
-void iggShell::OutputStartupMessage(const iString &message)
-{
-	mSubject->OutputStartupMessage(message);
-}
-
-
 void iggShell::DefineSpecificCommandLineOptions()
 {
 	//
 	//  Define generic GUI-specific command-line options
 	//
-	this->AddCommandLineOption("nf",false,"do not show the splash screen at start-up");
 	if(mSubject->CanRecognize8BitDisplay()) this->AddCommandLineOption("8",false,"accept an 8-bit display");
 	if(mSubject->CanDockWindows()) this->AddCommandLineOption("d",false,"start IFrIT with windows docked");
-	if(mSubject->CanRenderOffScreen()) this->AddCommandLineOption("b",true,"execute a control script from a file <arg> in the screenless mode");
 	if(mSubject->CanChangeFontSize()) this->AddCommandLineOption("fs",true,"increase/decrease window font size");
+	this->AddCommandLineOption("nf",false,"do not show the splash screen at start-up");
+	this->AddCommandLineOption("owm",false,"use old-style window manager");
+	this->AddCommandLineOption("sd",false,"assume the desktop size is small");
 }
 
 
@@ -190,37 +238,25 @@ iggShell::~iggShell()
 
 void iggShell::PrepareForConstruction()
 {
-	if(mScriptFileName.IsEmpty())
+	//
+	//  Check for the 8-bit display
+	//
+	if(!mAccept8BitDisplay && mSubject->CanRecognize8BitDisplay() && mSubject->CanRecognize8BitDisplay(true))
 	{
-		//
-		//  Check for the 8-bit display
-		//
-		if(!mAccept8BitDisplay && mSubject->CanRecognize8BitDisplay() && mSubject->CanRecognize8BitDisplay(true))
-		{
-			this->OutputStartupMessage("You are not using a True Color (24-bit) monitor.\n"
-				"Visualizations will be crappy without the True Color support.\n"
-				"If you wish to continue anyway, specify -8 as an option.");
-			exit(0);
-		}
+		iConsole::Display(iConsole::_FatalError,"You are not using a True Color (24-bit) monitor.\n"
+			"Visualizations will be crappy without the True Color support.\n"
+			"If you wish to continue anyway, specify -8 as an option.");
 	}
-	else
-	{
-		mShowFlashWindow = false;
-	}
-#if defined(I_DEBUG) && defined(I_EDITION)
-	this->OutputDebugMessage("Starting...");
-#ifdef IVTK_4
-	mTotalTime = vtkTimerLog::GetCurrentTime();
-#else
-	mTotalTime = vtkTimerLog::GetUniversalTime();
-#endif
+
+#ifdef I_DEBUG
+	iConsole::PrintDebugMessage("Starting...");
 #endif
 	//
 	//  Create and show message window
 	//
 	if(mShowFlashWindow)
 	{
-		mFlashWindow = new iggShell_Private::DialogFlashWindow(this); IERROR_ASSERT(mFlashWindow);
+		mFlashWindow = new iggDialogFlashWindow(this); IERROR_ASSERT(mFlashWindow);
 		//
 		//  calculate the position of the flash window
 		//
@@ -234,10 +270,10 @@ void iggShell::PrepareForConstruction()
 			dw /= 2;
 		}
 		mSubject->ProcessEvents(true);
-		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->PlaceOnDesktop(dw,dh);
+		mFlashWindow->PlaceOnDesktop(dw,dh);
 		mFlashWindow->Show(true);
 		mSubject->ProcessEvents(true);
-		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->DisplayMessage("Creating visualization window...");
+		mFlashWindow->DisplayMessage("Creating visualization window...");
 	}
 }
 
@@ -246,22 +282,13 @@ void iggShell::ConstructorBody()
 {
 	if(mShowFlashWindow)
 	{
-		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->DisplayMessage("Creating widgets...");
+		mFlashWindow->DisplayMessage("Creating widgets...");
 		mSubject->ProcessEvents(false);
 	}
 
-#if defined(I_DEBUG) && defined(I_EDITION)
-	iConsole::Instance()->StartTimer();
-#endif
-	mMainWindow = new iggMainWindow(this);
-#if defined(I_DEBUG) && defined(I_EDITION)
-	iConsole::Instance()->StopTimer("Creating main window");
-	iConsole::Instance()->StartTimer();
-#endif
+	mMainWindow = new iggMainWindow(this); IERROR_ASSERT(mMainWindow);
+	iOutputChannel::SetInstance(new iggOutputChannel(mMainWindow));
 	mMainWindow->StartInitialization();
-#if defined(I_DEBUG) && defined(I_EDITION)
-	iConsole::Instance()->StopTimer("Initializing main window");
-#endif
 }
 
   
@@ -272,40 +299,32 @@ void iggShell::DestructorBody()
 	//
 	mMainWindow->ShowAll(false);
 	mMainWindow->Block(true); // block all events
-	delete mMainWindow;
+	mMainWindow->Delete();
 	mMainWindow = 0;  // tell other objects that the MainWindow does not exist any more
 }
 
 
-void iggShell::LoadStateFile(const iString &fname)
+void iggShell::PrepareToLoadStateFile()
 {
 	if(mShowFlashWindow)
 	{
-		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->DisplayMessage("Loading the state file...");
+		mFlashWindow->DisplayMessage("Loading the state file...");
 		mSubject->ProcessEvents(false);
 	}
-	if(!this->GetControlModule()->LoadStateFromFile(fname))
-	{
-		mMainWindow->PopupWindow("The state file is corrupted.\n Default values of parameters will be used.",_PopupWindowError);
-	}
 }
 
 
 void iggShell::Start()
 {
-	const int topOffset = 64;
+	const int topOffset0 = 64;
 	const int frameXoffDefault = 13;
 	const int frameYoffDefault = 25;
 	int frameXoff = 1, frameYoff = 1;
-	int leftOffset = 0;
+	int topOffset, leftOffset = 0;
 
-	//
-	//  If we are running in a batch mode, show no windows.
-	//
-	if(!mScriptFileName.IsEmpty()) return;
-
-#if defined(I_DEBUG) && defined(I_EDITION)
-	iConsole::Instance()->StartTimer();
+#ifdef I_DEBUG
+	vtkTimerLog *debugTimer = vtkTimerLog::New(); IERROR_ASSERT(debugTimer);
+	debugTimer->StartTimer();
 #endif
 
 	if(mStartDocked) mMainWindow->mDocked = true;
@@ -315,13 +334,14 @@ void iggShell::Start()
 		
 	if(mShowFlashWindow)
 	{
-		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->DisplayMessage("Showing windows...");
+		mFlashWindow->DisplayMessage("Showing windows...");
 		mSubject->ProcessEvents(false);
 	}
+
 	//
 	//  Show visualization windows
 	//
-	if(mStateFileName.IsEmpty())
+	if(!this->HasStateFile() && !this->IsDesktopSmall(false))
 	{
 		//
 		// Calculate the left offset of the visualization window (it is the only one)
@@ -337,7 +357,7 @@ void iggShell::Start()
 		}
 
 		int mwg[4], vwg[4];
-		iggRenderWindow *visWindow = iPointerCast<iggRenderWindow,vtkRenderWindow>(mControlModule->GetViewModule()->GetRenderWindow());
+		iggRenderWindow *visWindow = iRequiredCast<iggRenderWindow>(INFO,this->ControlModule()->GetViewModule()->GetRenderWindow());
 
 		//
 		//  squeeze windows to the minimum possible size
@@ -347,6 +367,7 @@ void iggShell::Start()
 		mMainWindow->GetExtensionWindow()->GetSubject()->SetWindowGeometry(mwg);
 		mSubject->ProcessEvents(false);
 
+		topOffset = this->IsDesktopSmall(true) ? 0 : topOffset0;
 		//
 		//  Show all windows
 		//
@@ -376,10 +397,6 @@ void iggShell::Start()
 			if(redo) mMainWindow->GetSubject()->SetWindowGeometry(mwg);
 
 			mMainWindow->ShowAll(true);
-#if defined(I_DEBUG) && defined(I_EDITION)
-			iConsole::Instance()->StopTimer("Showing windows");
-			iConsole::Instance()->StartTimer();
-#endif
 		}
 		else
 		{
@@ -392,21 +409,17 @@ void iggShell::Start()
 			leftOffset = (dw-vwg[2]-mwg[2]-20)/2;
 			if(leftOffset < 0) leftOffset = 0;
 			//
-			//  Move the visual module window
+			//  Move the view module window
 			//
 			vwg[0] = leftOffset;
 			vwg[1] = topOffset;
 			visWindow->GetSubject()->SetWindowGeometry(vwg);
 
 			//
-			//  Show the visualization window and give a chance to the Window Manager to decorate the window
+			//  Show the visualization window and give window manager a chance to decorate it.
 			//			     
-			mControlModule->Render(_RenderModeAll);
+			this->ControlModule()->Render(_RenderOptionAll);
 			mSubject->ProcessEvents(false);
-#if defined(I_DEBUG) && defined(I_EDITION)
-			iConsole::Instance()->StopTimer("Showing render window");
-			iConsole::Instance()->StartTimer();
-#endif
 
 			//
 			//  Get the frame geometry
@@ -427,7 +440,10 @@ void iggShell::Start()
 			ewg[3] = mwg[3] - vwg[3] - frameYoff;
 			mMainWindow->GetExtensionWindow()->GetSubject()->SetWindowGeometry(ewg,true);
 			mMainWindow->GetExtensionWindow()->GetSubject()->GetWindowGeometry(ewg2,true);
-			if(ewg2[3] > ewg[3])
+			//
+			//  Stretch main window to match the extension window, but only if the desktop tall enough.
+			//
+			if(ewg2[3]>ewg[3] && !this->IsDesktopSmall(true))
 			{
 				mMainWindow->GetSubject()->GetWindowGeometry(mwg,true);
 				mwg[3] += (ewg2[3]-ewg[3]);
@@ -439,22 +455,14 @@ void iggShell::Start()
 			//			     
 			mMainWindow->GetSubject()->Show(true);
 			mSubject->ProcessEvents(false);
-#if defined(I_DEBUG) && defined(I_EDITION)
-			iConsole::Instance()->StopTimer("Showing main window");
-			iConsole::Instance()->StartTimer();
-#endif
 
 			mMainWindow->GetExtensionWindow()->GetSubject()->Show(true);
 			mSubject->ProcessEvents(false);
-#if defined(I_DEBUG) && defined(I_EDITION)
-			iConsole::Instance()->StopTimer("Showing extension window");
-			iConsole::Instance()->StartTimer();
-#endif
 		}
 	}
 	else
 	{
-		mControlModule->Render(_RenderModeAll);
+		this->ControlModule()->Render(_RenderOptionAll);
 		mMainWindow->GetSubject()->Show(true);
 		mMainWindow->GetExtensionWindow()->GetSubject()->Show(true);
 	}
@@ -474,79 +482,17 @@ void iggShell::Start()
 	mSubject->ProcessEvents(false);
 	mMainWindow->PostShowInitialization();
 
-#if defined(I_DEBUG) && defined(I_EDITION)
-	iConsole::Instance()->StopTimer("Mopping up");
-#ifdef IVTK_4
-	mTotalTime = vtkTimerLog::GetCurrentTime() - mTotalTime;
-#else
-	mTotalTime = vtkTimerLog::GetUniversalTime() - mTotalTime;
-#endif
-	this->OutputDebugMessage("Done: "+iString::FromNumber(mTotalTime));
+#ifdef I_DEBUG
+	debugTimer->StopTimer();
+	iConsole::PrintDebugMessage("Init: "+iString::FromNumber(debugTimer->GetElapsedTime()));
+	debugTimer->Delete();
 #endif
 }
 
 
 void iggShell::RunBody()
 {
-	if(mScriptFileName.IsEmpty())
-	{
-		mSubject->EnterEventLoop();
-	}
-	else
-	{
-		if(!mSubject->CanRenderOffScreen())
-		{
-			mSubject->OutputStartupMessage("This shell cannot execute a script in a batch mode.");
-			return;
-		}
-		//
-		//  Execute the batch script
-		//
-		iString fname;
-
-		if(mScriptFileName[0] == '+')
-		{
-			fname = mControlModule->GetFileName(_EnvironmentScript,mScriptFileName.Part(1));
-		}
-		else
-		{
-			fname = mScriptFileName;
-		}
-		iFile F(fname);
-
-		if(!F.Open(iFile::_Read,iFile::_Text)) 
-		{
-			mSubject->OutputStartupMessage(iString("File ")+fname+" cannot be open for reading. Abort.");
-			exit(1);
-		}
-
-		mSubject->OutputStartupMessage("Reading the file...");
-		iString text, line;
-		while(F.ReadLine(line)) text += "\n" + line;
-		text += "\n";
-
-		iControlScript *cs = mControlModule->GetControlScript();
-		mSubject->OutputStartupMessage("Compiling the script...");
-
-		cs->Run(text,true);
-		if(cs->GetErrorStatus()->IsError())
-		{
-			mSubject->OutputStartupMessage(iString("Syntax error in script, line ")+iString::FromNumber(cs->GetCurrentLine())+" : "+cs->GetErrorMessage());
-			return;
-		}
-
-		//
-		//  Set image method to pixmap
-		//
-		iggRenderWindow::SetRenderIntoMemory(true);
-
-		mSubject->OutputStartupMessage("Running the script...");
-		cs->Run(text);
-		if(cs->GetErrorStatus()->IsError())
-		{
-			mSubject->OutputStartupMessage(iString("Runtime error in script, line ")+iString::FromNumber(cs->GetCurrentLine())+" : "+cs->GetErrorMessage());
-		}
-	}
+	mSubject->EnterEventLoop();
 }
 
 
@@ -564,11 +510,17 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 		}
 		else
 		{
-			this->OutputStartupMessage("Invalid font size specification; should be in the form +<number> or -<number>. Abort.");
+			iConsole::Display(iConsole::_HighError,"Invalid font size specification; should be in the form +<number> or -<number>. Abort.");
 			exit(1);
 		}
 	} 
 
+	if(o.Name == "sd")
+	{
+		mSmallDesktop = true;
+		return true;
+	} 
+
 	if(o.Name == "nf")
 	{
 		mShowFlashWindow = false;
@@ -581,33 +533,32 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 		return true;
 	}
 
+	if(o.Name == "owm")
+	{
+		mUseOldWindowManager = true;
+		return true;
+	}
+
 	if(o.Name == "d")
 	{
 		mStartDocked = true;
 		return true;
 	} 
 	
-	if(o.Name == "b")
-	{
-		if(iFile::IsLoadable(o.Value))
-		{
-			mScriptFileName = o.Value;
-			return true;
-		}
-		else
-		{
-			mSubject->OutputStartupMessage("File "+o.Value+" is not accessible. Abort.");
-			exit(1);
-		}
-	}
 	return false;
 }
 
 
+bool iggShell::IsWindowManagerModern() const
+{
+	if(mUseOldWindowManager) return false; else return mSubject->IsWindowManagerModern();
+}
+
+
 //
 //  State saving
 //
-bool iggShell::LoadShellStateFromFile(iFile &F)
+bool iggShell::LoadShellStateFromFileBody(iFile &F)
 {
 	iString ws, line;
 	//
@@ -629,7 +580,7 @@ bool iggShell::LoadShellStateFromFile(iFile &F)
 }
 
 
-bool iggShell::SaveShellStateToFile(iFile &F) const
+bool iggShell::SaveShellStateToFileBody(iFile &F) const
 {
 	//
 	//  Save the state of the main window 
@@ -649,6 +600,17 @@ void iggShell::ProcessEvents(bool sync)
 
 void iggShell::OnInitAtomBody(bool timed)
 {
-	if(timed && mFlashWindow!=0) iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->OnInitAtom();
+	if(timed && mFlashWindow!=0) mFlashWindow->OnInitAtom();
+}
+
+
+void iggShell::OnLoadStateFileAtomBody(int prog)
+{
+	if(mMainWindow!=0 && mMainWindow->GetProgressBar()!=0)
+	{
+		if(prog == 0) mMainWindow->GetProgressBar()->Reset();
+		mMainWindow->GetProgressBar()->SetProgress(prog);
+		if(prog == 100) mMainWindow->GetProgressBar()->Reset();
+	}
 }
 
