@@ -41,21 +41,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkMath.h>
 
+#include "iparameter.h"
+#include "iggparameter.h"
+using namespace iggParameter;
+using namespace iParameter;
+
+
 //
 //  Templates
 //
 #include "iarraytemplate.h"
 
 
-int iggWidget::mIdCounter = 0;
+int iggWidget::mGlobalExecuteFlags = 0;
 
 //
 //  Main class
 //
-iggWidget::iggWidget(iggFrameBase *parent) : iShellComponent(parent?parent->GetShell():0)
+iggWidget::iggWidget(iggFrameBase *parent) : iggElement(parent?parent->GetShell():0)
 {
-	mId = mIdCounter++;
-
 	IERROR_ASSERT(parent);
 	mParent = parent;
 
@@ -68,7 +72,7 @@ iggWidget::iggWidget(iggFrameBase *parent) : iShellComponent(parent?parent->GetS
 }
 
 
-iggWidget::iggWidget(iShell *shell) : iShellComponent(shell)
+iggWidget::iggWidget(iShell *shell) : iggElement(shell)
 {
 	mParent = 0;
 
@@ -81,11 +85,13 @@ void iggWidget::Define()
 	mWasLaidOut = mHelpIsSet = mInUpdate = false;
 	mNeedsBaloonHelp = true;  //  used for checking internal consistency
 	mSubjectOwner = true;  // owns its subject
-	mMainWindow = iPointerCast<iggShell,iShell>(this->GetShell())->GetMainWindow();
+	mMainWindow = iRequiredCast<iggShell>(INFO,this->GetShell())->GetMainWindow();
 
 	mWidgetSubject = 0;
 	mWidgetHelper = 0;
 
+	mExecuteFlags = _DefaultOption;
+
 	mInitialized = false;
 
 	List().Add(this);
@@ -96,11 +102,11 @@ iggWidget::~iggWidget()
 {
 	List().Remove(this);
 
-	if(!this->CheckBaloonHelpStatus()) IERROR_REPORT("Context-sensitive help was not set.");
+	if(!this->CheckBaloonHelpStatus()) IERROR_LOW("Context-sensitive help was not set.");
 
 	if(!mWasLaidOut)
 	{
-		IERROR_REPORT("This widget was not added to a layout.");
+		IERROR_LOW("This widget was not added to a layout.");
 	}
 
 	while(mBuddies.Size() > 0) this->RemoveBuddy(mBuddies.Last());  // remove buddies first
@@ -213,7 +219,7 @@ void iggWidget::UpdateFailed() const
 	//  This is for debugging purposes only
 	//
 #ifdef I_DEBUG
-	IERROR_REPORT("Update failed.");
+	IERROR_LOW("Update failed.");
 #endif
 }
 
@@ -226,7 +232,7 @@ void iggWidget::SetBaloonHelp(const iString &help)
 
 void iggWidget::SetBaloonHelp(const iString &tooltip, const iString &whatsthis)
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	if(mWidgetHelper->SupportsHTMLHelp())
 	{
@@ -244,7 +250,7 @@ void iggWidget::SetBaloonHelp(const iString &tooltip, const iString &whatsthis)
 
 bool iggWidget::CheckBaloonHelpStatus()
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	return !mNeedsBaloonHelp || !mSubjectOwner || mWidgetHelper->HasBaloonHelp();
 }
@@ -252,7 +258,7 @@ bool iggWidget::CheckBaloonHelpStatus()
 
 void iggWidget::Show(bool s)
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	mWidgetHelper->Show(s);
 }
@@ -260,7 +266,7 @@ void iggWidget::Show(bool s)
 
 bool iggWidget::IsVisible() const
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	return mWidgetHelper->IsVisible();
 }
@@ -268,7 +274,7 @@ bool iggWidget::IsVisible() const
 
 void iggWidget::Enable(bool s)
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	mWidgetHelper->Enable(s);
 }
@@ -276,7 +282,7 @@ void iggWidget::Enable(bool s)
 
 bool iggWidget::IsEnabled() const
 {
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	return mWidgetHelper->IsEnabled();
 }
@@ -286,7 +292,7 @@ void iggWidget::Emphasize(bool s, bool random)
 {
 	static const iColor emp(255,50,50);
 
-	if(mWidgetHelper == 0) IERROR_FINISH("WidgetHelper has not been set.");
+	if(mWidgetHelper == 0) IERROR_FATAL("WidgetHelper has not been set.");
 
 	if(s)
 	{
@@ -311,3 +317,44 @@ void iggWidget::EmphasizeLayouts(bool s)
 }
 #endif
 
+
+void iggWidget::SetExecuteFlags(int f)
+{
+	mExecuteFlags = f;
+
+#ifdef I_CHECK1
+	int objOption = f & _ObjectOptionMask;
+	int modOption = f & _ModuleOptionMask;
+	int renOption = f & _RenderOptionMask;
+
+	//
+	//  Check that modes are valid
+	//
+	if(
+		(objOption!=_ObjectOptionOne && objOption!=_ObjectOptionAll) ||
+		(modOption!=_ModuleOptionOne && modOption!=_ModuleOptionAll && modOption!=_ModuleOptionClones) || 
+		(renOption!=_RenderOptionOne && renOption!=_RenderOptionAll && renOption!=_RenderOptionClones && renOption!=_RenderOptionAuto))
+	{
+		IERROR_LOW("Invalid option.");
+	}
+#endif
+}
+
+
+void iggWidget::SetGlobalExecuteFlags(int f)
+{
+	mGlobalExecuteFlags = f;
+}
+
+
+int iggWidget::GetExecuteFlags() const
+{
+	if(mGlobalExecuteFlags == 0) return mExecuteFlags;
+
+	int flags = 0;
+	if((mGlobalExecuteFlags & _ObjectOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _ObjectOptionMask); else flags = flags | (mExecuteFlags & _ObjectOptionMask); 
+	if((mGlobalExecuteFlags & _ModuleOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _ModuleOptionMask); else flags = flags | (mExecuteFlags & _ModuleOptionMask); 
+	if((mGlobalExecuteFlags & _RenderOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _RenderOptionMask); else flags = flags | (mExecuteFlags & _RenderOptionMask); 
+	return flags;
+}
+
