@@ -30,9 +30,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ihistogram.h"
+#include "ihistogrammaker.h"
 #include "imath.h"
 
 #include "iggframehistogramareaextra.h"
+#include "iggmainwindow.h"
 
 #include "ibgwidgetareasubject.h"
 
@@ -202,7 +204,8 @@ void iggWidgetHistogramArea::DrawHistogram(const iColor &drawColor)
 	}
 	ix2 = round(x2);
 
-	for(i=1; i<mHistogram->N()-1; i++)  
+	int n = mHistogram->N()-1;
+	for(i=1; i<n; i++)  
 	{
 		x1 = x2;
 		ix1 = ix2;
@@ -260,6 +263,30 @@ void iggWidgetHistogramArea::GetHistogramRange(float &min, float &max) const
 }
 
 
+void iggWidgetHistogramArea::SetFullResolution(bool s)
+{
+	if(mHistogram!=0 && mHistogram->GetMaker()!=0 && s!=mHistogram->GetMaker()->GetFullResolution())
+	{
+		mHistogram->GetMaker()->SetFullResolution(s);
+		if(s) this->GetMainWindow()->Block(true);
+		mHistogram->GetMaker()->Update();
+		if(s) this->GetMainWindow()->Block(false);
+	}
+}
+
+
+bool iggWidgetHistogramArea::GetFullResolution() const
+{
+	if(mHistogram!=0 && mHistogram->GetMaker()!=0) return mHistogram->GetMaker()->GetFullResolution(); else return false;
+}
+
+
+bool iggWidgetHistogramArea::SupportsFullResolution() const
+{
+	if(mHistogram!=0 && mHistogram->GetMaker()!=0) return mHistogram->GetMaker()->SupportsFullResolution(); else return false;
+}
+
+
 void iggWidgetHistogramArea::AddExtra(iggFrameHistogramAreaExtra *extra)
 {
 	mExtra = extra;
