@@ -177,7 +177,7 @@ iggWidgetKeyFileNameButton::iggWidgetKeyFileNameButton(const iString &text, cons
 
 	mHeader = header;
 	mSelection = selection;
-	mDefault = this->GetMainWindow()->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentBase);
+	mDefault = this->GetMainWindow()->GetShell()->GetEnvironment(_EnvironmentBase);
 }
 
 
@@ -197,7 +197,7 @@ void iggWidgetKeyFileNameButton::UpdateWidgetBody()
 
 void iggWidgetKeyFileNameButton::QueryValue(iString &val) const
 {
-	val = this->GetMainWindow()->GetFileName(mHeader,this->GetMainWindow()->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentBase),"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
+	val = this->GetMainWindow()->GetFileName(mHeader,this->GetMainWindow()->GetShell()->GetEnvironment(_EnvironmentBase),"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
 }
 
 
