@@ -37,6 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggparameter.h"
 using namespace iggParameter;
+using namespace iParameter;
 
 //
 //  templates
@@ -46,7 +47,6 @@ using namespace iggParameter;
 
 
 int iggWidgetKeyHandlerBase::mGlobalRenderMode = _RenderModeDelayed;
-int iggWidgetKeyHandlerBase::mGlobalExecuteFlags = 0;
 #ifdef I_CHECK1
 bool iggWidgetKeyHandlerBase::mCheckNullIndexKeys =  false;
 #endif
@@ -61,29 +61,28 @@ iggWidgetKeyHandlerBase::iggWidgetKeyHandlerBase(int type, const iObjectKey &key
 	mIndex = index;
 	if(mIndex<-1 || (mKey.Dimension()>0 && mIndex>=mKey.Dimension()))
 	{
-		IERROR_REPORT("Incorrect index value.");
+		IERROR_LOW("Incorrect index value.");
 		mIndex = -1;
 	}
 
 	if(mIndexKey!=0 && (mIndexKey->Argument()!=iObjectKey::_OffsetInt || mIndexKey->Dimension()!=1))
 	{
-		IERROR_REPORT("Index key must be a scalar OffsetInt-valued key.");
+		IERROR_LOW("Index key must be a scalar OffsetInt-valued key.");
 		mIndexKey = 0;
 	}
 
 #ifdef I_CHECK1
 	if(mCheckNullIndexKeys && mIndexKey==0)
 	{
-		IERROR_REPORT("Null index key.");
+		IERROR_LOW("Null index key.");
 	}
 #endif
 
 	mSelfChecking = false;
 
 	mRenderMode = rm;
-	mExecuteFlags = 0;
 
-	if(mParent == 0) IERROR_FINISH("iggWidgetKeyHandlerBase must have a parent.");
+	if(mParent == 0) IERROR_FATAL("iggWidgetKeyHandlerBase must have a parent.");
 
 	//
 	//  Find all my buddies
@@ -136,13 +135,13 @@ void iggWidgetKeyHandlerBase::SetIndex(int i)
 {
 	if(mIndexKey != 0)
 	{
-		IERROR_REPORT("Cannot set an index if the IndexKey is defined.");
+		IERROR_LOW("Cannot set an index if the IndexKey is defined.");
 		return;
 	}
 
 	if(i<-1 || (mKey.Dimension()>0 && i>=mKey.Dimension())) // zero-dimension key has no range checking
 	{
-		IERROR_REPORT("Incorrect index value.");
+		IERROR_LOW("Incorrect index value.");
 		i = -1;
 	}
 	mIndex = i;
@@ -155,12 +154,6 @@ void iggWidgetKeyHandlerBase::SetRenderMode(int m)
 }
 
 
-void iggWidgetKeyHandlerBase::SetExecuteFlags(int f)
-{
-	mExecuteFlags = f;
-}
-
-
 iPointerArray<iggWidgetKeyHandlerBase>& iggWidgetKeyHandlerBase::List()
 {
 	static iPointerArray<iggWidgetKeyHandlerBase> list(100);
@@ -181,7 +174,7 @@ iPointerArray<iggWidgetKeyHandlerBase>& iggWidgetKeyHandlerBase::PositionList()
 		const iObjectKey& key = list[i]->mKey;
 		if(key.PrefixedFullName().Part(-2) != "GL")
 		{
-			IERROR_REPORT("Incorrect position key");
+			IERROR_LOW("Incorrect position key");
 		}
 	}
 #endif
@@ -228,25 +221,6 @@ int iggWidgetKeyHandlerBase::GetRenderMode() const
 }
 
 
-void iggWidgetKeyHandlerBase::SetGlobalExecuteFlags(int f)
-{
-	mGlobalExecuteFlags = f;
-}
-
-
-int iggWidgetKeyHandlerBase::GetExecuteFlags() const
-{
-	if(mGlobalExecuteFlags != 0)
-	{
-		return mGlobalExecuteFlags;
-	}
-	else
-	{
-		return mExecuteFlags;
-	}
-}
-
-
 bool iggWidgetKeyHandlerBase::CheckBaloonHelpStatus()
 {
 	return !mHelpIsSet || this->iggWidget::CheckBaloonHelpStatus();
