@@ -254,7 +254,7 @@ iggWidgetKeyTextComboBox::iggWidgetKeyTextComboBox(int section, const iString &t
 {
 	if(section < 0)
 	{
-		IERROR_REPORT("Negative sections do not exist.");
+		IERROR_LOW("Negative sections do not exist.");
 		section = 0;
 	}
 	mSection = section;
@@ -289,7 +289,7 @@ void iggWidgetKeyTextComboBox::UpdateValue(int v)
 	else
 	{
 		mSubject->SetValue(0);
-		IERROR_REPORT("Invalid value in ComboBox widget.");
+		IERROR_LOW("Invalid value in ComboBox widget.");
 	}
 }
 
@@ -320,7 +320,7 @@ iggWidgetKeyStretchComboBox::iggWidgetKeyStretchComboBox(const iObjectKey &key,
 {
 	if(key.UnprefixedFullName().Contains("Stretch") < 0)
 	{
-		IERROR_FINISH("Invalid key in iggWidgetKeyStretchComboBox.");
+		IERROR_FATAL("Invalid key in iggWidgetKeyStretchComboBox.");
 	}
 
 	int i, n;
