@@ -42,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggsubjectfactory.h"
 #include "iggparameter.h"
 using namespace iggParameter;
+using namespace iParameter;
 
 //
 //  Template
@@ -58,12 +59,16 @@ using namespace iggParameter;
 //
 //******************************************
 //
+bool iggWidgetSlider::mIsEditableByDefault = false;
+
+
 iggWidgetSlider::iggWidgetSlider(int /*numdig*/, const iString& /*label*/, ibgWidgetEntrySubject *subject, iggWidget *owner) : iggWidget(owner->GetParent())
 {
 	mSubjectOwner = false;
 	mSubject = subject;
 	this->AttachSubject(subject);
 
+	mSubject->SetEditable(mIsEditableByDefault);
 	List().AddUnique(this);
 
 	mWasLaidOut = true;
@@ -91,6 +96,8 @@ void iggWidgetSlider::SetAllEditable(bool s)
 	{
 		list[i]->mSubject->SetEditable(s);
 	}
+
+	mIsEditableByDefault = s;
 }
 
 
@@ -118,7 +125,7 @@ iggWidgetKeyIntSlider::iggWidgetKeyIntSlider(int min, int max, int numdig, const
 	{
 		this->SetRange(smin,smax);
 	}
-	else IERROR_REPORT("Invalid slider range.");
+	else IERROR_LOW("Invalid slider range.");
 }
 
 
@@ -185,7 +192,7 @@ void iggWidgetKeyLargeIntSlider::ConvertFromSliderInt(int sint, int &val) const
 	if(sint+10+ndex*dex != sint2)
 	{
 		this->ConvertToSliderInt(val,sint2);
-		IERROR_FINISH("Bug in iggWidgetKeyLargeIntSlider::ConvertFromSliderIn");
+		IERROR_FATAL("Bug in iggWidgetKeyLargeIntSlider::ConvertFromSliderIn");
 	}
 #endif
 }
@@ -480,6 +487,10 @@ iggWidgetKeyVariableLimitsSlider::iggWidgetKeyVariableLimitsSlider(const iggData
 	mSelfChecking = true;
 	iggWidgetKeyHandlerBase::VariableLimitsList().AddUnique(this);
 
+	mStep = 0.0f;
+
+	this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+
 	this->AttachDataTypeProvider(provider);
 }
 
@@ -562,23 +573,36 @@ int iggWidgetKeyVariableLimitsSlider::ComputeResolution()
 	float min = iDataStretch::ApplyStretch(mMin,mStretch,false);
 	float max = iDataStretch::ApplyStretch(mMax,mStretch,true);
 
-	switch(mStretch)
+	if(mStep > 1.0e-36f)
 	{
-	case 1:
+		step = mStep;
+	}
+	else
+	{
+		switch(mStretch)
 		{
-			if(max > min+1.0f) step = 0.1f; else if(max > min+0.1f) step = 0.01f; else step = 0.01f*(max-min);
-			break;
+		case 1:
+			{
+				if(max > min+1.0f) step = 0.1f; else if(max > min+0.1f) step = 0.01f; else step = 0.01f*(max-min);
+				break;
+			}
+		default:
+			{
+				step = 0.01f*(max-min);
+				break;
+			}
 		}
-	default:
-		{
-			step = 0.01f*(max-min);
-			break;
-		}
+		if(step < 1.0e-36f) step = 1.0e-36f;
 	}
-	if(step < 1.0e-36f) step = 1.0e-36f;
 
 	int res = round((max-min)/step);
 	if(res < 1) res = 1;
 	return res;
 }
 
+
+void iggWidgetKeyVariableLimitsSlider::SetStep(float step)
+{
+	mStep = step;
+}
+
