@@ -62,13 +62,14 @@ public:
 	virtual ~iggWidgetSlider();
 
 	static void SetAllEditable(bool s);
-
+	static bool IsEditableByDefault(){ return mIsEditableByDefault; }
 
 protected:
 
 	virtual void UpdateWidgetBody();
 
 	ibgWidgetEntrySubject *mSubject;
+	static bool mIsEditableByDefault;
 	//
 	//  Registry functionality
 	//
@@ -243,12 +244,15 @@ public:
 //	iggWidgetKeyVariableLimitsSlider(const iggDataTypeProvider *provider, int numdig, const iString &label, const iObjectKey &key, const iObjectKey *varkey, const iObjectKey &varmaxkey, const iObjectKey &minkey, const iObjectKey &maxkey, const iObjectKey &stepkey, const iObjectKey *logkey, int rm, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
 	virtual ~iggWidgetKeyVariableLimitsSlider();
 
+	void SetStep(float step);
+
 protected:
 
 	int ComputeResolution();
 
 	virtual void UpdateWidgetBody();
 
+	float mStep;
 	const iObjectKey *mVarKey, *mStretchKey;
 };
 
