@@ -125,12 +125,12 @@ void iggWidgetKeySlider<T>::OnVoid1Body()
 	ivmax = this->GetInternalValue(dvmax);
 	if(vmin!=ivmin || vmax!=ivmax)
 	{
-		IERROR_BREAKPOINT;
+		IERROR_HIGH("Bug: GetDisplayedValue and GetInternalValue are NOT consistent.");
 		dvmin = this->GetDisplayedValue(vmin);
 		ivmin = this->GetInternalValue(dvmin);
 		dvmax = this->GetDisplayedValue(vmax);
 		ivmax = this->GetInternalValue(dvmax);
-		IERROR_FINISH("Bug: GetDisplayedValue and GetInternalValue are NOT consistent.");
+		IERROR_FATAL("Bug: GetDisplayedValue and GetInternalValue are NOT consistent.");
 	}
 #endif
 }
