@@ -58,7 +58,7 @@ iggWidgetKeyTrackBall::iggWidgetKeyTrackBall(const iObjectKey &dirkey, bool foll
 {
 	if(this->GetKey().Argument()!=iObjectKey::_Float || this->GetKey().Dimension()<2 || this->GetKey().Dimension()>3)
 	{
-		IERROR_REPORT("Widget iggWidgetKeyTrackBall is congifured incorrectly.");
+		IERROR_LOW("Widget iggWidgetKeyTrackBall is congifured incorrectly.");
 	}
 
 	mIsVectorKey = (this->GetKey().Dimension() == 3);
@@ -123,8 +123,8 @@ void iggWidgetKeyTrackBall::OnBool1Body(bool final)
 		this->GetShell()->GetControlModule()->PackCommand(ws,this->GetKey(),a,2);
 	}
 
-	bool ret = this->GetShell()->GetControlModule()->Execute(ws,final || this->GetRenderMode()==_RenderModeImmediate,this->GetExecuteFlags());
-	if(!ret) IERROR_REPORT("iggWidgetKeyTrackBall::OnDirection failed.");
+	bool ret = this->GetShell()->GetControlModule()->Execute(ws,(final || this->GetRenderMode()==_RenderModeImmediate) && this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
+	if(!ret) IERROR_LOW("iggWidgetKeyTrackBall::OnDirection failed.");
 }
 
 
