@@ -239,7 +239,13 @@ iggWidgetSimpleCheckBox::iggWidgetSimpleCheckBox(const iString &title, iggFrame
 }
 
 
-bool iggWidgetSimpleCheckBox::IsDown() const
+void iggWidgetSimpleCheckBox::SetChecked(bool s)
+{
+	mSubject->SetDown(s);
+}
+
+
+bool iggWidgetSimpleCheckBox::IsChecked() const
 {
 	return mSubject->IsDown();
 }
