@@ -69,7 +69,7 @@ iggWidgetShowButton::iggWidgetShowButton(const iObjectType &type, iggFrame *pare
 
 void iggWidgetShowButton::OnVoid1Body()
 {
-	this->GetShell()->GetControlModule()->Show(mType,mSubject->IsDown());
+	this->GetShell()->GetControlModule()->Show(mType,mSubject->IsDown(),true);
 	this->GetMainWindow()->UpdateAll();
 }
 
@@ -175,15 +175,14 @@ void iggWidgetAllInstancesCheckBox::OnVoid1Body()
 {
 	int i, ef;
 
-	ef = iggWidgetKeyHandlerBase::GetGlobalExecuteFlags();
-	if(ef == 0) ef = _ObjectModeCurrent|_ModuleModeCurrent|_RenderModeAuto;
+	ef = _DefaultOption;
 	if(mSubject->IsDown())
 	{
 		//
 		//  Unset the object mode flag
 		//
-		ef &= (~_ObjectModeMask);
-		ef |= _ObjectModeAll;
+		ef &= (~_ObjectOptionMask);
+		ef |= _ObjectOptionAll;
 	}
 
 	iggWidgetKeyHandlerBase *kh;
