@@ -61,7 +61,7 @@ iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *pa
 	mReadyIcon = iImageFactory::FindIcon("ready.png");
 	if(mDelayIcon==0 || mReadyIcon==0)
 	{
-		IERROR_REPORT("Icon images are not found.");
+		IERROR_LOW("Icon images are not found.");
 	}
 	if(registered) List().AddUnique(this);
 
@@ -100,7 +100,7 @@ void iggWidgetRenderModeButton::UpdateWidgetBody()
 		}
 	default:
 		{
-			IERROR_REPORT("iggWidgetRenderModeButton should only be used with rendering widgets.");
+			IERROR_LOW("iggWidgetRenderModeButton should only be used with rendering widgets.");
 		}
 	}
 }
@@ -122,7 +122,7 @@ void iggWidgetRenderModeButton::OnVoid1Body()
 		}
 	default:
 		{
-			IERROR_REPORT("iggWidgetRenderModeButton should only be used with rendering widgets.");
+			IERROR_LOW("iggWidgetRenderModeButton should only be used with rendering widgets.");
 		}
 	}
 	this->UpdateWidget();
