@@ -172,7 +172,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 	{
 		iString ws;
 		if(!mSubject->AppendBreaksLine()) ws = "<br>";
-		if(!prefix.IsEmpty())
+		if(!prefix.IsEmpty() && prefix!="\t")
 		{
 			ws += "<font color=\"#" + iString::FromNumber(prefixcolor.Red(),"%02X") + iString::FromNumber(prefixcolor.Green(),"%02X") + iString::FromNumber(prefixcolor.Blue(),"%02X") + "\">";
 			if(prefixbold) ws += "<b>";
@@ -185,6 +185,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 		}
 		else
 		{
+			if(prefix == "\t") ws += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"; 
 			ws += "<font color=\"#" + iString::FromNumber(color.Red(),"%02X") + iString::FromNumber(color.Green(),"%02X") + iString::FromNumber(color.Blue(),"%02X") + "\">";
 		}
 		ws += text + "</font>";
@@ -192,16 +193,19 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 	}
 	else
 	{
-		if(prefix.IsEmpty())
+		if(prefix.IsEmpty() || prefix=="\t")
 		{
+			iString ws;
+			if(prefix == "\t") ws += "        ";
+			ws += text;
 			mSubject->SetTextColor(color);
 			if(mSubject->AppendBreaksLine())
 			{
-				mSubject->AppendText(text);
+				mSubject->AppendText(ws);
 			}
 			else
 			{
-				mSubject->AppendText(text+"\n");
+				mSubject->AppendText(ws+"\n");
 			}
 		}
 		else
@@ -318,7 +322,7 @@ void iggWidgetListView::OnCursorPositionChanged(int para, int /*index*/)
 //
 //  iggWidgetHelpBrowser class
 //
-iggWidgetHelpBrowser::iggWidgetHelpBrowser(iggFrame *parent) : iggWidgetTextBrowser(true,false,parent), mVisitedTags(iString(),30)
+iggWidgetHelpBrowser::iggWidgetHelpBrowser(iggFrame *parent) : iggWidgetTextBrowser(true,false,parent)
 {
 	mHTMLSubject = iggSubjectFactory::CreateWidgetHelpBrowserSubject(this);
 	
@@ -366,7 +370,7 @@ void iggWidgetHelpBrowser::SetContentsText(const iString &text)
 			}
 			else
 			{
-				IERROR_REPORT(("Missing image "+name).ToCharPointer());
+				IERROR_LOW(("Missing image "+name).ToCharPointer());
 			}
 			i = tmp.Find("\"images::");
 		}
