@@ -35,8 +35,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframe.h"
 #include "iggmainwindow.h"
 
-#include "iqtassistant.h"
 #include "iqtframesubject.h"
+#include "iqthelper.h"
 #include "iqtmainwindowsubject.h"
 #include "iqtwindowhelper.h"
 
@@ -62,16 +62,16 @@ using namespace iggParameter;
 //
 iqtDialogSubject::iqtDialogSubject(iggDialog *owner, const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title) : 
 #ifdef IQT_3
-	QDialog((mode&_DialogUnattached)?0:iPointerCast<iqtWindowHelper,ibgWindowHelper>(base->GetHelper())->GetWidget(),"",false,iqtAssistant::GetFlags(iqtAssistant::_Dialog,mode)), 
+	QDialog((mode&_DialogUnattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),"",false,iqtHelper::GetFlags(iqtHelper::_Dialog,mode)), 
 #else
-	QDialog((mode&_DialogUnattached)?0:iPointerCast<iqtWindowHelper,ibgWindowHelper>(base->GetHelper())->GetWidget(),iqtAssistant::GetFlags(iqtAssistant::_Dialog,mode)), 
+	QDialog((mode&_DialogUnattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),iqtHelper::GetFlags(iqtHelper::_Dialog,mode)), 
 #endif
 	ibgDialogSubject(owner,base,mode,icon,title)
 {
 	mWindowHelper = new iqtWindowHelper(this,icon,title); IERROR_ASSERT(mWindowHelper);
 
 	mMode = mode;
-	QGridLayout *layout = iqtAssistant::NewLayout(this,1);
+	QGridLayout *layout = iqtHelper::NewLayout(this,1);
 
 	if((mode & _DialogBlocking) == 0) this->setSizeGripEnabled(true); else
 	{
@@ -82,7 +82,7 @@ iqtDialogSubject::iqtDialogSubject(iggDialog *owner, const ibgWindowSubject *bas
 	if((mode & _DialogNoTitleBar) != 0)
 	{
 		this->setFocusPolicy(QFocus::NoFocus);
-		iqtAssistant::SetBackground(this,0);
+		iqtHelper::SetBackground(this,0);
 	}
 }
 
@@ -112,12 +112,12 @@ void iqtDialogSubject::Show(bool s)
 
 void iqtDialogSubject::SetFrame(ibgFrameSubject *frame0)
 {
-	iqtFrameSubject *frame = iPointerCast<iqtFrameSubject,ibgFrameSubject>(frame0);
+	iqtFrameSubject *frame = iDynamicCast<iqtFrameSubject,ibgFrameSubject>(INFO,frame0);
 
 	if(frame->parentWidget() != this)
 	{
-		iqtAssistant::SetParent(frame,this);
-		iPointerCast<QGridLayout,QLayout>(this->layout())->addWidget(frame,0,0);
+		iqtHelper::SetParent(frame,this);
+		iDynamicCast<QGridLayout,QLayout>(INFO,this->layout())->addWidget(frame,0,0);
 	}
 	if((mMode & _DialogNoTitleBar) != 0)
 	{
