@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggframe.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
@@ -50,12 +50,12 @@ iqtExplicitFrameSubject::iqtExplicitFrameSubject(QWidget *qparent, iggFrame *own
 {
 	if(cols < 1)
 	{
-		IERROR_REPORT("Incorrect number of columns.");
+		IERROR_LOW("Incorrect number of columns.");
 		cols = 1;
 	}
 	if(cols > 7)
 	{
-		IERROR_REPORT("Current implementation does not support more than 7 columns.");
+		IERROR_LOW("Current implementation does not support more than 7 columns.");
 		cols = 7;
 	}
 
@@ -73,11 +73,11 @@ iqtExplicitFrameSubject::iqtExplicitFrameSubject(QWidget *qparent, iggFrame *own
 
 	if(this->layout() == 0)
 	{
-		mLayout = iqtAssistant::NewLayout(this,cols);
+		mLayout = iqtHelper::NewLayout(this,cols);
 	}
 	else
 	{
-		mLayout = iqtAssistant::NewLayout(this->layout(),cols);
+		mLayout = iqtHelper::NewLayout(this->layout(),cols);
 	}
 
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
@@ -91,7 +91,7 @@ iqtExplicitFrameSubject::~iqtExplicitFrameSubject()
 
 void iqtExplicitFrameSubject::SetTitle(const iString &title)
 {
-	this->setTitle(iqtAssistant::ConvertWithModifiers(this,title));
+	this->setTitle(iqtHelper::ConvertWithModifiers(this,title));
 	this->layout()->invalidate(); // Qt bug!!! 
 }
 
@@ -143,7 +143,7 @@ void iqtExplicitFrameSubject::SetColStretch(int col, int s)
 #ifdef IQT_3
 	if(mLayout->numCols() != mNumCols)
 	{
-		IERROR_REPORT("Corrupted layout.");
+		IERROR_LOW("Corrupted layout.");
 	}
 	if(col>=0 && col<mNumCols) mLayout->setColStretch(col,s);
 #else
@@ -157,7 +157,7 @@ void iqtExplicitFrameSubject::SetRowStretch(int row, int s)
 #ifdef IQT_3
 	if(mLayout->numRows() != mNumRows)
 	{
-		IERROR_REPORT("Corrupted layout.");
+		IERROR_LOW("Corrupted layout.");
 	}
 	if(row>=0 && row<mNumRows) mLayout->setRowStretch(row,s);
 #else
@@ -185,7 +185,7 @@ void iqtExplicitFrameSubject::PlaceWidget(int col, int row, ibgWidgetSubject *ch
 		//
 		//  First we need to reach QWidget hidden in ibgWidgetBase - well hidden too!!!
 		//
-		iqtWidgetHelper *tmp = iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(child->GetWidgetHelper());
+		iqtWidgetHelper *tmp = iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,child->GetWidgetHelper());
 #ifdef IQT_3
 		mLayout->addMultiCellWidget(tmp->GetWidget(),row,row,col,col+nc-1);
 #else
@@ -194,7 +194,7 @@ void iqtExplicitFrameSubject::PlaceWidget(int col, int row, ibgWidgetSubject *ch
 	}
 	else
 	{
-		IERROR_REPORT("Invalid layout cell.");
+		IERROR_LOW("Invalid layout cell.");
 	}
 }
 
