@@ -36,52 +36,31 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggabstractextension.h"
 #include "iggextensionwindow.h"
 
-#include "ibgframesubject.h"
-
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwindowhelper.h"
+#include "iqtframesubject.h"
 
 #ifdef IQT_3
 #include <qevent.h>
 #include <qlayout.h>
-#include <qtabwidget.h>
+#include <qstyle.h>
 #else
 #include <QtGui/QGridLayout>
 #include <QtGui/QMouseEvent>
-#include <QtGui/QTabWidget>
 #endif
 
 //
 //  Main class
 //
-iqtExtensionWindowSubject::iqtExtensionWindowSubject(iggExtensionWindow *ew, bool single) : 
+iqtExtensionWindowSubject::iqtExtensionWindowSubject(iggExtensionWindow *ew) : 
 #ifdef IQT_3
-	QWidget(0,0,iqtAssistant::GetFlags(iqtAssistant::_Extension)), 
+	QWidget(0,0,iqtHelper::GetFlags(iqtHelper::_Extension)), 
 #else
-	QWidget(0,iqtAssistant::GetFlags(iqtAssistant::_Extension)), 
+	QWidget(0,iqtHelper::GetFlags(iqtHelper::_Extension)), 
 #endif
-	ibgExtensionWindowSubject(ew,single)
+	ibgExtensionWindowSubject(ew)
 {
 	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1ext.png"),"IFrIT - Extension Window"); IERROR_ASSERT(mWindowHelper);
-
-	if(single)
-	{
-		mBase = 0;
-		mLayout = iqtAssistant::NewLayout(this,1);
-		mLayout->setMargin(ibgFrameSubject::GetPaddingWidth()*2);
-	}
-	else
-	{
-		mBase = new QTabWidget(this);
-		mLayout = iqtAssistant::NewLayout(this,1);
-		mLayout->setMargin(0);
-		mLayout->addWidget(mBase,0,0);
-#ifdef IQT_3
-		mBase->setTabPosition(QTabWidget::Bottom);
-#else
-		mBase->setTabPosition(QTabWidget::South);
-#endif
-	}
 }
 
 
@@ -90,51 +69,55 @@ iqtExtensionWindowSubject::~iqtExtensionWindowSubject()
 }
 
 
-void iqtExtensionWindowSubject::AddExtension(iggAbstractExtension *ext)
+void iqtExtensionWindowSubject::AttachPanels(iggFrame *main, iggFrame *bottom, iggFrame *left)
 {
-	if(ext != 0)
-	{
-		QWidget *w = iqtAssistant::Convert(ext); IERROR_ASSERT(w);
-#ifndef IQT_3
-		iqtAssistant::SetParent(w,0);
-#endif
-		if(mBase == 0)
-		{
+	QGridLayout *layout = iqtHelper::NewLayout(this,2);
 #ifdef IQT_3
-			iqtAssistant::SetParent(w,this);
+	layout->expand(2,2);
 #endif
-			mLayout->addWidget(w,0,0);
-		}
-		else
-		{
-			QWidget *b = new QWidget;
-			QGridLayout *l = iqtAssistant::NewLayout(b,1);
-			l->setMargin(ibgFrameSubject::GetPaddingWidth()*2);
-#ifdef IQT_3
-			iqtAssistant::SetParent(b,mBase);
-			iqtAssistant::SetParent(w,b);
-#endif
-			l->addWidget(w,0,0);
-			mBase->addTab(b,iqtAssistant::ConvertToIcon(*ext->GetIcon()),iqtAssistant::Convert(ext->GetTitle()));
-		}
-		mLayout->invalidate();
-	}
-}
 
-
-void iqtExtensionWindowSubject::SetPadding(bool s)
-{
-	if(mBase == 0)
+	iqtFrameSubject *ms = iDynamicCast<iqtFrameSubject,ibgFrameSubject>(INFO,main->GetSubject());
+	if(ms->parentWidget() != this)
 	{
-		if(s)
-		{
-			mLayout->setMargin(ibgFrameSubject::GetPaddingWidth()*2);
-		}
-		else
-		{
-			mLayout->setMargin(0);
-		}
+		iqtHelper::SetParent(ms,this);
+		layout->addWidget(ms,0,1);
 	}
+
+	iqtFrameSubject *bs = iDynamicCast<iqtFrameSubject,ibgFrameSubject>(INFO,bottom->GetSubject());
+	if(bs->parentWidget() != this)
+	{
+		iqtHelper::SetParent(bs,this);
+		layout->addWidget(bs,1,1);
+	}
+
+	iqtFrameSubject *ls = iDynamicCast<iqtFrameSubject,ibgFrameSubject>(INFO,left->GetSubject());
+	if(ls->parentWidget() != this)
+	{
+		iqtHelper::SetParent(ls,this);
+		layout->addWidget(ls,0,0);
+	}
+
+	//
+	//  Beautify
+	//
+#ifdef IQT_3
+	QFrame *f = new QFrame(ls);
+	f->setFrameStyle(QFrame::TabWidgetPanel|QFrame::Raised);
+	f->setLineWidth(f->style().pixelMetric(QStyle::PM_DefaultFrameWidth,this));
+	f->setMinimumWidth(2*f->lineWidth()+1);
+	ls->GetLayout()->addMultiCellWidget(f,0,ls->GetLayout()->numRows()-1,1,1);
+#else
+	bs->setMinimumHeight(35);
+#endif
+
+	layout->setRowStretch(0,10);
+	layout->setRowStretch(1,0);
+#ifdef IQT_3
+	layout->setColStretch(1,10);
+#else
+	layout->setColumnStretch(1,10);
+#endif
+	layout->invalidate();
 }
 
 
@@ -157,4 +140,5 @@ bool iqtExtensionWindowSubject::event(QEvent *e)
 void iqtExtensionWindowSubject::closeEvent(QCloseEvent *e)
 {
 	e->ignore();
+	mExtensionWindow->OnCloseAttempt();
 }
