@@ -34,13 +34,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggframe.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
 #include <qimage.h>
 #include <qlayout.h>
+#include <qobjectlist.h> 
 #else
+#include <QtCore/QEvent>
 #include <QtGui/QImage>
 #include <QtGui/QLayout>
 #include <QtGui/QScrollBar>
@@ -54,7 +56,7 @@ using namespace iggParameter;
 //
 //  Plain Frame class
 //
-iqtFrameSubject::iqtFrameSubject(iggFrame *owner, int cols) : iqtExplicitFrameSubject(iqtAssistant::Convert(owner->GetParent()),owner,cols)
+iqtFrameSubject::iqtFrameSubject(iggFrame *owner, int cols) : iqtExplicitFrameSubject(iqtHelper::Convert(owner->GetParent()),owner,cols)
 {
 }
 
@@ -67,7 +69,7 @@ iqtFrameSubject::~iqtFrameSubject()
 //
 //  FrameBook class
 //
-iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback) : QTabWidget(iqtAssistant::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback)
+iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop) : QTabWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback,tabsOnTop)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -79,12 +81,29 @@ iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback)
 #endif
 #endif
 
+	if(tabsOnTop)
+	{
+#ifdef IQT_3
+		this->setTabPosition(QTabWidget::Top);
+#else
+		this->setTabPosition(QTabWidget::North);
+#endif
+	}
+	else
+	{
+#ifdef IQT_3
+		this->setTabPosition(QTabWidget::Bottom);
+#else
+		this->setTabPosition(QTabWidget::South);
+#endif
+	}
+
 	if(withFeedback)
 	{
 #ifdef IQT_3
-		if(!this->connect(this,SIGNAL(currentChanged(QWidget*)),this,SLOT(OnCurrentChanged(QWidget*)))) IERROR_REPORT("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(QWidget * )),this,SLOT(OnCurrentChanged(QWidget * )))) IERROR_LOW("Missed connection.");
 #else
-		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IERROR_REPORT("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IERROR_LOW("Missed connection.");
 #endif
 	}
 }
@@ -108,41 +127,41 @@ iqtFrameBookSubject::~iqtFrameBookSubject()
 
 void iqtFrameBookSubject::OnCurrentChanged(QWidget *w)
 {
-	iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnInt1(this->indexOf(w));
+	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnInt1(this->indexOf(w));
 }
 
 
 void iqtFrameBookSubject::OnCurrentChanged(int v)
 {
-	iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnInt1(v);
+	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnInt1(v);
 }
 
 
 void iqtFrameBookSubject::OpenPage(int i)
 {
-	this->blockSignals(true);
+//	this->blockSignals(true);
 #ifdef IQT_3
 	this->setCurrentPage(i);
 #else
 	this->setCurrentIndex(i);
 #endif
-	this->blockSignals(false);
+//	this->blockSignals(false);
 }
 
 
 void iqtFrameBookSubject::AddPage(const iString &title, const iImage *image, iggFrame *frame)
 {
-	QWidget *w = iqtAssistant::Convert(frame); IERROR_ASSERT(w);
+	QWidget *w = iqtHelper::Convert(frame); IERROR_ASSERT(w);
 #ifndef IQT_3
-	iqtAssistant::SetParent(w,0);
+	iqtHelper::SetParent(w,0);
 #endif
 	if(image == 0)
 	{
-		this->addTab(w,iqtAssistant::ConvertWithModifiers(this,title));
+		this->addTab(w,iqtHelper::ConvertWithModifiers(this,title));
 	}
 	else
 	{
-		this->addTab(w,iqtAssistant::ConvertToIcon(*image),iqtAssistant::ConvertWithModifiers(this,title));
+		this->addTab(w,iqtHelper::ConvertToIcon(*image),iqtHelper::ConvertWithModifiers(this,title));
 	}
 	if(this->parentWidget()!=0 && this->parentWidget()->layout()!=0)
 	{
@@ -161,10 +180,10 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 			if(image != 0)
 			{
 #ifdef IQT_3
-				this->changeTab(this->page(n),iqtAssistant::ConvertToIcon(*image),QString());
+				this->changeTab(this->page(n),iqtHelper::ConvertToIcon(*image),QString());
 #else
 				this->setTabText(n,QString());
-				this->setTabIcon(n,iqtAssistant::ConvertToIcon(*image));
+				this->setTabIcon(n,iqtHelper::ConvertToIcon(*image));
 #endif
 			}
 			break;
@@ -172,9 +191,9 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 	case _BookTitleOnly:
 		{
 #ifdef IQT_3
-			this->changeTab(this->page(n),QIconSet(),iqtAssistant::ConvertWithModifiers(this,title));
+			this->changeTab(this->page(n),QIconSet(),iqtHelper::ConvertWithModifiers(this,title));
 #else
-			this->setTabText(n,iqtAssistant::ConvertWithModifiers(this,title));
+			this->setTabText(n,iqtHelper::ConvertWithModifiers(this,title));
 			this->setTabIcon(n,QIcon());
 #endif
 			break;
@@ -184,18 +203,18 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 			if(image != 0)
 			{
 #ifdef IQT_3
-				this->changeTab(this->page(n),iqtAssistant::ConvertToIcon(*image),iqtAssistant::ConvertWithModifiers(this,title));
+				this->changeTab(this->page(n),iqtHelper::ConvertToIcon(*image),iqtHelper::ConvertWithModifiers(this,title));
 #else
-				this->setTabText(n,iqtAssistant::ConvertWithModifiers(this,title));
-				this->setTabIcon(n,iqtAssistant::ConvertToIcon(*image));
+				this->setTabText(n,iqtHelper::ConvertWithModifiers(this,title));
+				this->setTabIcon(n,iqtHelper::ConvertToIcon(*image));
 #endif
 			}
 			else
 			{
 #ifdef IQT_3
-				this->changeTab(this->page(n),iqtAssistant::ConvertWithModifiers(this,title));
+				this->changeTab(this->page(n),iqtHelper::ConvertWithModifiers(this,title));
 #else
-				this->setTabText(n,iqtAssistant::ConvertWithModifiers(this,title));
+				this->setTabText(n,iqtHelper::ConvertWithModifiers(this,title));
 				this->setTabIcon(n,QIcon());
 #endif
 			}
@@ -227,11 +246,11 @@ void iqtFrameBookSubject::ChangeIcon(int n, const iImage &image)
 #ifdef IQT_3
 		!this->tabIconSet(this->page(n)).isNull())
 	{
-		this->setTabIconSet(this->page(n),iqtAssistant::ConvertToIcon(image));
+		this->setTabIconSet(this->page(n),iqtHelper::ConvertToIcon(image));
 #else
 		!this->tabIcon(n).isNull())
 	{
-		this->setTabIcon(n,iqtAssistant::ConvertToIcon(image));
+		this->setTabIcon(n,iqtHelper::ConvertToIcon(image));
 #endif
 	}
 }
@@ -240,7 +259,7 @@ void iqtFrameBookSubject::ChangeIcon(int n, const iImage &image)
 //
 //  FrameFlip class
 //
-iqtFrameFlipSubject::iqtFrameFlipSubject(iggFrameFlip *owner, bool expanding) : QStackedWidget(iqtAssistant::Convert(owner->GetParent())), ibgFrameFlipSubject(owner,expanding)
+iqtFrameFlipSubject::iqtFrameFlipSubject(iggFrameFlip *owner, bool expanding) : QStackedWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameFlipSubject(owner,expanding)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -274,9 +293,9 @@ void iqtFrameFlipSubject::ShowLayer(int i)
 void iqtFrameFlipSubject::AddLayerBody(iggFrame *page)
 {
 #ifdef IQT_3
-	this->addWidget(iqtAssistant::Convert(page),mCount);
+	this->addWidget(iqtHelper::Convert(page),mCount);
 #else
-	this->addWidget(iqtAssistant::Convert(page));
+	this->addWidget(iqtHelper::Convert(page));
 	mCount = this->count();
 #endif
 	if(this->parentWidget()!=0 && this->parentWidget()->layout()!=0)
@@ -290,16 +309,16 @@ void iqtFrameFlipSubject::AddLayerBody(iggFrame *page)
 //
 //  FrameScroll class
 //
-iqtFrameScrollSubject::iqtFrameScrollSubject(iggFrameScroll *owner, bool withHor) : QScrollArea(iqtAssistant::Convert(owner->GetParent())), ibgFrameScrollSubject(owner,withHor)
+iqtFrameScrollSubject::iqtFrameScrollSubject(iggFrameScroll *owner, bool withHor, bool withVer) : QScrollArea(iqtHelper::Convert(owner->GetParent())), ibgFrameScrollSubject(owner,withHor)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 #ifdef IQT_3
-	this->setVScrollBarMode(QScrollView::Auto);
+	this->setVScrollBarMode(withVer?QScrollView::Auto:QScrollView::AlwaysOff);
 	this->setHScrollBarMode(withHor?QScrollView::Auto:QScrollView::AlwaysOff);
 	this->setResizePolicy(QScrollView::AutoOneFit);
 #else
-	this->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+	this->setVerticalScrollBarPolicy(withVer?Qt::ScrollBarAsNeeded:Qt::ScrollBarAlwaysOff);
 	this->setHorizontalScrollBarPolicy(withHor?Qt::ScrollBarAsNeeded:Qt::ScrollBarAlwaysOff);
 	this->setWidgetResizable(true);
 #endif
@@ -316,7 +335,7 @@ void iqtFrameScrollSubject::AttachContents(iggFrame *frame)
 	if(this->viewport()->children().count() == 0)
 #endif
 	{
-		iqtFrameSubject *f = iPointerCast<iqtFrameSubject,ibgFrameSubject>(frame->GetSubject());
+		iqtFrameSubject *f = iDynamicCast<iqtFrameSubject,ibgFrameSubject>(INFO,frame->GetSubject());
 #ifdef IQT_3
 		f->reparent(this->viewport(),QPoint(0,0));
 		this->addChild(f);
@@ -330,31 +349,46 @@ void iqtFrameScrollSubject::AttachContents(iggFrame *frame)
 //
 //  Qt-specific
 //
-void iqtFrameScrollSubject::paintEvent(QPaintEvent *e)
+bool iqtFrameScrollSubject::event(QEvent *e)
 {
 	//
 	//  Remove the frame if the contents fits in full
 	//
-	if(this->verticalScrollBar()->isVisible())
-	{
-		if(this->frameShape() != QFrame::Panel)
-		{
-			this->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-			iqtAssistant::SetBackground(this,0);
-		}
-	}
-	else
-	{
-		if(this->frameShape() != QFrame::NoFrame)
-		{
-			this->setFrameStyle(QFrame::NoFrame);
-#ifdef IQT_3
-			this->unsetPalette();
-#else
-			this->setPalette(QPalette());
+	if(e!=0 && (
+#ifndef IQT_3
+		e->type()==QEvent::LayoutRequest || 
 #endif
+		e->type()==QEvent::Paint))
+	{
+		if(this->verticalScrollBar()->isVisible())
+		{
+			if(this->frameShape() != QFrame::Panel)
+			{
+				this->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+				iqtHelper::SetBackground(this,0);
+			}
+		}
+		else
+		{
+			if(this->frameShape() != QFrame::NoFrame)
+			{
+				this->setFrameStyle(QFrame::NoFrame);
+#ifdef IQT_3
+				this->unsetPalette();
+#else
+				this->setPalette(QPalette());
+#endif
+			}
 		}
 	}
-	QScrollArea::paintEvent(e);
+	return QScrollArea::event(e);
 }
 
+
+#ifndef IQT_3
+QSize iqtFrameScrollSubject::sizeHint() const
+{
+	return this->QAbstractScrollArea::sizeHint();
+}
+#endif
+
