@@ -44,9 +44,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwindowhelper.h"
 
-#include "iqtassistant.h"
 #include "iqtextensionwindowsubject.h"
 #include "iqtframesubject.h"
+#include "iqthelper.h"
 #include "iqtrenderwindowsubject.h"
 #include "iqtwidgetprogressbarsubject.h"
 
@@ -144,7 +144,7 @@ iqtMainWindowSubject::iqtMainWindowSubject(iggMainWindow *owner) : iqtMenuWindow
 	//  Available themes
 	//
 	QStringList l = QStyleFactory::keys();
-	for(i=0; i<(int)l.count(); i++) mMainWindow->AddTheme(iqtAssistant::Convert(l[i]));
+	for(i=0; i<(int)l.count(); i++) mMainWindow->AddTheme(iqtHelper::Convert(l[i]));
 }
 
 
@@ -162,17 +162,17 @@ void iqtMainWindowSubject::SetTopParentSubjects(iggFrameTopParent *busyIndicator
 
 void iqtMainWindowSubject::PopulateStatusBar(iggFrame *busyIndicatorFrame, ibgWidgetProgressBarSubject *progressBarSubject, iggFrame *visitedFileListFrame)
 {
-	iqtWidgetProgressBarSubject *pb = iPointerCast<iqtWidgetProgressBarSubject,ibgWidgetProgressBarSubject>(progressBarSubject);
-	iqtAssistant::SetParent(pb,this->statusBar());
+	iqtWidgetProgressBarSubject *pb = iDynamicCast<iqtWidgetProgressBarSubject,ibgWidgetProgressBarSubject>(INFO,progressBarSubject);
+	iqtHelper::SetParent(pb,this->statusBar());
 
 #ifdef IQT_3
-	this->statusBar()->addWidget(iqtAssistant::Convert(busyIndicatorFrame),0,true);
+	this->statusBar()->addWidget(iqtHelper::Convert(busyIndicatorFrame),0,true);
 	this->statusBar()->addWidget(pb,2,true);
-    this->statusBar()->addWidget(iqtAssistant::Convert(visitedFileListFrame),3,true);
+    this->statusBar()->addWidget(iqtHelper::Convert(visitedFileListFrame),3,true);
 #else
-	this->statusBar()->addWidget(iqtAssistant::Convert(busyIndicatorFrame),0);
+	this->statusBar()->addWidget(iqtHelper::Convert(busyIndicatorFrame),0);
 	this->statusBar()->addWidget(pb,2);
-    this->statusBar()->addWidget(iqtAssistant::Convert(visitedFileListFrame),3);
+    this->statusBar()->addWidget(iqtHelper::Convert(visitedFileListFrame),3);
 #endif
 }
 
@@ -182,30 +182,46 @@ int iqtMainWindowSubject::PopupWindow(const iggFrame *parent, const iString &tex
 	QWidget *w;
 	if(parent != 0)
 	{
-		w = iqtAssistant::Convert(parent);
+		w = iqtHelper::Convert(parent);
 	}
 	else
 	{
 		w = this;
 	}
+	
+	return PopupWindowBody(w,text,type,b0,b1,b2);
+}
 
+
+int iqtMainWindowSubject::PopupWindow(const iggRenderWindow *parent, const iString &text, int type, const char *b0, const char *b1, const char *b2)
+{
+	if(parent != 0)
+	{
+		return PopupWindowBody(iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,parent->GetSubject()),text,type,b0,b1,b2);
+	}
+	else return -1;
+}
+
+
+int iqtMainWindowSubject::PopupWindowBody(QWidget *w, const iString &text, int type, const char *b0, const char *b1, const char *b2)
+{
 	switch(type)
 	{
 	case _PopupWindowMessage:
 		{
-			return QMessageBox::information(w,"IFrIT",iqtAssistant::Convert(text),b0,b1,b2);
+			return QMessageBox::information(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
 		}
 	case _PopupWindowWarning:
 		{
-			return QMessageBox::warning(w,"IFrIT",iqtAssistant::Convert(text),b0,b1,b2);
+			return QMessageBox::warning(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
 		}
 	case _PopupWindowError:
 		{
-			return QMessageBox::critical(w,"IFrIT",iqtAssistant::Convert(text),b0,b1,b2);
+			return QMessageBox::critical(w,"IFrIT",iqtHelper::Convert(text),b0,b1,b2);
 		}
 	default:
 		{
-			IERROR_REPORT("Incorrect type for pop-up window.");
+			IERROR_LOW("Incorrect type for pop-up window.");
 		}
 	}
 	return -1;
@@ -222,7 +238,7 @@ void iqtMainWindowSubject::ShowToolTips(bool s)
 
 void iqtMainWindowSubject::SetTheme(const iString &name)
 {
-	qApp->setStyle(iqtAssistant::Convert(name));
+	qApp->setStyle(iqtHelper::Convert(name));
 }
 
 
@@ -233,7 +249,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 {
 	if(mMainFrame != 0)
 	{
-		IERROR_FINISH("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
+		IERROR_FATAL("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
 	}
 
 	QSize s = this->size();
@@ -243,7 +259,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	mMainFrame = this->centralWidget();
 
 	QWidget *base = new QWidget(this);
-	QGridLayout *l = iqtAssistant::NewLayout(base,2); IERROR_ASSERT(l);
+	QGridLayout *l = iqtHelper::NewLayout(base,2); IERROR_ASSERT(l);
 #ifdef IQT_3
 	l->expand(2,2);
 	l->setColStretch(0,10);
@@ -259,7 +275,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	fw->setLineWidth(3);
 	fw->setFrameStyle(QFrame::Panel|QFrame::Sunken);
 
-	QGridLayout *fl = iqtAssistant::NewLayout(fw,1);
+	QGridLayout *fl = iqtHelper::NewLayout(fw,1);
 
     Workspace *ws = new Workspace(fw); IERROR_ASSERT(ws);
 	fl->addWidget(ws,0,0);
@@ -269,14 +285,14 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	//
 	//  Attach extension
 	//
-	iqtExtensionWindowSubject *ext = iPointerCast<iqtExtensionWindowSubject,ibgExtensionWindowSubject>(mMainWindow->GetExtensionWindow()->GetSubject());
-	iqtAssistant::SetParent(ext,base,0);
+	iqtExtensionWindowSubject *ext = iDynamicCast<iqtExtensionWindowSubject,ibgExtensionWindowSubject>(INFO,mMainWindow->GetExtensionWindow()->GetSubject());
+	iqtHelper::SetParent(ext,base,0);
 	l->addWidget(ext,1,0);
 
 	//
 	//  Attach global frame
 	//
-	iqtAssistant::SetParent(mMainFrame,base);
+	iqtHelper::SetParent(mMainFrame,base);
 #ifdef IQT_3
 	l->addMultiCellWidget(mMainFrame,0,1,1,1);
 #else
@@ -288,7 +304,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	//
 	FOR_EVERY_RENDER_WINDOW(w)
 	{
-		ws->AddWindow(iPointerCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(w->GetSubject()));
+		ws->AddWindow(iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject()));
 	}
 
 	this->setCentralWidget(base);
@@ -305,7 +321,7 @@ void iqtMainWindowSubject::RestoreWindowsFromDockedPositions()
 {
 	if(mMainFrame == 0)
 	{
-		IERROR_FINISH("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
+		IERROR_FATAL("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
 	}
 
 	this->hide();
@@ -317,24 +333,25 @@ void iqtMainWindowSubject::RestoreWindowsFromDockedPositions()
 	//
 	FOR_EVERY_RENDER_WINDOW(w)
 	{
-		iPointerCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(w->GetSubject())->AttachToParent(0);
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->showNormal();
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->AttachToParent(0);
 #ifdef IQT_3
-		iPointerCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(w->GetSubject())->setIcon(iqtAssistant::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setIcon(iqtHelper::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
 #else
-		iPointerCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(w->GetSubject())->setWindowIcon(iqtAssistant::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
+		iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,w->GetSubject())->setWindowIcon(iqtHelper::ConvertToPixmap(*iImageFactory::FindIcon("genie1vtk.png")));
 #endif
 	}
 
 	//
 	//  Detach extension
 	//
-	iqtExtensionWindowSubject *ext = iPointerCast<iqtExtensionWindowSubject,ibgExtensionWindowSubject>(mMainWindow->GetExtensionWindow()->GetSubject());
-	iqtAssistant::SetParent(ext,0,iqtAssistant::GetFlags(iqtAssistant::_Extension));
+	iqtExtensionWindowSubject *ext = iDynamicCast<iqtExtensionWindowSubject,ibgExtensionWindowSubject>(INFO,mMainWindow->GetExtensionWindow()->GetSubject());
+	iqtHelper::SetParent(ext,0,iqtHelper::GetFlags(iqtHelper::_Extension));
 
 	//
 	//  Re-attach main window
 	//
-	iqtAssistant::SetParent(mMainFrame,this);
+	iqtHelper::SetParent(mMainFrame,this);
 
 	this->setCentralWidget(mMainFrame);
 
@@ -357,8 +374,8 @@ void iqtMainWindowSubject::AttachRenderWindow(iggRenderWindow *rw)
 {
 	if(rw==0 || mDockingWorkspace==0) return;
 
-	iqtRenderWindowSubject *s = iPointerCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(rw->GetSubject());
-	Workspace *ws = iPointerCast<Workspace,QWorkspace>(mDockingWorkspace);
+	iqtRenderWindowSubject *s = iDynamicCast<iqtRenderWindowSubject,ibgRenderWindowSubject>(INFO,rw->GetSubject());
+	Workspace *ws = iDynamicCast<Workspace,QWorkspace>(INFO,mDockingWorkspace);
 
 	if(mMainWindow->IsDocked())
 	{
@@ -380,7 +397,7 @@ bool iqtMainWindowSubject::event(QEvent *e)
 		if(e->type() == QEvent::Shortcut)
 #endif
 		{
-			QKeyEvent *ke = (QKeyEvent*)e;
+			QKeyEvent *ke = static_cast<QKeyEvent*>(e);
 			if(ke->key()==Qt::Key_F1 && 
 #ifdef IQT_3
 				ke->state()==Qt::ShiftButton
@@ -406,7 +423,7 @@ void iqtMainWindowSubject::moveEvent(QMoveEvent *e)
 {
 	if(e != 0)
 	{
-		mMainWindow->MoveWindows((QCursor::pos().x()>this->x()+this->width()/10));
+		mMainWindow->MoveWindows(QCursor::pos().x()>(this->x()+this->width()/10) && QCursor::pos().x()<(this->x()+this->width()) && QCursor::pos().y()>this->y() && QCursor::pos().y()<(this->y()+this->height()));
 	}
 	QMainWindow::moveEvent(e);
 }
