@@ -36,14 +36,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframetopparent.h"
 #include "iggmenuwindow.h"
 
-#include "iqtassistant.h"
 #include "iqtexplicitframesubject.h"
+#include "iqthelper.h"
 #include "iqtwindowhelper.h"
 
 #ifdef IQT_3
 #include <qfiledialog.h>
 #include <qmenubar.h>
 #include <qtoolbar.h>
+#include <qtoolbutton.h>
 #include <qwhatsthis.h>
 #else
 #include <QtCore/QEvent>
@@ -51,6 +52,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QFileDialog>
 #include <QtGui/QMenuBar>
 #include <QtGui/QToolBar>
+#include <QtGui/QToolButton>
 #include <QtGui/QWhatsThis>
 #endif
 
@@ -72,7 +74,7 @@ iqtMenuItem::iqtMenuItem(int id, iqtMenuWindowSubject *subject, const iObjectKey
 
 	if(mEnableKey!=0 && mEnableKey->Argument()!=iObjectKey::_Bool)
 	{
-		IERROR_FINISH("Incorrectly configured iqtMenuItem");
+		IERROR_FATAL("Incorrectly configured iqtMenuItem");
 	}
 
 	if(mValueKey!=0 && !((mValueKey->Argument()==iObjectKey::_Bool && mValue==iMath::_IntMax) || (mValueKey->Argument()==iObjectKey::_Int && mValue<iMath::_IntMax)) && 
@@ -83,7 +85,7 @@ iqtMenuItem::iqtMenuItem(int id, iqtMenuWindowSubject *subject, const iObjectKey
 #endif
 		)
 	{
-		IERROR_FINISH("Incorrectly configured iqtMenuItem");
+		IERROR_FATAL("Incorrectly configured iqtMenuItem");
 	}
 
 #ifdef IQT_3
@@ -132,7 +134,7 @@ void iqtMenuItem::Update()
 			}
 		default:
 			{
-				IERROR_FINISH("Incorrectly configured iqtMenuItem");
+				IERROR_FATAL("Incorrectly configured iqtMenuItem");
 			}
 		}
 		this->blockSignals(true);
@@ -168,9 +170,9 @@ iqtMenu::iqtMenu(iqtMenuWindowSubject *subject, const iString &text, bool exclus
 	mParent = 0;
 	this->Define(exclusive);
 #ifdef IQT_3
-	subject->menuBar()->insertItem(iqtAssistant::Convert(text),this);
+	subject->menuBar()->insertItem(iqtHelper::Convert(text),this);
 #else
-	this->setTitle(iqtAssistant::Convert(text));
+	this->setTitle(iqtHelper::Convert(text));
 	subject->menuBar()->addMenu(this);
 #endif
 }
@@ -183,9 +185,9 @@ iqtMenu::iqtMenu(iqtMenu *parent, const iString &text, bool exclusive) : QMenu(p
 	mParent = parent;
 	this->Define(exclusive);
 #ifdef IQT_3
-	parent->insertItem(iqtAssistant::Convert(text),this);
+	parent->insertItem(iqtHelper::Convert(text),this);
 #else
-	this->setTitle(iqtAssistant::Convert(text));
+	this->setTitle(iqtHelper::Convert(text));
 	parent->addMenu(this);
 #endif
 }
@@ -230,11 +232,11 @@ void iqtMenu::AddSeparator()
 //
 iqtMenuWindowSubject::iqtMenuWindowSubject(iggMenuWindow *owner, const iImage *icon, const iString &title) : 
 #ifdef IQT_3
-	QMainWindow(0,0,iqtAssistant::GetFlags(iqtAssistant::_MainWindow)), 
+	QMainWindow(0,0,iqtHelper::GetFlags(iqtHelper::_MainWindow)), 
 #else
-	QMainWindow(0,iqtAssistant::GetFlags(iqtAssistant::_MainWindow)), 
+	QMainWindow(0,iqtHelper::GetFlags(iqtHelper::_MainWindow)), 
 #endif
-	ibgMenuWindowSubject(owner,icon,title), mMenuItems(0), mToolBarButtons(0)
+	ibgMenuWindowSubject(owner,icon,title)
 {
 	mWindowHelper = new iqtWindowHelper(this,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_ASSERT(mWindowHelper);
 	mCurrentMenu = 0;
@@ -250,7 +252,12 @@ iqtMenuWindowSubject::iqtMenuWindowSubject(iggMenuWindow *owner, const iImage *i
 
 //	mToolbar->setAcceptDrops(true);  //  add dynamic toolbar later?
 
-	iqtAssistant::SetBackground(this->menuBar(),2);
+	iqtHelper::SetBackground(this->menuBar(),2);
+}
+
+
+iqtMenuWindowSubject::~iqtMenuWindowSubject()
+{
 }
 
 
@@ -273,9 +280,9 @@ void iqtMenuWindowSubject::SetToolBarIcon(int id, const iImage &icon)
 	for(i=0; i<n; i++) if(mToolBarButtons[i]->GetId() == id)
 	{
 #ifdef IQT_3
-		mToolBarButtons[i]->setIconSet(iqtAssistant::ConvertToIcon(icon));
+		mToolBarButtons[i]->setIconSet(iqtHelper::ConvertToIcon(icon));
 #else
-		mToolBarButtons[i]->setIcon(iqtAssistant::ConvertToIcon(icon));
+		mToolBarButtons[i]->setIcon(iqtHelper::ConvertToIcon(icon));
 #endif
 		return;
 	}
@@ -300,7 +307,7 @@ void iqtMenuWindowSubject::UpdateMenus()
 }
 
 
-iString iqtMenuWindowSubject::GetFileName(const iString &header, const iString &file, const iString &selection, bool onlyexisting)
+iString iqtMenuWindowSubject::GetFileName(const iString &header, const iString &file, const iString &selection, bool reading)
 {
 	static QFileDialog *fd = new QFileDialog(this);  // only one is needed, as it is modal
 	static bool generic = false;
@@ -309,7 +316,7 @@ iString iqtMenuWindowSubject::GetFileName(const iString &header, const iString &
 	if(generic)
 	{
 		IERROR_ASSERT(fd);
-		if(onlyexisting)
+		if(reading)
 		{
 #ifdef IQT_3
 			fd->setMode(QFileDialog::ExistingFile);
@@ -326,52 +333,52 @@ iString iqtMenuWindowSubject::GetFileName(const iString &header, const iString &
 #endif
 		}
 #ifdef IQT_3
-		fd->setCaption(iqtAssistant::Convert(header));
+		fd->setCaption(iqtHelper::Convert(header));
 #else
-		fd->setWindowTitle(iqtAssistant::Convert(header));
+		fd->setWindowTitle(iqtHelper::Convert(header));
 #endif
-		fd->setFilter(iqtAssistant::Convert(selection));
+		fd->setFilter(iqtHelper::Convert(selection));
 		if(!file.IsEmpty())
 		{
 #ifdef IQT_3
-			fd->setSelection(iqtAssistant::Convert(file));
+			fd->setSelection(iqtHelper::Convert(file));
 #else
-			fd->selectFile(iqtAssistant::Convert(file));
+			fd->selectFile(iqtHelper::Convert(file));
 #endif
 		}
 		if(fd->exec() == QDialog::Accepted)
 		{
 #ifdef IQT_3
-			out = iqtAssistant::Convert(fd->selectedFile());
+			out = iqtHelper::Convert(fd->selectedFile());
 #else
 			QStringList files = fd->selectedFiles();
 			QString selected;
 			if(!files.isEmpty()) selected = files[0];
-			out = iqtAssistant::Convert(selected);
+			out = iqtHelper::Convert(selected);
 #endif
 		}
 	}
 	else
 	{
-		if(onlyexisting)
+		if(reading)
 		{
-			out = iqtAssistant::Convert(QFileDialog::getOpenFileName(
+			out = iqtHelper::Convert(QFileDialog::getOpenFileName(
 #ifdef IQT_3
 //  QString QFileDialog::getOpenFileName(const QString &dir, const QString &filter, QWidget *parent, const char *name, const QString &caption, QString *selectedFilter, bool resolveSymlinks) 
-				iqtAssistant::Convert(file),iqtAssistant::Convert(selection),this,0,iqtAssistant::Convert(header))
+				iqtHelper::Convert(file),iqtHelper::Convert(selection),this,0,iqtHelper::Convert(header))
 #else
 //  QString QFileDialog::getOpenFileName(QWidget *parent, const QString &caption, const QString &dir, const QString &filter, QString *selectedFilter, Options options) 
-				this,iqtAssistant::Convert(header),iqtAssistant::Convert(file),iqtAssistant::Convert(selection))
+				this,iqtHelper::Convert(header),iqtHelper::Convert(file),iqtHelper::Convert(selection))
 #endif
 				);
 		}
 		else
 		{
-			out = iqtAssistant::Convert(QFileDialog::getSaveFileName(
+			out = iqtHelper::Convert(QFileDialog::getSaveFileName(
 #ifdef IQT_3
-				iqtAssistant::Convert(file),iqtAssistant::Convert(selection),this,0,iqtAssistant::Convert(header))
+				iqtHelper::Convert(file),iqtHelper::Convert(selection),this,0,iqtHelper::Convert(header))
 #else
-				this,iqtAssistant::Convert(header),iqtAssistant::Convert(file),iqtAssistant::Convert(selection))
+				this,iqtHelper::Convert(header),iqtHelper::Convert(file),iqtHelper::Convert(selection))
 #endif
 				);
 		}
@@ -401,7 +408,7 @@ void iqtMenuWindowSubject::EndMenu()
 {
 	if(mCurrentMenu == 0)
 	{
-		IERROR_FINISH("Misconfigured menu structure");
+		IERROR_FATAL("Misconfigured menu structure");
 	}
 
 	mCurrentMenu = mCurrentMenu->GetParent();
@@ -414,15 +421,15 @@ void iqtMenuWindowSubject::AddMenuItem(int id, const iString &text, const iImage
 	mMenuItems.Add(mi);
 
 #ifdef IQT_3
-	if(icon != 0) mi->setIconSet(iqtAssistant::ConvertToIcon(*icon));
-	mi->setMenuText(iqtAssistant::Convert(text));
+	if(icon != 0) mi->setIconSet(iqtHelper::ConvertToIcon(*icon));
+	mi->setMenuText(iqtHelper::Convert(text));
 	mi->setToggleAction(toggle);
-	if(!accel.IsEmpty()) mi->setAccel(QKeySequence(iqtAssistant::Convert(accel)));
+	if(!accel.IsEmpty()) mi->setAccel(QKeySequence(iqtHelper::Convert(accel)));
 #else
-	if(icon != 0) mi->setIcon(iqtAssistant::ConvertToIcon(*icon));
-	mi->setText(iqtAssistant::Convert(text));
+	if(icon != 0) mi->setIcon(iqtHelper::ConvertToIcon(*icon));
+	mi->setText(iqtHelper::Convert(text));
 	mi->setCheckable(toggle);
-	if(!accel.IsEmpty()) mi->setShortcut(QKeySequence(iqtAssistant::Convert(accel)));
+	if(!accel.IsEmpty()) mi->setShortcut(QKeySequence(iqtHelper::Convert(accel)));
 #endif
 
 	if(toggle)
@@ -472,7 +479,7 @@ void iqtMenuWindowSubject::AddToolBarButton(int id, const iString &tooltip, cons
 #else
 		mToolBar->addAction(mMenuItems[i]);
 #endif
-		mMenuItems[i]->setToolTip(iqtAssistant::Convert(tooltip));
+		mMenuItems[i]->setToolTip(iqtHelper::Convert(tooltip));
 	}
 	else
 	{
@@ -482,10 +489,10 @@ void iqtMenuWindowSubject::AddToolBarButton(int id, const iString &tooltip, cons
 		mToolBarButtons.Add(mi);
 
 #ifdef IQT_3
-		mi->setIconSet(iqtAssistant::ConvertToIcon(*icon));
+		mi->setIconSet(iqtHelper::ConvertToIcon(*icon));
 		mi->setToggleAction(toggle);
 #else
-		mi->setIcon(iqtAssistant::ConvertToIcon(*icon));
+		mi->setIcon(iqtHelper::ConvertToIcon(*icon));
 		mi->setCheckable(toggle);
 #endif
 
@@ -502,7 +509,7 @@ void iqtMenuWindowSubject::AddToolBarButton(int id, const iString &tooltip, cons
 #else
 		mToolBar->addAction(mi);
 #endif
-		mi->setToolTip(iqtAssistant::Convert(tooltip));
+		mi->setToolTip(iqtHelper::Convert(tooltip));
 		mi->Update();
 	}
 }
@@ -517,7 +524,7 @@ void iqtMenuWindowSubject::AddToolBarSeparator()
 void iqtMenuWindowSubject::CompleteMenu()
 {
 #ifdef IQT_3
-	this->menuBar()->insertItem((QWidget *)QWhatsThis::whatsThisButton(this->menuBar())); 
+	this->menuBar()->insertItem(QWhatsThis::whatsThisButton(this->menuBar())); 
 #else
 	this->menuBar()->addAction(QWhatsThis::createAction(this->menuBar())); 
 #endif
