@@ -41,7 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggrenderwindow.h"
 #include "iggshell.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtmainwindowsubject.h"
 #include "iqtwindowhelper.h"
 
@@ -61,9 +61,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget* parent) : 
 #ifdef IQT_3
-	QGLWidget(parent,0,0,parent?Qt::WFlags(0):iqtAssistant::GetFlags(iqtAssistant::_VisualizationWindow)), 
+	QGLWidget(parent,0,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(iqtHelper::_VisualizationWindow)), 
 #else
-	QGLWidget(parent,0,parent?Qt::WFlags(0):iqtAssistant::GetFlags(iqtAssistant::_VisualizationWindow)), 
+	QGLWidget(parent,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(iqtHelper::_VisualizationWindow)), 
 #endif
 	ibgRenderWindowSubject(owner)
 {
@@ -76,7 +76,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 	//
 	if(!this->doubleBuffer())
 	{
-		IERROR_FINISH("IFrIT only works in double buffering mode.");
+		IERROR_FATAL("IFrIT only works in double buffering mode.");
 	}
 	this->setMinimumWidth(120);
 	this->setMinimumHeight(120);
@@ -84,10 +84,10 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 	this->setAutoBufferSwap(false);
 
-	if(parent!=0 && parent->layout()!=0) iPointerCast<QGridLayout,QLayout>(parent->layout())->addWidget(this,0,0);
+	if(parent!=0 && parent->layout()!=0) iDynamicCast<QGridLayout,QLayout>(INFO,parent->layout())->addWidget(this,0,0);
 
 	mTimer = new QTimer(this); IERROR_ASSERT(mTimer);
-	if(!connect(mTimer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FINISH("Missed connection.");
+	if(!connect(mTimer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FATAL("Missed connection.");
 }
 
 
@@ -101,23 +101,23 @@ iqtRenderWindowSubject::~iqtRenderWindowSubject()
 }
 
 
-void iqtRenderWindowSubject::AttachToParent(QWidget *parent)
+void iqtRenderWindowSubject::AttachToParent(QWidget *parent, bool border)
 {
 	if(parent == 0)
 	{
-		iqtAssistant::SetParent(this,parent,iqtAssistant::GetFlags(iqtAssistant::_VisualizationWindow));
+		iqtHelper::SetParent(this,parent,iqtHelper::GetFlags(border ? iqtHelper::_VisualizationWindow : iqtHelper::_VisualizationWindowWithoutBorder));
 #ifndef IQT_3
 		this->setFormat(this->format()); // is this Qt 4 bug?
 #endif
 	}
 	else
 	{
-		iqtAssistant::SetParent(this,parent,0);
+		iqtHelper::SetParent(this,parent,0);
 	}
 #ifdef I_DEBUG
 	if(!this->context()->isValid())
 	{
-		IERROR_FINISH("Invalid context in iqtRenderWindowSubject.");
+		IERROR_FATAL("Invalid context in iqtRenderWindowSubject.");
 	}
 #endif
 }
@@ -161,6 +161,17 @@ void iqtRenderWindowSubject::SwapBuffers()
 }
 
 
+void iqtRenderWindowSubject::SetBorder(bool s)
+{
+    if(!this->isTopLevel()) return;
+
+	QPoint p = this->pos();
+	this->AttachToParent(0,s);
+	this->move(p);
+	this->show();
+}
+
+
 void iqtRenderWindowSubject::SetFullScreen(bool s) 
 {
 	if(s) this->showFullScreen(); else this->showNormal();
@@ -182,9 +193,9 @@ void* iqtRenderWindowSubject::GetGenericWindowId() const
 void iqtRenderWindowSubject::SetWindowName(const iString &s)
 {
 #ifdef IQT_3
-	this->setCaption(iqtAssistant::Convert(s));
+	this->setCaption(iqtHelper::Convert(s));
 #else
-	this->setWindowTitle(iqtAssistant::Convert(s));
+	this->setWindowTitle(iqtHelper::Convert(s));
 #endif
 } 
 
@@ -196,7 +207,7 @@ void iqtRenderWindowSubject::RenderIntoMemory(iImage &image)
 #else
 	QImage q = this->renderPixmap(image.Width(),image.Height(),false).toImage();
 #endif
-	image = iqtAssistant::Convert(q);
+	image = iqtHelper::Convert(q);
 }
 
 
@@ -207,8 +218,7 @@ bool iqtRenderWindowSubject::IsReadyForDumpingImage()
 		this->showNormal();
 		if(this->isMinimized()) 
 		{
-			const iggShell *s = iPointerCast<const iggShell,iShell>(this->GetShell());
-			if(s != 0) s->GetMainWindow()->PopupWindow("The visualization window must be visible.\n Please, restore the visualization window before creating an image.");
+			iRequiredCast<iggShell>(INFO,this->GetShell())->GetMainWindow()->PopupWindow("The visualization window must be visible.\n Please, restore the visualization window before creating an image.");
 			return false;
 		}
 	}
@@ -272,7 +282,7 @@ void iqtRenderWindowSubject::paintGL()
 	//
 	if(this->autoBufferSwap())
 	{
-		IERROR_REPORT("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
+		IERROR_LOW("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
 		return;
 	}
 
@@ -294,9 +304,9 @@ void iqtRenderWindowSubject::resizeGL(int w, int h)
 void iqtRenderWindowSubject::mouseMoveEvent(QMouseEvent *event) 
 {
 #ifdef IQT_3
-	this->OnMouseMoveBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->state()));
+	this->OnMouseMoveBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->state()));
 #else
-	this->OnMouseMoveBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->buttons() | event->modifiers()));
+	this->OnMouseMoveBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->buttons() | event->modifiers()));
 #endif
 }
 
@@ -304,9 +314,9 @@ void iqtRenderWindowSubject::mouseMoveEvent(QMouseEvent *event)
 void iqtRenderWindowSubject::mousePressEvent(QMouseEvent *event) 
 {
 #ifdef IQT_3
-	this->OnMousePressBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->stateAfter()));
+	this->OnMousePressBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->stateAfter()));
 #else
-	this->OnMousePressBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->buttons() | event->modifiers()));
+	this->OnMousePressBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->buttons() | event->modifiers()));
 #endif
 }
 
@@ -314,9 +324,9 @@ void iqtRenderWindowSubject::mousePressEvent(QMouseEvent *event)
 void iqtRenderWindowSubject::mouseReleaseEvent(QMouseEvent *event) 
 {
 #ifdef IQT_3
-	this->OnMouseReleaseBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->state()));
+	this->OnMouseReleaseBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->state()));
 #else
-	this->OnMouseReleaseBody(event->x(),this->height()-event->y()-1,iqtAssistant::Convert(event->buttons() | event->button() | event->modifiers()));
+	this->OnMouseReleaseBody(event->x(),this->height()-event->y()-1,iqtHelper::Convert(event->buttons() | event->button() | event->modifiers()));
 #endif
 }
 
@@ -324,9 +334,9 @@ void iqtRenderWindowSubject::mouseReleaseEvent(QMouseEvent *event)
 void iqtRenderWindowSubject::keyPressEvent(QKeyEvent * event)
 {
 #ifdef IQT_3
-	this->OnKeyPressBody(event->key(),iqtAssistant::Convert(event->state()));
+	this->OnKeyPressBody(event->key(),iqtHelper::Convert(event->state()));
 #else
-	this->OnKeyPressBody(event->key(),iqtAssistant::Convert(event->modifiers()));
+	this->OnKeyPressBody(event->key(),iqtHelper::Convert(event->modifiers()));
 #endif
 }
 
@@ -352,8 +362,10 @@ bool iqtRenderWindowSubject::event(QEvent *e)
 //
 //  Event handles
 //
-void iqtRenderWindowSubject::closeEvent(QCloseEvent *)
+void iqtRenderWindowSubject::closeEvent(QCloseEvent *e)
 {
+	e->ignore();
+	mOwner->OnCloseAttempt();
 }
 
 
