@@ -29,6 +29,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtshellsubject.h"
 
 
+#include "ierror.h"
+#include "ishell.h"
 #include "istring.h"
 
 #include "iqt.h"
@@ -58,13 +60,13 @@ iqtShellSubject::iqtShellSubject(iggShell *owner, int argc, char **argv) : ibgSh
 	QWidget *pp = new QMessageBox();
 	if(pp == 0)
 	{
-		this->OutputStartupMessage("There is not enough memory to run IFrIT.");
+		IERROR_FATAL("There is not enough memory to run IFrIT.");
 		exit(0);
 	}
 	QMessageBox *ps = dynamic_cast<QMessageBox*>(pp);
 	if(ps == 0)
 	{
-		this->OutputStartupMessage("Qt has not been compiled with the RTTI (Run-Time Type Information) support.\nIFrIT needs all components to be compiled with the RTTI support.\nPlease re-compile Qt with the RTTI support enabled.");
+		IERROR_FATAL("Qt has not been compiled with the RTTI (Run-Time Type Information) support.\nIFrIT needs all components to be compiled with the RTTI support.\nPlease re-compile Qt with the RTTI support enabled.");
 		delete qApp;
 		exit(0);
 	}
@@ -84,24 +86,6 @@ void iqtShellSubject::Exit()
 }
 
 
-void iqtShellSubject::OutputStartupMessage(const iString &message)
-{
-#ifdef _WIN32
-	QMessageBox::warning(qApp->desktop(),"IFrIT Error",message.ToCharPointer(),0,0);
-#else
-	cerr << message.ToCharPointer() << endl;
-#endif
-}
-
-
-#ifdef I_DEBUG
-void iqtShellSubject::OutputDebugMessage(const iString &message) const
-{
-	qWarning(message.ToCharPointer());
-}
-#endif
-
-
 void iqtShellSubject::GetDesktopDimensions(int &w, int &h) const
 {
 	w = qApp->desktop()->width();
@@ -111,8 +95,8 @@ void iqtShellSubject::GetDesktopDimensions(int &w, int &h) const
 
 void iqtShellSubject::ProcessEvents(bool sync)
 {
-	if(sync) qApp->syncX();
 	qApp->flush();
+	if(sync) qApp->syncX();
 	qApp->sendPostedEvents();
 	qApp->processEvents();
 }
@@ -165,7 +149,8 @@ bool iqtShellSubject::CanChangeFontSize() const
 }
 
 
-bool iqtShellSubject::CanRenderOffScreen() const
+bool iqtShellSubject::IsWindowManagerModern() const
 {
-	return true;
+	return true;  // seems not possible to discover from Qt?
 }
+
