@@ -36,8 +36,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframe.h"
 #include "iggwidgetarea.h"
 
-#include "iqtassistant.h"
 #include "iqtframesubject.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
@@ -65,7 +65,7 @@ using namespace iggParameter;
 //
 //  WidgetDisplayAreaSubject class
 //
-iqtWidgetDisplayAreaSubject::iqtWidgetDisplayAreaSubject(iggWidget *owner, const iString &text) : QLabel(iqtAssistant::Convert(owner->GetParent())), ibgWidgetDisplayAreaSubject(owner,text)
+iqtWidgetDisplayAreaSubject::iqtWidgetDisplayAreaSubject(iggWidget *owner, const iString &text) : QLabel(iqtHelper::Convert(owner->GetParent())), ibgWidgetDisplayAreaSubject(owner,text)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -78,7 +78,7 @@ iqtWidgetDisplayAreaSubject::iqtWidgetDisplayAreaSubject(iggWidget *owner, const
 void iqtWidgetDisplayAreaSubject::SetText(const iString &text)
 {
 	this->setPixmap(QPixmap());
-	this->setText(iqtAssistant::ConvertWithModifiers(this,text));
+	this->setText(iqtHelper::ConvertWithModifiers(this,text));
 	this->setScaledContents(true);
 }
 
@@ -102,7 +102,7 @@ void iqtWidgetDisplayAreaSubject::SetImage(const iImage *image, bool withMask, b
 	{
 		this->setText(0);
 		this->setScaledContents(scaled);
-		this->setPixmap(iqtAssistant::ConvertToPixmap(*image,withMask));
+		this->setPixmap(iqtHelper::ConvertToPixmap(*image,withMask));
 	}
 	else this->setPixmap(QPixmap());
 	this->repaint(); // needed for proper update outside of an event loop
@@ -112,7 +112,7 @@ void iqtWidgetDisplayAreaSubject::SetImage(const iImage *image, bool withMask, b
 //
 //  WidgetMultiImageDisplayAreaSubject class
 //
-iqtWidgetMultiImageDisplayAreaSubject::iqtWidgetMultiImageDisplayAreaSubject(iggWidget *owner) : QLabel(iqtAssistant::Convert(owner->GetParent())), ibgWidgetMultiImageDisplayAreaSubject(owner)
+iqtWidgetMultiImageDisplayAreaSubject::iqtWidgetMultiImageDisplayAreaSubject(iggWidget *owner) : QLabel(iqtHelper::Convert(owner->GetParent())), ibgWidgetMultiImageDisplayAreaSubject(owner)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -121,7 +121,7 @@ iqtWidgetMultiImageDisplayAreaSubject::iqtWidgetMultiImageDisplayAreaSubject(igg
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
 	mTimer = new QTimer(this); IERROR_ASSERT(mTimer);
-	if(!connect(mTimer,SIGNAL(timeout()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
+	if(!connect(mTimer,SIGNAL(timeout()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
 };
 
 
@@ -132,7 +132,7 @@ iqtWidgetMultiImageDisplayAreaSubject::~iqtWidgetMultiImageDisplayAreaSubject()
 
 ibgWidgetMultiImageDisplayAreaSubject::Image* iqtWidgetMultiImageDisplayAreaSubject::AddImageBody(const iImage &image, bool withmask, bool first)
 {
-	QPixmap tmp(iqtAssistant::ConvertToPixmap(image,withmask));
+	QPixmap tmp(iqtHelper::ConvertToPixmap(image,withmask));
 	if(first)
 	{
 		this->setFixedSize(tmp.size());
@@ -140,10 +140,10 @@ ibgWidgetMultiImageDisplayAreaSubject::Image* iqtWidgetMultiImageDisplayAreaSubj
 	}
 	else
 	{
-		QPixmap &base = iPointerCast<qtImage,Image>(mImages[0])->Pixmap;
+		QPixmap &base = iDynamicCast<qtImage,Image>(INFO,mImages[0])->Pixmap;
 		if(tmp.size() != base.size())
 		{
-			IERROR_REPORT("Incompatible size of iqtWidgetMultiImageDisplayAreaSubject images.");
+			IERROR_LOW("Incompatible size of iqtWidgetMultiImageDisplayAreaSubject images.");
 			tmp = QPixmap(base.size());
 		}
 	}
@@ -153,7 +153,7 @@ ibgWidgetMultiImageDisplayAreaSubject::Image* iqtWidgetMultiImageDisplayAreaSubj
 
 void iqtWidgetMultiImageDisplayAreaSubject::ShowImageBody(int n)
 {
-	QPixmap &tmp(iPointerCast<qtImage,Image>(mImages[n])->Pixmap);
+	QPixmap &tmp(iDynamicCast<qtImage,Image>(INFO,mImages[n])->Pixmap);
 #ifdef IQT_3
 	bitBlt(this,0,0,&tmp,0,0,tmp.width(),tmp.height(),Qt::CopyROP); 
 #else
@@ -177,7 +177,7 @@ void iqtWidgetMultiImageDisplayAreaSubject::Abort()
 //
 //  WidgetDrawAreaSubject class
 //
-iqtWidgetDrawAreaSubject::iqtWidgetDrawAreaSubject(iggWidgetDrawArea *owner, bool interactive) : QFrame(iqtAssistant::Convert(owner->GetParent())
+iqtWidgetDrawAreaSubject::iqtWidgetDrawAreaSubject(iggWidgetDrawArea *owner, bool interactive) : QFrame(iqtHelper::Convert(owner->GetParent())
 #ifdef IQT_3
 																			  ,0,Qt::WRepaintNoErase|Qt::WResizeNoErase
 #endif
@@ -245,10 +245,10 @@ void iqtWidgetDrawAreaSubject::Begin(Mode m, bool clear)
 			if(this->contentsRect().size() != mBackgroundPixmap->size()) *mBackgroundPixmap = QPixmap(this->contentsRect().size());
 			mPainter->begin(mBackgroundPixmap);
 #ifdef IQT_3
-			mPainter->setBackgroundColor(iqtAssistant::Convert(mBackgroundColor));
+			mPainter->setBackgroundColor(iqtHelper::Convert(mBackgroundColor));
 			if(clear) mPainter->fillRect(0,0,mBackgroundPixmap->width(),mBackgroundPixmap->height(),mPainter->backgroundColor());
 #else
-			mPainter->setBackground(iqtAssistant::Convert(mBackgroundColor));
+			mPainter->setBackground(iqtHelper::Convert(mBackgroundColor));
 			if(clear) mPainter->fillRect(0,0,mBackgroundPixmap->width(),mBackgroundPixmap->height(),mPainter->background().color());
 #endif
 			break;
@@ -266,17 +266,17 @@ void iqtWidgetDrawAreaSubject::Begin(Mode m, bool clear)
 			}
 			mPainter->begin(mForegroundPixmap);
 #ifdef IQT_3
-			mPainter->setBackgroundColor(iqtAssistant::Convert(mBackgroundColor));
+			mPainter->setBackgroundColor(iqtHelper::Convert(mBackgroundColor));
 			if(clear) mPainter->fillRect(0,0,mForegroundPixmap->width(),mForegroundPixmap->height(),mPainter->backgroundColor());
 #else
-			mPainter->setBackground(iqtAssistant::Convert(mBackgroundColor));
+			mPainter->setBackground(iqtHelper::Convert(mBackgroundColor));
 			if(clear) mPainter->fillRect(0,0,mForegroundPixmap->width(),mForegroundPixmap->height(),mPainter->background().color());
 #endif
 			break;
 		}
 	default:
 		{
-			IERROR_REPORT("Incorrect iqtWidgetDrawArea mode.");
+			IERROR_LOW("Incorrect iqtWidgetDrawArea mode.");
 		}
 	}
 	mOffsetY = this->Height() - 1;
@@ -295,7 +295,7 @@ void iqtWidgetDrawAreaSubject::End()
 		}
 	default:
 		{
-			IERROR_REPORT("Incorrect iqtWidgetDrawArea mode.");
+			IERROR_LOW("Incorrect iqtWidgetDrawArea mode.");
 		}
 	}
 }
@@ -321,23 +321,23 @@ void iqtWidgetDrawAreaSubject::Clear()
 
 void iqtWidgetDrawAreaSubject::DrawLine(int x1, int y1, int x2, int y2, const iColor &color, int width, bool dotted)
 {
-	mPainter->setPen(QPen(iqtAssistant::Convert(color),width,(width>0)?(dotted?DotLine:SolidLine):NoPen));
+	mPainter->setPen(QPen(iqtHelper::Convert(color),width,(width>0)?(dotted?DotLine:SolidLine):NoPen));
 	mPainter->drawLine(x1,mOffsetY-y1,x2,mOffsetY-y2);
 }
 
 
 void iqtWidgetDrawAreaSubject::DrawRectangle(int x1, int y1, int x2, int y2, const iColor &color, const iColor& fillColor, int width)
 {
-	mPainter->setPen(QPen(iqtAssistant::Convert(color),width,(width>0)?SolidLine:NoPen));
-	mPainter->setBrush(iqtAssistant::Convert(fillColor));
+	mPainter->setPen(QPen(iqtHelper::Convert(color),width,(width>0)?SolidLine:NoPen));
+	mPainter->setBrush(iqtHelper::Convert(fillColor));
 	mPainter->drawRect(x1,mOffsetY-y2,x2-x1+1,y2-y1+1);
 }
 
 
 void iqtWidgetDrawAreaSubject::DrawEllipse(int x1, int y1, int x2, int y2, const iColor &color, const iColor& fillColor, int width)
 {
-	mPainter->setPen(QPen(iqtAssistant::Convert(color),width,(width>0)?SolidLine:NoPen));
-	mPainter->setBrush(iqtAssistant::Convert(fillColor));
+	mPainter->setPen(QPen(iqtHelper::Convert(color),width,(width>0)?SolidLine:NoPen));
+	mPainter->setBrush(iqtHelper::Convert(fillColor));
 	mPainter->drawEllipse(x1,mOffsetY-y2,x2-x1+1,y2-y1+1);
 }
 
@@ -347,14 +347,14 @@ void iqtWidgetDrawAreaSubject::DrawImage(int x1, int y1, int x2, int y2, const i
 	{
 		iImage tmp = image;
 		tmp.Scale(x2-x1+1,y2-y1+1,mode);
-		mPainter->drawImage(x1+(x2-x1+1-tmp.Width())/2,mOffsetY-y2+(y2-y1+1-tmp.Height())/2,iqtAssistant::Convert(tmp));
+		mPainter->drawImage(x1+(x2-x1+1-tmp.Width())/2,mOffsetY-y2+(y2-y1+1-tmp.Height())/2,iqtHelper::Convert(tmp));
 	}
 }
 
 
 void iqtWidgetDrawAreaSubject::DrawTextLine(int x1, int y1, int x2, int y2, const iString &text, const iColor &color)
 {
-	mPainter->setPen(iqtAssistant::Convert(color));
+	mPainter->setPen(iqtHelper::Convert(color));
 	int f1 = y2 - y1 + 1;
 	int f2 = (x2-x1+1)/text.Length();
 	QFont font(mPainter->font());
@@ -367,7 +367,7 @@ void iqtWidgetDrawAreaSubject::DrawTextLine(int x1, int y1, int x2, int y2, cons
 #else
 		TextSingleLine
 #endif
-		,iqtAssistant::Convert(text));
+		,iqtHelper::Convert(text));
 }
 
 
@@ -422,7 +422,7 @@ void iqtWidgetDrawAreaSubject::paintEvent(QPaintEvent *e)
 	//
 	if(this->contentsRect().size() != mForegroundPixmap->size())
 	{
-		iPointerCast<iqtFrameSubject,QWidget>(this->parentWidget())->GetFrame()->UpdateWidget();
+		iDynamicCast<iqtFrameSubject,QWidget>(INFO,this->parentWidget())->GetFrame()->UpdateWidget();
 	}
 
 	QFrame::paintEvent(e);
@@ -436,9 +436,9 @@ void iqtWidgetDrawAreaSubject::mouseMoveEvent(QMouseEvent *e)
 	if(e == 0) return;
 
 #ifdef IQT_3
-	this->OnMouseMove(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->state()));
+	this->OnMouseMove(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->state()));
 #else
-	this->OnMouseMove(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->buttons() | e->modifiers()));
+	this->OnMouseMove(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->buttons() | e->modifiers()));
 #endif
 	QFrame::mouseMoveEvent(e);
 }
@@ -449,9 +449,9 @@ void iqtWidgetDrawAreaSubject::mousePressEvent(QMouseEvent *e)
 	if(e == 0) return;
 
 #ifdef IQT_3
-	this->OnMousePress(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->stateAfter()));
+	this->OnMousePress(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->stateAfter()));
 #else
-	this->OnMousePress(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->buttons() | e->modifiers()));
+	this->OnMousePress(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->buttons() | e->modifiers()));
 #endif
 	QFrame::mousePressEvent(e);
 }
@@ -462,9 +462,9 @@ void iqtWidgetDrawAreaSubject::mouseReleaseEvent(QMouseEvent *e)
 	if(e == 0) return;
 
 #ifdef IQT_3
-	this->OnMouseRelease(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->state()));
+	this->OnMouseRelease(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->state()));
 #else
-	this->OnMouseRelease(e->x(),mOffsetY-e->y(),iqtAssistant::Convert(e->buttons() | e->button() | e->modifiers()));
+	this->OnMouseRelease(e->x(),mOffsetY-e->y(),iqtHelper::Convert(e->buttons() | e->button() | e->modifiers()));
 #endif
 	QFrame::mouseReleaseEvent(e);
 }
