@@ -35,7 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidget.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
@@ -61,7 +61,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iggParameter;
 
 
-iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetButtonSubject(owner,type,text,slot)
+iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetButtonSubject(owner,type,text,slot)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -69,14 +69,20 @@ iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l = iqtAssistant::NewLayout(this,1);
+	QGridLayout *l = iqtHelper::NewLayout(this,1);
 
 	mType = type;
 	switch(mType)
 	{
 	case _ButtonTypePushButton:
+	case _ButtonTypeSwitchButton:
 		{
 			mButton = new QPushButton(this);
+#ifdef IQT_3
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==_ButtonTypeSwitchButton);
+#else
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==_ButtonTypeSwitchButton);
+#endif
 			break;
 		}
 	case _ButtonTypeToolButton:
@@ -84,9 +90,9 @@ iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const
 		{
 			mButton = new QToolButton(this);
 #ifdef IQT_3
-			iPointerCast<QToolButton,QAbstractButton>(mButton)->setToggleButton(mType==_ButtonTypeToggleButton);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==_ButtonTypeToggleButton);
 #else
-			iPointerCast<QToolButton,QAbstractButton>(mButton)->setCheckable(mType==_ButtonTypeToggleButton);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==_ButtonTypeToggleButton);
 #endif
 			mButton->setMinimumSize(25,25);
 			break;
@@ -96,10 +102,10 @@ iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const
 			mButton = new QCheckBox(this);
 			break;
 		}
-	default: IERROR_REPORT("Incorrect button type.");
+	default: IERROR_LOW("Incorrect button type.");
 	}
 
-	mButton->setText(iqtAssistant::ConvertWithModifiers(mButton,text));
+	mButton->setText(iqtHelper::ConvertWithModifiers(mButton,text));
 	mButton->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	l->addWidget(mButton,0,0);
 
@@ -109,22 +115,22 @@ iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const
 	{
 	case 1:
 		{
-			if(!this->connect(mButton,SIGNAL(clicked()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
+			if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
 			break;
 		}
 	case 2:
 		{
-			if(!this->connect(mButton,SIGNAL(clicked()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid2()))) IERROR_REPORT("Missed connection.");
+			if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid2()))) IERROR_LOW("Missed connection.");
 			break;
 		}
 	case 3:
 		{
-			if(!this->connect(mButton,SIGNAL(clicked()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid3()))) IERROR_REPORT("Missed connection.");
+			if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid3()))) IERROR_LOW("Missed connection.");
 			break;
 		}
 	default:
 		{
-			IERROR_FINISH("Incorrect slot number.");
+			IERROR_FATAL("Incorrect slot number.");
 		}
 	}
 }
@@ -146,14 +152,15 @@ void iqtWidgetButtonSubject::SetFlat(bool s)
 	switch(mType)
 	{
 	case _ButtonTypePushButton:
+	case _ButtonTypeSwitchButton:
 		{
-			iPointerCast<QPushButton,QAbstractButton>(mButton)->setFlat(s);
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setFlat(s);
 			break;
 		}
 	case _ButtonTypeToolButton:
 	case _ButtonTypeToggleButton:
 		{
-			iPointerCast<QToolButton,QAbstractButton>(mButton)->setAutoRaise(s);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setAutoRaise(s);
 			break;
 		}
 	}
@@ -171,10 +178,11 @@ bool iqtWidgetButtonSubject::IsDown() const
 	switch(mType)
 	{
 	case _ButtonTypePushButton:
+	case _ButtonTypeToolButton:
 		{
 			return false;
 		}
-	case _ButtonTypeToolButton:
+	case _ButtonTypeSwitchButton:
 	case _ButtonTypeToggleButton:
 	case _ButtonTypeCheckBox:
 		{
@@ -186,7 +194,7 @@ bool iqtWidgetButtonSubject::IsDown() const
 		}
 	default:
 		{
-			IERROR_REPORT("Incorrect button type.");
+			IERROR_LOW("Incorrect button type.");
 			return false;
 		}
 	}
@@ -199,25 +207,34 @@ void iqtWidgetButtonSubject::SetDown(bool s)
 	switch(mType)
 	{
 	case _ButtonTypePushButton:
+	case _ButtonTypeToolButton:
 		{
 			break;
 		}
-	case _ButtonTypeToolButton:
+	case _ButtonTypeSwitchButton:
+		{
+#ifdef IQT_3
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setOn(s);
+#else
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setChecked(s);
+#endif
+			break;
+		}
 	case _ButtonTypeToggleButton:
 		{
 #ifdef IQT_3
-			iPointerCast<QToolButton,QAbstractButton>(mButton)->setOn(s);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setOn(s);
 #else
-			iPointerCast<QToolButton,QAbstractButton>(mButton)->setChecked(s);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setChecked(s);
 #endif
 			break;
 		}
 	case _ButtonTypeCheckBox:
 		{
-			iPointerCast<QCheckBox,QAbstractButton>(mButton)->setChecked(s);
+			iDynamicCast<QCheckBox,QAbstractButton>(INFO,mButton)->setChecked(s);
 			break;
 		}
-	default: IERROR_REPORT("Incorrect button type.");
+	default: IERROR_LOW("Incorrect button type.");
 	}
 	mButton->blockSignals(false);
 }
@@ -226,16 +243,20 @@ void iqtWidgetButtonSubject::SetDown(bool s)
 void iqtWidgetButtonSubject::SetIcon(const iImage &icon)
 {
 #ifdef IQT_3
-	mButton->setPixmap(iqtAssistant::ConvertToPixmap(icon));
+	mButton->setPixmap(iqtHelper::ConvertToPixmap(icon));
 #else
-	QIcon ic = iqtAssistant::ConvertToIcon(icon);
+	QIcon ic = iqtHelper::ConvertToIcon(icon);
 	mButton->setIcon(ic);
+	if(mButton->minimumSize() == mButton->maximumSize())
+	{
+		mButton->setIconSize(QSize(icon.Width(),icon.Height()));
+	}
 #endif
 }
 
 
 void iqtWidgetButtonSubject::SetText(const iString &text)
 {
-	mButton->setText(iqtAssistant::ConvertWithModifiers(mButton,text));
+	mButton->setText(iqtHelper::ConvertWithModifiers(mButton,text));
 }
 
