@@ -36,7 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgframesubject.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
@@ -54,7 +54,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner, bool horizontal) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetColorSelectionSubject(owner,horizontal)
+iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner, bool horizontal) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetColorSelectionSubject(owner,horizontal)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -63,9 +63,9 @@ iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner,
 	//
 	if(this->layout() != 0) delete this->layout();
 	QGridLayout *l;
-	if(horizontal) l = iqtAssistant::NewLayout(this,2); else
+	if(horizontal) l = iqtHelper::NewLayout(this,2); else
 	{
-		l = iqtAssistant::NewLayout(this,1);
+		l = iqtHelper::NewLayout(this,1);
 #ifdef IQT_3
 		l->expand(3,1);
 #endif
@@ -80,20 +80,24 @@ iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner,
 #endif
 #endif
 	mLabel->setScaledContents(true);
-	mLabel->setMinimumSize(32,32);
-	if(horizontal) l->addWidget(mLabel,0,0); else
+	mLabel->setMinimumSize(24,24);
+	if(horizontal)
+	{
+		l->addWidget(mLabel,0,0);
+	}
+	else
 	{
 		l->addWidget(mLabel,1,0);
 		l->setRowStretch(0,10);
 	}
 
 	mButton = new QPushButton(this);
-	mButton->setText("Select color");
+	mButton->setText("Color");
 	if(horizontal) l->addWidget(mButton,0,1); else l->addWidget(mButton,2,0);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
-	if(!this->connect(mButton,SIGNAL(clicked()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mButton,SIGNAL(clicked()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
 }
 
 
@@ -104,22 +108,29 @@ iqtWidgetColorSelectionSubject::~iqtWidgetColorSelectionSubject()
 
 const iColor iqtWidgetColorSelectionSubject::GetColor() const
 {
-    QColor c = QColorDialog::getColor(); 
+#ifdef IQT_3
+	QColor c0 = mLabel->paletteBackgroundColor();
+#else
+	QColor c0 = mLabel->palette().color(mLabel->backgroundRole());
+#endif
+
+	QColor c = QColorDialog::getColor(c0); 
 	if(c.isValid())
 	{
-		iqtAssistant::SetBackground(mLabel,c);
+		iqtHelper::SetBackground(mLabel,c);
 	}
-	return iqtAssistant::Convert(c);
+	else c = c0;
+	return iqtHelper::Convert(c);
 }
 
 
 void iqtWidgetColorSelectionSubject::SetColor(const iColor &v)
 {
-	iqtAssistant::SetBackground(mLabel,iqtAssistant::Convert(v));
+	iqtHelper::SetBackground(mLabel,iqtHelper::Convert(v));
 }
 
 	
 void iqtWidgetColorSelectionSubject::SetText(const iString &text)
 {
-	mButton->setText(iqtAssistant::ConvertWithModifiers(mButton,text));
+	mButton->setText(iqtHelper::ConvertWithModifiers(mButton,text));
 }
