@@ -35,7 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidgetrendermodebutton.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgetbuttonsubject.h"
 #include "iqtwidgethelper.h"
 
@@ -172,7 +172,7 @@ namespace iqtWidgetEntrySubject_Private
 };
 
 
-iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetEntrySubject(owner,slider,numdig,label,rmb)
+iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetEntrySubject(owner,slider,numdig,label,rmb)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -180,10 +180,10 @@ iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *w = iqtAssistant::NewLayout(this,3);
+	QGridLayout *w = iqtHelper::NewLayout(this,3);
 
 	QLabel *l = new QLabel(this);
-	l->setText(iqtAssistant::ConvertWithModifiers(l,label));
+	l->setText(iqtHelper::ConvertWithModifiers(l,label));
 	l->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	w->addWidget(l,0,0);
 	if(label.IsEmpty()) l->hide();
@@ -204,16 +204,16 @@ iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int
 	mSlider->setPageStep(1);
 	mSlider->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
 	w->addWidget(mSlider,0,1);
-	if(!this->connect(mSlider,SIGNAL(valueChanged(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT("Missed connection.");
-	if(!this->connect(mSlider,SIGNAL(sliderReleased()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mSlider,SIGNAL(valueChanged(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mSlider,SIGNAL(sliderReleased()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
 	if(!slider) mSlider->hide();
 
 	mEdit = new iqtWidgetEntrySubject_Private::LineEdit(slider,this);
 	if(slider || numdig>0) mEdit->setValidator(new QDoubleValidator(mEdit));
 	if(slider) mEdit->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum)); else mEdit->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
 	w->addWidget(mEdit,0,2);
-	if(!this->connect(mEdit,SIGNAL(textChanged(const QString&)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnString1(const QString &)))) IERROR_REPORT("Missed connection.");
-	if(!this->connect(mEdit,SIGNAL(returnPressed()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mEdit,SIGNAL(textChanged(const QString&)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnString1(const QString &)))) IERROR_LOW("Missed connection.");
+	if(!this->connect(mEdit,SIGNAL(returnPressed()),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnVoid1()))) IERROR_LOW("Missed connection.");
 	if(slider && numdig<=0) mEdit->hide();
 
 	mView = new QLCDNumber(this);
@@ -226,13 +226,13 @@ iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int
 	mView->setSegmentStyle(QLCDNumber::Flat);
 	mView->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	w->addWidget(mView,0,2);
-	iqtAssistant::SetBackground(mView,0);
+	iqtHelper::SetBackground(mView,0);
 	if(numdig <= 0)	mView->hide();
 
 	if(rmb != 0)
 	{
-		iqtWidgetButtonSubject *rmbs = iPointerCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(rmb->GetSubject());
-		iqtAssistant::SetParent(rmbs,this);
+		iqtWidgetButtonSubject *rmbs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,rmb->GetSubject());
+		iqtHelper::SetParent(rmbs,this);
 #ifdef IQT_3
 		w->expand(1,4);
 		w->addWidget(rmbs,0,3);
@@ -325,14 +325,15 @@ void iqtWidgetEntrySubject::SetDoubleValue(int v, double dv, bool withEdit)
 				//
 				//  Add another one - this way we have more room if the number just fits
 				//
-				mView->setNumDigits(++nd);
+				nd += 2;
+				mView->setNumDigits(nd);
 			}
 			mView->display(dv);
 		}
 		if(withEdit && !mEdit->isHidden())
 		{
 			mEdit->blockSignals(true);
-			mEdit->setText(QString::number(dv));
+			mEdit->setText(QString::number(dv,'g',2));
 			mEdit->setCursorPosition(0);
 			mEdit->blockSignals(false);
 		}
@@ -363,7 +364,7 @@ void iqtWidgetEntrySubject::SetRange(int smin, int smax, int pagestep)
 
 void iqtWidgetEntrySubject::SetStretch(int label, int slider, int number)
 {
-	QGridLayout *l = iPointerCast<QGridLayout,QLayout>(this->layout());
+	QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
 #ifdef IQT_3
 	l->setColStretch(0,label);
 	l->setColStretch(1,slider);
@@ -425,7 +426,7 @@ void iqtWidgetEntrySubject::SetEditable(bool s)
 //
 const iString iqtWidgetEntrySubject::GetText() const
 {
-	return iqtAssistant::Convert(mEdit->text());
+	return iqtHelper::Convert(mEdit->text());
 }
 
 
@@ -434,7 +435,7 @@ void iqtWidgetEntrySubject::SetText(const iString &s)
 	if(!mEdit->isHidden())
 	{
 		mEdit->blockSignals(true);
-		mEdit->setText(iqtAssistant::Convert(s));
+		mEdit->setText(iqtHelper::Convert(s));
 		mEdit->setCursorPosition(0);
 		mEdit->blockSignals(false);
 	}
@@ -443,7 +444,7 @@ void iqtWidgetEntrySubject::SetText(const iString &s)
 
 void iqtWidgetEntrySubject::SetDelayedEdit(bool s)
 {
-	iPointerCast<iqtWidgetEntrySubject_Private::LineEdit,QLineEdit>(mEdit)->SetDelayedEdit(s);
+	iDynamicCast<iqtWidgetEntrySubject_Private::LineEdit,QLineEdit>(INFO,mEdit)->SetDelayedEdit(s);
 }
 
 
@@ -467,6 +468,6 @@ void iqtWidgetEntrySubject::SelectText(int start, int len)
 
 void iqtWidgetEntrySubject::OnKeyUpDown(bool up)
 {
-	iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnBool1(up);
+	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(up);
 }
 
