@@ -35,7 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidgettext.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #include "iggparameter.h"
@@ -56,7 +56,7 @@ using namespace iggParameter;
 //
 // Constructs a browser
 //
-iqtWidgetHelpBrowserSubject::iqtWidgetHelpBrowserSubject(iggWidgetHelpBrowser *owner) : QTextBrowser(iqtAssistant::Convert(owner->GetParent())), ibgWidgetHelpBrowserSubject(owner)
+iqtWidgetHelpBrowserSubject::iqtWidgetHelpBrowserSubject(iggWidgetHelpBrowser *owner) : QTextBrowser(iqtHelper::Convert(owner->GetParent())), ibgWidgetHelpBrowserSubject(owner)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner->Self()); IERROR_ASSERT(mWidgetHelper);
 
@@ -76,9 +76,9 @@ iqtWidgetHelpBrowserSubject::~iqtWidgetHelpBrowserSubject()
 void iqtWidgetHelpBrowserSubject::SetText(const iString &text)
 {
 #ifdef IQT_3
-	this->setText(iqtAssistant::Convert(text));
+	this->setText(iqtHelper::Convert(text));
 #else
-	this->setHtml(iqtAssistant::Convert(text));
+	this->setHtml(iqtHelper::Convert(text));
 #endif
 }
 
@@ -86,9 +86,9 @@ void iqtWidgetHelpBrowserSubject::SetText(const iString &text)
 iString iqtWidgetHelpBrowserSubject::GetText() const
 {
 #ifdef IQT_3
-	return iqtAssistant::Convert(this->text());
+	return iqtHelper::Convert(this->text());
 #else
-	return iqtAssistant::Convert(this->toHtml());
+	return iqtHelper::Convert(this->toHtml());
 #endif
 }
 
@@ -96,7 +96,7 @@ iString iqtWidgetHelpBrowserSubject::GetText() const
 void iqtWidgetHelpBrowserSubject::AddImage(const iString &name, const iImage &image)
 {
 #ifdef IQT_3
-	this->mimeSourceFactory()->setImage(iqtAssistant::Convert(name),iqtAssistant::Convert(image));
+	this->mimeSourceFactory()->setImage(iqtHelper::Convert(name),iqtHelper::Convert(image));
 #else
 #endif
 }
@@ -143,11 +143,11 @@ QVariant iqtWidgetHelpBrowserSubject::loadResource(int type, const QUrl &name)
 		//
 		//  Look for an image
 		//
-		iString ws = iqtAssistant::Convert(name.toString());
+		iString ws = iqtHelper::Convert(name.toString());
 		const iImage* im = iImageFactory::FindHelpChart(ws.Part(8));
 		if(im != 0)
 		{
-			return QVariant(iqtAssistant::Convert(*im));
+			return QVariant(iqtHelper::Convert(*im));
 		}
 	}
 
