@@ -34,7 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidget.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 
 #ifdef IQT_3
 #include <qtooltip.h>
@@ -85,12 +85,12 @@ public:
 #ifdef IQT_3
 	virtual QString text(const QPoint& /*pos*/)
 	{
-		if(mText.IsEmpty()) return QString::null; else return iqtAssistant::Convert(mText);
+		if(mText.IsEmpty()) return QString::null; else return iqtHelper::Convert(mText);
 	}
 
 	virtual bool clicked(const QString& ref)
 	{
-		mOwner->OpenHelpPage(iqtAssistant::Convert(ref));
+		mOwner->OpenHelpPage(iqtHelper::Convert(ref));
 		return true;
 	}
 #else
@@ -98,7 +98,7 @@ public:
 	{
 		if(e!=0 && e->type()==QEvent::WhatsThisClicked && obj==mOwner->mWidget)
 		{
-			mOwner->OpenHelpPage(iqtAssistant::Convert(iPointerCast<QWhatsThisClickedEvent,QEvent>(e)->href()));
+			mOwner->OpenHelpPage(iqtHelper::Convert(iDynamicCast<QWhatsThisClickedEvent,QEvent>(INFO,e)->href()));
 		}
 		return QObject::eventFilter(obj,e);
 	}
@@ -119,6 +119,8 @@ iqtWidgetHelper::iqtWidgetHelper(QWidget *widget, iggWidget *owner) : ibgWidgetH
 	IERROR_ASSERT(widget);
 	mWidget = widget;
 	mBaloonHelp = 0;
+
+	mIsDisabling = false;
 }
 
 
@@ -133,10 +135,10 @@ iqtWidgetHelper::~iqtWidgetHelper()
 void iqtWidgetHelper::SetBaloonHelp(const iString &tooltip, const iString &whatsthis)
 {
 #ifdef IQT_3
-	QToolTip::add(mWidget,iqtAssistant::Convert(tooltip));
+	QToolTip::add(mWidget,iqtHelper::Convert(tooltip));
 #else
-	mWidget->setToolTip(iqtAssistant::Convert(tooltip));
-	mWidget->setWhatsThis(iqtAssistant::Convert(whatsthis));
+	mWidget->setToolTip(iqtHelper::Convert(tooltip));
+	mWidget->setWhatsThis(iqtHelper::Convert(whatsthis));
 #endif
 	//
 	//  Make the element to accept keyboard events
@@ -197,7 +199,7 @@ bool iqtWidgetHelper::IsVisible() const
 
 void iqtWidgetHelper::SetBackgroundColor(const iColor &c)
 {
-	iqtAssistant::SetBackground(mWidget,iqtAssistant::Convert(c));
+	iqtHelper::SetBackground(mWidget,iqtHelper::Convert(c));
 }
 
 
@@ -207,6 +209,9 @@ void iqtWidgetHelper::UnSetBackgroundColor()
 	mWidget->unsetPalette();
 #else
 	mWidget->setPalette(QPalette());
+#ifndef IQT_40
+	mWidget->setAutoFillBackground(false);
+#endif
 #endif
 }
 
@@ -218,7 +223,9 @@ void iqtWidgetHelper::OnInt1(int v)
 {
 	if(!mWidget->signalsBlocked()) 
 	{
+		if(mIsDisabling) mWidget->setEnabled(false);
 		this->OnInt1Body(v);
+		if(mIsDisabling) mWidget->setEnabled(true);
 	}
 }
 
@@ -272,7 +279,7 @@ void iqtWidgetHelper::OnString1(const QString &v)
 {
 	if(!mWidget->signalsBlocked())
 	{
-		this->OnString1Body(iqtAssistant::Convert(v));
+		this->OnString1Body(iqtHelper::Convert(v));
 	}
 }
 
