@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidgetprogressbar.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 
@@ -47,7 +47,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-iqtWidgetProgressBarSubject::iqtWidgetProgressBarSubject(iggWidget *owner) : QProgressBar(iqtAssistant::Convert(owner->GetParent())), ibgWidgetProgressBarSubject(owner)
+iqtWidgetProgressBarSubject::iqtWidgetProgressBarSubject(iggWidget *owner) : QProgressBar(iqtHelper::Convert(owner->GetParent())), ibgWidgetProgressBarSubject(owner)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -102,7 +102,7 @@ bool iqtWidgetProgressBarSubject::setIndicator(QString &indicator, int progress,
 	{
 		if(mModified)
 		{
-			indicator = iqtAssistant::Convert(mLabel);
+			indicator = iqtHelper::Convert(mLabel);
 			return true;
 		}
 		else return false;
@@ -119,7 +119,7 @@ QString iqtWidgetProgressBarSubject::text() const
 	}
 	else 
 	{
-		return iqtAssistant::Convert(mLabel);
+		return iqtHelper::Convert(mLabel);
     }
 }
 
