@@ -36,7 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgframesubject.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #ifdef IQT_3
@@ -64,17 +64,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //******************************************
 //
-iqtWidgetSpinBoxSubject::iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int max, const iString &title, int step) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetSpinBoxSubject(owner,min,max,title,step)
+iqtWidgetSpinBoxSubject::iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int max, const iString &title, int step) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetSpinBoxSubject(owner,min,max,title,step)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 	//
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l = iqtAssistant::NewLayout(this,2);
+	QGridLayout *l = iqtHelper::NewLayout(this,2);
 
 	mTitle = new QLabel(this);
-	mTitle->setText(iqtAssistant::ConvertWithModifiers(mTitle,title));
+	mTitle->setText(iqtHelper::ConvertWithModifiers(mTitle,title));
 	mTitle->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	l->addWidget(mTitle,0,0);
 
@@ -91,7 +91,9 @@ iqtWidgetSpinBoxSubject::iqtWidgetSpinBoxSubject(iggWidget *owner, int min, int
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
-	if(!this->connect(mBox,SIGNAL(valueChanged(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT("Missed connection.");
+	iqtWidgetHelper *h = iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper);
+	if(h != 0) h->SetDisabling(true);
+	if(!this->connect(mBox,SIGNAL(valueChanged(int)),h,SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
 }
 
 
@@ -116,7 +118,7 @@ void iqtWidgetSpinBoxSubject::SetValue(int v)
 
 void iqtWidgetSpinBoxSubject::SetFirstEntryText(const iString &text)
 {
-	mBox->setSpecialValueText(iqtAssistant::Convert(text));
+	mBox->setSpecialValueText(iqtHelper::Convert(text));
 }
 
 
@@ -128,7 +130,7 @@ void iqtWidgetSpinBoxSubject::SetRange(int min, int max)
 
 void iqtWidgetSpinBoxSubject::SetStretch(int title, int box)
 {
-	QGridLayout *l = iPointerCast<QGridLayout,QLayout>(this->layout());
+	QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
 #ifdef IQT_3
 	l->setColStretch(0,title);
 	l->setColStretch(1,box);
@@ -155,17 +157,17 @@ int iqtWidgetSpinBoxSubject::Count()
 //
 //******************************************
 //
-iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetComboBoxSubject(owner,title,bold)
+iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetComboBoxSubject(owner,title,bold)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 	//
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l = iqtAssistant::NewLayout(this,2);
+	QGridLayout *l = iqtHelper::NewLayout(this,2);
 
 	mTitle = new QLabel(this);
-	mTitle->setText(iqtAssistant::ConvertWithModifiers(mTitle,title));
+	mTitle->setText(iqtHelper::ConvertWithModifiers(mTitle,title));
 	mTitle->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 	l->addWidget(mTitle,0,0);
 
@@ -176,12 +178,12 @@ iqtWidgetComboBoxSubject::iqtWidgetComboBoxSubject(iggWidget *owner, const iStri
 	{
 		QFont f = mBox->font();
 		f.setBold(true);
-		iqtAssistant::SetFont(mBox,f);
+		iqtHelper::SetFont(mBox,f);
 	}
 //	mBox->listBox()->setAutoBottomScrollBar(true); 
 
-	if(!this->connect(mBox,SIGNAL(activated(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT("Missed connection.");
-//	if(!this->connect(mBox,SIGNAL(highlighted(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt2(int)))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mBox,SIGNAL(activated(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
+//	if(!this->connect(mBox,SIGNAL(highlighted(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt2(int)))) IERROR_LOW("Missed connection.");
 }
 
 
@@ -235,14 +237,14 @@ const iString iqtWidgetComboBoxSubject::GetText(int index) const
 
 	if(index < 0)
 	{
-		return iqtAssistant::Convert(mBox->currentText());
+		return iqtHelper::Convert(mBox->currentText());
 	}
 	else if(index < mBox->count())
 	{
 #ifdef IQT_3
-		return iqtAssistant::Convert(mBox->text(index));
+		return iqtHelper::Convert(mBox->text(index));
 #else
-		return iqtAssistant::Convert(mBox->itemText(index));
+		return iqtHelper::Convert(mBox->itemText(index));
 #endif
 	}
 	else
@@ -256,9 +258,9 @@ void iqtWidgetComboBoxSubject::SetText(const iString &text)
 {
 	mBox->blockSignals(true);
 #ifdef IQT_3
-	mBox->setCurrentText(iqtAssistant::Convert(text));
+	mBox->setCurrentText(iqtHelper::Convert(text));
 #else
-	mBox->setItemText(mBox->currentIndex(),iqtAssistant::Convert(text));
+	mBox->setItemText(mBox->currentIndex(),iqtHelper::Convert(text));
 #endif
 	mBox->blockSignals(false);
 }
@@ -266,7 +268,7 @@ void iqtWidgetComboBoxSubject::SetText(const iString &text)
 
 void iqtWidgetComboBoxSubject::SetStretch(int title, int box)
 {
-	QGridLayout *l = iPointerCast<QGridLayout,QLayout>(this->layout());
+	QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
 #ifdef IQT_3
 	l->setColStretch(0,title);
 	l->setColStretch(1,box);
@@ -280,9 +282,19 @@ void iqtWidgetComboBoxSubject::SetStretch(int title, int box)
 void iqtWidgetComboBoxSubject::InsertItem(const iString &text, int index)
 {
 #ifdef IQT_3
-	mBox->insertItem(iqtAssistant::Convert(text),index);
+	mBox->insertItem(iqtHelper::Convert(text),index);
 #else
-	if(index < 0) mBox->addItem(iqtAssistant::Convert(text)); else mBox->insertItem(index,iqtAssistant::Convert(text));
+	if(index < 0) mBox->addItem(iqtHelper::Convert(text)); else mBox->insertItem(index,iqtHelper::Convert(text));
+#endif
+}
+
+
+void iqtWidgetComboBoxSubject::InsertItem(const iImage &icon, const iString &text, int index)
+{
+#ifdef IQT_3
+	mBox->insertItem(iqtHelper::ConvertToPixmap(icon),iqtHelper::Convert(text),index);
+#else
+	if(index < 0) mBox->addItem(iqtHelper::ConvertToIcon(icon),iqtHelper::Convert(text)); else mBox->insertItem(index,iqtHelper::ConvertToIcon(icon),iqtHelper::Convert(text));
 #endif
 }
 
@@ -295,7 +307,7 @@ void iqtWidgetComboBoxSubject::SetItem(const iString &text, int index, bool vis)
 	{
 		if(vis)
 		{
-			QString s = iqtAssistant::Convert(text);
+			QString s = iqtHelper::Convert(text);
 #ifdef IQT_3
 			if(!s.isEmpty() && s!=mBox->text(index)) mBox->changeItem(s,index);
 #else
@@ -307,9 +319,9 @@ void iqtWidgetComboBoxSubject::SetItem(const iString &text, int index, bool vis)
 	else
 	{
 #ifdef IQT_3
-		if(vis) mBox->insertItem(iqtAssistant::Convert(text));
+		if(vis) mBox->insertItem(iqtHelper::Convert(text));
 #else
-		if(vis) mBox->addItem(iqtAssistant::Convert(text));
+		if(vis) mBox->addItem(iqtHelper::Convert(text));
 #endif
 	}
 }
@@ -341,18 +353,18 @@ void iqtWidgetComboBoxSubject::Clear()
 //
 //******************************************
 //
-iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, const iString &title) : QRadioBox(iqtAssistant::Convert(owner->GetParent())), ibgWidgetRadioBoxSubject(owner,cols,title)
+iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, const iString &title) : QRadioBox(iqtHelper::Convert(owner->GetParent())), ibgWidgetRadioBoxSubject(owner,cols,title)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 	//
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l = iqtAssistant::NewLayout(this,1);
+	QGridLayout *l = iqtHelper::NewLayout(this,1);
 
 	if(cols < 0)
 	{
-		IERROR_REPORT("Incorrect number of columns.");
+		IERROR_LOW("Incorrect number of columns.");
 		cols = 1;
 	}
 
@@ -362,14 +374,15 @@ iqtWidgetRadioBoxSubject::iqtWidgetRadioBoxSubject(iggWidget *owner, int cols, c
 	l->setMargin(ibgFrameSubject::GetPaddingWidth());
 	mGroup = new QButtonGroup(this);
 	mGroup->setExclusive(true);
+	if(cols > 1) l->setColumnStretch(cols-1,0);
 #endif
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
-	this->setTitle(iqtAssistant::ConvertWithModifiers(this,title));
+	this->setTitle(iqtHelper::ConvertWithModifiers(this,title));
 
 #ifdef IQT_3
-	if(!this->connect(this,SIGNAL(clicked(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(this,SIGNAL(clicked(int)),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnInt1(int)))) IERROR_LOW("Missed connection.");
 #else
-	if(!this->connect(mGroup,SIGNAL(buttonClicked(QAbstractButton*)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnButtonClicked(QAbstractButton*)))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mGroup,SIGNAL(buttonClicked(QAbstractButton * )),iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper),SLOT(OnButtonClicked(QAbstractButton * )))) IERROR_LOW("Missed connection.");
 #endif
 }
 
@@ -405,7 +418,7 @@ void iqtWidgetRadioBoxSubject::SetValue(int v)
 	}
 	else
 	{
-		IERROR_REPORT("Invalid button index.");
+		IERROR_LOW("Invalid button index.");
 	}
 #endif
 }
@@ -414,13 +427,29 @@ void iqtWidgetRadioBoxSubject::SetValue(int v)
 void iqtWidgetRadioBoxSubject::InsertItem(const iString &text, int index)
 {
 	QRadioButton *r = new QRadioButton(this);
-	r->setText(iqtAssistant::ConvertWithModifiers(r,text));
 #ifdef IQT_3
 	this->insert(r,index);
 #else
 	mGroup->addButton(r);
 	this->layout()->addWidget(r);
 #endif
+	r->setText(iqtHelper::ConvertWithModifiers(r,text));
+	this->layout()->invalidate(); // Qt bug!!! 
+}
+
+
+void iqtWidgetRadioBoxSubject::InsertItem(const iImage &icon, const iString &text, int index)
+{
+	QRadioButton *r = new QRadioButton(this);
+#ifdef IQT_3
+	r->setPixmap(iqtHelper::ConvertToPixmap(icon));
+	this->insert(r,index);
+#else
+	r->setIcon(iqtHelper::ConvertToIcon(icon));
+	mGroup->addButton(r);
+	this->layout()->addWidget(r);
+#endif
+	r->setText(iqtHelper::ConvertWithModifiers(r,text));
 	this->layout()->invalidate(); // Qt bug!!! 
 }
 
@@ -451,7 +480,7 @@ void iqtWidgetRadioBoxSubject::SetItem(const iString &text, int index, bool vis)
 #endif
 		this->layout()->invalidate(); // Qt bug!!! 
 	}
-	QString s = iqtAssistant::ConvertWithModifiers(b,text);
+	QString s = iqtHelper::ConvertWithModifiers(b,text);
 	if(!s.isEmpty() && s!=b->text()) b->setText(s);
 	if(b->isEnabled() != vis) b->setEnabled(vis);
 }
