@@ -36,7 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwindowhelper.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
@@ -93,7 +93,7 @@ class iqtSyntaxHighlighter : public QTextPreProcessor
 
 public:
 
-	iqtSyntaxHighlighter() : QTextPreProcessor(), mLastFormat(0), mLastFormatId(-1), mKeywords(0)
+	iqtSyntaxHighlighter() : QTextPreProcessor(), mLastFormat(0), mLastFormatId(-1)
 	{
 		mActive = false;
 
@@ -202,7 +202,7 @@ public:
 		}
 	}
 
-	QTextFormat *iqtSyntaxHighlighter::format(int id)
+	QTextFormat* format(int id)
 	{
 		if(mLastFormatId==id && mLastFormat) return mLastFormat;
 
@@ -212,7 +212,7 @@ public:
 		return mLastFormat;
 	}
 
-	void iqtSyntaxHighlighter::Activate(bool s)
+	void Activate(bool s)
 	{
 		mActive = s;
 	}
@@ -252,7 +252,7 @@ public:
 
 private:
 
-	void iqtSyntaxHighlighter::AddFormat(int id, QTextFormat *f)
+	void AddFormat(int id, QTextFormat *f)
 	{
 		mFormats.insert(id,f);
 	}
@@ -279,7 +279,7 @@ private:
 //
 // Constructs an editor and connects a syntax highlighter
 //
-iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode) : QTextEdit(iqtAssistant::Convert(owner->GetParent())), ibgWidgetTextEditorSubject(owner,mode), mMode(mode)
+iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode) : QTextEdit(iqtHelper::Convert(owner->GetParent())), ibgWidgetTextEditorSubject(owner,mode), mMode(mode)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -292,7 +292,7 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	QFont f(this->font());
 	f.setFamily("courier");
 	f.setFixedPitch(true);
-	iqtAssistant::SetFont(this,f);
+	iqtHelper::SetFont(this,f);
 	if(mode & _TextEditorWrapping)
 	{
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
@@ -325,10 +325,10 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	mSyntaxHighlighter = 0;
 #endif
 
-	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_REPORT("Missed connection.");
-	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_REPORT("Missed connection.");
-	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_REPORT("Missed connection.");
-	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_REPORT("Missed connection.");
+	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_LOW("Missed connection.");
 }
 
 
@@ -392,9 +392,9 @@ void iqtWidgetTextEditorSubject::SetText(const iString &text)
 {
 	this->blockSignals(true);
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
-	this->setText(iqtAssistant::Convert(text));
+	this->setText(iqtHelper::Convert(text));
 #else
-	if(this->SupportsHTML()) this->setHtml(iqtAssistant::Convert(text)); else this->setPlainText(iqtAssistant::Convert(text));
+	if(this->SupportsHTML()) this->setHtml(iqtHelper::Convert(text)); else this->setPlainText(iqtHelper::Convert(text));
 #endif
 	this->blockSignals(false);
 }
@@ -403,9 +403,9 @@ void iqtWidgetTextEditorSubject::SetText(const iString &text)
 iString iqtWidgetTextEditorSubject::GetText() const
 {
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
-	return iqtAssistant::Convert(this->text());
+	return iqtHelper::Convert(this->text());
 #else
-	if(this->SupportsHTML()) return iqtAssistant::Convert(this->toHtml()); else return iqtAssistant::Convert(this->toPlainText());
+	if(this->SupportsHTML()) return iqtHelper::Convert(this->toHtml()); else return iqtHelper::Convert(this->toPlainText());
 #endif
 }
 
@@ -416,7 +416,8 @@ void iqtWidgetTextEditorSubject::AppendText(const iString &text, bool scroll)
 	//
 	//  A work-around for a bug in some versions - needed on idunn, for example
 	//
-	if(this->GetText().IsEmpty()) this->SetText(text); else this->append(iqtAssistant::Convert(text));
+	// if(this->GetText().IsEmpty()) this->SetText(text); else
+	this->append(iqtHelper::Convert(text));
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
 	if(scroll) this->scrollToBottom();
 #endif
@@ -459,7 +460,7 @@ iString iqtWidgetTextEditorSubject::GetLine(int n) const
 {
 	static iString none;
 
-	if(n>=0 && n<this->paragraphs()) return iqtAssistant::Convert(this->text(n)); else return none;
+	if(n>=0 && n<this->paragraphs()) return iqtHelper::Convert(this->text(n)); else return none;
 }
 
 
@@ -485,7 +486,7 @@ void iqtWidgetTextEditorSubject::SetTextColor(const iColor &color)
 	if(!this->SupportsHTML())
 	{
 		this->blockSignals(true);
-		this->setColor(iqtAssistant::Convert(color));
+		this->setColor(iqtHelper::Convert(color));
 		this->blockSignals(false);
 	}
 }
@@ -505,7 +506,7 @@ void iqtWidgetTextEditorSubject::SetBoldText(bool s)
 void iqtWidgetTextEditorSubject::SetLineColor(int line, const iColor &color)
 {
 	this->blockSignals(true);
-	this->setParagraphBackgroundColor(line,iqtAssistant::Convert(color));
+	this->setParagraphBackgroundColor(line,iqtHelper::Convert(color));
 	this->blockSignals(false);
 }
 
@@ -520,7 +521,7 @@ void iqtWidgetTextEditorSubject::UnSetLineColor(int line)
 
 iColor iqtWidgetTextEditorSubject::GetLineColor(int line) const
 {
-	return iqtAssistant::Convert(this->paragraphBackgroundColor(line));
+	return iqtHelper::Convert(this->paragraphBackgroundColor(line));
 }
 
 
@@ -642,7 +643,7 @@ void iqtWidgetTextEditorSubject::UseEditingFunction(int type)
 //
 bool iqtWidgetTextEditorSubject::Find(const iString &text, bool cs, bool wo, bool forward, int &para, int &index)
 {
-	return this->find(iqtAssistant::Convert(text),cs,wo,forward,&para,&index);
+	return this->find(iqtHelper::Convert(text),cs,wo,forward,&para,&index);
 }
 
 
@@ -660,7 +661,7 @@ void iqtWidgetTextEditorSubject::HighlightSyntax(bool s)
 void iqtWidgetTextEditorSubject::AddKeyword(const iString &word, int category)
 {
 #ifndef I_NO_SYNTAX_HIGHLIGHTING
-	mSyntaxHighlighter->AddKeyword(iqtAssistant::Convert(word),category);
+	mSyntaxHighlighter->AddKeyword(iqtHelper::Convert(word),category);
 #endif
 }
 
@@ -668,7 +669,7 @@ void iqtWidgetTextEditorSubject::AddKeyword(const iString &word, int category)
 void iqtWidgetTextEditorSubject::AddCategory(const iColor &color)
 {
 #ifndef I_NO_SYNTAX_HIGHLIGHTING
-	mSyntaxHighlighter->AddCategory(iqtAssistant::Convert(color));
+	mSyntaxHighlighter->AddCategory(iqtHelper::Convert(color));
 #endif
 }
 
@@ -676,7 +677,7 @@ void iqtWidgetTextEditorSubject::AddCategory(const iColor &color)
 void iqtWidgetTextEditorSubject::HighlightComments(const iString &comment, const iColor &color)
 {
 #ifndef I_NO_SYNTAX_HIGHLIGHTING
-	mSyntaxHighlighter->SetHighlightComments(iqtAssistant::Convert(comment),iqtAssistant::Convert(color));
+	mSyntaxHighlighter->SetHighlightComments(iqtHelper::Convert(comment),iqtHelper::Convert(color));
 #endif
 }
 
@@ -684,12 +685,12 @@ void iqtWidgetTextEditorSubject::HighlightComments(const iString &comment, const
 void iqtWidgetTextEditorSubject::HighlightStrings(const iColor &color)
 {
 #ifndef I_NO_SYNTAX_HIGHLIGHTING
-	mSyntaxHighlighter->SetHighlightStrings(iqtAssistant::Convert(color));
+	mSyntaxHighlighter->SetHighlightStrings(iqtHelper::Convert(color));
 #endif
 }
 
 
-void iqtWidgetTextEditorSubject::enterEvent(QEvent *)
+void iqtWidgetTextEditorSubject::enterEvent(QEvent * )
 {
 	//
 	//  So that keyboard events are delivered without clicking first
