@@ -39,7 +39,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidget.h"
 #include "iggwidgetrendermodebutton.h"
 
-#include "iqtassistant.h"
+#include "iqthelper.h"
 #include "iqtwidgetbuttonsubject.h"
 #include "iqtwidgethelper.h"
 
@@ -78,18 +78,18 @@ using namespace iqtWidgetTrackBall_Private;
 //
 // Constructs a iTrackball.
 //
-iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb) : QWidget(iqtAssistant::Convert(owner->GetParent())
+iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb) : QWidget(iqtHelper::Convert(owner->GetParent())
 #ifdef IQT_3
 																																	,0,Qt::WRepaintNoErase
 #endif
-																																	), ibgWidgetTrackBallSubject(owner,followCamera,rmb), mTimerIds(0)
+																																	), ibgWidgetTrackBallSubject(owner,followCamera,rmb)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 	//
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l = iqtAssistant::NewLayout(this,1);
+	QGridLayout *l = iqtHelper::NewLayout(this,1);
 
 	mPixmap = new QPixmap(this->size());
 	mPixmapMask = new QBitmap(this->size());
@@ -104,8 +104,8 @@ iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool foll
 #ifdef IQT_3
 		l->expand(2,2);
 #endif
-		iqtWidgetButtonSubject *rmbs = iPointerCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(rmb->GetSubject());
-		iqtAssistant::SetParent(rmbs,this);
+		iqtWidgetButtonSubject *rmbs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,rmb->GetSubject());
+		iqtHelper::SetParent(rmbs,this);
 		l->addWidget(rmbs,0,1);
 #ifdef IQT_3
 		l->setColStretch(0,10);
@@ -159,8 +159,11 @@ void iqtWidgetTrackBallSubject::mousePressEvent(QMouseEvent *e)
 			mResizable = !mResizable;
 			this->layout()->invalidate();
 			this->update();
+#ifdef IQT_3
+			this->erase();
+#endif
 		}
-		iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnVoid1();
+		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid1();
 	}
 
 	if(e!=0 && e->button()==Qt::RightButton)
@@ -176,8 +179,8 @@ void iqtWidgetTrackBallSubject::mouseReleaseEvent(QMouseEvent *e)
 {
 	if(e!=0 && (e->button()==Qt::LeftButton || e->button()==Qt::RightButton))
 	{
-		iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnBool1(true);
-		iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnVoid2();
+		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(true);
+		iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnVoid2();
 		if(e->button() == Qt::RightButton)
 		{
 			while(mTimerIds.Size() > 0) this->killTimer(mTimerIds.RemoveLast());
@@ -191,7 +194,7 @@ void iqtWidgetTrackBallSubject::mouseMoveEvent(QMouseEvent *e)
 	if(e == 0) return;
 		
 	this->UpdateTransform(e->x(),e->y());
-	iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnBool1(false);
+	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(false);
 }
 
 
@@ -208,14 +211,14 @@ void iqtWidgetTrackBallSubject::timerEvent(QTimerEvent *e)
 	int y = mOldY + (y0-mOldY)/3;
 
 	this->UpdateTransform(x,y);
-	iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper)->OnBool1(false);
+	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(false);
 
 	mOldX = x0;
 	mOldY = y0;
 }
 
 
-void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent *)
+void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent * )
 {
 	if(mInUpdate) return;
 
@@ -314,7 +317,7 @@ void iqtWidgetTrackBallSubject::paintEvent(QPaintEvent *)
 					//
 					//  Unmodified color
 					//
-					c = iqtAssistant::Convert(this->ColorAtLonLat(lon,lat)); 
+					c = iqtHelper::Convert(this->ColorAtLonLat(lon,lat)); 
 				}
 				else
 				{
