@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 #include "iqt.h"
-#include "iqtassistant.h"
+#include "iqthelper.h"
 
 #ifdef IQT_3
 #include <qapplication.h>
@@ -57,26 +57,33 @@ iqtWindowHelper::iqtWindowHelper(QWidget *widget, const iImage *icon, const iStr
 	mWidget = widget; IERROR_ASSERT(widget);
 
 #ifndef IQT_40
-	iqtAssistant::SetBackground(mWidget,1); // messes things on Unix under Qt 4.0
+	iqtHelper::SetBackground(mWidget,1); // messes things on Unix under Qt 4.0
 #endif
 
 	QFont f(mWidget->font());
-	iqtAssistant::SetFont(mWidget,f);
+	iqtHelper::SetFont(mWidget,f);
+
+	this->RestoreIcon();
 
-	if(icon != 0)
-	{
-#ifdef IQT_3
-		mWidget->setIcon(iqtAssistant::ConvertToPixmap(*icon));
-#else
-		mWidget->setWindowIcon(iqtAssistant::ConvertToIcon(*icon));
-#endif
-	}
 	if(!title.IsEmpty())
 	{
 #ifdef IQT_3
-		mWidget->setCaption(iqtAssistant::Convert(title));
+		mWidget->setCaption(iqtHelper::Convert(title));
 #else
-		mWidget->setWindowTitle(iqtAssistant::Convert(title));
+		mWidget->setWindowTitle(iqtHelper::Convert(title));
+#endif
+	}
+}
+
+
+void iqtWindowHelper::RestoreIcon()
+{
+	if(mIcon != 0)
+	{
+#ifdef IQT_3
+		mWidget->setIcon(iqtHelper::ConvertToPixmap(*mIcon));
+#else
+		mWidget->setWindowIcon(iqtHelper::ConvertToIcon(*mIcon));
 #endif
 	}
 }
